@@ -54,7 +54,7 @@ static void cla_updatearc(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void cla_domovearcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void cla_makeoldrot(NODEINST*, XARRAY);
 static void cla_makeoldtrans(NODEINST*, XARRAY);
-static void cla_computefacet(NODEPROTO*, BOOLEAN);
+static void cla_computecell(NODEPROTO*, BOOLEAN);
 static BOOLEAN cla_lookdown(NODEPROTO*);
 
 #define CLA_DEBUG 1			/* comment out for normal life */
@@ -159,25 +159,25 @@ INTBIG cla_layconrequest(CHAR *command, INTBIG arg1)
 }
 
 /*
- * routine to do hierarchical update on any facets that changed
+ * routine to do hierarchical update on any cells that changed
  */
 void cla_layconsolve(NODEPROTO *np)
 {
-	REGISTER CHANGEFACET *cc;
+	REGISTER CHANGECELL *cc;
 	REGISTER CHANGEBATCH *curbatch;
 	REGISTER CHANGE *c;
 
-	/* if only one facet is requested, solve that */
+	/* if only one cell is requested, solve that */
 	curbatch = db_getcurrentbatch();
 	if (np != NONODEPROTO)
 	{
-		cla_computefacet(np, FALSE);
+		cla_computecell(np, FALSE);
 	} else
 	{
-		/* solve all facets that changed */
+		/* solve all cells that changed */
 		if (curbatch != NOCHANGEBATCH)
-			for(cc = curbatch->firstchangefacet; cc != NOCHANGEFACET; cc = cc->nextchangefacet)
-				cla_computefacet(cc->changefacet, cc->forcedlook);
+			for(cc = curbatch->firstchangecell; cc != NOCHANGECELL; cc = cc->nextchangecell)
+				cla_computecell(cc->changecell, cc->forcedlook);
 	}
 
 	if (curbatch == NOCHANGEBATCH) return;
@@ -208,7 +208,7 @@ void cla_layconsolve(NODEPROTO *np)
 }
 
 /*
- * If an export is created, touch all instances of the facet
+ * If an export is created, touch all instances of the cell
  */
 void cla_layconnewobject(INTBIG addr, INTBIG type)
 {
@@ -221,17 +221,17 @@ void cla_layconnewobject(INTBIG addr, INTBIG type)
 		pp = (PORTPROTO *)addr;
 		np = pp->parent;
 		for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
-		{
 			(void)db_change((INTBIG)ni, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
+		for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
 			(void)db_change((INTBIG)ni, NODEINSTMOD, ni->lowx, ni->lowy,
 				ni->highx, ni->highy, ni->rotation, ni->transpose);
+		for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
 			(void)db_change((INTBIG)ni, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
-		}
 	}
 }
 
 /*
- * If an export is deleted, touch all instances of the facet
+ * If an export is deleted, touch all instances of the cell
  */
 void cla_layconkillobject(INTBIG addr, INTBIG type)
 {
@@ -254,7 +254,7 @@ void cla_layconkillobject(INTBIG addr, INTBIG type)
 }
 
 /*
- * If an export is renamed, touch all instances of the facet
+ * If an export is renamed, touch all instances of the cell
  */
 void cla_layconnewvariable(INTBIG addr, INTBIG type, INTBIG skey, INTBIG stype)
 {
@@ -474,9 +474,9 @@ void cla_layconmodifydescript(INTBIG addr, INTBIG type, INTBIG key, UINTBIG *old
  * routine to modify nodeinst "ni" by "deltalx" in low X, "deltaly" in low Y,
  * "deltahx" in high X, "deltahy" in high Y, and "dangle" tenth-degrees.  If
  * "announce" is true, report "start" and "end" changes on the node.
- * If the nodeinst is a portproto of the current facet and has any arcs
+ * If the nodeinst is a portproto of the current cell and has any arcs
  * connected to it, the routine returns nonzero to indicate that the outer
- * facet has ports that moved (the nodeinst has exports).
+ * cell has ports that moved (the nodeinst has exports).
  */
 BOOLEAN cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx,
 	INTBIG deltahy, INTBIG dangle, INTBIG dtrans, BOOLEAN announce)
@@ -527,7 +527,7 @@ BOOLEAN cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG
 
 	ni->changed = cla_changeclock + change;
 
-	/* see if this nodeinst is a port of the current facet */
+	/* see if this nodeinst is a port of the current cell */
 	if (ni->firstportexpinst == NOPORTEXPINST) return(FALSE);
 	return(TRUE);
 }
@@ -535,26 +535,26 @@ BOOLEAN cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG
 /*
  * routine to modify all of the arcs connected to nodeinst "ni" (which has
  * been rotated by "dangle" tenth-degrees).  If the routine returns nonzero,
- * some ports on the current facet have moved and the facet must be
+ * some ports on the current cell have moved and the cell must be
  * re-examined for portproto locations.
  */
 BOOLEAN cla_modnodearcs(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 {
-	REGISTER BOOLEAN examinefacet;
+	REGISTER BOOLEAN examinecell;
 
-	/* assume facet needs no further looks */
-	examinefacet = FALSE;
+	/* assume cell needs no further looks */
+	examinecell = FALSE;
 
 	/* next look at arcs that run within this nodeinst */
 	cla_modwithin(ni, dangle, dtrans);
 
 	/* next look at the rest of the rigid arcs on this nodeinst */
-	if (cla_modrigid(ni, dangle, dtrans)) examinefacet = TRUE;
+	if (cla_modrigid(ni, dangle, dtrans)) examinecell = TRUE;
 
 	/* finally, look at rest of the flexible arcs on this nodeinst */
-	if (cla_modflex(ni, dangle, dtrans)) examinefacet = TRUE;
+	if (cla_modflex(ni, dangle, dtrans)) examinecell = TRUE;
 
-	return(examinefacet);
+	return(examinecell);
 }
 
 /*
@@ -633,8 +633,8 @@ void cla_modwithin(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 /*
  * routine to modify the rigid arcs that run from nodeinst "ni".  The nodeinst
  * has changed "dangle" tenth-degrees.  If any nodes that are ports in the
- * current facet change position, the routine returns nonzero to indicate
- * that instances of the current facet must be examined for arcinst motion.
+ * current cell change position, the routine returns nonzero to indicate
+ * that instances of the current cell must be examined for arcinst motion.
  */
 BOOLEAN cla_modrigid(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 {
@@ -646,7 +646,7 @@ BOOLEAN cla_modrigid(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 	XARRAY trans;
 	REGISTER INTBIG othx, othy, ox, oy, i, total, thisend, thatend;
 	REGISTER INTBIG nextangle;
-	REGISTER BOOLEAN examinefacet, locked;
+	REGISTER BOOLEAN examinecell, locked;
 
 	/* build a list of the rigid arcs on this nodeinst */
 	total = 0;
@@ -681,7 +681,7 @@ BOOLEAN cla_modrigid(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 	makeangle(nextangle, dtrans, trans);
 
 	/* look for rigid arcs on this nodeinst */
-	examinefacet = FALSE;
+	examinecell = FALSE;
 	for(i=0; i<total; i++)
 	{
 		ai = arclist[i];
@@ -769,7 +769,7 @@ BOOLEAN cla_modrigid(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 			{
 				ai->userbits |= FIXEDMOD;
 				if (cla_modifynodeinst(ono, dx, dy, dx, dy, nextangle, dtrans, TRUE))
-					examinefacet = TRUE;
+					examinecell = TRUE;
 			}
 		}
 
@@ -798,16 +798,16 @@ BOOLEAN cla_modrigid(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 		nextangle = dangle;
 		if (dtrans != 0 && ((CHANGE *)ono->changeaddr)->p6 != ((CHANGE *)ni->changeaddr)->p6)
 			nextangle = (3600 - nextangle) % 3600;
-		if (cla_modnodearcs(ono, nextangle, dtrans)) examinefacet = TRUE;
+		if (cla_modnodearcs(ono, nextangle, dtrans)) examinecell = TRUE;
 	}
 	efree((CHAR *)arclist);
-	return(examinefacet);
+	return(examinecell);
 }
 
 /*
  * routine to modify the flexible arcs connected to nodeinst "ni".  If any
  * nodes that are ports move, the routine returns nonzero to indicate that
- * instances of the current facet must be examined for arcinst motion
+ * instances of the current cell must be examined for arcinst motion
  */
 BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 {
@@ -816,7 +816,7 @@ BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 	REGISTER NODEINST *ono;
 	REGISTER INTBIG i, total, ox, oy, odx, ody, thisend, thatend, mangle;
 	REGISTER INTBIG nextangle;
-	REGISTER BOOLEAN examinefacet;
+	REGISTER BOOLEAN examinecell;
 	XARRAY trans;
 	INTBIG ax[2], ay[2], dx, dy, lx, hx, ly, hy;
 	static POLYGON *poly = NOPOLYGON;
@@ -854,7 +854,7 @@ BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 	makeangle(nextangle, dtrans, trans);
 
 	/* look at all of the flexible arcs on this nodeinst */
-	examinefacet = FALSE;
+	examinecell = FALSE;
 	for(i=0; i<total; i++)
 	{
 		ai = arclist[i];
@@ -984,11 +984,11 @@ BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 					if (dx != odx)
 					{
 						if (cla_modifynodeinst(ono, dx-odx, 0, dx-odx, 0, 0, 0, TRUE))
-							examinefacet = TRUE;
+							examinecell = TRUE;
 					}
 					cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 1);
 					if (dx != odx)
-						if (cla_modnodearcs(ono, 0, 0)) examinefacet = TRUE;
+						if (cla_modnodearcs(ono, 0, 0)) examinecell = TRUE;
 					continue;
 				}
 			}
@@ -1016,10 +1016,10 @@ BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 				if (dy != ody)
 				{
 					if (cla_modifynodeinst(ono, 0, dy-ody, 0, dy-ody, 0, 0, TRUE))
-						examinefacet = TRUE;
+						examinecell = TRUE;
 				}
 				cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 1);
-				if (dy != ody) if (cla_modnodearcs(ono, 0, 0)) examinefacet = TRUE;
+				if (dy != ody) if (cla_modnodearcs(ono, 0, 0)) examinecell = TRUE;
 				continue;
 			}
 
@@ -1039,8 +1039,8 @@ BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 			if (dx != 0 || dy != 0)
 			{
 				if (cla_modifynodeinst(ono, dx, dy, dx, dy, 0, 0, TRUE))
-					examinefacet = TRUE;
-				if (cla_modnodearcs(ono, 0, 0)) examinefacet = TRUE;
+					examinecell = TRUE;
+				if (cla_modnodearcs(ono, 0, 0)) examinecell = TRUE;
 			}
 			continue;
 		}
@@ -1054,7 +1054,7 @@ BOOLEAN cla_modflex(NODEINST *ni, INTBIG dangle, INTBIG dtrans)
 		cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 1);
 	}
 	efree((CHAR *)arclist);
-	return(examinefacet);
+	return(examinecell);
 }
 
 /*
@@ -1339,7 +1339,7 @@ void cla_domovearcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
  *
  * there are only two types of nodeinst changes: internal and external.
  * The internal changes are scaling and port motion changes that
- * are usually caused by other changes within the facet.  The external
+ * are usually caused by other changes within the cell.  The external
  * changes are rotation and transposition.  These two changes never
  * occur at the same time.  There is also translation change that
  * can occur at any time and is of no importance here.  What is
@@ -1511,14 +1511,14 @@ void cla_makeoldtrans(NODEINST *ni, XARRAY trans)
 }
 
 /*
- * routine to re-compute the bounds of the facet "facet" (because an object
+ * routine to re-compute the bounds of the cell "cell" (because an object
  * has been added or removed from it) and store these bounds in the nominal
- * size and the size of each instantiation of the facet.  It is also necessary
- * to re-position each instantiation of the facet in its proper position list.
- * If "forcedlook" is true, the facet is re-examined regardless of
+ * size and the size of each instantiation of the cell.  It is also necessary
+ * to re-position each instantiation of the cell in its proper position list.
+ * If "forcedlook" is true, the cell is re-examined regardless of
  * whether its size changed.
  */
-void cla_computefacet(NODEPROTO *facet, BOOLEAN forcedlook)
+void cla_computecell(NODEPROTO *cell, BOOLEAN forcedlook)
 {
 	REGISTER NODEINST *ni, *lni;
 	REGISTER NODEPROTO *np, *oneparent;
@@ -1531,23 +1531,23 @@ void cla_computefacet(NODEPROTO *facet, BOOLEAN forcedlook)
 
 #ifdef	CLA_DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg(M_("In computefacet on facet %s (fl=%ld)"),
-			facet->cell->cellname, forcedlook);
+		ttyputmsg(M_("In computecell on cell %s (fl=%ld)"),
+			cell->protoname, forcedlook);
 #endif
-	/* get current boundary of facet */
-	db_boundfacet(facet, &nlx,&nhx, &nly,&nhy);
+	/* get current boundary of cell */
+	db_boundcell(cell, &nlx,&nhx, &nly,&nhy);
 
 	/* quit if it has not changed */
-	if (facet->lowx == nlx && facet->highx == nhx && facet->lowy == nly &&
-		facet->highy == nhy && !forcedlook) return;
+	if (cell->lowx == nlx && cell->highx == nhx && cell->lowy == nly &&
+		cell->highy == nhy && !forcedlook) return;
 
 	/* advance the change clock */
 	cla_changeclock += 4;
 
-	/* get former size of facet from change information */
-	flx = facet->lowx;   fhx = facet->highx;
-	fly = facet->lowy;   fhy = facet->highy;
-	c = (CHANGE *)facet->changeaddr;
+	/* get former size of cell from change information */
+	flx = cell->lowx;   fhx = cell->highx;
+	fly = cell->lowy;   fhy = cell->highy;
+	c = (CHANGE *)cell->changeaddr;
 	if (c != NOCHANGE && c->changetype == NODEPROTOMOD)
 	{
 		/* modification changes carry original size */
@@ -1555,36 +1555,36 @@ void cla_computefacet(NODEPROTO *facet, BOOLEAN forcedlook)
 		fly = c->p3;   fhy = c->p4;
 	}
 
-	/* update the facet size */
-	facet->lowx = nlx;   facet->highx = nhx;
-	facet->lowy = nly;   facet->highy = nhy;
-	facet->changeaddr = (CHAR *)db_change((INTBIG)facet, NODEPROTOMOD, flx, fhx, fly, fhy, 0, 0);
+	/* update the cell size */
+	cell->lowx = nlx;   cell->highx = nhx;
+	cell->lowy = nly;   cell->highy = nhy;
+	cell->changeaddr = (CHAR *)db_change((INTBIG)cell, NODEPROTOMOD, flx, fhx, fly, fhy, 0, 0);
 
-	/* see if all instances of this facet are in the same location */
+	/* see if all instances of this cell are in the same location */
 	mixed = FALSE;
 	oneparent = NONODEPROTO;
 	lni = NONODEINST;
-	for(ni = facet->firstinst; ni != NONODEINST; ni = ni->nextinst)
+	for(ni = cell->firstinst; ni != NONODEINST; ni = ni->nextinst)
 	{
 		oneparent = ni->parent;
 		if (lni != NONODEINST) if (ni->parent != lni->parent) mixed = TRUE;
 		lni = ni;
 	}
 
-	/* if there are no constrained instances of the facet, no change */
+	/* if there are no constrained instances of the cell, no change */
 	if (oneparent == NONODEPROTO) return;
 
-	/* if all parent facets the same, make changes to the instances */
+	/* if all parent cells the same, make changes to the instances */
 	if (!mixed && !forcedlook)
 	{
 #ifdef	CLA_DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg(M_("   Recomputing uniform parents of facet %s"),
-				describenodeproto(facet));
+			ttyputmsg(M_("   Recomputing uniform parents of cell %s"),
+				describenodeproto(cell));
 #endif
-		dlx = facet->lowx - flx;   dhx = facet->highx - fhx;
-		dly = facet->lowy - fly;   dhy = facet->highy - fhy;
-		for(ni = facet->firstinst; ni != NONODEINST; ni = ni->nextinst)
+		dlx = cell->lowx - flx;   dhx = cell->highx - fhx;
+		dly = cell->lowy - fly;   dhy = cell->highy - fhy;
+		for(ni = cell->firstinst; ni != NONODEINST; ni = ni->nextinst)
 		{
 			makeangle(ni->rotation, ni->transpose, trans);
 			xform(dhx+dlx, dhy+dly, &offx, &offy, trans);
@@ -1592,15 +1592,15 @@ void cla_computefacet(NODEPROTO *facet, BOOLEAN forcedlook)
 			nly = (dly-dhy+offy)/2;  nhy = offy - nly;
 			if (cla_modifynodeinst(ni, nlx, nly, nhx, nhy, 0, 0, TRUE)) forcedlook = TRUE;
 		}
-		for(ni = facet->firstinst; ni != NONODEINST; ni = ni->nextinst)
+		for(ni = cell->firstinst; ni != NONODEINST; ni = ni->nextinst)
 			if (cla_modnodearcs(ni, 0, 0)) forcedlook = TRUE;
-		cla_computefacet(oneparent, forcedlook);
+		cla_computecell(oneparent, forcedlook);
 		return;
 	}
 
 	/*
 	 * if instances are scattered or port motion has occured, examine
-	 * entire database in proper recursive order and adjust facet sizes
+	 * entire database in proper recursive order and adjust cell sizes
 	 */
 #ifdef	CLA_DEBUG
 	if (cla_conlaydebug)
@@ -1608,15 +1608,15 @@ void cla_computefacet(NODEPROTO *facet, BOOLEAN forcedlook)
 #endif
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			np->userbits &= ~(FACETMOD|FACETNOMOD);
-	facet->userbits |= FACETMOD;
+			np->userbits &= ~(CELLMOD|CELLNOMOD);
+	cell->userbits |= CELLMOD;
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
-		/* only want facets with no instances as roots of trees */
+		/* only want cells with no instances as roots of trees */
 		if (np->firstinst != NONODEINST) continue;
 
-		/* now look recursively at the nodes in this facet */
+		/* now look recursively at the nodes in this cell */
 		(void)cla_lookdown(np);
 	}
 }
@@ -1630,7 +1630,7 @@ BOOLEAN cla_lookdown(NODEPROTO *start)
 	INTBIG nlx, nhx, nly, nhy, offx, offy;
 	XARRAY trans;
 
-	/* first look recursively to the bottom to see if this facet changed */
+	/* first look recursively to the bottom to see if this cell changed */
 	for(ni = start->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		if (ni->proto->primindex == 0) ni->userbits |= MARKN; else
 			ni->userbits &= ~MARKN;
@@ -1646,24 +1646,24 @@ BOOLEAN cla_lookdown(NODEPROTO *start)
 			np = ni->proto;
 
 			/* ignore recursive references (showing icon in contents) */
-/*			if (np->cell == start->cell) continue; */
+			if (isiconof(np, start)) continue;
 
-			/* if this nodeinst is to change, mark the parent facet also */
-			if ((np->userbits & FACETMOD) != 0) start->userbits |= FACETMOD;
+			/* if this nodeinst is to change, mark the parent cell also */
+			if ((np->userbits & CELLMOD) != 0) start->userbits |= CELLMOD;
 
-			/* don't look inside if the facet is certified */
-			if ((np->userbits & (FACETNOMOD|FACETMOD)) != 0) continue;
+			/* don't look inside if the cell is certified */
+			if ((np->userbits & (CELLNOMOD|CELLMOD)) != 0) continue;
 
 			/* look inside nodeinst to see if it changed */
-			if (cla_lookdown(np)) start->userbits |= FACETMOD;
+			if (cla_lookdown(np)) start->userbits |= CELLMOD;
 			foundone = TRUE;
 		}
 	}
 
-	/* if this facet did not change, certify so and quit */
-	if ((start->userbits & FACETMOD) == 0)
+	/* if this cell did not change, certify so and quit */
+	if ((start->userbits & CELLMOD) == 0)
 	{
-		start->userbits |= FACETNOMOD;
+		start->userbits |= CELLNOMOD;
 		return(FALSE);
 	}
 
@@ -1673,15 +1673,15 @@ BOOLEAN cla_lookdown(NODEPROTO *start)
 		np = ni->proto;
 		ni->userbits &= ~(MARKN|TOUCHN);
 		if (np->primindex != 0) continue;
-/*		if (np->cell == start->cell) continue; */
-		if ((np->userbits & FACETMOD) == 0) continue;
+		if (isiconof(np, start)) continue;
+		if ((np->userbits & CELLMOD) == 0) continue;
 		ni->userbits |= MARKN | TOUCHN;
 	}
 #ifdef	CLA_DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg(M_("      Complex tree search at facet %s"), describenodeproto(start));
+		ttyputmsg(M_("      Complex tree search at cell %s"), describenodeproto(start));
 #endif
-	/* modify the nodes in this facet that changed */
+	/* modify the nodes in this cell that changed */
 	forcedlook = FALSE;
 	foundone = TRUE;
 	while (foundone)
@@ -1693,7 +1693,7 @@ BOOLEAN cla_lookdown(NODEPROTO *start)
 			ni->userbits &= ~MARKN;
 			np = ni->proto;
 
-			/* determine original size of facet */
+			/* determine original size of cell */
 			if ((CHANGE *)np->changeaddr != NOCHANGE &&
 				((CHANGE *)np->changeaddr)->changetype == NODEPROTOMOD)
 			{
@@ -1723,7 +1723,7 @@ BOOLEAN cla_lookdown(NODEPROTO *start)
 		}
 	}
 
-	/* now change the arcs in the nodes in this facet that changed */
+	/* now change the arcs in the nodes in this cell that changed */
 	foundone = TRUE;
 	while (foundone)
 	{
@@ -1737,18 +1737,18 @@ BOOLEAN cla_lookdown(NODEPROTO *start)
 		}
 	}
 
-	/* now change the size of this facet */
-	db_boundfacet(start, &nlx,&nhx, &nly,&nhy);
+	/* now change the size of this cell */
+	db_boundcell(start, &nlx,&nhx, &nly,&nhy);
 
 	/* quit if it has not changed */
 	if (start->lowx == nlx && start->highx == nhx && start->lowy == nly &&
 		start->highy == nhy && !forcedlook)
 	{
-		start->userbits |= FACETNOMOD;
+		start->userbits |= CELLNOMOD;
 		return(FALSE);
 	}
 
-	/* update the facet size */
+	/* update the cell size */
 	start->changeaddr = (CHAR *)db_change((INTBIG)start, NODEPROTOMOD,
 		start->lowx, start->highx, start->lowy, start->highy, 0, 0);
 	start->lowx = nlx;  start->highx = nhx;
