@@ -33,8 +33,8 @@
 #include "conlin.h"
 
 /* command completion table for this constraint solver */
-static COMCOMP cli_linconsp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, x_(" \t"), M_("facet to solve for linear inequalities"), 0};
+static COMCOMP cli_linconsp = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
+	INPUTOPT, x_(" \t"), M_("cell to solve for linear inequalities"), 0};
 static KEYWORD linconiopt[] =
 {
 	{x_("on"),                   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -67,7 +67,7 @@ COMCOMP cli_linconp = {linconopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
        CONSTRAINT *cli_constraint;	/* the constraint object for this solver */
        BOOLEAN     cli_manhattan;	/* true to assume Manhattan constraints */
        INTBIG      cli_properties_key;	/* variable key for "CONLIN_properties" */
-       NODEPROTO  *cli_curfacet;	/* the current facet being equated to text */
+       NODEPROTO  *cli_curcell;		/* the current cell being equated to text */
        BOOLEAN     cli_ownchanges;	/* true if changes are internally generated */
        INTBIG      cli_textlines;	/* number of declaration/connection lines */
        BOOLEAN     cli_texton;		/* true if text/graphics system is on */
@@ -189,7 +189,7 @@ void cli_linconinit(CONSTRAINT *con)
 		cli_connodefree = NOCONNODE;
 		cli_conlindebug = FALSE;
 		cli_didsolve = FALSE;
-		cli_curfacet = NONODEPROTO;
+		cli_curcell = NONODEPROTO;
 		cli_manhattan = TRUE;
 
 		/* get the primary key for the properties variable */
@@ -242,10 +242,10 @@ void cli_linconsetmode(INTBIG count, CHAR *par[])
 		l = estrlen(pp = par[1]);
 		if (namesamen(pp, x_("name-nodes"), l) == 0 && l >= 1)
 		{
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(M_("Must have a current facet to generate names"));
+				ttyputerr(M_("Must have a current cell to generate names"));
 				return;
 			}
 			cli_nameallnodes(np);
@@ -253,17 +253,17 @@ void cli_linconsetmode(INTBIG count, CHAR *par[])
 		}
 		if (namesamen(pp, x_("go"), l) == 0 && l >= 1)
 		{
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO) ttyputverbose(M_("Enabling text/graphics association")); else
 			{
 				if (cli_texton)
 				{
-					if (np == cli_curfacet)
+					if (np == cli_curcell)
 						ttyputverbose(M_("Reevaluating textual description")); else
-							ttyputverbose(M_("Switching association to facet %s"), describenodeproto(np));
-				} else ttyputverbose(M_("Text window will mirror facet %s"), describenodeproto(np));
+							ttyputverbose(M_("Switching association to cell %s"), describenodeproto(np));
+				} else ttyputverbose(M_("Text window will mirror cell %s"), describenodeproto(np));
 			}
-			cli_maketextfacet(np);
+			cli_maketextcell(np);
 			return;
 		}
 		if (namesamen(pp, x_("highlight-equivalent"), l) == 0 && l >= 1)
@@ -304,10 +304,10 @@ void cli_linconsetmode(INTBIG count, CHAR *par[])
 	{
 		if (count < 2)
 		{
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(M_("No facet specified and no current facet"));
+				ttyputerr(M_("No cell specified and no current cell"));
 				return;
 			}
 		} else
@@ -315,18 +315,18 @@ void cli_linconsetmode(INTBIG count, CHAR *par[])
 			np = getnodeproto(par[1]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(M_("No facet named %s"), par[1]);
+				ttyputerr(M_("No cell named %s"), par[1]);
 				return;
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr(M_("Must solve facets, not primitives"));
+				ttyputerr(M_("Must solve cells, not primitives"));
 				return;
 			}
 		}
 
 		/* do constraint work */
-		cli_solvefacet(np, TRUE, TRUE);
+		cli_solvecell(np, TRUE, TRUE);
 		cli_didsolve = TRUE;
 		return;
 	}
@@ -369,7 +369,7 @@ INTBIG cli_linconrequest(CHAR *command, INTBIG arg1)
 
 void cli_linconsolve(NODEPROTO *np)
 {
-	REGISTER CHANGEFACET *cc;
+	REGISTER CHANGECELL *cc;
 	REGISTER CHANGEBATCH *curbatch;
 
 	if (np != NONODEPROTO)
@@ -382,37 +382,37 @@ void cli_linconsolve(NODEPROTO *np)
 
 	curbatch = db_getcurrentbatch();
 	if (curbatch != NOCHANGEBATCH)
-		for(cc = curbatch->firstchangefacet; cc != NOCHANGEFACET; cc = cc->nextchangefacet)
-			cli_dosolve(cc->changefacet);
+		for(cc = curbatch->firstchangecell; cc != NOCHANGECELL; cc = cc->nextchangecell)
+			cli_dosolve(cc->changecell);
 	cli_didsolve = FALSE;
 }
 
-void cli_dosolve(NODEPROTO *facet)
+void cli_dosolve(NODEPROTO *cell)
 {
 	INTBIG nlx, nhx, nly, nhy;
 	REGISTER NODEINST *ni;
 	REGISTER INTBIG dlx, dhx, dly, dhy;
 
 	if (cli_conlindebug)
-		ttyputmsg(M_("Re-checking linear constraints for facet %s"), describenodeproto(facet));
-	if (!cli_didsolve) cli_solvefacet(facet, FALSE, FALSE);
+		ttyputmsg(M_("Re-checking linear constraints for cell %s"), describenodeproto(cell));
+	if (!cli_didsolve) cli_solvecell(cell, FALSE, FALSE);
 
-	/* get current boundary of facet */
-	db_boundfacet(facet, &nlx,&nhx, &nly,&nhy);
-	dlx = nlx - facet->lowx;  dhx = nhx - facet->highx;
-	dly = nly - facet->lowy;  dhy = nhy - facet->highy;
+	/* get current boundary of cell */
+	db_boundcell(cell, &nlx,&nhx, &nly,&nhy);
+	dlx = nlx - cell->lowx;  dhx = nhx - cell->highx;
+	dly = nly - cell->lowy;  dhy = nhy - cell->highy;
 
 	/* quit if it has not changed */
 	if (dlx == 0 && dhx == 0 && dly == 0 && dhy == 0) return;
 
-	/* update the facet size */
-	facet->changeaddr = (CHAR *)db_change((INTBIG)facet, NODEPROTOMOD,
-		facet->lowx, facet->lowy, facet->highx, facet->highy, 0, 0);
-	facet->lowx = nlx;  facet->highx = nhx;
-	facet->lowy = nly;  facet->highy = nhy;
+	/* update the cell size */
+	cell->changeaddr = (CHAR *)db_change((INTBIG)cell, NODEPROTOMOD,
+		cell->lowx, cell->lowy, cell->highx, cell->highy, 0, 0);
+	cell->lowx = nlx;  cell->highx = nhx;
+	cell->lowy = nly;  cell->highy = nhy;
 
-	/* now update instances of the facet */
-	for(ni = facet->firstinst; ni != NONODEINST; ni = ni->nextinst)
+	/* now update instances of the cell */
+	for(ni = cell->firstinst; ni != NONODEINST; ni = ni->nextinst)
 	{
 		(void)db_change((INTBIG)ni, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
 		cli_linconmodifynodeinst(ni, dlx, dly, dhx, dhy, 0, 0);
@@ -431,7 +431,7 @@ void cli_linconnewobject(INTBIG addr, INTBIG type)
 			ai = (ARCINST *)addr;
 			if (getvalkey((INTBIG)ai, VARCINST, VINTEGER|VISARRAY, cli_properties_key) != NOVARIABLE)
 			{
-				db_setchangefacet(ai->parent);
+				db_setchangecell(ai->parent);
 				db_forcehierarchicalanalysis(ai->parent);
 			}
 			cli_eq_newarc(ai);
@@ -451,7 +451,7 @@ void cli_linconkillobject(INTBIG addr, INTBIG type)
 			ai = (ARCINST *)addr;
 			if (getvalkey((INTBIG)ai, VARCINST, VINTEGER|VISARRAY, cli_properties_key) != NOVARIABLE)
 			{
-				db_setchangefacet(ai->parent);
+				db_setchangecell(ai->parent);
 				db_forcehierarchicalanalysis(ai->parent);
 			}
 			cli_eq_killarc(ai);
@@ -532,7 +532,7 @@ void cli_linconmodifynodeinst(NODEINST *ni, INTBIG dlx, INTBIG dly, INTBIG dhx,
 		/* demand constraint satisfaction if arc with properties moved */
 		if (getvalkey((INTBIG)ai, VARCINST, VINTEGER|VISARRAY, cli_properties_key) != NOVARIABLE)
 		{
-			db_setchangefacet(ai->parent);
+			db_setchangecell(ai->parent);
 			db_forcehierarchicalanalysis(ai->parent);
 		}
 
@@ -627,7 +627,7 @@ BOOLEAN cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG
 		len = getlength(var) / LINCONSIZE;
 		(void)delvalkey((INTBIG)ai, VARCINST, cli_properties_key);
 		cli_eq_modarc(ai);
-		db_setchangefacet(ai->parent);
+		db_setchangecell(ai->parent);
 		db_forcehierarchicalanalysis(ai->parent);
 		return(FALSE);
 	}
@@ -694,7 +694,7 @@ BOOLEAN cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG
 		return(TRUE);
 	}
 
-	db_setchangefacet(ai->parent);
+	db_setchangecell(ai->parent);
 	db_forcehierarchicalanalysis(ai->parent);
 	if (cli_addarcconstraint(ai, variable, oper, value, changetype)) return(TRUE);
 	if (changetype == 0) ttyputverbose(M_("Constraint set")); else
@@ -827,7 +827,7 @@ void cli_linconnewvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG newtype)
 		if (key == cli_properties_key)
 		{
 			/* mark the parent of this arc as changed */
-			db_setchangefacet(((ARCINST *)addr)->parent);
+			db_setchangecell(((ARCINST *)addr)->parent);
 			db_forcehierarchicalanalysis(((ARCINST *)addr)->parent);
 		}
 	}
@@ -843,7 +843,7 @@ void cli_linconkillvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG oldaddr
 		if (key == cli_properties_key)
 		{
 			/* mark the parent of this arc as changed */
-			db_setchangefacet(((ARCINST *)addr)->parent);
+			db_setchangecell(((ARCINST *)addr)->parent);
 			db_forcehierarchicalanalysis(((ARCINST *)addr)->parent);
 		}
 	}
@@ -858,7 +858,7 @@ void cli_linconmodifyvariable(INTBIG addr, INTBIG type, INTBIG key, INTBIG stype
 		if (key == cli_properties_key)
 		{
 			/* mark the parent of this arc as changed */
-			db_setchangefacet(((ARCINST *)addr)->parent);
+			db_setchangecell(((ARCINST *)addr)->parent);
 			db_forcehierarchicalanalysis(((ARCINST *)addr)->parent);
 		}
 	}
@@ -874,12 +874,12 @@ void cli_linconsetvariable(void) {}
 /***************************** CONSTRAINT SOLVING *****************************/
 
 /*
- * routine to solve the linear constraints in facet "np".  If "minimum" is
+ * routine to solve the linear constraints in cell "np".  If "minimum" is
  * true, re-solve for minimum spacing even if the network is satisfied.
  * If "noanchors" is true, do not presume anchoring of the components that
  * just changed
  */
-void cli_solvefacet(NODEPROTO *np, BOOLEAN minimum, BOOLEAN noanchors)
+void cli_solvecell(NODEPROTO *np, BOOLEAN minimum, BOOLEAN noanchors)
 {
 	CONNODE *firstx, *firsty;
 	REGISTER BOOLEAN failure, xnotsolved, ynotsolved;
@@ -944,7 +944,7 @@ void cli_solvefacet(NODEPROTO *np, BOOLEAN minimum, BOOLEAN noanchors)
 }
 
 /*
- * routine to convert the constraints found in facet "np" into a network of
+ * routine to convert the constraints found in cell "np" into a network of
  * internal constraint nodes headed by "first".  If "axis" is false, build
  * the X constraints, otherwise build the Y constraints.  If "noanchors" is
  * true, do not presume presolution of changed nodes.  The routine returns
@@ -962,7 +962,7 @@ BOOLEAN cli_buildconstraints(NODEPROTO *np, CONNODE **first, BOOLEAN axis, BOOLE
 	REGISTER CONNODE *cn;
 
 	/* get the value of lambda */
-	lambda = lambdaoffacet(np);
+	lambda = lambdaofcell(np);
 
 	/* mark all real nodes as un-converted to constraint nodes */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -971,7 +971,7 @@ BOOLEAN cli_buildconstraints(NODEPROTO *np, CONNODE **first, BOOLEAN axis, BOOLE
 	/* initialize the list of constraint nodes */
 	*first = NOCONNODE;
 
-	/* look at all constraints in the facet */
+	/* look at all constraints in the cell */
 	notsolved = FALSE;
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
@@ -1433,8 +1433,8 @@ void cli_applyconstraints(NODEPROTO *np, CONNODE *first, BOOLEAN axis)
 	/* look for the lowest value in the constraints and the circuit */
 	lowestcon = lowestcir = 0;
 
-	/* mark this facet as changed so its size will be adjusted */
-	db_setchangefacet(first->realn->parent);
+	/* mark this cell as changed so its size will be adjusted */
+	db_setchangecell(first->realn->parent);
 
 	/* now adjust the nodes in the circuit */
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -1530,7 +1530,7 @@ void cli_printconstraints(CONNODE *first, CHAR *message, CHAR *axis)
 }
 
 /*
- * routine to name all of the nodes in facet "np"
+ * routine to name all of the nodes in cell "np"
  */
 #define NOABBREV ((ABBREV *)-1)
 
@@ -1548,7 +1548,7 @@ void cli_nameallnodes(NODEPROTO *np)
 	REGISTER BOOLEAN upper;
 	REGISTER VARIABLE *var;
 	REGISTER ABBREV *firstabbrev, *a, *nexta;
-	CHAR line[20];
+	CHAR line[20], *newname;
 	REGISTER void *infstr;
 
 	firstabbrev = NOABBREV;
@@ -1558,12 +1558,12 @@ void cli_nameallnodes(NODEPROTO *np)
 		if (getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key) != NOVARIABLE) continue;
 
 		if (ni->proto->primindex == 0) upper = TRUE; else upper = FALSE;
-		pt = makeabbrev(ni->proto->cell->cellname, upper);
+		pt = makeabbrev(ni->proto->protoname, upper);
 
 		/* if the name is null, assign a name */
 		if (estrlen(pt) == 0)
 		{
-			if (ni->proto->primindex == 0) pt = M_("FACET"); else pt = M_("node");
+			if (ni->proto->primindex == 0) pt = M_("CELL"); else pt = M_("node");
 		}
 
 		/* find an abbreviation module for this */
@@ -1584,7 +1584,9 @@ void cli_nameallnodes(NODEPROTO *np)
 		addstringtoinfstr(infstr, a->name);
 		(void)esnprintf(line, 20, x_("%ld"), a->aindex++);
 		addstringtoinfstr(infstr, line);
-		var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)returninfstr(infstr), VSTRING|VDISPLAY);
+		allocstring(&newname, returninfstr(infstr), el_tempcluster);
+		var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)newname, VSTRING|VDISPLAY);
+		efree(newname);
 		if (var != NOVARIABLE)
 			defaulttextsize(3, var->textdescript);
 	}
