@@ -62,7 +62,7 @@ void cli_highlightequivalent(GEOM *geom)
 	REGISTER COMPONENT *compo;
 
 	par = geomparent(geom);
-	if (cli_curfacet != par) return;
+	if (cli_curcell != par) return;
 
 	/* handle pointing to graphics */
 	if (!geom->entryisnode)
@@ -99,13 +99,13 @@ void cli_highlightequivalent(GEOM *geom)
 	}
 }
 
-/**************************** CONVERT ENTIRE FACET ****************************/
+/**************************** CONVERT ENTIRE CELL ****************************/
 
 /*
- * routine to fill the text window with the description of graphics facet "np".
+ * routine to fill the text window with the description of graphics cell "np".
  * If "np" is NONODEPROTO, turn off the text system.
  */
-void cli_maketextfacet(NODEPROTO *np)
+void cli_maketextcell(NODEPROTO *np)
 {
 	CHAR *name;
 	REGISTER CHAR *pt;
@@ -117,14 +117,14 @@ void cli_maketextfacet(NODEPROTO *np)
 	REGISTER void *infstr;
 
 	/* initialize the textual equivalent window */
-	cli_curfacet = np;
+	cli_curcell = np;
 	if (!cli_texton)
 	{
 		(void)asktool(us_tool, x_("edit-describe"), (INTBIG)&name);
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, name);
-		addstringtoinfstr(infstr, M_(" Editor equivalence for facet "));
-		addstringtoinfstr(infstr, np->cell->cellname);
+		addstringtoinfstr(infstr, M_(" Editor equivalence for cell "));
+		addstringtoinfstr(infstr, np->protoname);
 		(void)allocstring(&name, returninfstr(infstr), el_tempcluster);
 		cli_curwindow = cli_makeeditorwindow(name, &chars, &lines);
 		efree(name);
@@ -140,12 +140,12 @@ void cli_maketextfacet(NODEPROTO *np)
 	for(i=0; i<len; i++)
 		(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)cli_curwindow, i);
 
-	/* load the facet */
+	/* load the cell */
 	trunclen = chars / 4 * 3;
 	cli_textlines = 0;
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, x_("BEGINFACET "));
-	addstringtoinfstr(infstr, np->cell->cellname);
+	addstringtoinfstr(infstr, x_("BEGINCELL "));
+	addstringtoinfstr(infstr, np->protoname);
 	addstringtoinfstr(infstr, x_(";"));
 	(void)asktool(us_tool, x_("edit-addline"), (INTBIG)cli_curwindow, 0, (INTBIG)returninfstr(infstr));
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -206,7 +206,7 @@ void cli_maketextfacet(NODEPROTO *np)
 	/* now convert the constaints */
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		cli_addequivcon(ai);
-	cli_replaceendfacet(x_("ENDFACET;"), cli_curwindow);
+	cli_replaceendcell(x_("ENDCELL;"), cli_curwindow);
 	(void)asktool(us_tool, x_("edit-resumegraphics"), (INTBIG)cli_curwindow);
 }
 
@@ -226,8 +226,8 @@ void cli_eq_newnode(NODEINST *ni)
 	/* ignore changes generated by constraint results */
 	if (cli_ownchanges) return;
 
-	/* ignore changes made to a facet not being equated */
-	if (ni->parent != cli_curfacet) return;
+	/* ignore changes made to a cell not being equated */
+	if (ni->parent != cli_curcell) return;
 
 	/* look for a declaration of this type of node */
 	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
@@ -289,11 +289,11 @@ void cli_eq_killnode(NODEINST *ni)
 	REGISTER COMPONENT *compo, *ocomp;
 	REGISTER void *infstr;
 
-	/* see if node is in graphics facet that has equivalent text */
+	/* see if node is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
 
-	/* ignore changes made to a facet not being equated */
-	if (ni->parent != cli_curfacet) return;
+	/* ignore changes made to a cell not being equated */
+	if (ni->parent != cli_curcell) return;
 
 	/* look for a declaration of this type of node */
 	compname = cli_componentname(ni);
@@ -355,9 +355,9 @@ void cli_eq_killnode(NODEINST *ni)
 /* handle the change of node "ni" */
 void cli_eq_modnode(NODEINST *ni)
 {
-	/* see if node is in graphics facet that has equivalent text */
+	/* see if node is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
-	if (ni->parent == cli_curfacet) cli_changeequivcomp(ni);
+	if (ni->parent == cli_curcell) cli_changeequivcomp(ni);
 }
 
 /* handle the creation of new arc "ai" */
@@ -367,9 +367,9 @@ void cli_eq_newarc(ARCINST *ai)
 	REGISTER NODEINST *ni;
 	REGISTER PORTARCINST *pi;
 
-	/* see if arc is in graphics facet that has equivalent text */
+	/* see if arc is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
-	if (ai->parent != cli_curfacet) return;
+	if (ai->parent != cli_curcell) return;
 
 	cli_addequivcon(ai);
 
@@ -389,9 +389,9 @@ void cli_eq_killarc(ARCINST *ai)
 	REGISTER NODEINST *ni;
 	REGISTER INTBIG i;
 
-	/* see if arc is in graphics facet that has equivalent text */
+	/* see if arc is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
-	if (ai->parent != cli_curfacet) return;
+	if (ai->parent != cli_curcell) return;
 
 	cli_deleteequivcon(ai);
 
@@ -413,11 +413,11 @@ void cli_eq_modarc(ARCINST *ai)
 	REGISTER CHAR *str;
 	REGISTER INTBIG cindex;
 
-	/* see if arc is in graphics facet that has equivalent text */
+	/* see if arc is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
 
-	/* ignore changes made to a facet not being equated */
-	if (ai->parent != cli_curfacet) return;
+	/* ignore changes made to a cell not being equated */
+	if (ai->parent != cli_curcell) return;
 
 	/* get the text node that describes this arc */
 	cindex = cli_findtextconn(ai);
@@ -437,9 +437,9 @@ void cli_eq_modarc(ARCINST *ai)
 /* handle the creation of port "pp" */
 void cli_eq_newport(PORTPROTO *pp)
 {
-	/* see if port is in graphics facet that has equivalent text */
+	/* see if port is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
-	if (pp->parent != cli_curfacet) return;
+	if (pp->parent != cli_curcell) return;
 	cli_addcomponentline(cli_makeportline(pp), cli_curwindow);
 }
 
@@ -450,9 +450,9 @@ void cli_eq_killport(PORTPROTO *pp)
 	REGISTER CHAR *str;
 	REGISTER EXPORT *e;
 
-	/* see if port is in graphics facet that has equivalent text */
+	/* see if port is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
-	if (pp->parent != cli_curfacet) return;
+	if (pp->parent != cli_curcell) return;
 
 	/* find the export line with this port */
 	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
@@ -487,9 +487,9 @@ void cli_eq_modport(PORTPROTO *pp)
 	REGISTER EXPORT *e;
 	REGISTER INTBIG i, total;
 
-	/* see if port is in graphics facet that has equivalent text */
+	/* see if port is in graphics cell that has equivalent text */
 	if (cli_ownchanges) return;
-	if (pp->parent != cli_curfacet) return;
+	if (pp->parent != cli_curcell) return;
 
 	/* find the export line with this port */
 	total = asktool(us_tool, x_("edit-totallines"), (INTBIG)cli_curwindow);
@@ -528,9 +528,9 @@ void cli_eq_newvar(INTBIG addr, INTBIG type, INTBIG key)
 
 	if (type == VNODEINST)
 	{
-		/* node added variable: see if this is in a graphics facet */
+		/* node added variable: see if this is in a graphics cell */
 		ni = (NODEINST *)addr;
-		if (ni->parent != cli_curfacet) return;
+		if (ni->parent != cli_curcell) return;
 
 		/* name changes are handled specially */
 		if (key == el_node_name_key)
@@ -573,9 +573,9 @@ void cli_eq_killvar(INTBIG addr, INTBIG type, INTBIG key)
 	if (cli_ownchanges) return;
 	if (type == VNODEINST)
 	{
-		/* node variable removed: see if this is in a graphics facet */
+		/* node variable removed: see if this is in a graphics cell */
 		ni = (NODEINST *)addr;
-		if (ni->parent != cli_curfacet) return;
+		if (ni->parent != cli_curcell) return;
 
 		if (key == el_node_name_key)
 		{
@@ -1408,6 +1408,6 @@ void cli_addnodeprotoname(void *infstr, NODEPROTO *np)
 			addstringtoinfstr(infstr, np->tech->techname);
 			addtoinfstr(infstr, ':');
 		}
-		addstringtoinfstr(infstr, np->primname);
-	} else addstringtoinfstr(infstr, np->cell->cellname);
+		addstringtoinfstr(infstr, np->protoname);
+	} else addstringtoinfstr(infstr, np->protoname);
 }
