@@ -72,33 +72,33 @@ INTBIG cli_linetype(CHAR *line)
 	if (namesamen(line, x_("declare"), 7) == 0) return(LINEDECL);
 	if (namesamen(line, x_("connect"), 4) == 0) return(LINECONN);
 	if (namesamen(line, x_("export"), 6) == 0) return(LINEEXPORT);
-	if (namesamen(line, x_("beginfacet"), 9) == 0) return(LINEBEGIN);
-	if (namesamen(line, x_("endfacet"), 7) == 0) return(LINEEND);
+	if (namesamen(line, x_("begincell"), 9) == 0) return(LINEBEGIN);
+	if (namesamen(line, x_("endcell"), 7) == 0) return(LINEEND);
 	return(LINEUNKN);
 }
 
 /*
- * routine to parse a "beginfacet" command and return the facet name.  This
- * facet name must be deallocated when done.  If "quiet" is true, do not
+ * routine to parse a "begincell" command and return the cell name.  This
+ * cell name must be deallocated when done.  If "quiet" is true, do not
  * print error messages.  Returns -1 if the line cannot be parsed
  */
-CHAR *cli_parsebeginfacet(CHAR *str, BOOLEAN quiet)
+CHAR *cli_parsebegincell(CHAR *str, BOOLEAN quiet)
 {
 	CHAR *pt;
 	REGISTER CHAR *st;
 
 	pt = str;
 
-	/* get the "beginfacet" keyword */
+	/* get the "begincell" keyword */
 	st = getkeyword(&pt, x_(" \t"));
 	if (st == NOSTRING) return(NOSTRING);
-	if (namesame(st, x_("beginfacet")) != 0)
+	if (namesame(st, x_("begincell")) != 0)
 	{
-		if (!quiet) ttyputerr(M_("Missing 'beginfacet' keyword in '%s'"), str);
+		if (!quiet) ttyputerr(M_("Missing 'begincell' keyword in '%s'"), str);
 		return(NOSTRING);
 	}
 
-	/* get the facet name */
+	/* get the cell name */
 	st = getkeyword(&pt, x_(" \t;"));
 	if (st == NOSTRING) return(NOSTRING);
 
@@ -810,7 +810,7 @@ ATTR *cli_getattr(CHAR *opt, CHAR **pt, CHAR *str, BOOLEAN quiet)
 /***************************** HIGHER-LEVEL *****************************/
 
 /*
- * routine to find the node with the name "name" in the current graphics facet.
+ * routine to find the node with the name "name" in the current graphics cell.
  * Returns that node (NONODEINST if not found).
  */
 NODEINST *cli_findnodename(CHAR *name)
@@ -818,7 +818,7 @@ NODEINST *cli_findnodename(CHAR *name)
 	REGISTER NODEINST *ni, *numni;
 	REGISTER VARIABLE *var;
 
-	for(ni = cli_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cli_curcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 		if (var == NOVARIABLE) continue;
@@ -828,7 +828,7 @@ NODEINST *cli_findnodename(CHAR *name)
 	/* look for the special case of "NODEdddd" */
 	if (namesamen(name, x_("node"), 4) != 0) return(NONODEINST);
 	numni = (NODEINST *)myatoi(&name[4]);
-	for(ni = cli_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cli_curcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		if (ni == numni) break;
 	return(ni);
 }
@@ -858,7 +858,7 @@ ARCINST *cli_findarcname(CHAR *line)
 
 	/* look for this arc */
 	pai = NOARCINST;
-	for(ai = cli_curfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cli_curcell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		aend = bend = -1;
 		if (ai->end[0].nodeinst == nA) aend = 0; else
