@@ -102,9 +102,9 @@ BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 	}
 
 	/* M(=) typed: highlight the equivalent line */
-	if (cli_curfacet == NONODEPROTO)
+	if (cli_curcell == NONODEPROTO)
 	{
-		ttyputmsg(M_("No valid facet to associate"));
+		ttyputmsg(M_("No valid cell to associate"));
 		return(FALSE);
 	}
 	line = (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, -1);
@@ -116,10 +116,10 @@ BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 			ttyputmsg(M_("No graphic equivalent of comment line"));
 			break;
 		case LINEBEGIN:
-			ttyputmsg(M_("No graphic equivalent of BEGINFACET line"));
+			ttyputmsg(M_("No graphic equivalent of BEGINCELL line"));
 			break;
 		case LINEEND:
-			ttyputmsg(M_("No graphic equivalent of ENDFACET line"));
+			ttyputmsg(M_("No graphic equivalent of ENDCELL line"));
 			break;
 		case LINEEXPORT:
 			ttyputmsg(M_("No graphic equivalent of EXPORT line"));
@@ -171,7 +171,7 @@ BOOLEAN cli_charhandler(WINDOWPART *win, INTSML i, INTBIG special)
 void cli_termhandler(WINDOWPART *win)
 {
 	cli_texton = FALSE;
-	cli_curfacet = NONODEPROTO;
+	cli_curcell = NONODEPROTO;
 	if (cli_oldttermhandler!= 0) (*cli_oldttermhandler)(win);
 }
 
@@ -219,8 +219,8 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 	/* handle rewrites of the same type of line */
 	if (otype == ntype)
 	{
-		/* ignore changes if facet is not valid */
-		if (cli_curfacet == NONODEPROTO) return;
+		/* ignore changes if cell is not valid */
+		if (cli_curcell == NONODEPROTO) return;
 
 		switch (otype)
 		{
@@ -234,18 +234,18 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 				cli_changeexport(oldline, newline, changed, win);
 				break;
 			case LINEBEGIN:
-				oldname = cli_parsebeginfacet(oldline, FALSE);
-				newname = cli_parsebeginfacet(newline, FALSE);
+				oldname = cli_parsebegincell(oldline, FALSE);
+				newname = cli_parsebegincell(newline, FALSE);
 				if (oldname != NOSTRING && newname != NOSTRING)
 				{
 					if (namesame(oldname, newname) != 0)
 					{
-						(void)setval((INTBIG)cli_curfacet->cell, VCELL, x_("cellname"), (INTBIG)newname, VSTRING);
-						ttyputmsg(M_("Facet name changed from %s to %s"), oldname, newname);
+						(void)setval((INTBIG)cli_curcell, VNODEPROTO, x_("protoname"), (INTBIG)newname, VSTRING);
+						ttyputmsg(M_("Cell name changed from %s to %s"), oldname, newname);
 					}
 				} else if (newname == NOSTRING)
 				{
-					ttyputmsg(M_("Erroneous BEGINFACET line"));
+					ttyputmsg(M_("Erroneous BEGINCELL line"));
 					cli_restoreline(oldline, changed, win);
 				}
 				if (oldname != NOSTRING) efree(oldname);
@@ -265,18 +265,18 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 		switch (otype)
 		{
 			case LINEDECL:
-				if (cli_curfacet != NONODEPROTO) cli_deletedeclaration(oldline);
+				if (cli_curcell != NONODEPROTO) cli_deletedeclaration(oldline);
 				cli_textlines--;
 				break;
 			case LINECONN:
-				if (cli_curfacet != NONODEPROTO) cli_deletewire(oldline);
+				if (cli_curcell != NONODEPROTO) cli_deletewire(oldline);
 				cli_textlines--;
 				break;
 			case LINEEXPORT:
-				if (cli_curfacet != NONODEPROTO) cli_deleteexportline(oldline);
+				if (cli_curcell != NONODEPROTO) cli_deleteexportline(oldline);
 				break;
 			case LINEBEGIN:
-				cli_curfacet = NONODEPROTO;
+				cli_curcell = NONODEPROTO;
 				break;
 			case LINEEND:
 				break;
@@ -289,7 +289,7 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 		switch (ntype)
 		{
 			case LINEDECL:
-				if (cli_curfacet != NONODEPROTO)
+				if (cli_curcell != NONODEPROTO)
 				{
 					if (cli_adddeclaration(newline, changed, win)) break;
 				}
@@ -297,7 +297,7 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 				break;
 
 			case LINECONN:
-				if (cli_curfacet != NONODEPROTO)
+				if (cli_curcell != NONODEPROTO)
 				{
 					if (cli_addwire(newline, changed, win)) break;
 				}
@@ -305,7 +305,7 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 				break;
 
 			case LINEEXPORT:
-				if (cli_curfacet != NONODEPROTO)
+				if (cli_curcell != NONODEPROTO)
 					(void)cli_addexport(newline, changed, win);
 				break;
 
@@ -313,30 +313,30 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 				/* must be the first line entered */
 				if (cli_textlines > 0)
 				{
-					ttyputmsg(M_("Already a valid facet definition"));
+					ttyputmsg(M_("Already a valid cell definition"));
 					cli_commentline(changed, win);
 					return;
 				}
 
-				/* get the facet name */
-				newname = cli_parsebeginfacet(newline, FALSE);
+				/* get the cell name */
+				newname = cli_parsebegincell(newline, FALSE);
 				if (newname == NOSTRING)
 				{
-					ttyputmsg(M_("Erroneous BEGINFACET line removed"));
+					ttyputmsg(M_("Erroneous BEGINCELL line removed"));
 					cli_commentline(changed, win);
 					return;
 				}
 
-				/* delete the specified facet if it exists */
+				/* delete the specified cell if it exists */
 				np = getnodeproto(newname);
 				if (np != NONODEPROTO && np->primindex != 0)
 				{
-					newpar[0] = x_("killfacet");
+					newpar[0] = x_("killcell");
 					newpar[1] = newname;
 					telltool(us_tool, 2, newpar);
 				}
 
-				/* find a window in which to place the facet */
+				/* find a window in which to place the cell */
 				for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 					if (w->editor == NOEDITOR && w->curnodeproto == NONODEPROTO) break;
 				if (w == NOWINDOWPART)
@@ -345,18 +345,18 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 						if (w->editor == NOEDITOR) break;
 				}
 
-				/* create the specified facet */
+				/* create the specified cell */
 				if (w != NOWINDOWPART)
 				{
 					newpar[0] = x_("window");
 					newpar[1] = x_("use");
 					newpar[2] = w->location;
 					telltool(us_tool, 3, newpar);
-					newpar[0] = x_("editfacet");
+					newpar[0] = x_("editcell");
 					newpar[1] = newname;
 					telltool(us_tool, 2, newpar);
-					cli_curfacet = getcurfacet();
-				} else cli_curfacet = newnodeproto(newname, el_curlib);
+					cli_curcell = getcurcell();
+				} else cli_curcell = newnodeproto(newname, el_curlib);
 				efree(newname);
 				break;
 
@@ -365,7 +365,7 @@ void cli_changehandler(WINDOWPART *win, INTBIG nature, CHAR *oldline, CHAR *newl
 				infstr = initinfstr();
 				addstringtoinfstr(infstr, (CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, changed));
 				(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)win, changed);
-				cli_replaceendfacet(returninfstr(infstr), win);
+				cli_replaceendcell(returninfstr(infstr), win);
 				break;
 		}
 	}
@@ -400,7 +400,7 @@ void cli_changeexport(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPART *
 	}
 
 	/* get the former port */
-	oldpp = getportproto(cli_curfacet, olde->portname);
+	oldpp = getportproto(cli_curcell, olde->portname);
 	if (oldpp == NOPORTPROTO)
 	{
 		ttyputerr(M_("Cannot parse old port name"));
@@ -444,7 +444,7 @@ void cli_changeexport(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPART *
 	/* see if the port name changed */
 	if (namesame(olde->portname, newe->portname) != 0)
 	{
-		if (getportproto(cli_curfacet, newe->portname) != NOPORTPROTO)
+		if (getportproto(cli_curcell, newe->portname) != NOPORTPROTO)
 		{
 			ttyputerr(M_("New port name not unique"));
 			cli_restoreline(oldline, changed, win);
@@ -453,7 +453,7 @@ void cli_changeexport(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPART *
 		}
 		if (oldni == newni && oldsubpp == newsubpp)
 			(void)db_change((INTBIG)oldni, OBJECTSTART, VNODEINST, 0, 0, 0, 0, 0);
-		(void)reallocstring(&oldpp->protoname, newe->portname, oldpp->parent->cell->cluster);
+		(void)reallocstring(&oldpp->protoname, newe->portname, oldpp->parent->lib->cluster);
 		if (oldni == newni && oldsubpp == newsubpp)
 			(void)db_change((INTBIG)oldni, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
 	}
@@ -462,7 +462,7 @@ void cli_changeexport(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPART *
 	if (oldni != newni || oldsubpp != newsubpp)
 	{
 		cli_ownchanges = TRUE;
-		(void)moveportproto(cli_curfacet, oldpp, newni, newsubpp);
+		(void)moveportproto(cli_curcell, oldpp, newni, newsubpp);
 		cli_ownchanges = FALSE;
 	}
 }
@@ -616,7 +616,7 @@ void cli_changedeclaration(CHAR *oldline, CHAR *newline, INTBIG changed,
 	{
 		if (newcomp->assoc != NOCOMPONENT) continue;
 
-		/* first see if this name exists in the facet */
+		/* first see if this name exists in the cell */
 		ni = cli_findnodename(newcomp->name);
 		if (ni != NONODEINST)
 		{
@@ -628,7 +628,7 @@ void cli_changedeclaration(CHAR *oldline, CHAR *newline, INTBIG changed,
 		cli_getfactors(NONODEINST, newnp, newcomp, &lx, &hx, &ly, &hy, &rot, &trn, 0, 0);
 
 		cli_ownchanges = TRUE;
-		ni = newnodeinst(newnp, lx, hx, ly, hy, trn, rot, cli_curfacet);
+		ni = newnodeinst(newnp, lx, hx, ly, hy, trn, rot, cli_curcell);
 		if (ni != NONODEINST)
 		{
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)newcomp->name,
@@ -878,7 +878,7 @@ void cli_changeconnection(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPA
 		portposition(newend2, newport2, &x2, &y2);
 		cli_ownchanges = TRUE;
 		newai = newarcinst(newap, widnew, 0, newend1, newport1, x1, y1,
-			newend2, newport2, x2, y2, cli_curfacet);
+			newend2, newport2, x2, y2, cli_curcell);
 		cli_ownchanges = FALSE;
 		if (newai == NOARCINST)
 		{
@@ -1009,7 +1009,7 @@ void cli_changeconnection(CHAR *oldline, CHAR *newline, INTBIG changed, WINDOWPA
 	}
 
 	/* make sure all constraints are met */
-	if (resolve) cli_solvefacet(cli_curfacet, FALSE, TRUE);
+	if (resolve) cli_solvecell(cli_curcell, FALSE, TRUE);
 
 	/* remove temporary constraints to handle offset specification */
 	if (offchanged)
@@ -1152,7 +1152,7 @@ void cli_deleteexportline(CHAR *oldline)
 	if (e == NOEXPORT) return;
 
 	/* find the exported port name */
-	pp = getportproto(cli_curfacet, e->portname);
+	pp = getportproto(cli_curcell, e->portname);
 	if (pp == NOPORTPROTO)
 	{
 		ttyputerr(M_("Unknown port: %s"), e->portname);
@@ -1162,7 +1162,7 @@ void cli_deleteexportline(CHAR *oldline)
 
 	/* remove the port prototype */
 	cli_ownchanges = TRUE;
-	(void)killportproto(cli_curfacet, pp);
+	(void)killportproto(cli_curcell, pp);
 	cli_ownchanges = FALSE;
 	cli_deleteexport(e);
 }
@@ -1205,7 +1205,7 @@ BOOLEAN cli_adddeclaration(CHAR *newline, INTBIG changed, WINDOWPART *win)
 	/* check for duplicate component names */
 	for(compo = dec->firstcomponent; compo != NOCOMPONENT; compo = compo->nextcomponent)
 	{
-		/* first see if this name exists in the facet */
+		/* first see if this name exists in the cell */
 		ni = cli_findnodename(compo->name);
 		if (ni != NONODEINST)
 		{
@@ -1235,7 +1235,7 @@ BOOLEAN cli_adddeclaration(CHAR *newline, INTBIG changed, WINDOWPART *win)
 		cli_getfactors(NONODEINST, np, compo, &lx, &hx, &ly, &hy, &rot, &trn, 0, 0);
 
 		cli_ownchanges = TRUE;
-		ni = newnodeinst(np, lx, hx, ly, hy, trn, rot, cli_curfacet);
+		ni = newnodeinst(np, lx, hx, ly, hy, trn, rot, cli_curcell);
 		if (ni != NONODEINST)
 		{
 			var = setvalkey((INTBIG)ni, VNODEINST, el_node_name_key, (INTBIG)compo->name,
@@ -1286,7 +1286,7 @@ BOOLEAN cli_addwire(CHAR *newline, INTBIG changed, WINDOWPART *win)
 	portposition(nA, pA, &xA, &yA);
 	portposition(nB, pB, &xB, &yB);
 	cli_ownchanges = TRUE;
-	ai = newarcinst(ap, wid, 0, nA,pA,xA,yA, nB,pB,xB,yB, cli_curfacet);
+	ai = newarcinst(ap, wid, 0, nA,pA,xA,yA, nB,pB,xB,yB, cli_curcell);
 	cli_ownchanges = FALSE;
 	if (ai == NOARCINST)
 	{
@@ -1332,7 +1332,7 @@ BOOLEAN cli_addwire(CHAR *newline, INTBIG changed, WINDOWPART *win)
 	}
 
 	/* make sure all constraints are met */
-	cli_solvefacet(cli_curfacet, FALSE, TRUE);
+	cli_solvecell(cli_curcell, FALSE, TRUE);
 
 	/* remove temporary manhattan constraint if it was added */
 	if (addedmanhattan)
@@ -1359,7 +1359,7 @@ void cli_addexport(CHAR *newline, INTBIG changed, WINDOWPART *win)
 	}
 
 	/* make sure the export is unique */
-	pp = getportproto(cli_curfacet, e->portname);
+	pp = getportproto(cli_curcell, e->portname);
 	if (pp != NOPORTPROTO)
 	{
 		ttyputerr(M_("Already an export called %s"), pp->protoname);
@@ -1389,7 +1389,7 @@ void cli_addexport(CHAR *newline, INTBIG changed, WINDOWPART *win)
 
 	/* create the port */
 	cli_ownchanges = TRUE;
-	newpp = newportproto(cli_curfacet, ni, pp, e->portname);
+	newpp = newportproto(cli_curcell, ni, pp, e->portname);
 	cli_ownchanges = FALSE;
 	if (newpp == NOPORTPROTO)
 	{
@@ -1565,19 +1565,19 @@ void cli_restoreline(CHAR *str, INTBIG cindex, WINDOWPART *win)
 	(void)asktool(us_tool, x_("edit-replaceline"), (INTBIG)win, cindex, (INTBIG)returninfstr(infstr));
 }
 
-void cli_replaceendfacet(CHAR *str, WINDOWPART *win)
+void cli_replaceendcell(CHAR *str, WINDOWPART *win)
 {
 	REGISTER INTBIG i, maxlines, type;
 
 	maxlines = asktool(us_tool, x_("edit-totallines"), (INTBIG)win);
 
-	/* search for all other "beginfacet" lines */
+	/* search for all other "begincell" lines */
 	for(i = 0; i < maxlines; i++)
 	{
 		type = cli_linetype((CHAR *)asktool(us_tool, x_("edit-getline"), (INTBIG)win, i));
 		if (type != LINEEND) continue;
 
-		/* found another "beginfacet", delete the text */
+		/* found another "begincell", delete the text */
 		(void)asktool(us_tool, x_("edit-deleteline"), (INTBIG)win, i);
 		i--;
 		maxlines--;
