@@ -36,8 +36,8 @@
 /* the null constraint solver */
 static void db_nullconinit(CONSTRAINT*);
 static void db_nullconterm(void);
-static void db_nullconsetmode(INTBIG, char*[]);
-static INTBIG db_nullconrequest(char*, INTBIG);
+static void db_nullconsetmode(INTBIG, CHAR*[]);
+static INTBIG db_nullconrequest(CHAR*, INTBIG);
 static void db_nullconsolve(NODEPROTO*);
 static void db_nullconnewobject(INTBIG, INTBIG);
 static void db_nullconkillobject(INTBIG, INTBIG);
@@ -59,7 +59,7 @@ static void db_nullconsetvariable(void);
 
 CONSTRAINT el_constraints[] =
 {
-	{"null", N_("Null constraints"), NOCOMCOMP, NOCLUSTER, NOVARIABLE, 0,
+	{x_("null"), N_("Null constraints"), NOCOMCOMP, NOCLUSTER, NOVARIABLE, 0,
 	db_nullconinit, db_nullconterm,						/* control */
 	db_nullconsetmode, db_nullconrequest,				/* action */
 	db_nullconsolve,									/* solution */
@@ -74,7 +74,7 @@ CONSTRAINT el_constraints[] =
 	db_nullconmodifyvariable, db_nullconinsertvariable,
 	db_nullcondeletevariable, db_nullconsetvariable},
 
-	{"layout", N_("Hierarchical layout constraints"), &cla_layconp, NOCLUSTER,
+	{x_("layout"), N_("Hierarchical layout constraints"), &cla_layconp, NOCLUSTER,
 		NOVARIABLE, 0,
 	cla_layconinit, cla_layconterm,						/* control */
 	cla_layconsetmode, cla_layconrequest,				/* action */
@@ -90,7 +90,7 @@ CONSTRAINT el_constraints[] =
 	cla_layconmodifyvariable, cla_layconinsertvariable,
 	cla_laycondeletevariable, cla_layconsetvariable},
 
-	{"linear", N_("Linear constraints"), &cli_linconp, NOCLUSTER, NOVARIABLE, 0,
+	{x_("linear"), N_("Linear constraints"), &cli_linconp, NOCLUSTER, NOVARIABLE, 0,
 	cli_linconinit, cli_linconterm,						/* control */
 	cli_linconsetmode, cli_linconrequest,				/* action */
 	cli_linconsolve,									/* solution */
@@ -124,8 +124,8 @@ CONSTRAINT el_constraints[] =
 /* the null constraint solver */
 void db_nullconinit(CONSTRAINT *con) {}
 void db_nullconterm(void) {}
-void db_nullconsetmode(INTBIG count, char *par[]) {}
-INTBIG db_nullconrequest(char *command, INTBIG arg1) { return(0); }
+void db_nullconsetmode(INTBIG count, CHAR *par[]) {}
+INTBIG db_nullconrequest(CHAR *command, INTBIG arg1) { return(0); }
 void db_nullconsolve(NODEPROTO *np) {}
 void db_nullconnewobject(INTBIG addr, INTBIG type) {}
 void db_nullconkillobject(INTBIG addr, INTBIG type) {}
