@@ -397,7 +397,7 @@ TOOL el_tools[] =
 
 #if SIMTOOL
 	/* simulation module */
-	{x_("simulation"), TOOLANALYSIS, 0, &sim_simulatorp, NOCLUSTER,
+	{x_("simulation"), TOOLON|TOOLANALYSIS, 0, &sim_simulatorp, NOCLUSTER,
 	sim_init,              sim_done,             sim_set,				/* init/done/set */
 	sim_request,           0,                    sim_slice,				/* request/examine/slice */
 	sim_startbatch,        0,											/* startbatch/endbatch */
