@@ -41,7 +41,7 @@ INTBIG       el_node_name_key;			/* key for "NODE_name" */
 INTBIG       el_arc_name_key;			/* key for "ARC_name" */
 INTBIG       el_arc_radius_key;			/* key for "ARC_radius" */
 INTBIG       el_trace_key;				/* key for "trace" */
-INTBIG       el_facet_message_key;		/* key for "FACET_message" */
+INTBIG       el_cell_message_key;		/* key for "FACET_message" */
 INTBIG       el_schematic_page_size_key;/* key for "FACET_schematic_page_size" */
 INTBIG       el_transistor_width_key;	/* key for "transistor_width" */
 INTBIG       el_prototype_center_key;	/* key for "prototype_center" */
@@ -102,8 +102,8 @@ INTBIG       el_units;					/* display and internal units */
 /******************************* GRAPHICS *******************************/
 
 INTBIG       el_maplength;				/* number of entries in color map */
-INTBIG       el_colfacettxt;			/* color to use for facet text and port names */
-INTBIG       el_colfacet;				/* color to use for facet outline */
+INTBIG       el_colcelltxt;				/* color to use for cell text and port names */
+INTBIG       el_colcell;				/* color to use for cell outline */
 INTBIG       el_colwinbor;				/* color to use for window border */
 INTBIG       el_colhwinbor;				/* color to use for highlighted window border */
 INTBIG       el_colmenbor;				/* color to use for menu border */
