@@ -44,7 +44,7 @@ static CHANGEBATCH *db_tailbatch;				/* oldest change in the list */
 static CHANGEBATCH *db_donebatch;				/* last done batch in the list */
 static CHANGEBATCH *db_changebatchfree;			/* head of free change batches */
 static CHANGE      *db_changefree;				/* head of free change modules */
-static CHANGEFACET *db_changefacetfree;			/* head of free change facet modules */
+static CHANGECELL  *db_changecellfree;			/* head of free change cell modules */
 static TOOL        *db_currenttool;				/* current tool being given a slice */
        BOOLEAN      db_donextchangequietly = FALSE;	/* true to do next change quietly */
        BOOLEAN      db_dochangesquietly = FALSE;/* true to do changes quietly */
@@ -54,13 +54,13 @@ static TOOL        *db_currenttool;				/* current tool being given a slice */
 /* prototypes for local routines */
 static CHANGE      *db_allocchange(void);
 static void         db_freechange(CHANGE*);
-static CHANGEFACET *db_allocchangefacet(void);
+static CHANGECELL  *db_allocchangecell(void);
 static CHANGEBATCH *db_allocchangebatch(void);
 static void         db_freechangebatch(CHANGEBATCH*);
 static void         db_killbatch(CHANGEBATCH*);
 static CHANGEBATCH *db_preparenewbatch(void);
 static void         db_erasebatch(CHANGEBATCH*);
-static void         db_freechangefacet(CHANGEFACET*);
+static void         db_freechangecell(CHANGECELL*);
 static void         db_loadhistorylist(INTBIG, void*);
 static void         db_broadcastchange(CHANGE*, BOOLEAN, BOOLEAN);
 static BOOLEAN      db_reversechange(CHANGE*);
@@ -74,7 +74,7 @@ static void         db_setdirty(INTBIG change, INTBIG obj, INTBIG a1, INTBIG a2,
 void db_freechangememory(void)
 {
 	REGISTER CHANGE *c;
-	REGISTER CHANGEFACET *cf;
+	REGISTER CHANGECELL *cf;
 	REGISTER CHANGEBATCH *b;
 
 	while (db_changefree != NOCHANGE)
@@ -83,10 +83,10 @@ void db_freechangememory(void)
 		db_changefree = db_changefree->nextchange;
 		efree((CHAR *)c);
 	}
-	while (db_changefacetfree != NOCHANGEFACET)
+	while (db_changecellfree != NOCHANGECELL)
 	{
-		cf = db_changefacetfree;
-		db_changefacetfree = db_changefacetfree->nextchangefacet;
+		cf = db_changecellfree;
+		db_changecellfree = db_changecellfree->nextchangecell;
 		efree((CHAR *)cf);
 	}
 	while (db_changebatchfree != NOCHANGEBATCH)
@@ -106,7 +106,7 @@ void db_initializechanges(void)
 {
 	/* initialize change lists */
 	db_changefree = NOCHANGE;
-	db_changefacetfree = NOCHANGEFACET;
+	db_changecellfree = NOCHANGECELL;
 	db_changebatchfree = NOCHANGEBATCH;
 
 	/* initialize changes */
@@ -204,7 +204,7 @@ void db_setdirty(INTBIG change, INTBIG obj, INTBIG a1, INTBIG a2, INTBIG a3, INT
 		case NODEINSTMOD:
 			ni = (NODEINST *)obj;
 			np = ni->parent;
-			lib = np->cell->lib;
+			lib = np->lib;
 			major = 1;
 			break;
 		case ARCINSTNEW:
@@ -212,7 +212,7 @@ void db_setdirty(INTBIG change, INTBIG obj, INTBIG a1, INTBIG a2, INTBIG a3, INT
 		case ARCINSTMOD:
 			ai = (ARCINST *)obj;
 			np = ai->parent;
-			lib = np->cell->lib;
+			lib = np->lib;
 			major = 1;
 			break;
 		case PORTPROTONEW:
@@ -220,19 +220,19 @@ void db_setdirty(INTBIG change, INTBIG obj, INTBIG a1, INTBIG a2, INTBIG a3, INT
 		case PORTPROTOMOD:
 			pp = (PORTPROTO *)obj;
 			np = pp->parent;
-			lib = np->cell->lib;
+			lib = np->lib;
 			major = 1;
 			break;
 		case NODEPROTONEW:
 			np = (NODEPROTO *)obj;
-			lib = np->cell->lib;
+			lib = np->lib;
 			major = 1;
 			break;
 		case NODEPROTOKILL:
 			major = 1;
 			/* FALLTHROUGH */ 
 		case NODEPROTOMOD:
-			lib = ((NODEPROTO *)obj)->cell->lib;
+			lib = ((NODEPROTO *)obj)->lib;
 			break;
 		case OBJECTNEW:
 		case OBJECTKILL:
@@ -291,8 +291,8 @@ BOOLEAN db_majorvariable(INTBIG type, INTBIG key)
 	switch (type)
 	{
 		case VNODEPROTO:
-			/* when changing text in text-only facet */
-			if (key == el_facet_message_key) return(TRUE);
+			/* when changing text in text-only cell */
+			if (key == el_cell_message_key) return(TRUE);
 			break;
 		case VNODEINST:
 			/* when changing node name */
@@ -539,7 +539,7 @@ CHANGEBATCH *db_preparenewbatch(void)
 	}
 
 	/* miscellaneous initialization */
-	thisbatch->firstchangefacet = NOCHANGEFACET;
+	thisbatch->firstchangecell = NOCHANGECELL;
 	thisbatch->tool = db_currenttool;
 	thisbatch->activity = 0;
 	return(thisbatch);
@@ -561,12 +561,11 @@ void db_killbatch(CHANGEBATCH *batch)
 void db_erasebatch(CHANGEBATCH *batch)
 {
 	REGISTER CHANGE *c, *nextc;
-	REGISTER CHANGEFACET *cc, *nextcc;
+	REGISTER CHANGECELL *cc, *nextcc;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER NODEPROTO *np;
 	REGISTER PORTPROTO *pp;
-	REGISTER CELL *cell;
 	REGISTER WINDOWPART *w;
 	REGISTER EDITOR *e;
 
@@ -617,11 +616,6 @@ void db_erasebatch(CHANGEBATCH *batch)
 					}
 					freewindowpart(w);
 					break;
-				case VCELL:
-					cell = (CELL *)c->entryaddr;
-					efree(cell->cellname);
-					freecell(cell);
-					break;
 			}
 		} else if (c->changetype == VARIABLEDEL ||
 			c->changetype == VARIABLEMOD)
@@ -636,13 +630,13 @@ void db_erasebatch(CHANGEBATCH *batch)
 	}
 	batch->changehead = batch->changetail = NOCHANGE;
 
-	/* erase the change facet information */
-	for(cc = batch->firstchangefacet; cc != NOCHANGEFACET; cc = nextcc)
+	/* erase the change cell information */
+	for(cc = batch->firstchangecell; cc != NOCHANGECELL; cc = nextcc)
 	{
-		nextcc = cc->nextchangefacet;
-		db_freechangefacet(cc);
+		nextcc = cc->nextchangecell;
+		db_freechangecell(cc);
 	}
-	batch->firstchangefacet = NOCHANGEFACET;
+	batch->firstchangecell = NOCHANGECELL;
 
 	/* erase the activity information */
 	if (batch->activity != 0) efree(batch->activity);
@@ -687,17 +681,8 @@ void noredoallowed(void)
 	{
 		killbatch = db_headbatch;
 		db_headbatch = db_headbatch->lastchangebatch;
-#if 0		/* Stefan Muller wants to do it this way */
-		/* "If we load a design and make several Undos the software crashes" */
-		if (db_headbatch != NOCHANGEBATCH)
-		{
-			db_headbatch->nextchangebatch = NOCHANGEBATCH;
-			db_killbatch(killbatch);
-		}
-#else
 		if (db_headbatch != NOCHANGEBATCH) db_headbatch->nextchangebatch = NOCHANGEBATCH;
 		db_killbatch(killbatch);
-#endif
 	}
 }
 
@@ -821,7 +806,7 @@ INTBIG undonature(BOOLEAN undo)
  * routine to undo backward through the list of change batches.  If there is no batch to
  * undo, the routine returns zero.  If there is a batch, it is undone and the
  * routine returns the batch number (a positive value) if the batch involved changes to
- * nodes/arcs/ports/facets or the negative batch number if the batch only involves minor
+ * nodes/arcs/ports/cells or the negative batch number if the batch only involves minor
  * changes (variables, etc.).  The tool that produced the batch is returned in "tool".
  */
 INTBIG undoabatch(TOOL **tool)
@@ -868,7 +853,7 @@ INTBIG undoabatch(TOOL **tool)
  * routine to redo forward through the list of change batches.  If there is no batch to
  * redo, the routine returns zero.  If there is a batch, it is redone and the
  * routine returns the batch number (a positive value) if the batch involved changes to
- * nodes/arcs/ports/facets or the negative batch number if the batch only involves minor
+ * nodes/arcs/ports/cells or the negative batch number if the batch only involves minor
  * changes (variables, etc.).  The tool that produced the batch is returned in "tool".
  */
 INTBIG redoabatch(TOOL **tool)
@@ -1223,42 +1208,42 @@ BOOLEAN db_reversechange(CHANGE *c)
 	return(FALSE);
 }
 
-/************************* CHANGE FACETS *************************/
+/************************* CHANGE CELLS *************************/
 
 /*
- * routine to add facet "facet" to the list of facets that are being
+ * routine to add cell "cell" to the list of cells that are being
  * changed in this batch.
  */
-void db_setchangefacet(NODEPROTO *facet)
+void db_setchangecell(NODEPROTO *cell)
 {
-	REGISTER CHANGEFACET *cc;
+	REGISTER CHANGECELL *cc;
 
 	if (db_currentbatch == NOCHANGEBATCH) return;
-	if (db_currentbatch->firstchangefacet == NOCHANGEFACET ||
-		db_currentbatch->firstchangefacet->changefacet != facet)
+	if (db_currentbatch->firstchangecell == NOCHANGECELL ||
+		db_currentbatch->firstchangecell->changecell != cell)
 	{
-		cc = db_allocchangefacet();
-		cc->nextchangefacet = db_currentbatch->firstchangefacet;
-		db_currentbatch->firstchangefacet = cc;
-		cc->changefacet = facet;
+		cc = db_allocchangecell();
+		cc->nextchangecell = db_currentbatch->firstchangecell;
+		db_currentbatch->firstchangecell = cc;
+		cc->changecell = cell;
 		cc->forcedlook = FALSE;
 	}
 }
 
-void db_removechangefacet(NODEPROTO *np)
+void db_removechangecell(NODEPROTO *np)
 {
-	REGISTER CHANGEFACET *cc, *lastcc, *nextcc;
+	REGISTER CHANGECELL *cc, *lastcc, *nextcc;
 
 	if (db_currentbatch == NOCHANGEBATCH) return;
-	lastcc = NOCHANGEFACET;
-	for(cc = db_currentbatch->firstchangefacet; cc != NOCHANGEFACET; cc = nextcc)
+	lastcc = NOCHANGECELL;
+	for(cc = db_currentbatch->firstchangecell; cc != NOCHANGECELL; cc = nextcc)
 	{
-		nextcc = cc->nextchangefacet;
-		if (cc->changefacet == np)
+		nextcc = cc->nextchangecell;
+		if (cc->changecell == np)
 		{
-			if (lastcc == NOCHANGEFACET) db_currentbatch->firstchangefacet = nextcc; else
-				lastcc->nextchangefacet = nextcc;
-			db_freechangefacet(cc);
+			if (lastcc == NOCHANGECELL) db_currentbatch->firstchangecell = nextcc; else
+				lastcc->nextchangecell = nextcc;
+			db_freechangecell(cc);
 			return;
 		}
 		lastcc = cc;
@@ -1266,23 +1251,23 @@ void db_removechangefacet(NODEPROTO *np)
 }
 
 /*
- * Routine to ensure that facet "np" is given a hierarchical analysis by the
+ * Routine to ensure that cell "np" is given a hierarchical analysis by the
  * constraint system.
  */
 void db_forcehierarchicalanalysis(NODEPROTO *np)
 {
-	REGISTER CHANGEFACET *cc;
+	REGISTER CHANGECELL *cc;
 
 	if (db_currentbatch == NOCHANGEBATCH) return;
-	for(cc = db_currentbatch->firstchangefacet; cc != NOCHANGEFACET; cc = cc->nextchangefacet)
-		if (cc->changefacet == np)
+	for(cc = db_currentbatch->firstchangecell; cc != NOCHANGECELL; cc = cc->nextchangecell)
+		if (cc->changecell == np)
 	{
 		cc->forcedlook = TRUE;
 		return;
 	}
 
 	/* if not in the list, create the entry and try again */
-	db_setchangefacet(np);
+	db_setchangecell(np);
 	db_forcehierarchicalanalysis(np);
 }
 
@@ -1398,7 +1383,7 @@ void showhistorylist(INTBIG which)
 		}
 		if (nproto != 0)
 		{
-			(void)esnprintf(line, 50, x_(" %ld %s"), nproto, makeplural(M_("facet"), nproto));
+			(void)esnprintf(line, 50, x_(" %ld %s"), nproto, makeplural(M_("cell"), nproto));
 			addstringtoinfstr(infstr, line);
 		}
 		if (object != 0)
@@ -1431,20 +1416,20 @@ CHAR *db_describechange(INTBIG changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 		case NODEINSTNEW:
 			ni = (NODEINST *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Node '%s' created in facet %s"), describenodeinst(ni),
+			formatinfstr(infstr, M_(" Node '%s' created in cell %s"), describenodeinst(ni),
 				describenodeproto(ni->parent));
 			return(returninfstr(infstr));
 		case NODEINSTKILL:
 			ni = (NODEINST *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Node '%s' killed in facet %s"), describenodeinst(ni),
+			formatinfstr(infstr, M_(" Node '%s' killed in cell %s"), describenodeinst(ni),
 				describenodeproto(ni->parent));
 			return(returninfstr(infstr));
 		case NODEINSTMOD:
 			ni = (NODEINST *)entryaddr;
 			lambda = lambdaofnode(ni);
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Node '%s' changed in facet %s [was %sx%s, center (%s,%s), rotated %ld"),
+			formatinfstr(infstr, M_(" Node '%s' changed in cell %s [was %sx%s, center (%s,%s), rotated %ld"),
 				describenodeinst(ni), describenodeproto(ni->parent), latoa(p3-p1, lambda),
 				latoa(p4-p2, lambda), latoa((p1+p3)/2, lambda), latoa((p2+p4)/2, lambda), p5);
 			if (p6 != 0) addstringtoinfstr(infstr, M_(", transposed"));
@@ -1453,57 +1438,57 @@ CHAR *db_describechange(INTBIG changetype, INTBIG entryaddr, INTBIG p1, INTBIG p
 		case ARCINSTNEW:
 			ai = (ARCINST *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Arc '%s' created in facet %s"), describearcinst(ai),
+			formatinfstr(infstr, M_(" Arc '%s' created in cell %s"), describearcinst(ai),
 				describenodeproto(ai->parent));
 			return(returninfstr(infstr));
 		case ARCINSTKILL:
 			ai = (ARCINST *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Arc '%s' killed in facet %s"), describearcinst(ai),
+			formatinfstr(infstr, M_(" Arc '%s' killed in cell %s"), describearcinst(ai),
 				describenodeproto(ai->parent));
 			return(returninfstr(infstr));
 		case ARCINSTMOD:
 			ai = (ARCINST *)entryaddr;
 			lambda = lambdaofarc(ai);
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Arc '%s' modified in facet %s [was %s wide %s long from (%s,%s) to (%s,%s)]"),
+			formatinfstr(infstr, M_(" Arc '%s' modified in cell %s [was %s wide %s long from (%s,%s) to (%s,%s)]"),
 				describearcinst(ai), describenodeproto(ai->parent), latoa(p5, lambda), latoa(p6, lambda),
 					latoa(p1, lambda), latoa(p2, lambda), latoa(p3, lambda), latoa(p4, lambda));
 			return(returninfstr(infstr));
 		case PORTPROTONEW:
 			pp = (PORTPROTO *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Port '%s' created in facet %s"), pp->protoname,
+			formatinfstr(infstr, M_(" Port '%s' created in cell %s"), pp->protoname,
 				describenodeproto(pp->parent));
 			return(returninfstr(infstr));
 		case PORTPROTOKILL:
 			pp = (PORTPROTO *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Port '%s' killed in facet %s"), pp->protoname,
+			formatinfstr(infstr, M_(" Port '%s' killed in cell %s"), pp->protoname,
 				describenodeproto(pp->parent));
 			return(returninfstr(infstr));
 		case PORTPROTOMOD:
 			pp = (PORTPROTO *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Port '%s' moved in facet %s [was on node %s, subport %s]"),
+			formatinfstr(infstr, M_(" Port '%s' moved in cell %s [was on node %s, subport %s]"),
 				pp->protoname, describenodeproto(pp->parent), describenodeinst((NODEINST *)p1),
 				((PORTPROTO *)p2)->protoname);
 			return(returninfstr(infstr));
 		case NODEPROTONEW:
 			np = (NODEPROTO *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Facet '%s' created"), describenodeproto(np));
+			formatinfstr(infstr, M_(" Cell '%s' created"), describenodeproto(np));
 			return(returninfstr(infstr));
 		case NODEPROTOKILL:
 			np = (NODEPROTO *)entryaddr;
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Facet %s' killed"), describenodeproto(np));
+			formatinfstr(infstr, M_(" Cell %s' killed"), describenodeproto(np));
 			return(returninfstr(infstr));
 		case NODEPROTOMOD:
 			np = (NODEPROTO *)entryaddr;
-			lambda = lambdaoffacet(np);
+			lambda = lambdaofcell(np);
 			infstr = initinfstr();
-			formatinfstr(infstr, M_(" Facet '%s' modified [was from %s<=X<=%s %s<=Y<=%s]"),
+			formatinfstr(infstr, M_(" Cell '%s' modified [was from %s<=X<=%s %s<=Y<=%s]"),
 				describenodeproto(np), latoa(p1, lambda), latoa(p2, lambda),
 					latoa(p3, lambda), latoa(p4, lambda));
 			return(returninfstr(infstr));
@@ -1715,7 +1700,7 @@ void db_loadhistorylist(INTBIG details, void *dia)
 		}
 		if (nproto != 0)
 		{
-			(void)esnprintf(line, 50, x_(" %ld %s"), nproto, makeplural(M_("facet"), nproto));
+			(void)esnprintf(line, 50, x_(" %ld %s"), nproto, makeplural(M_("cell"), nproto));
 			addstringtoinfstr(infstr, line);
 		}
 		if (object != 0)
@@ -1781,33 +1766,33 @@ void db_freechange(CHANGE *c)
 }
 
 /*
- * routine to allocate a changefacet module from the pool (if any) or memory
- * the routine returns NOCHANGEFACET if allocation fails.
+ * routine to allocate a changecell module from the pool (if any) or memory
+ * the routine returns NOCHANGECELL if allocation fails.
  */
-CHANGEFACET *db_allocchangefacet(void)
+CHANGECELL *db_allocchangecell(void)
 {
-	REGISTER CHANGEFACET *c;
+	REGISTER CHANGECELL *c;
 
-	if (db_changefacetfree == NOCHANGEFACET)
+	if (db_changecellfree == NOCHANGECELL)
 	{
-		c = (CHANGEFACET *)emalloc((sizeof (CHANGEFACET)), db_cluster);
-		if (c == 0) return(NOCHANGEFACET);
+		c = (CHANGECELL *)emalloc((sizeof (CHANGECELL)), db_cluster);
+		if (c == 0) return(NOCHANGECELL);
 		return(c);
 	}
 
 	/* take change module from free list */
-	c = db_changefacetfree;
-	db_changefacetfree = db_changefacetfree->nextchangefacet;
+	c = db_changecellfree;
+	db_changecellfree = db_changecellfree->nextchangecell;
 	return(c);
 }
 
 /*
- * routine to free a changefacet module
+ * routine to free a changecell module
  */
-void db_freechangefacet(CHANGEFACET *c)
+void db_freechangecell(CHANGECELL *c)
 {
-	c->nextchangefacet = db_changefacetfree;
-	db_changefacetfree = c;
+	c->nextchangecell = db_changecellfree;
+	db_changecellfree = c;
 }
 
 /*
