@@ -45,12 +45,12 @@ static BOOLEAN db_contourendpoints(NODEINST *ni, INTBIG *fx, INTBIG *fy, INTBIG
 static void    db_getcontoursegmentparameters(void);
 
 /*
- * routine to examine all of the geometry in facet "np" and build a contour structure for it.
+ * routine to examine all of the geometry in cell "np" and build a contour structure for it.
  * If "usearray" is nonzero, it is a NONODEINST-terminated array of nodes to consider.
  * To allow for gaps in the data, "bestthresh" is the initial error threshold that will be
  * allowed, and "worstthresh" is the greatest error threshold that will be allowed (usually
  * 2 or 3 orders of magnitude larger than "bestthresh").  If both thresholds are zero,
- * endpoints must meet precisely.  Returns a list of contours for this facet (NOCONTOUR on
+ * endpoints must meet precisely.  Returns a list of contours for this cell (NOCONTOUR on
  * error).
  */
 CONTOUR *gathercontours(NODEPROTO *np, NODEINST **usearray, INTBIG bestthresh, INTBIG worstthresh)
@@ -209,7 +209,7 @@ BOOLEAN db_contourendpoints(NODEINST *ni, INTBIG *fx, INTBIG *fy, INTBIG *tx, IN
 
 	if (ni->proto == art_openedpolygonprim || ni->proto == art_closedpolygonprim)
 	{
-		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+		var = gettrace(ni);
 		if (var == NOVARIABLE) return(TRUE);
 		len = getlength(var);
 		makerot(ni, trans);
@@ -244,7 +244,7 @@ BOOLEAN db_addelementtocontour(CONTOUR *con, NODEINST *ni)
 	cy = (ni->lowy + ni->highy) / 2;
 	if (ni->proto == art_openedpolygonprim || ni->proto == art_closedpolygonprim)
 	{
-		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+		var = gettrace(ni);
 		if (var == NOVARIABLE) return(FALSE);
 		len = getlength(var);
 		makerot(ni, trans);
