@@ -57,7 +57,7 @@
  *    version "6.03"   has major=6, minor=3, and detail=1000
  * The routine "io_getversion()" parses these version strings.
  */
-CHAR *el_version = x_("6.08");
+CHAR *el_version = x_("7.00");
 
        BOOLEAN db_multiprocessing;	/* true if multiprocessing */
 
@@ -208,11 +208,6 @@ void osprimaryosinit(void)
 	estrcpy(libfile, x_("noname"));
 	lib = newlibrary(libname, libfile);
 	selectlibrary(lib, TRUE);
-
-#if 0	/* moved this to "usr.c:us_do2init()" */
-	/* establish the library location */
-	setupenvironment();
-#endif
 }
 
 /*
@@ -314,32 +309,12 @@ INTBIG asktool(TOOL *tool, CHAR *command, ...)
 
 /*
  * routine to turn tool "tool" back on.  The user interface will notice this change
- * and inform the tool of each facet that changed while it was off (via "examinenodeproto").
+ * and inform the tool of each cell that changed while it was off (via "examinenodeproto").
  */
 void toolturnon(TOOL *tool)
 {
 	/* turn on the tool */
 	(void)setval((INTBIG)tool, VTOOL, x_("toolstate"), tool->toolstate|TOOLON, VINTEGER);
-#if 0
-	/* if the tool is not incremental, don't inform it of changes while off */
-	if ((tool->toolstate & TOOLINCREMENTAL) == 0) return;
-
-	/* if catch-up action is supressed, quit now */
-	if (nocatchup) return;
-
-	/* look through all facets and update those that need it */
-	bit = 1 << tool->toolindex;
-	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
-		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-	{
-		if ((np->adirty & bit) != 0)
-		{
-			if (tool->examinenodeproto != 0)
-				(*tool->examinenodeproto)(np);
-		}
-		np->adirty &= ~bit;
-	}
-#endif
 }
 
 /*
@@ -452,8 +427,16 @@ void db_freeallmemory(void)
 BOOLEAN stopping(INTBIG reason)
 {
 	extern CHAR *db_stoppingreason[];
+	static UINTBIG lastchecktime = 0;
+	REGISTER UINTBIG curtime;
 
 	if ((us_tool->toolstate&TERMNOINTERRUPT) != 0) return(FALSE);
+
+	/* only check once per second */
+	curtime = ticktime();
+	if (curtime - lastchecktime < 60) return(FALSE);
+	lastchecktime = curtime;
+
 	checkforinterrupt();
 	if (el_pleasestop == 1)
 	{
