@@ -107,7 +107,7 @@ void endobjectchange(INTBIG addr, INTBIG type)
 /*
  * create a new nodeinst of proto "typ" located at (lx-hx, ly-hy), transposed
  * if "trans" is nonzero, rotated "angle" tenth-degrees.  The nodeinst is located
- * in facet "parnt". The address of the nodeinst is returned.
+ * in cell "parnt". The address of the nodeinst is returned.
  * If NONODEINST is returned, there is an error creating the nodeinst.
  */
 NODEINST *newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
@@ -147,7 +147,7 @@ NODEINST *newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
 /*
  * internal procedure to create a new nodeinst of proto "np" located at
  * (lx-hx, ly-hy), transposed if "trans" is nonzero, rotated "angle" tenth-degrees.
- * The nodeinst is located in facet "parnt". The address of the nodeinst is
+ * The nodeinst is located in cell "parnt". The address of the nodeinst is
  * returned.  NONODEINST is returned upon error.
  */
 NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
@@ -156,7 +156,7 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 	REGISTER NODEINST *ni;
 
 	/* allocate the nodeinst */
-	ni = allocnodeinst(parnt->cell->cluster);
+	ni = allocnodeinst(parnt->lib->cluster);
 	if (ni == NONODEINST)
 	{
 		db_donextchangequietly = FALSE;
@@ -175,7 +175,7 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 	ni->firstportexpinst = NOPORTEXPINST;
 
 	/* make a geometry module for this nodeinst */
-	ni->geom = allocgeom(parnt->cell->cluster);
+	ni->geom = allocgeom(parnt->lib->cluster);
 	if (ni->geom == NOGEOM) return(NONODEINST);
 	ni->geom->entryisnode = TRUE;   ni->geom->entryaddr.ni = ni;
 
@@ -185,8 +185,8 @@ NODEINST *db_newnodeinst(NODEPROTO *np, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG
 	/* handle change control, constraint, and broadcast */
 	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
-		/* set the change facet environment */
-		db_setchangefacet(parnt);
+		/* set the change cell environment */
+		db_setchangecell(parnt);
 
 		/* tell all tools about this nodeinst */
 		ni->changeaddr = (CHAR *)db_change((INTBIG)ni, NODEINSTNEW, 0, 0, 0, 0, 0, 0);
@@ -222,7 +222,7 @@ void db_enternodeinst(NODEINST *ni)
 	ni->previnst = NONODEINST;
 	np->firstinst = ni;
 
-	/* put in list of nodes in this facet */
+	/* put in list of nodes in this cell */
 	if (par->firstnodeinst != NONODEINST) par->firstnodeinst->prevnodeinst = ni;
 	ni->nextnodeinst = par->firstnodeinst;
 	ni->prevnodeinst = NONODEINST;
@@ -281,8 +281,8 @@ void db_killnodeinst(NODEINST *ni)
 	/* handle change control, constraint, and broadcast */
 	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
-		/* set the change facet environment */
-		db_setchangefacet(ni->parent);
+		/* set the change cell environment */
+		db_setchangecell(ni->parent);
 
 		/* tell all tools about this nodeinst */
 		ni->changeaddr = (CHAR *)db_change((INTBIG)ni, NODEINSTKILL, 0, 0, 0, 0, 0, 0);
@@ -309,7 +309,7 @@ void db_retractnodeinst(NODEINST *ni)
 	if (ni->previnst != NONODEINST) ni->previnst->nextinst = ni->nextinst; else
 		ni->proto->firstinst = ni->nextinst;
 
-	/* remove from list of nodes in this facet */
+	/* remove from list of nodes in this cell */
 	if (ni->nextnodeinst != NONODEINST) ni->nextnodeinst->prevnodeinst = ni->prevnodeinst;
 	if (ni->prevnodeinst != NONODEINST) ni->prevnodeinst->nextnodeinst = ni->nextnodeinst; else
 		ni->parent->firstnodeinst = ni->nextnodeinst;
@@ -336,7 +336,7 @@ void defaultnodesize(NODEPROTO *np, INTBIG *xs, INTBIG *ys)
 	*xs = np->highx - np->lowx;
 	*ys = np->highy - np->lowy;
 
-	/* facets always use this */
+	/* cells always use this */
 	if (np->primindex == 0) return;
 
 	/* see if there is an override on the node */
@@ -381,8 +381,8 @@ void modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx
 	}
 	db_donextchangequietly = FALSE;
 
-	/* set the change facet environment */
-	db_setchangefacet(ni->parent);
+	/* set the change cell environment */
+	db_setchangecell(ni->parent);
 
 	/* mark a change to the database */
 	db_changetimestamp++;
@@ -405,7 +405,7 @@ void modifynodeinsts(INTBIG count, NODEINST **nis, INTBIG *deltalxs, INTBIG *del
 		/* tell constraint system about modified node */
 		(*el_curconstraint->modifynodeinsts)(count, nis, deltalxs, deltalys, deltahxs, deltahys, deltarots, deltatranss);
 		for(i=0; i<count; i++)
-			db_setchangefacet(nis[i]->parent);
+			db_setchangecell(nis[i]->parent);
 	} else
 	{
 		for(i=0; i<count; i++)
@@ -598,7 +598,7 @@ void freeportarcinst(PORTARCINST *pi)
  * create a new arcinst of proto "typ", width "width", and initial userbits in
  * "initialbits".  One end is connected to portproto "pA" of nodeinst
  * "nA" and the other end is connected to portproto "pB" of nodeinst "nB".
- * The arcinst is located in facet "parnt".  The address of the arcinst is
+ * The arcinst is located in cell "parnt".  The address of the arcinst is
  * returned (NOARCINST if an error is found).
  */
 ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
@@ -637,7 +637,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 		return((ARCINST *)db_error(DBBADENDBN|DBNEWARCINST));
 	}
 
-	/* make sure that the node is in the facet */
+	/* make sure that the node is in the cell */
 	if (nA->parent != parnt)
 	{
 		db_donextchangequietly = FALSE;
@@ -672,7 +672,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	{
 		(void)db_error(DBBADENDAC|DBNEWARCINST);
 		if (db_printerrors)
-			ttyputmsg(_("Port %s of node %s in facet %s cannot connect to arc %s"), pA->protoname,
+			ttyputmsg(_("Port %s of node %s in cell %s cannot connect to arc %s"), pA->protoname,
 				describenodeinst(nA), describenodeproto(parnt), describearcproto(typ));
 		db_donextchangequietly = FALSE;
 		return(NOARCINST);
@@ -683,7 +683,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	{
 		(void)db_error(DBBADENDBC|DBNEWARCINST);
 		if (db_printerrors)
-			ttyputmsg(_("Port %s of node %s in facet %s cannot connect to arc %s"), pB->protoname,
+			ttyputmsg(_("Port %s of node %s in cell %s cannot connect to arc %s"), pB->protoname,
 				describenodeinst(nB), describenodeproto(parnt), describearcproto(typ));
 		db_donextchangequietly = FALSE;
 		return(NOARCINST);
@@ -697,8 +697,8 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 		(void)db_error(DBBADENDAP|DBNEWARCINST);
 		if (db_printerrors)
 		{
-			lambda = lambdaoffacet(parnt);
-			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in facet %s"), latoa(xA, lambda),
+			lambda = lambdaofcell(parnt);
+			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in cell %s"), latoa(xA, lambda),
 				latoa(yA, lambda), pA->protoname, describenodeinst(nA), describenodeproto(parnt));
 		}
 		db_donextchangequietly = FALSE;
@@ -711,8 +711,8 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 		(void)db_error(DBBADENDBP|DBNEWARCINST);
 		if (db_printerrors)
 		{
-			lambda = lambdaoffacet(parnt);
-			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in facet %s"), latoa(xB, lambda),
+			lambda = lambdaofcell(parnt);
+			ttyputmsg(_("Point (%s,%s) not inside port %s of node %s in cell %s"), latoa(xB, lambda),
 				latoa(yB, lambda), pB->protoname, describenodeinst(nB), describenodeproto(parnt));
 		}
 		db_donextchangequietly = FALSE;
@@ -721,14 +721,14 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
 	}
 	freepolygon(poly);
 
-	/* mark the start of a change to any facet instances that this arc connects */
+	/* mark the start of a change to any cell instances that this arc connects */
 	if (nA->proto->primindex == 0) startobjectchange((INTBIG)nA, VNODEINST);
 	if (nB->proto->primindex == 0) startobjectchange((INTBIG)nB, VNODEINST);
 
 	/* create the arcinst */
 	ai = db_newarcinst(typ, wid, initialbits, nA,pA,xA,yA, nB,pB,xB,yB, parnt);
 
-	/* mark the start of a change to any facet instances that this arc connects */
+	/* mark the start of a change to any cell instances that this arc connects */
 	if (nA->proto->primindex == 0) endobjectchange((INTBIG)nA, VNODEINST);
 	if (nB->proto->primindex == 0) endobjectchange((INTBIG)nB, VNODEINST);
 
@@ -739,7 +739,7 @@ ARCINST *newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
  * internal procedure to create a new arcinst of proto "typ" with width
  * "width".  One end is connected to portproto "pA" of nodeinst "nA" and the
  * other end is connected to portproto "pB" of nodeinst "nB".  The arcinst
- * is located in facet "parnt".  The address of the arcinst is returned.
+ * is located in cell "parnt".  The address of the arcinst is returned.
  * NOARCINST is returned upon error.
  */
 ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *nA,
@@ -749,7 +749,7 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *npi;
 
-	ai = allocarcinst(parnt->cell->cluster);
+	ai = allocarcinst(parnt->lib->cluster);
 	if (ai == NOARCINST)
 	{
 		db_donextchangequietly = FALSE;
@@ -767,18 +767,18 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 	ai->parent = parnt;
 	ai->endshrink = 0;
 
-	ai->end[0].portarcinst = allocportarcinst(parnt->cell->cluster);
+	ai->end[0].portarcinst = allocportarcinst(parnt->lib->cluster);
 	npi = ai->end[0].portarcinst;
 	npi->proto = pA;
 	db_addportarcinst(nA, npi);
 
-	ai->end[1].portarcinst = allocportarcinst(parnt->cell->cluster);
+	ai->end[1].portarcinst = allocportarcinst(parnt->lib->cluster);
 	npi = ai->end[1].portarcinst;
 	npi->proto = pB;
 	db_addportarcinst(nB, npi);
 
 	/* create a geometry module for this arcinst */
-	ai->geom = allocgeom(parnt->cell->cluster);
+	ai->geom = allocgeom(parnt->lib->cluster);
 	if (ai->geom == NOGEOM) return(NOARCINST);
 	ai->geom->entryisnode = FALSE;
 	ai->geom->entryaddr.ai = ai;
@@ -789,8 +789,8 @@ ARCINST *db_newarcinst(ARCPROTO *typ, INTBIG wid, INTBIG initialbits, NODEINST *
 	/* handle change control, constraint, and broadcast */
 	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
-		/* set the change facet environment */
-		db_setchangefacet(parnt);
+		/* set the change cell environment */
+		db_setchangecell(parnt);
 
 		/* tell all tools about this arcinst */
 		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTNEW, 0, 0, 0, 0, 0, 0);
@@ -820,7 +820,7 @@ void db_enterarcinst(ARCINST *ai)
 	/* place connection in the nodes */
 	for(i=0; i<2; i++) ai->end[i].portarcinst->conarcinst = ai;
 
-	/* put in list of arcs in this facet */
+	/* put in list of arcs in this cell */
 	np = ai->parent;
 	if (np->firstarcinst != NOARCINST) np->firstarcinst->prevarcinst = ai;
 	ai->nextarcinst = np->firstarcinst;
@@ -902,7 +902,7 @@ BOOLEAN killarcinst(ARCINST *ai)
 		return(db_error(DBBADINST|DBKILLARCINST) != 0);
 	}
 
-	/* mark the start of a change to any facet instances that this arc connects */
+	/* mark the start of a change to any cell instances that this arc connects */
 	ni1 = ai->end[0].nodeinst;   ni2 = ai->end[1].nodeinst;
 	if (ni1->proto->primindex == 0) startobjectchange((INTBIG)ni1, VNODEINST);
 	if (ni2->proto->primindex == 0) startobjectchange((INTBIG)ni2, VNODEINST);
@@ -910,7 +910,7 @@ BOOLEAN killarcinst(ARCINST *ai)
 	/* remove arcinst from appropriate lists */
 	db_killarcinst(ai);
 
-	/* mark the start of a change to any facet instances that this arc connects */
+	/* mark the start of a change to any cell instances that this arc connects */
 	if (ni1->proto->primindex == 0) endobjectchange((INTBIG)ni1, VNODEINST);
 	if (ni2->proto->primindex == 0) endobjectchange((INTBIG)ni2, VNODEINST);
 
@@ -925,8 +925,8 @@ void db_killarcinst(ARCINST *ai)
 	/* handle change control, constraint, and broadcast */
 	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
-		/* set the change facet environment */
-		db_setchangefacet(ai->parent);
+		/* set the change cell environment */
+		db_setchangecell(ai->parent);
 
 		/* tell all tools about this arcinst */
 		ai->changeaddr = (CHAR *)db_change((INTBIG)ai, ARCINSTKILL, 0, 0, 0, 0, 0, 0);
@@ -951,7 +951,7 @@ void db_retractarcinst(ARCINST *ai)
 	REGISTER PORTARCINST *pi, *lpi;
 	REGISTER ARCINST *oai;
 
-	/* remove from list of arcs in this facet */
+	/* remove from list of arcs in this cell */
 	if (ai->nextarcinst != NOARCINST) ai->nextarcinst->prevarcinst = ai->prevarcinst;
 	if (ai->prevarcinst != NOARCINST) ai->prevarcinst->nextarcinst = ai->nextarcinst; else
 		ai->parent->firstarcinst = ai->nextarcinst;
@@ -1078,8 +1078,8 @@ BOOLEAN modifyarcinst(ARCINST *ai, INTBIG deltawid, INTBIG deltax1, INTBIG delta
 		/* tell constraint system about modified arc */
 		(*el_curconstraint->modifyarcinst)(ai, oldx0, oldy0, oldx1, oldy1, oldwid, oldlen);
 
-		/* set the change facet environment */
-		db_setchangefacet(ai->parent);
+		/* set the change cell environment */
+		db_setchangecell(ai->parent);
 	}
 	db_donextchangequietly = FALSE;
 
@@ -1107,6 +1107,7 @@ INTBIG setshrinkvalue(ARCINST *ai, BOOLEAN extend)
 	{
 		if (ai->end[i].nodeinst == NONODEINST) return(0);
 		ai->end[i].nodeinst->userbits &= ~NSHORT;
+if (ai->end[i].portarcinst->proto == NOPORTPROTO) continue;
 		shorter[i] = db_checkshortening(ai->end[i].nodeinst, ai->end[i].portarcinst->proto);
 	}
 
@@ -1342,7 +1343,7 @@ void freeportexpinst(PORTEXPINST *pe)
 }
 
 /*
- * routine to add a portproto to a facet.  The port proto is in facet "np".
+ * routine to add a portproto to a cell.  The port proto is in cell "np".
  * The location of the portproto is based on a sub-nodeinst and portproto on
  * that sub-nodeinst: the subnodeinst is "nodeinst" and the subportproto is
  * portproto "portaddress".  The name of the portproto is in "name".  The
@@ -1359,7 +1360,7 @@ PORTPROTO *newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portaddres
 	if (np == NONODEPROTO)
 	{
 		db_donextchangequietly = FALSE;
-		return((PORTPROTO *)db_error(DBBADFACET|DBNEWPORTPROTO));
+		return((PORTPROTO *)db_error(DBBADCELL|DBNEWPORTPROTO));
 	}
 	if (*name == 0)
 	{
@@ -1402,7 +1403,7 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 	REGISTER PORTPROTO *pp;
 
 	/* allocate a new portproto */
-	pp = allocportproto(np->cell->cluster);
+	pp = allocportproto(np->lib->cluster);
 	if (pp == NOPORTPROTO)
 	{
 		db_donextchangequietly = FALSE;
@@ -1418,7 +1419,7 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 	TDCLEAR(pp->textdescript);
 	defaulttextdescript(pp->textdescript, nodeinst->geom);
 	defaulttextsize(1, pp->textdescript);
-	if (allocstring(&pp->protoname, name, np->cell->cluster))
+	if (allocstring(&pp->protoname, name, np->lib->cluster))
 	{
 		db_donextchangequietly = FALSE;
 		return(NOPORTPROTO);
@@ -1430,8 +1431,8 @@ PORTPROTO *db_newportproto(NODEPROTO *np, NODEINST *nodeinst, PORTPROTO *portadd
 	/* handle change control, constraint, and broadcast */
 	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
-		/* set the change facet environment */
-		db_setchangefacet(np);
+		/* set the change cell environment */
+		db_setchangecell(np);
 
 		/* announce it */
 		pp->changeaddr = (CHAR *)db_change((INTBIG)pp, PORTPROTONEW, 0, 0, 0, 0, 0, 0);
@@ -1448,62 +1449,62 @@ void db_enterportproto(PORTPROTO *pp)
 {
 	REGISTER INTBIG i, j;
 	REGISTER PORTPROTO *p, *last;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER PORTEXPINST *pe;
 
-	facet = pp->parent;
-	for(last = NOPORTPROTO, p = facet->firstportproto; p != NOPORTPROTO; p = p->nextportproto)
+	cell = pp->parent;
+	for(last = NOPORTPROTO, p = cell->firstportproto; p != NOPORTPROTO; p = p->nextportproto)
 		last = p;
-	if (last == NOPORTPROTO) facet->firstportproto = pp; else
+	if (last == NOPORTPROTO) cell->firstportproto = pp; else
 		last->nextportproto = pp;
 	pp->nextportproto = NOPORTPROTO;
 
 	/* load up this portexpinst description */
-	pe = allocportexpinst(facet->cell->cluster);
+	pe = allocportexpinst(cell->lib->cluster);
 	pe->proto = pp->subportproto;
 	db_addportexpinst(pp->subnodeinst, pe);
 	pe->exportproto = pp;
 	pp->subportexpinst = pe;
 
 	/* insert into hash table of portproto names */
-	facet->numportprotos++;
-	if (facet->numportprotos < facet->portprotohashtablesize/2)
+	cell->numportprotos++;
+	if (cell->numportprotos < cell->portprotohashtablesize/2)
 	{
-		i = db_namehash(pp->protoname) % facet->portprotohashtablesize;
-		for(j=1; j<=facet->portprotohashtablesize; j += 2)
+		i = db_namehash(pp->protoname) % cell->portprotohashtablesize;
+		for(j=1; j<=cell->portprotohashtablesize; j += 2)
 		{
-			if (facet->portprotohashtable[i] == NOPORTPROTO)
+			if (cell->portprotohashtable[i] == NOPORTPROTO)
 			{
-				facet->portprotohashtable[i] = pp;
+				cell->portprotohashtable[i] = pp;
 				break;
 			}
 			i += j;
-			if (i >= facet->portprotohashtablesize) i -= facet->portprotohashtablesize;
+			if (i >= cell->portprotohashtablesize) i -= cell->portprotohashtablesize;
 		}
 	} else
 	{
-		db_buildportprotohashtable(facet);
+		db_buildportprotohashtable(cell);
 	}
 
 	/* special case: if port is on node that changes size with connectivity, update its geometry */
 	if ((pp->subnodeinst->proto->userbits&WIPEON1OR2) != 0)
-		updategeom(pp->subnodeinst->geom, facet);
+		updategeom(pp->subnodeinst->geom, cell);
 
 	/* clear cache of port associations in this cell */
-	db_clearportcache(facet);
+	db_clearportcache(cell);
 
 	/* mark a change to the database */
 	db_changetimestamp++;
 }
 
-void db_clearportcache(NODEPROTO *facet)
+void db_clearportcache(NODEPROTO *cell)
 {
 	REGISTER NODEPROTO *np, *onp;
 
-	for(np = facet->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
+	FOR_CELLGROUP(np, cell)
 	{
 		for(onp = np; onp != NONODEPROTO; onp = onp->prevversion)
-			onp->cachedequivfacet = NONODEPROTO;
+			onp->cachedequivcell = NONODEPROTO;
 	}
 }
 
@@ -1556,7 +1557,7 @@ PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, CHAR *name)
 	/* name must not have blank space in it */
 	for(ptr = name; *ptr != 0; ptr++) if (*ptr <= ' ' || *ptr >= 0177)
 	{
-		ttyputmsg(_("Port '%s' on primitive '%s' has bad name (spaces?)"), name, np->primname);
+		ttyputmsg(_("Port '%s' on primitive '%s' has bad name (spaces?)"), name, np->protoname);
 		return(NOPORTPROTO);
 	}
 
@@ -1588,8 +1589,8 @@ PORTPROTO *db_newprimportproto(NODEPROTO *np, ARCPROTO **arcs, CHAR *name)
  * routine to delete portproto "pp" from nodeproto "np".  Returns FALSE if
  * successful, TRUE if the portproto could not be deleted (does not
  * exist).  If the portproto has arcs connected to it in instances of the
- * facet, the arcs are deleted.  If the portproto is an export of
- * the facet, those exports are deleted (recursively).
+ * cell, the arcs are deleted.  If the portproto is an export of
+ * the cell, those exports are deleted (recursively).
  */
 BOOLEAN killportproto(NODEPROTO *np, PORTPROTO *pp)
 {
@@ -1599,7 +1600,7 @@ BOOLEAN killportproto(NODEPROTO *np, PORTPROTO *pp)
 	if (np == NONODEPROTO)
 	{
 		db_donextchangequietly = FALSE;
-		return(db_error(DBBADFACET|DBKILLPORTPROTO) != 0);
+		return(db_error(DBBADCELL|DBKILLPORTPROTO) != 0);
 	}
 	for(spt = np->firstportproto; spt != NOPORTPROTO; spt = spt->nextportproto)
 		if (spt == pp) break;
@@ -1659,8 +1660,8 @@ void db_killportproto(PORTPROTO *pp)
 	/* handle change control, constraint, and broadcast */
 	if (!db_donextchangequietly && !db_dochangesquietly)
 	{
-		/* set the change facet environment */
-		db_setchangefacet(np);
+		/* set the change cell environment */
+		db_setchangecell(np);
 
 		/* report the change */
 		pp->changeaddr = (CHAR *)db_change((INTBIG)pp, PORTPROTOKILL, 0, 0, 0, 0, 0, 0);
@@ -1739,45 +1740,45 @@ void db_removeportexpinst(PORTPROTO *pp)
 /*
  * Routine to rebuild the hash table of cell names in library "lib".
  */
-void db_buildportprotohashtable(NODEPROTO *facet)
+void db_buildportprotohashtable(NODEPROTO *cell)
 {
 	REGISTER INTBIG i, j, numportprotos, hashtablesize;
 	REGISTER PORTPROTO *pp;
 
 	/* free the former table */
-	if (facet->portprotohashtablesize > 0)
+	if (cell->portprotohashtablesize > 0)
 	{
-		facet->portprotohashtablesize = 0;
-		efree((CHAR *)facet->portprotohashtable);
+		cell->portprotohashtablesize = 0;
+		efree((CHAR *)cell->portprotohashtable);
 	}
 
 	/* determine the size of the hash table */
 	numportprotos = 0;
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto) numportprotos++;
-	if (numportprotos != facet->numportprotos)
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto) numportprotos++;
+	if (numportprotos != cell->numportprotos)
 	{
-		ttyputmsg(_("Warning: number of ports in facet %s corrected"), describenodeproto(facet));
-		facet->numportprotos = numportprotos;
+		ttyputmsg(_("Warning: number of ports in cell %s corrected"), describenodeproto(cell));
+		cell->numportprotos = numportprotos;
 	}
 	hashtablesize = pickprime(numportprotos * 4);
 
 	/* create the hash table and clear it */
-	facet->portprotohashtable = (PORTPROTO **)emalloc(hashtablesize * (sizeof (PORTPROTO *)),
-		facet->cell->cluster);
-	if (facet->portprotohashtable == 0) return;
+	cell->portprotohashtable = (PORTPROTO **)emalloc(hashtablesize * (sizeof (PORTPROTO *)),
+		cell->lib->cluster);
+	if (cell->portprotohashtable == 0) return;
 	for(i=0; i<hashtablesize; i++)
-		facet->portprotohashtable[i] = NOPORTPROTO;
-	facet->portprotohashtablesize = hashtablesize;
+		cell->portprotohashtable[i] = NOPORTPROTO;
+	cell->portprotohashtablesize = hashtablesize;
 
 	/* insert all cells into the table */
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		i = db_namehash(pp->protoname) % hashtablesize;
 		for(j=1; j<=hashtablesize; j += 2)
 		{
-			if (facet->portprotohashtable[i] == NOPORTPROTO)
+			if (cell->portprotohashtable[i] == NOPORTPROTO)
 			{
-				facet->portprotohashtable[i] = pp;
+				cell->portprotohashtable[i] = pp;
 				break;
 			}
 			i += j;
