@@ -56,14 +56,14 @@ static CHAR *db_errortype[] =
 	N_("bad end A position"),					/* DBBADENDAP */
 	N_("bad end B position"),					/* DBBADENDBP */
 	N_("bad new width"),						/* DBBADNEWWID */
-	N_("bad facet"),							/* DBBADFACET */
+	N_("bad cell"), 							/* DBBADCELL */
 	N_("bad library"),							/* DBBADLIB */
 	N_("bad size"),								/* DBBADSIZE */
 	N_("bad object type"),						/* DBBADOBJECT */
 	N_("bad sub port"),							/* DBBADSUBPORT */
 	N_("still has arcs"),						/* DBHASARCS */
 	N_("still has ports"),						/* DBHASPORTS */
-	N_("facet has instances"),					/* DBHASINSTANCES */
+	N_("cell has instances"),					/* DBHASINSTANCES */
 	N_("recursive call"),						/* DBRECURSIVE */
 	N_("arc not in port"),						/* DBNOTINPORT */
 	N_("conflicts with primitive"),				/* DBCONFLICT */
@@ -88,52 +88,51 @@ static CHAR *db_routines[] =
 	x_("addtechnology"),		/*  2 */
 	x_("addtoinfstr"),			/*  3 */
 	x_("allocarcinst"),			/*  4 */
-	x_("alloccell"),			/*  5 */
-	x_("allocgeom"),			/*  6 */
-	x_("alloclibrary"),			/*  7 */
-	x_("allocnodeinst"),		/*  8 */
-	x_("allocnodeproto"),		/*  9 */
-	x_("allocpolygon"),			/* 10 */
-	x_("allocportarcinst"),		/* 11 */
-	x_("allocportexpinst"),		/* 12 */
-	x_("allocportproto"),		/* 13 */
-	x_("allocstring"),			/* 14 */
-	x_("alloctechnology"),		/* 15 */
-	x_("allocview"),			/* 16 */
-	x_("copynodeproto"),		/* 17 */
-	x_("delind"),				/* 18 */
-	x_("delindkey"),			/* 19 */
-	x_("delvalkey"),			/* 20 */
-	x_("describevariable"),		/* 21 */
-	x_("extendpolygon"),		/* 22 */
-	x_("initinfstr"),			/* 23 */
-	x_("initobjlist"),			/* 24 */
-	x_("insind"),				/* 25 */
-	x_("insindkey"),			/* 26 */
-	x_("killarcinst"),			/* 27 */
-	x_("killlibrary"),			/* 28 */
-	x_("killnodeinst"),			/* 29 */
-	x_("killnodeproto"),		/* 30 */
-	x_("killportproto"),		/* 31 */
-	x_("killtechnology"),		/* 32 */
-	x_("makekey"),				/* 33 */
-	x_("modifyarcinst"),		/* 34 */
-	x_("moveportproto"),		/* 35 */
-	x_("newarcinst"),			/* 36 */
-	x_("newlibrary"),			/* 37 */
-	x_("newnodeinst"),			/* 38 */
-	x_("newnodeproto"),			/* 39 */
-	x_("newportproto"),			/* 40 */
-	x_("newview"),				/* 41 */
-	x_("replacearcinst"),		/* 42 */
-	x_("replacenodeinst"),		/* 43 */
-	x_("returninfstr"),			/* 44 */
-	x_("setind"),				/* 45 */
-	x_("setindkey"),			/* 46 */
-	x_("setval"),				/* 47 */
-	x_("setvalkey"),			/* 48 */
-	x_("transmult"),			/* 49 */
-	x_("xform"),				/* 50 */
+	x_("allocgeom"),			/*  5 */
+	x_("alloclibrary"),			/*  6 */
+	x_("allocnodeinst"),		/*  7 */
+	x_("allocnodeproto"),		/*  8 */
+	x_("allocpolygon"),			/*  9 */
+	x_("allocportarcinst"),		/* 10 */
+	x_("allocportexpinst"),		/* 11 */
+	x_("allocportproto"),		/* 12 */
+	x_("allocstring"),			/* 13 */
+	x_("alloctechnology"),		/* 14 */
+	x_("allocview"),			/* 15 */
+	x_("copynodeproto"),		/* 16 */
+	x_("delind"),				/* 17 */
+	x_("delindkey"),			/* 18 */
+	x_("delvalkey"),			/* 19 */
+	x_("describevariable"),		/* 20 */
+	x_("extendpolygon"),		/* 21 */
+	x_("initinfstr"),			/* 22 */
+	x_("initobjlist"),			/* 23 */
+	x_("insind"),				/* 24 */
+	x_("insindkey"),			/* 25 */
+	x_("killarcinst"),			/* 26 */
+	x_("killlibrary"),			/* 27 */
+	x_("killnodeinst"),			/* 28 */
+	x_("killnodeproto"),		/* 29 */
+	x_("killportproto"),		/* 30 */
+	x_("killtechnology"),		/* 31 */
+	x_("makekey"),				/* 32 */
+	x_("modifyarcinst"),		/* 33 */
+	x_("moveportproto"),		/* 34 */
+	x_("newarcinst"),			/* 35 */
+	x_("newlibrary"),			/* 36 */
+	x_("newnodeinst"),			/* 37 */
+	x_("newnodeproto"),			/* 38 */
+	x_("newportproto"),			/* 39 */
+	x_("newview"),				/* 40 */
+	x_("replacearcinst"),		/* 41 */
+	x_("replacenodeinst"),		/* 42 */
+	x_("returninfstr"),			/* 43 */
+	x_("setind"),				/* 44 */
+	x_("setindkey"),			/* 45 */
+	x_("setval"),				/* 46 */
+	x_("setvalkey"),			/* 47 */
+	x_("transmult"),			/* 48 */
+	x_("xform"),				/* 49 */
 };
 
 /*
@@ -164,7 +163,7 @@ void telldatabaseerror(void)
 /*
  * These are the routines to log errors:
  *   initerrorlogging(CHAR *s)                   initialize for subsystem "s"
- *   e = logerror(CHAR *msg, NODEPROTO *f, k)    log message "msg" in facet "f", sort key "k"
+ *   e = logerror(CHAR *msg, NODEPROTO *f, k)    log message "msg" in cell "f", sort key "k"
  *   addgeomtoerror(void *e, GEOM *g, BOOLEAN s, INTBIG l, NODEINST **p)
  *                                               add geom "g" to error "e" (show if "s" nonzero)
  *   addexporttoerror(void *e, PORTPROTO *p, BOOLEAN s)  add export "pp" to error "e"
@@ -212,7 +211,7 @@ typedef struct
 typedef struct iErrorList
 {
 	CHAR              *message;
-	NODEPROTO         *facet;
+	NODEPROTO         *cell;
 	INTBIG             sortkey;
 	INTBIG             index;
 	INTBIG             numhighlights;
@@ -239,7 +238,7 @@ static int     db_errorlistascending(const void *e1, const void *e2);
 static CHAR   *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2);
 static void    db_clearerrorlist(void);
 #ifdef	NEWERRORS
-static BOOLEAN db_validatefacet(NODEPROTO *facet);
+static BOOLEAN db_validatecell(NODEPROTO *cell);
 #endif
 
 /*
@@ -263,8 +262,8 @@ void db_freeerrormemory(void)
 
 /*
  * Routine to free all previously stored errors and initialize the system.
- * The errors are described by "system" and up to two facets "facet1" and
- * "facet2" (may be NONODEPROTO).
+ * The errors are described by "system" and up to two cells "cell1" and
+ * "cell2" (may be NONODEPROTO).
  */
 void initerrorlogging(CHAR *system)
 {
@@ -320,10 +319,10 @@ void db_clearerrorlist(void)
 }
 
 /*
- * Routine to create an error message with the text "message" applying to facet "facet".
+ * Routine to create an error message with the text "message" applying to cell "cell".
  * Returns a pointer to the message (0 on error) which can be used to add highlights.
  */
-void *logerror(CHAR *message, NODEPROTO *facet, INTBIG sortkey)
+void *logerror(CHAR *message, NODEPROTO *cell, INTBIG sortkey)
 {
 	REGISTER ERRORLIST *el;
 
@@ -356,7 +355,7 @@ void *logerror(CHAR *message, NODEPROTO *facet, INTBIG sortkey)
 
 	/* store information about the error */
 	if (allocstring(&el->message, message, db_cluster)) return(0);
-	el->facet = facet;
+	el->cell = cell;
 	el->sortkey = sortkey;
 	el->numhighlights = 0;
 
@@ -549,74 +548,6 @@ void sorterrors(void)
 	efree((CHAR *)sortedlist);
 }
 
-#if 0		/* cannot save errors to file yet */
-static void    db_describenodetoerrorfile(FILE *io, NODEINST *ni);
-
-/*
- * Routine to save the current errors to disk.
- */
-void saveerrors(void)
-{
-	REGISTER ERRORLIST *el;
-	REGISTER ERRORHIGHLIGHT *eh;
-	FILE *io;
-
-	io = efopen(x_("errors.txt"), x_("w"));
-	if (io == 0) return;
-	for(el = db_firsterrorlist; el != NOERRORLIST; el = el->nexterrorlist)
-	{
-		efprintf(io, x_("ERROR %ld %s %s\n"), el->numhighlights, describenodeproto(el->facet), el->message);
-		for(i=0; i<el->numhighlights; i++)
-		{
-			eh = el->highlights[i];
-			switch (eh->type)
-			{
-				case ERRORTYPEGEOM:
-					efprintf(io, x_("  GEOM"));
-					if (eh->geom->entryisnode)
-					{
-						efprintf(io, x_(" NODE"));
-						ni = eh->geom->entryaddr.ni;
-						db_describenodetoerrorfile(io, ni);
-					} else
-					{
-						ai = eh->geom->entryaddr.ai;
-						var = getvalkey((INTBIG)ai, VARCINST, -1, el_arc_name_key);
-						if (var != NOVARIABLE) efprintf(io, x_("ARC NAME %s"), (CHAR *)var->addr); else
-						{
-							efprintf(io, x_("ARC TYPE %s WIDTH %s AT %s %s %s %s"), ai->proto->protoname,
-								ai->width, ai->end[0].xpos, ai->end[0].ypos, ai->end[1].xpos,
-									ai->end[1].ypos);
-						}
-					}
-					if (eh->showgeom) efprintf(io, x_(" SHOW")); else efprintf(io, x_(" NOSHOW"));
-					efprintf(io, x_(" PATH %ld"), eh->pathlen);
-					for(j=0; j<eh->pathlen; j++)
-					{
-						ni = el->path[j];
-						efprintf(io, x_(" %s"), describenodeproto(ni->parent));
-						db_describenodetoerrorfile(io, ni);
-					}
-					efprintf(io, x_("\n"));
-					break;
-			}
-		}
-	}
-}
-
-void db_describenodetoerrorfile(FILE *io, NODEINST *ni)
-{
-	REGISTER VARIABLE *var;
-
-	var = getvalkey((INTBIG)ni, VNODEINST, -1, el_node_name_key);
-	if (var != NOVARIABLE) efprintf(io, x_(" NAME %s"), (CHAR *)var->addr); else
-	{
-		efprintf(io, x_(" TYPE %s AT %ld %ld %ld %ld"), describenodeproto(ni->proto),
-			ni->lowx, ni->highx, ni->lowy, ni->highy);
-	}
-}
-#endif
-
 /*
  * Routine to return the number of logged errors.
  */
@@ -754,7 +685,7 @@ CHAR *describeerrorgeom(void *ehv)
 	for(i=0; i<eh->pathlen; i++)
 	{
 		ni = eh->path[i];
-		formatinfstr(infstr, _(" in %s:%s:%s"), ni->parent->cell->lib->libname,
+		formatinfstr(infstr, _(" in %s:%s:%s"), ni->parent->lib->libname,
 			nldescribenodeproto(ni->parent), describenodeinst(ni));
 	}
 	return(returninfstr(infstr));
@@ -782,13 +713,13 @@ void showerrorgeom(void *ehv)
 	{
 		el_curwindowpart = us_wantnewwindow(0);
 		us_fullview(np, &lx, &hx, &ly, &hy);
-		us_switchtofacet(np, lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, FALSE, FALSE);
+		us_switchtocell(np, lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, FALSE, FALSE);
 	}
 	(void)asktool(us_tool, x_("show-object"), (INTBIG)geom);
 
 	for(i=eh->pathlen-1; i>=0; i--)
 	{
-		sethierarchicalparent(np, eh->path[i], NOWINDOWPART, 0);
+		sethierarchicalparent(np, eh->path[i], NOWINDOWPART, 0, 0);
 		np = eh->path[i]->parent;
 	}
 }
@@ -869,15 +800,15 @@ int db_errorlistascending(const void *e1, const void *e2)
  * Highlights associated graphics if "showhigh" is nonzero.  Fills "g1" and "g2"
  * with associated geometry modules (if nonzero).
  */
-#define MAXFACETS 20
+#define MAXCELLS 20
 
 CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 {
 	REGISTER ERRORLIST *el;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER PORTPROTO *pp;
-	NODEPROTO *facetlist[MAXFACETS];
-	REGISTER INTBIG i, j, consize, numfacets, havegeoms, newwindows, count, hierpathcount;
+	NODEPROTO *celllist[MAXCELLS];
+	REGISTER INTBIG i, j, consize, numcells, havegeoms, newwindows, count, hierpathcount;
 	REGISTER NODEINST **hierpath, *ni;
 	REGISTER ARCINST *ai;
 	INTBIG lx, hx, ly, hy;
@@ -900,15 +831,15 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 	{
 		(void)asktool(us_tool, x_("clear"));
 
-		/* validate the facet (it may have been deleted) */
-		facet = el->facet;
+		/* validate the cell (it may have been deleted) */
+		cell = el->cell;
 #ifdef	NEWERRORS
-		if (facet != NONODEPROTO)
+		if (cell != NONODEPROTO)
 		{
-			if (!db_validatefacet(facet))
+			if (!db_validatecell(cell))
 			{
 				infstr = initinfstr();
-				formatinfstr(infstr, _("%s error %ld of %ld (but facet is deleted): %s"), db_errorsystem,
+				formatinfstr(infstr, _("%s error %ld of %ld (but cell is deleted): %s"), db_errorsystem,
 					el->index, db_numerrors, el->message);
 				return(returninfstr(infstr));
 			}
@@ -920,60 +851,60 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			{
 				for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-					if (np == facet) break;
+					if (np == cell) break;
 				if (np != NONODEPROTO) break;
 			}
 			if (lib == NOLIBRARY)
 			{
 				infstr = initinfstr();
-				formatinfstr(infstr, _("%s error %ld of %ld (but facet is deleted): %s"), db_errorsystem,
+				formatinfstr(infstr, _("%s error %ld of %ld (but cell is deleted): %s"), db_errorsystem,
 					el->index, db_numerrors, el->message);
 				return(returninfstr(infstr));
 			}
 		}
 #endif
 
-		/* first figure out which facets need to be displayed */
-		numfacets = 0;
+		/* first figure out which cells need to be displayed */
+		numcells = 0;
 		for(i=0; i<el->numhighlights; i++)
 		{
 			eh = el->highlights[i];
 			hierpathcount = 0;
-			facet = el->facet;
+			cell = el->cell;
 #ifdef	NEWERRORS
-			if (eh->showgeom && eh->type == ERRORTYPEGEOM && facet == NONODEPROTO)
+			if (eh->showgeom && eh->type == ERRORTYPEGEOM && cell == NONODEPROTO)
 			{
-				facet = geomparent(eh->geom);
-				if (facet != NONODEPROTO && !db_validatefacet(facet))
-					facet = NONODEPROTO;
+				cell = geomparent(eh->geom);
+				if (cell != NONODEPROTO && !db_validatecell(cell))
+					cell = NONODEPROTO;
 			}
 #endif
 			switch (eh->type)
 			{
 				case ERRORTYPEGEOM:
-					if (!eh->showgeom) facet = NONODEPROTO; else
+					if (!eh->showgeom) cell = NONODEPROTO; else
 #ifdef	NEWERRORS
-						if (facet != NONODEPROTO)
+						if (cell != NONODEPROTO)
 #endif
 					{
 						/* validate the geometry */
-						for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+						for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 							if (ai->geom == eh->geom) break;
 						if (ai == NOARCINST)
 						{
-							for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+							for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 								if (ni->geom == eh->geom) break;
 							if (ni == NONODEINST)
 							{
 								/* geometry pointer is not valid */
 								eh->showgeom = FALSE;
-								facet = NONODEPROTO;
+								cell = NONODEPROTO;
 							}
 						}
 					}
 					if (eh->showgeom)
 					{
-						facet = geomparent(eh->geom);
+						cell = geomparent(eh->geom);
 						if (eh->pathlen > 0)
 						{
 							hierpathcount = eh->pathlen;
@@ -982,45 +913,46 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 					}
 					break;
 				case ERRORTYPEEXPORT:
-					if (!eh->showgeom) facet = NONODEPROTO; else
+					if (!eh->showgeom) cell = NONODEPROTO; else
 #ifdef	NEWERRORS
-						if (facet != NONODEPROTO)
+						if (cell != NONODEPROTO)
 #endif
 					{
 						/* validate the export */
-						for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+						for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 							if (pp == eh->pp) break;
 						if (pp == NOPORTPROTO)
 						{
 							eh->showgeom = FALSE;
-							facet = NONODEPROTO;
-						} else facet = eh->pp->parent;
+							cell = NONODEPROTO;
+						} else cell = eh->pp->parent;
 					}
 					break;
 				case ERRORTYPELINE:
 				case ERRORTYPEPOINT:
 					break;
 			}
-			if (facet == NONODEPROTO) continue;
-			for(j=0; j<numfacets; j++)
-				if (facetlist[j] == facet) break;
-			if (j < numfacets) continue;
-			if (numfacets >= MAXFACETS) break;
-			facetlist[numfacets] = facet;
-			numfacets++;
+			if (cell == NONODEPROTO) continue;
+			for(j=0; j<numcells; j++)
+				if (celllist[j] == cell) break;
+			if (j < numcells) continue;
+			if (numcells >= MAXCELLS) break;
+			celllist[numcells] = cell;
+			numcells++;
 		}
 
-		/* be sure that all requested facets are shown */
+		/* be sure that all requested cells are shown */
 		newwindows = 0;
-		for(i=0; i<numfacets; i++)
+		for(i=0; i<numcells; i++)
 		{
-			/* see if the facet is already being displayed */
+			/* see if the cell is already being displayed */
 			for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
-				if (w->curnodeproto == facetlist[i]) break;
+				if (w->curnodeproto == celllist[i]) break;
 			if (w != NOWINDOWPART)
 			{
-				/* already displayed: mark this facet done */
-				facetlist[i] = NONODEPROTO;
+				/* already displayed: mark this cell done */
+				bringwindowtofront(w->frame);
+				celllist[i] = NONODEPROTO;
 				continue;
 			}
 
@@ -1050,13 +982,13 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 				newwindows--;
 			}
 			count = 0;
-			for(i=0; i<numfacets; i++)
+			for(i=0; i<numcells; i++)
 			{
-				if (facetlist[i] == NONODEPROTO) continue;
+				if (celllist[i] == NONODEPROTO) continue;
 				el_curwindowpart = neww[count++];
-				us_fullview(facetlist[i], &lx, &hx, &ly, &hy);
-				us_switchtofacet(facetlist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, FALSE, FALSE);
-				facetlist[i] = NONODEPROTO;
+				us_fullview(celllist[i], &lx, &hx, &ly, &hy);
+				us_switchtocell(celllist[i], lx, hx, ly, hy, NONODEINST, NOPORTPROTO, FALSE, FALSE, FALSE);
+				celllist[i] = NONODEPROTO;
 				if (count >= 4) break;
 			}
 		}
@@ -1079,14 +1011,14 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 				if (havegeoms == 0) infstr = initinfstr(); else
 					addtoinfstr(infstr, '\n');
 				havegeoms++;
-				formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
+				formatinfstr(infstr, x_("CELL=%s FROM=0%lo;-1;0"),
 					describenodeproto(geomparent(eh->geom)), (INTBIG)eh->geom);
 				break;
 			case ERRORTYPEEXPORT:
 				if (havegeoms == 0) infstr = initinfstr(); else
 					addtoinfstr(infstr, '\n');
 				havegeoms++;
-				formatinfstr(infstr, x_("FACET=%s TEXT=0%lo;0%lo;-"),
+				formatinfstr(infstr, x_("CELL=%s TEXT=0%lo;0%lo;-"),
 					describenodeproto(eh->pp->parent), (INTBIG)eh->pp->subnodeinst->geom,
 						(INTBIG)eh->pp);
 				break;
@@ -1098,15 +1030,15 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 		/* set the hierarchical path */
 		if (eh->type == ERRORTYPEGEOM && eh->showgeom && eh->pathlen > 0)
 		{
-			facet = geomparent(eh->geom);
+			cell = geomparent(eh->geom);
 			for(w=el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
-				if (w->curnodeproto == facet) break;
+				if (w->curnodeproto == cell) break;
 			if (w != NOWINDOWPART)
 			{
 				for(j=eh->pathlen-1; j>=0; j--)
 				{
-					sethierarchicalparent(facet, eh->path[j], w, 0);
-					facet = eh->path[j]->parent;
+					sethierarchicalparent(cell, eh->path[j], w, 0, 0);
+					cell = eh->path[j]->parent;
 				}
 			}
 		}
@@ -1124,16 +1056,16 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 			case ERRORTYPELINE:
 				if (showhigh != 0)
 					(void)asktool(us_tool, x_("show-line"), eh->x1, eh->y1, eh->x2, eh->y2,
-						el->facet);
+						el->cell);
 				break;
 			case ERRORTYPEPOINT:
 				if (showhigh != 0)
 				{
-					consize = lambdaoffacet(el->facet) * 5;
+					consize = lambdaofcell(el->cell) * 5;
 					(void)asktool(us_tool, x_("show-line"), eh->x1-consize, eh->y1-consize,
-						eh->x1+consize, eh->y1+consize, el->facet);
+						eh->x1+consize, eh->y1+consize, el->cell);
 					(void)asktool(us_tool, x_("show-line"), eh->x1-consize, eh->y1+consize,
-						eh->x1+consize, eh->y1-consize, el->facet);
+						eh->x1+consize, eh->y1-consize, el->cell);
 				}
 				break;
 			case ERRORTYPEGEOM:
@@ -1154,7 +1086,7 @@ CHAR *db_reportcurrenterror(INTBIG showhigh, GEOM **g1, GEOM **g2)
 }
 
 #ifdef NEWERRORS
-BOOLEAN db_validatefacet(NODEPROTO *facet)
+BOOLEAN db_validatecell(NODEPROTO *cell)
 {
 	REGISTER LIBRARY *lib;
 	REGISTER NODEPROTO *np;
@@ -1162,7 +1094,7 @@ BOOLEAN db_validatefacet(NODEPROTO *facet)
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			if (np == facet) return(TRUE);
+			if (np == cell) return(TRUE);
 	}
 	return(FALSE);
 }
