@@ -195,14 +195,14 @@ void db_freersearch(RSEARCH *rs)
 /*********************** CREATING A NEW R-TREE ***********************/
 
 /*
- * routine to build geometry module structure in facet "np".
+ * routine to build geometry module structure in cell "np".
  * returns true upon error.
  */
 BOOLEAN geomstructure(NODEPROTO *np)
 {
 	REGISTER RTNODE *top;
 
-	top = allocrtnode(np->cell->cluster);
+	top = allocrtnode(np->lib->cluster);
 	if (top == NORTNODE) return(TRUE);
 	top->lowx = top->highx = top->lowy = top->highy = 0;
 	top->total = 0;
@@ -289,7 +289,7 @@ void linkgeom(GEOM *geom, NODEPROTO *parnt)
 			if (geom->highy > hyv) hyv = geom->highy;
 			if (geom->lowy < lyv) lyv = geom->lowy;
 #ifdef	USEFLOATS
-			newarea = hxv - lxv;   area *= hyv - lyv;
+			newarea = hxv - lxv;   newarea *= hyv - lyv;
 #else
 			newarea = ((hxv - lxv) / scaledown) * ((hyv - lyv) / scaledown);
 #endif
@@ -315,7 +315,7 @@ void linkgeom(GEOM *geom, NODEPROTO *parnt)
  * routine to add "object" to R-tree node "rtn".  Routine may have to
  * split the node and recurse up the tree
  */
-BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
+BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *cell)
 {
 	RTNODE temp;
 	REGISTER INTBIG i, oldcount, oldn, newn, bestoldnode, bestnewnode;
@@ -379,7 +379,7 @@ BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 		}
 
 		/* allocate a new R-tree node and put in first seed element */
-		newrtn = allocrtnode(facet->cell->cluster);
+		newrtn = allocrtnode(cell->lib->cluster);
 		if (newrtn == NORTNODE) return(TRUE);
 		newrtn->flag = rtn->flag;
 		newrtn->parent = rtn->parent;
@@ -527,7 +527,7 @@ BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 		if (rtn->parent == NORTNODE)
 		{
 			/* at top of tree: create a new level */
-			newroot = allocrtnode(facet->cell->cluster);
+			newroot = allocrtnode(cell->lib->cluster);
 			if (newroot == 0) return(TRUE);
 			newroot->total = 2;
 			newroot->pointers[0] = (UINTBIG)rtn;
@@ -539,14 +539,14 @@ BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 			newroot->highx = mmaxi(rtn->highx, newrtn->highx);
 			newroot->lowy = mmini(rtn->lowy, newrtn->lowy);
 			newroot->highy = mmaxi(rtn->highy, newrtn->highy);
-			facet->rtree = newroot;
+			cell->rtree = newroot;
 		} else
 		{
 			/* first recompute bounding box of R-tree nodes up the tree */
 			for(r = rtn->parent; r != NORTNODE; r = r->parent) db_figbounds(r);
 
 			/* now add the new node up the tree */
-			if (db_addtortnode((UINTBIG)newrtn, rtn->parent, facet)) return(TRUE);
+			if (db_addtortnode((UINTBIG)newrtn, rtn->parent, cell)) return(TRUE);
 		}
 	}
 
@@ -555,7 +555,7 @@ BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 	db_rtnbbox(rtn, rtn->total, &lxv, &hxv, &lyv, &hyv);
 	rtn->total++;
 
-	/* special case when adding the first node in a facet */
+	/* special case when adding the first node in a cell */
 	if (rtn->total == 1 && rtn->parent == NORTNODE)
 	{
 		rtn->lowx = lxv;
@@ -581,7 +581,7 @@ BOOLEAN db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 /*********************** DELETING FROM AN R-TREE ***********************/
 
 /*
- * routine to remove geometry module "geom" from the R-tree in facet "parnt"
+ * routine to remove geometry module "geom" from the R-tree in cell "parnt"
  */
 void undogeom(GEOM *geom, NODEPROTO *parnt)
 {
@@ -606,9 +606,9 @@ void undogeom(GEOM *geom, NODEPROTO *parnt)
 }
 
 /*
- * routine to remove entry "ind" from R-tree node "rtn" in facet "facet"
+ * routine to remove entry "ind" from R-tree node "rtn" in cell "cell"
  */
-void db_removertnode(RTNODE *rtn, INTBIG ind, NODEPROTO *facet)
+void db_removertnode(RTNODE *rtn, INTBIG ind, NODEPROTO *cell)
 {
 	REGISTER RTNODE *prtn;
 	RTNODE temp;
@@ -644,7 +644,7 @@ void db_removertnode(RTNODE *rtn, INTBIG ind, NODEPROTO *facet)
 			rtn->flag = 1;
 
 			/* reinsert all data */
-			for(i=0; i<t; i++) db_reinsert((RTNODE *)temp.pointers[i], facet);
+			for(i=0; i<t; i++) db_reinsert((RTNODE *)temp.pointers[i], cell);
 			return;
 		}
 
@@ -654,10 +654,10 @@ void db_removertnode(RTNODE *rtn, INTBIG ind, NODEPROTO *facet)
 		if (i >= prtn->total) ttyputerr(_("R-trees: cannot find entry in parent"));
 
 		/* remove this entry from its parent */
-		db_removertnode(prtn, i, facet);
+		db_removertnode(prtn, i, cell);
 
 		/* reinsert the entries */
-		db_reinsert(rtn, facet);
+		db_reinsert(rtn, cell);
 		return;
 	}
 
@@ -671,19 +671,19 @@ void db_removertnode(RTNODE *rtn, INTBIG ind, NODEPROTO *facet)
 }
 
 /*
- * routine to reinsert the tree of nodes below "rtn" into facet "facet".
+ * routine to reinsert the tree of nodes below "rtn" into cell "cell".
  */
-void db_reinsert(RTNODE *rtn, NODEPROTO *facet)
+void db_reinsert(RTNODE *rtn, NODEPROTO *cell)
 {
 	REGISTER INTBIG i;
 
 	if (rtn->flag != 0)
 	{
-		for(i=0; i<rtn->total; i++) linkgeom((GEOM *)rtn->pointers[i], facet);
+		for(i=0; i<rtn->total; i++) linkgeom((GEOM *)rtn->pointers[i], cell);
 	} else
 	{
 		for(i=0; i<rtn->total; i++)
-			db_reinsert((RTNODE *)rtn->pointers[i], facet);
+			db_reinsert((RTNODE *)rtn->pointers[i], cell);
 	}
 	freertnode(rtn);
 }
@@ -958,7 +958,7 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 			/* special case for polygonally-defined nodes: compute precise geometry */
 			if ((ni->proto->userbits&HOLDSTRACE) != 0)
 			{
-				var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+				var = gettrace(ni);
 				if (var != NOVARIABLE)
 				{
 					poly = allocpolygon(4, db_cluster);
@@ -1083,11 +1083,11 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 }
 
 /*
- * routine to compute the boundary of nodeproto "facet" and fill the
+ * routine to compute the boundary of nodeproto "cell" and fill the
  * reference parameters "lx", "hx", "ly", and "hy" with the minimum
  * bounding rectangle
  */
-void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
+void db_boundcell(NODEPROTO *cell, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -1095,16 +1095,16 @@ void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 	REGISTER BOOLEAN first;
 	REGISTER INTBIG i;
 
-	/* cannot compute bounds if facet has nothing in it */
+	/* cannot compute bounds if cell has nothing in it */
 	*lx = *hx = *ly = *hy = 0;
-	if (facet->firstnodeinst == NONODEINST) return;
+	if (cell->firstnodeinst == NONODEINST) return;
 
-	/* include all nodes in the facet */
+	/* include all nodes in the cell */
 	first = TRUE;
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		/* special case: do not include "facet center" or "essential-bounds" primitives from Generic */
-		if (ni->proto == gen_facetcenterprim || ni->proto == gen_essentialprim) continue;
+		/* special case: do not include "cell center" primitives from Generic */
+		if (ni->proto == gen_cellcenterprim /* || ni->proto == gen_essentialprim */ ) continue;
 
 		/* special case for invisible pins: do not include if inheritable or interior-only */
 		if (ni->proto == gen_invispinprim)
@@ -1134,8 +1134,8 @@ void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 		*hy = mmaxi(*hy, ni->geom->highy);
 	}
 
-	/* include all arcs in the facet */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	/* include all arcs in the cell */
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (first)
 		{
@@ -1157,18 +1157,18 @@ void db_boundfacet(NODEPROTO *facet, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG
 
 /*
  * search routine initialization.  Begin search for objects that are in
- * facet "facet" and fall in the bounding box X from "lx" to "hx" and
+ * cell "cell" and fall in the bounding box X from "lx" to "hx" and
  * Y from "ly" to "hy".  Routine returns value that is passed to
  * "nextobject" calls to run the search.
  */
-INTBIG initsearch(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, NODEPROTO *facet)
+INTBIG initsearch(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, NODEPROTO *cell)
 {
 	REGISTER RSEARCH *rs;
 
 	rs = db_allocrsearch();
 	if (rs == NORSEARCH) return(-1);
 	rs->depth = 0;
-	rs->rtn[0] = facet->rtree;
+	rs->rtn[0] = cell->rtree;
 	rs->position[0] = 0;
 	rs->lx = lx;
 	rs->hx = hx;
