@@ -56,7 +56,6 @@ static int ETechnology_Print(ELKObject, ELKObject, int, int, int);
 static int ETool_Print(ELKObject, ELKObject, int, int, int);
 static int ERTNode_Print(ELKObject, ELKObject, int, int, int);
 static int ENetwork_Print(ELKObject, ELKObject, int, int, int);
-static int ECell_Print(ELKObject, ELKObject, int, int, int);
 static int EView_Print(ELKObject, ELKObject, int, int, int);
 static int EWindow_Print(ELKObject, ELKObject, int, int, int);
 static int EGraphics_Print(ELKObject, ELKObject, int, int, int);
@@ -75,7 +74,6 @@ static ELKObject P_ETechnologyP(ELKObject);
 static ELKObject P_EToolP(ELKObject);
 static ELKObject P_ERTNodeP(ELKObject);
 static ELKObject P_ENetworkP(ELKObject);
-static ELKObject P_ECellP(ELKObject);
 static ELKObject P_EViewP(ELKObject);
 static ELKObject P_EWindowP(ELKObject);
 static ELKObject P_EGraphicsP(ELKObject);
@@ -139,7 +137,6 @@ static ELKObject lsp_newview(ELKObject, ELKObject);
 static ELKObject lsp_killview(ELKObject);
 static ELKObject lsp_telltool(long, ELKObject[]);
 static ELKObject lsp_getarcproto(ELKObject);
-static ELKObject lsp_getcell(ELKObject);
 static ELKObject lsp_gettechnology(ELKObject);
 static ELKObject lsp_getpinproto(ELKObject);
 static ELKObject lsp_getnetwork(ELKObject, ELKObject);
@@ -149,7 +146,7 @@ static ELKObject lsp_getnetwork(ELKObject, ELKObject);
 /* the internal LISP types */
 static long T_ENodeInst, T_ENodeProto, T_EPortArcInst, T_EPortExpInst, T_EPortProto,
 	T_EArcInst, T_EArcProto, T_EGeom, T_ELibrary, T_ETechnology, T_ETool,
-	T_ERTNode, T_ENetwork, T_ECell, T_EView, T_EWindow, T_EGraphics, T_EConstraint,
+	T_ERTNode, T_ENetwork, T_EView, T_EWindow, T_EGraphics, T_EConstraint,
 	T_EWindowFrame;
 
 /* the LISP structures */
@@ -167,7 +164,6 @@ struct S_ETechnology  { TECHNOLOGY  *handle; };
 struct S_ETool        { TOOL        *handle; };
 struct S_ERTNode      { RTNODE      *handle; };
 struct S_ENetwork     { NETWORK     *handle; };
-struct S_ECell        { CELL        *handle; };
 struct S_EView        { VIEW        *handle; };
 struct S_EWindow      { WINDOWPART  *handle; };
 struct S_EGraphics    { GRAPHICS    *handle; };
@@ -189,7 +185,6 @@ struct S_EWindowFrame { WINDOWFRAME *handle; };
 #define ETOOL(obj)        ((struct S_ETool *)POINTER(obj))
 #define ERTNODE(obj)      ((struct S_ERTNode *)POINTER(obj))
 #define ENETWORK(obj)     ((struct S_ENetwork *)POINTER(obj))
-#define ECELL(obj)        ((struct S_ECell *)POINTER(obj))
 #define EVIEW(obj)        ((struct S_EView *)POINTER(obj))
 #define EWINDOW(obj)      ((struct S_EWindow *)POINTER(obj))
 #define EGRAPHICS(obj)    ((struct S_EGraphics *)POINTER(obj))
@@ -229,8 +224,6 @@ int ERTNode_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
 { Printf(port, x_("#[r-tree %u]"), ERTNODE(w)->handle);  return(0); }
 int ENetwork_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
 { Printf(port, x_("#[network %u]"), ENETWORK(w)->handle);  return(0); }
-int ECell_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
-{ Printf(port, x_("#[cell %s]"), ECELL(w)->handle->cellname);  return(0); }
 int EView_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
 { Printf(port, x_("#[view %s]"), EVIEW(w)->handle->viewname);  return(0); }
 int EWindow_Print(ELKObject w, ELKObject port, int raw, int depth, int len)
@@ -256,7 +249,6 @@ ELKObject P_ETechnologyP(ELKObject x)  { return(TYPE(x) == T_ETechnology  ? True
 ELKObject P_EToolP(ELKObject x)        { return(TYPE(x) == T_ETool        ? Trueob : Falseob); }
 ELKObject P_ERTNodeP(ELKObject x)      { return(TYPE(x) == T_ERTNode      ? Trueob : Falseob); }
 ELKObject P_ENetworkP(ELKObject x)     { return(TYPE(x) == T_ENetwork     ? Trueob : Falseob); }
-ELKObject P_ECellP(ELKObject x)        { return(TYPE(x) == T_ECell        ? Trueob : Falseob); }
 ELKObject P_EViewP(ELKObject x)        { return(TYPE(x) == T_EView        ? Trueob : Falseob); }
 ELKObject P_EWindowP(ELKObject x)      { return(TYPE(x) == T_EWindow      ? Trueob : Falseob); }
 ELKObject P_EGraphicsP(ELKObject x)    { return(TYPE(x) == T_EGraphics    ? Trueob : Falseob); }
@@ -355,9 +347,6 @@ BOOLEAN lsp_describeobject(ELKObject obj, INTBIG type, INTBIG *retval)
 	INTBIG t;
 	ELKObject strobj;
 	CHAR *str, *p;
-	void Pr_List(ELKObject port, ELKObject list, int raw, int depth, int length);
-	void Pr_Vector(ELKObject port, ELKObject vec, int raw, int depth, int length);
-	int Print_Char(ELKObject port, int c);
 
 	t = TYPE(obj);
 	switch (type&VTYPE)
@@ -731,7 +720,6 @@ void lsp_getaddrandtype(ELKObject oaddr, INTBIG *addr, INTBIG *type)
 	if (otype == T_ETool)        *type = VTOOL; else
 	if (otype == T_ERTNode)      *type = VRTNODE; else
 	if (otype == T_ENetwork)     *type = VNETWORK; else
-	if (otype == T_ECell)        *type = VCELL; else
 	if (otype == T_EView)        *type = VVIEW; else
 	if (otype == T_EWindow)      *type = VWINDOWPART; else
 	if (otype == T_EGraphics)    *type = VGRAPHICS; else
@@ -796,9 +784,6 @@ ELKObject lsp_makevarobject(INTBIG type, INTBIG addr)
 		case VNETWORK:
 			ret = Make_EElectric(addr, T_ENetwork);
 			if (ENETWORK(ret)->handle == NONETWORK) return(Null); else return(ret);
-		case VCELL:
-			ret = Make_EElectric(addr, T_ECell);
-			if (ECELL(ret)->handle == NOCELL) return(Null); else return(ret);
 		case VVIEW:
 			ret = Make_EElectric(addr, T_EView);
 			if (EVIEW(ret)->handle == NOVIEW) return(Null); else return(ret);
@@ -1615,20 +1600,6 @@ ELKObject lsp_getarcproto(ELKObject oname)
 	return(Make_EElectric((INTBIG)ap, T_EArcProto));
 }
 
-ELKObject lsp_getcell(ELKObject oname)
-{
-	CHAR *name;
-	REGISTER CELL *c;
-
-	/* get inputs from LISP */
-	name = lsp_getstringobject(oname);
-	if (name == 0) return(Null);
-
-	c = getcell(name);
-	if (c == NOCELL) return(Null);
-	return(Make_EElectric((INTBIG)c, T_ECell));
-}
-
 ELKObject lsp_gettechnology(ELKObject oname)
 {
 	CHAR *name;
@@ -1702,8 +1673,6 @@ void init_lib_electric(void)
 		EElectric_Equal, EElectric_Equal, ERTNode_Print, NOFUNC);
 	T_ENetwork = Define_Type(0, x_("network"), NOFUNC, sizeof (struct S_ENetwork),
 		EElectric_Equal, EElectric_Equal, ENetwork_Print, NOFUNC);
-	T_ECell = Define_Type(0, x_("cell"), NOFUNC, sizeof (struct S_ECell),
-		EElectric_Equal, EElectric_Equal, ECell_Print, NOFUNC);
 	T_EView = Define_Type(0, x_("view"), NOFUNC, sizeof (struct S_EView),
 		EElectric_Equal, EElectric_Equal, EView_Print, NOFUNC);
 	T_EWindow = Define_Type(0, x_("window"), NOFUNC, sizeof (struct S_EWindow),
@@ -1729,7 +1698,6 @@ void init_lib_electric(void)
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_EToolP, x_("tool?"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ERTNodeP, x_("rtnode?"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ENetworkP, x_("network?"), 1, 1, EVAL);
-	Define_Primitive((ELKObject(*)(ELLIPSIS))P_ECellP, x_("cell?"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_EViewP, x_("view?"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_EWindowP, x_("window?"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))P_EGraphicsP, x_("graphics?"), 1, 1, EVAL);
@@ -1809,7 +1777,6 @@ void init_lib_electric(void)
 	/* define the miscellaneous predicates */
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_telltool, x_("telltool"), 1, MANY, VARARGS);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getarcproto, x_("getarcproto"), 1, 1, EVAL);
-	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getcell, x_("getcell"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_gettechnology, x_("gettechnology"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getpinproto, x_("getpinproto"), 1, 1, EVAL);
 	Define_Primitive((ELKObject(*)(ELLIPSIS))lsp_getnetwork, x_("getnetwork"), 2, 2, EVAL);
