@@ -104,7 +104,6 @@ static int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **a
 static int tcl_telltool(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv);
 static int tcl_asktool(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv);
 static int tcl_getarcproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv);
-static int tcl_getcell(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv);
 static int tcl_gettechnology(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv);
 static int tcl_getpinproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv);
 static int tcl_getnetwork(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv);
@@ -259,7 +258,6 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	Tcl_CreateCommand(tcl_interp, x_("telltool"),        tcl_telltool,        (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, x_("asktool"),         tcl_asktool,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, x_("getarcproto"),     tcl_getarcproto,     (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, x_("getcell"),         tcl_getcell,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, x_("gettechnology"),   tcl_gettechnology,   (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, x_("getpinproto"),     tcl_getpinproto,     (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, x_("getnetwork"),      tcl_getnetwork,      (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
@@ -304,7 +302,6 @@ void tcl_converttoanyelectric(CHAR *tclstr, INTBIG *addr, INTBIG *type)
 	if (namesamen(tclstr, x_("#tool"),         5) == 0) { *addr = myatoi(&tclstr[5]);  *type = VTOOL;        return; }
 	if (namesamen(tclstr, x_("#rtnode"),       7) == 0) { *addr = myatoi(&tclstr[7]);  *type = VRTNODE;      return; }
 	if (namesamen(tclstr, x_("#network"),      8) == 0) { *addr = myatoi(&tclstr[8]);  *type = VNETWORK;     return; }
-	if (namesamen(tclstr, x_("#cell"),         5) == 0) { *addr = myatoi(&tclstr[5]);  *type = VCELL;        return; }
 	if (namesamen(tclstr, x_("#view"),         5) == 0) { *addr = myatoi(&tclstr[5]);  *type = VVIEW;        return; }
 	if (namesamen(tclstr, x_("#window"),       7) == 0) { *addr = myatoi(&tclstr[7]);  *type = VWINDOWPART;  return; }
 	if (namesamen(tclstr, x_("#graphics"),     9) == 0) { *addr = myatoi(&tclstr[9]);  *type = VGRAPHICS;    return; }
@@ -355,7 +352,6 @@ INTBIG tcl_converttoelectric(CHAR *tclstr, INTBIG type)
 		case VTOOL:        if (namesamen(tclstr, x_("#tool"),         5) == 0) return(myatoi(&tclstr[5]));  break;
 		case VRTNODE:      if (namesamen(tclstr, x_("#rtnode"),       7) == 0) return(myatoi(&tclstr[7]));  break;
 		case VNETWORK:     if (namesamen(tclstr, x_("#network"),      8) == 0) return(myatoi(&tclstr[8]));  break;
-		case VCELL:        if (namesamen(tclstr, x_("#cell"),         5) == 0) return(myatoi(&tclstr[5]));  break;
 		case VVIEW:        if (namesamen(tclstr, x_("#view"),         5) == 0) return(myatoi(&tclstr[5]));  break;
 		case VWINDOWPART:  if (namesamen(tclstr, x_("#window"),       7) == 0) return(myatoi(&tclstr[7]));  break;
 		case VGRAPHICS:    if (namesamen(tclstr, x_("#graphics"),     9) == 0) return(myatoi(&tclstr[9]));  break;
@@ -472,7 +468,6 @@ void tcl_converttoscalartcl(void *infstr, INTBIG addr, INTBIG type)
 		case VTOOL:        esnprintf(line, 50, x_("#tool%ld"),        addr);    break;
 		case VRTNODE:      esnprintf(line, 50, x_("#rtnode%ld"),      addr);    break;
 		case VNETWORK:     esnprintf(line, 50, x_("#network%ld"),     addr);    break;
-		case VCELL:        esnprintf(line, 50, x_("#cell%ld"),        addr);    break;
 		case VVIEW:        esnprintf(line, 50, x_("#view%ld"),        addr);    break;
 		case VWINDOWPART:  esnprintf(line, 50, x_("#window%ld"),      addr);    break;
 		case VGRAPHICS:    esnprintf(line, 50, x_("#graphics%ld"),    addr);    break;
@@ -833,7 +828,7 @@ int tcl_initsearch(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 	/* get input */
 	if (argc != 6)
 	{
-		Tcl_AppendResult(interp, x_("Usage: initsearch LX HX LY HY FACET"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: initsearch LX HX LY HY CELL"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	lx = myatoi(argv[1]);
@@ -1109,7 +1104,7 @@ int tcl_killnodeproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **arg
 	/* get input */
 	if (argc != 2)
 	{
-		Tcl_AppendResult(interp, x_("Usage: killnodeproto FACET"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: killnodeproto CELL"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1131,7 +1126,7 @@ int tcl_copynodeproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **arg
 	/* get input */
 	if (argc != 4)
 	{
-		Tcl_AppendResult(interp, x_("Usage: copynodeproto FACET LIBRARY NAME"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: copynodeproto CELL LIBRARY NAME"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1153,7 +1148,7 @@ int tcl_iconview(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 	/* get input */
 	if (argc != 2)
 	{
-		Tcl_AppendResult(interp, x_("Usage: iconview FACET"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: iconview CELL"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1174,7 +1169,7 @@ int tcl_contentsview(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv
 	/* get input */
 	if (argc != 2)
 	{
-		Tcl_AppendResult(interp, x_("Usage: contentsview FACET"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: contentsview CELL"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1193,13 +1188,13 @@ int tcl_contentsview(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv
 int tcl_newnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 {
 	REGISTER NODEINST *ni;
-	REGISTER NODEPROTO *np, *facet;
+	REGISTER NODEPROTO *np, *cell;
 	REGISTER INTBIG lx, hx, ly, hy, rot, tran;
 
 	/* get input */
 	if (argc != 9)
 	{
-		Tcl_AppendResult(interp, x_("Usage: newnodeinst PROTO LX HX LY HY TRAN ROT FACET"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: newnodeinst PROTO LX HX LY HY TRAN ROT CELL"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1209,11 +1204,11 @@ int tcl_newnodeinst(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 	hy = myatoi(argv[5]);
 	tran = myatoi(argv[6]);
 	rot = myatoi(argv[7]);
-	facet = (NODEPROTO *)tcl_converttowarnedelectric(argv[8], VNODEPROTO, x_("eighth"));
-	if (np == NONODEPROTO || facet == NONODEPROTO) return TCL_ERROR;
+	cell = (NODEPROTO *)tcl_converttowarnedelectric(argv[8], VNODEPROTO, x_("eighth"));
+	if (np == NONODEPROTO || cell == NONODEPROTO) return TCL_ERROR;
 
 	/* call Electric */
-	ni = newnodeinst(np, lx, hx, ly, hy, tran, rot, facet);
+	ni = newnodeinst(np, lx, hx, ly, hy, tran, rot, cell);
 
 	/* convert result */
 	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)ni, VNODEINST), (CHAR *) NULL);
@@ -1326,7 +1321,7 @@ int tcl_newarcinst(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 	/* get input */
 	if (argc != 13)
 	{
-		Tcl_AppendResult(interp, x_("Usage: newarcinst PROTO WID BITS NODE1 PORT1 X1 Y1 NODE2 PORT2 X2 Y2 FACET"),
+		Tcl_AppendResult(interp, x_("Usage: newarcinst PROTO WID BITS NODE1 PORT1 X1 Y1 NODE2 PORT2 X2 Y2 CELL"),
 			(CHAR *)NULL);
 		return TCL_ERROR;
 	}
@@ -1437,7 +1432,7 @@ int tcl_newportproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv
 	/* get input */
 	if (argc != 5)
 	{
-		Tcl_AppendResult(interp, x_("Usage: newportproto FACET NODE PORT NAME"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: newportproto CELL NODE PORT NAME"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1487,7 +1482,7 @@ int tcl_getportproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv
 	/* get input */
 	if (argc != 3)
 	{
-		Tcl_AppendResult(interp, x_("Usage: getportproto FACET NAME"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: getportproto CELL NAME"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1510,7 +1505,7 @@ int tcl_killportproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **arg
 	/* get input */
 	if (argc != 3)
 	{
-		Tcl_AppendResult(interp, x_("Usage: killportproto FACET PORT"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: killportproto CELL PORT"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1535,7 +1530,7 @@ int tcl_moveportproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **arg
 	/* get input */
 	if (argc != 5)
 	{
-		Tcl_AppendResult(interp, x_("Usage: moveportproto FACET PORT NEWNODE NEWPORT"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: moveportproto CELL PORT NEWNODE NEWPORT"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[1], VNODEPROTO, x_("first"));
@@ -1721,7 +1716,7 @@ int tcl_asktool(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 					if (first != 0) addtoinfstr(infstr, '\n');
 					first++;
 					tcl_converttoanyelectric(argvS[i], &addr, &type);
-					formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
+					formatinfstr(infstr, x_("CELL=%s FROM=0%lo;-1;0"),
 						describenodeproto(((GEOM *)addr)->entryaddr.ni->parent), addr);
 				}
 				ret = asktool(tool, command, (INTBIG)returninfstr(infstr));
@@ -1776,25 +1771,6 @@ int tcl_getarcproto(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 	return TCL_OK;
 }
 
-int tcl_getcell(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
-{
-	REGISTER CELL *cell;
-
-	/* get input */
-	if (argc != 2)
-	{
-		Tcl_AppendResult(interp, x_("Usage: getcell NAME"), (CHAR *)NULL);
-		return TCL_ERROR;
-	}
-
-	/* call Electric */
-	cell = getcell(argv[1]);
-
-	/* convert result */
-	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)cell, VCELL), (CHAR *) NULL);
-	return TCL_OK;
-}
-
 int tcl_gettechnology(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 {
 	REGISTER TECHNOLOGY *tech;
@@ -1844,7 +1820,7 @@ int tcl_getnetwork(ClientData dummy, Tcl_Interp *interp, int argc, CHAR **argv)
 	/* get input */
 	if (argc != 3)
 	{
-		Tcl_AppendResult(interp, x_("Usage: getnetwork NAME FACET"), (CHAR *)NULL);
+		Tcl_AppendResult(interp, x_("Usage: getnetwork NAME CELL"), (CHAR *)NULL);
 		return TCL_ERROR;
 	}
 	np = (NODEPROTO *)tcl_converttowarnedelectric(argv[2], VNODEPROTO, x_("second"));
