@@ -34,7 +34,7 @@
 #include "network.h"
 
 /* prototypes for local routines */
-static void   db_scalefacet(NODEPROTO*, INTBIG, TECHNOLOGY**, INTBIG*);
+static void   db_scalecell(NODEPROTO*, INTBIG, TECHNOLOGY**, INTBIG*);
 static void   db_validatearcinst(ARCINST*);
 static void   db_setarcinst(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG);
 static INTBIG db_scaleunits(INTBIG *value, INTBIG num, INTBIG den);
@@ -81,12 +81,11 @@ LIBRARY *alloclibrary(void)
 	lib->firstvar = NOVARIABLE;
 	lib->firstnodeproto = NONODEPROTO;
 	lib->tailnodeproto = NONODEPROTO;
-	lib->firstcell = NOCELL;
-	lib->tailcell = NOCELL;
-	lib->numcells = 0;
 	lib->curnodeproto = NONODEPROTO;
 	lib->nextlibrary = NOLIBRARY;
-	lib->cellhashtablesize = 0;
+	lib->numnodeprotos = 0;
+	lib->nodeprotohashtablesize = 0;
+	lib->freenetwork = NONETWORK;
 	return(lib);
 }
 
@@ -96,11 +95,22 @@ LIBRARY *alloclibrary(void)
 void freelibrary(LIBRARY *lib)
 {
 	REGISTER CLUSTER *clus;
+	REGISTER NETWORK *net, *nextnet;
 
 	if (lib == NOLIBRARY) return;
 	if (lib->numvar != 0) db_freevars(&lib->firstvar, &lib->numvar);
 	efree((CHAR *)lib->lambda);
-	if (lib->cellhashtablesize > 0) efree((CHAR *)lib->cellhashtable);
+	if (lib->nodeprotohashtablesize > 0)
+	{
+		efree((CHAR *)lib->nodeprotohashtable);
+		efree((CHAR *)lib->nodeprotoviewhashtable);
+	}
+	for(net = lib->freenetwork; net != NONETWORK; net = nextnet)
+	{
+		nextnet = net->nextnetwork;
+		if (net->arctotal != 0) efree((CHAR *)net->arcaddr);
+		efree((CHAR *)net);
+	}
 	clus = lib->cluster;
 	efree((CHAR *)lib);
 	freecluster(clus);
@@ -234,7 +244,7 @@ void killlibrary(LIBRARY *lib)
 }
 
 /*
- * routine to erase the contents of a library of facets.
+ * routine to erase the contents of a library of cells.
  * The index of the library is in "libindex".
  */
 void eraselibrary(LIBRARY *lib)
@@ -246,7 +256,6 @@ void eraselibrary(LIBRARY *lib)
 	REGISTER PORTARCINST *pi, *lpo;
 	REGISTER PORTEXPINST *pe, *lpe;
 	REGISTER NETWORK *net, *nnet;
-	REGISTER CELL *c, *nextc;
 	REGISTER INTBIG i;
 
 	/* see if this library exists */
@@ -262,7 +271,7 @@ void eraselibrary(LIBRARY *lib)
 	/* erase the nodes, ports, arcs, and geometry modules in each nodeproto */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
-		/* erase all arcs and nodes in this facet */
+		/* erase all arcs and nodes in this cell */
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = nni)
 		{
 			nni = ni->nextnodeinst;
@@ -324,22 +333,6 @@ void eraselibrary(LIBRARY *lib)
 	lib->tailnodeproto = NONODEPROTO;
 	lib->curnodeproto = NONODEPROTO;
 
-	/* now erase the cells */
-	for(c = lib->firstcell; c != NOCELL; c = nextc)
-	{
-		nextc = c->nextcell;
-		efree(c->cellname);
-		freecell(c);
-	}
-	lib->firstcell = NOCELL;
-	lib->tailcell = NOCELL;
-	lib->numcells = 0;
-	if (lib->cellhashtablesize > 0)
-	{
-		efree((CHAR *)lib->cellhashtable);
-		lib->cellhashtablesize = 0;
-	}
-
 	/* now erase the library information */
 	if (lib->numvar != 0) db_freevars(&lib->firstvar, &lib->numvar);
 
@@ -358,27 +351,26 @@ LIBRARY *whichlibrary(INTBIG addr, INTBIG type)
 
 	switch (type&VTYPE)
 	{
-		case VNODEINST: return(((NODEINST *)addr)->parent->cell->lib);
+		case VNODEINST: return(((NODEINST *)addr)->parent->lib);
 		case VNODEPROTO:
 			np = (NODEPROTO *)addr;
-			if (np->primindex == 0) return(np->cell->lib);
+			if (np->primindex == 0) return(np->lib);
 			return(NOLIBRARY);
 		case VPORTARCINST:
-			return(((PORTARCINST *)addr)->conarcinst->parent->cell->lib);
+			return(((PORTARCINST *)addr)->conarcinst->parent->lib);
 		case VPORTEXPINST:
-			return(((PORTEXPINST *)addr)->exportproto->parent->cell->lib);
+			return(((PORTEXPINST *)addr)->exportproto->parent->lib);
 		case VPORTPROTO:
 			np = ((PORTPROTO *)addr)->parent;
-			if (np->primindex == 0) return(np->cell->lib);
+			if (np->primindex == 0) return(np->lib);
 			return(NOLIBRARY);
-		case VARCINST: return(((ARCINST *)addr)->parent->cell->lib);
+		case VARCINST: return(((ARCINST *)addr)->parent->lib);
 		case VGEOM: geom = (GEOM *)addr;
 			if (geom->entryisnode)
-				return(geom->entryaddr.ni->parent->cell->lib);
-			return(geom->entryaddr.ai->parent->cell->lib);
+				return(geom->entryaddr.ni->parent->lib);
+			return(geom->entryaddr.ai->parent->lib);
 		case VLIBRARY: return((LIBRARY *)addr);
-		case VNETWORK: return(((NETWORK *)addr)->parent->cell->lib);
-		case VCELL: return(((CELL *)addr)->lib);
+		case VNETWORK: return(((NETWORK *)addr)->parent->lib);
 	}
 	return(NOLIBRARY);
 }
@@ -436,17 +428,17 @@ void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
 
 	}
 
-	/* mark all facets in the library for scaling */
+	/* mark all cells in the library for scaling */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
 
-	/* scale all the facets */
+	/* scale all the cells */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
 		if (how == 1 && whichlib != lib) continue;
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			db_scalefacet(np, count, techarray, newlam);
+			db_scalecell(np, count, techarray, newlam);
 		if (lib->firstnodeproto != NONODEPROTO)
 			lib->userbits |= LIBCHANGEDMAJOR;
 	}
@@ -464,47 +456,47 @@ void changelambda(INTBIG count, TECHNOLOGY **techarray, INTBIG *newlam,
 }
 
 /*
- * routine to recursively scale the contents of facet "np" by "newlam/oldlam"
+ * routine to recursively scale the contents of cell "np" by "newlam/oldlam"
  */
-void db_scalefacet(NODEPROTO *np, INTBIG count, TECHNOLOGY **techarray, INTBIG *newlamarray)
+void db_scalecell(NODEPROTO *np, INTBIG count, TECHNOLOGY **techarray, INTBIG *newlamarray)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER VARIABLE *var;
 	REGISTER INTBIG i, *oldlamarray, *position, oldlam, newlam;
 
-	/* quit if the facet is already done */
+	/* quit if the cell is already done */
 	if (np->temp1 != 0) return;
 
-	/* first look for sub-facets that are not yet scaled */
+	/* first look for sub-cells that are not yet scaled */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		if (ni->proto->primindex == 0)
-			db_scalefacet(ni->proto, count, techarray, newlamarray);
+			db_scalecell(ni->proto, count, techarray, newlamarray);
 
-	/* mark this facet "scaled" */
+	/* mark this cell "scaled" */
 	np->temp1++;
 
-	/* see if this facet gets scaled */
+	/* see if this cell gets scaled */
 	for(i=0; i<count; i++)
 		if (np->tech == techarray[i]) break;
 	if (i < count)
 	{
 		/* get the old lambda value */
-		oldlamarray = (INTBIG *)np->cell->lib->temp2;
+		oldlamarray = (INTBIG *)np->lib->temp2;
 		if (oldlamarray == 0) return;
 		oldlam = oldlamarray[i];
 		newlam = newlamarray[i];
 
-		/* scale nodes and arcs in the facet */
+		/* scale nodes and arcs in the cell */
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 			db_scalenodeinst(ni, newlam, oldlam);
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 			db_scalearcinst(ai, newlam, oldlam);
 
-		/* scale the facet */
-		db_boundfacet(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
+		/* scale the cell */
+		db_boundcell(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
 
-		/* scale variables such as facet-center and characteristic spacing */
+		/* scale variables such as cell-center and characteristic spacing */
 		var = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center_key);
 		if (var != NOVARIABLE)
 		{
@@ -546,7 +538,7 @@ void db_scalenodeinst(NODEINST *ni, INTBIG newlam, INTBIG oldlam)
 			dy = ni->highy - ni->lowy - sizey;
 			if (dx != 0 || dy != 0)
 			{
-				ttyputmsg(_("Facet %s, node %s size and position adjusted"),
+				ttyputmsg(_("Cell %s, node %s size and position adjusted"),
 					describenodeproto(ni->parent), describenodeinst(ni));
 				ni->lowx += dx/2;   ni->highx = ni->lowx + sizex;
 				ni->lowy += dy/2;   ni->highy = ni->lowy + sizey;
@@ -557,7 +549,7 @@ void db_scalenodeinst(NODEINST *ni, INTBIG newlam, INTBIG oldlam)
 		/* look for trace data on primitives */
 		ni->lowx = newlx;   ni->highx = newhx;
 		ni->lowy = newly;   ni->highy = newhy;
-		var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+		var = gettrace(ni);
 		if (var != NOVARIABLE)
 		{
 			len = getlength(var);
@@ -641,7 +633,7 @@ void db_validatearcinst(ARCINST *ai)
 				if (!inside1) closestpoint(poly1, &tx, &ty);
 				ai->userbits &= ~FIXANG;
 				db_setarcinst(ai, fx, fy, tx, ty);
-				ttyputmsg(_("Facet %s, arc %s no longer fixed-angle"),
+				ttyputmsg(_("Cell %s, arc %s no longer fixed-angle"),
 					describenodeproto(ai->parent), describearcinst(ai));
 			}
 		}
@@ -772,7 +764,7 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 		/* only scale requested library if request was made */
 		if (whichlib != NOLIBRARY && whichlib != lib) continue;
 
-		/* scale each facet */
+		/* scale each cell */
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
 			/* scale nodes */
@@ -785,7 +777,7 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 				if (ni->proto->primindex != 0)
 				{
 					/* look for trace data on primitives */
-					var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+					var = gettrace(ni);
 					if (var != NOVARIABLE)
 					{
 						len = getlength(var);
@@ -813,8 +805,8 @@ void changeinternalunits(LIBRARY *whichlib, INTBIG oldunits, INTBIG newunits)
 				if (var != NOVARIABLE) hardscaleerror += db_scaleunits(&var->addr, num, den);
 			}
 
-			/* scale facet size */
-			db_boundfacet(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
+			/* scale cell size */
+			db_boundcell(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
 		}
 		lib->userbits = (lib->userbits & ~LIBUNITS) |
 			(((newunits & INTERNALUNITS) >> INTERNALUNITSSH) << LIBUNITSSH);
