@@ -44,10 +44,10 @@
  */
 #define MAXARCPIECES   16		/* maximum segments in curved arc */
 
-static GRAPHICS tech_arrow = {LAYERO, FACETOUT, SOLIDC, SOLIDC,
+static GRAPHICS tech_arrow = {LAYERO, CELLOUT, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
 	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
-static GRAPHICS tech_vartxt = {LAYERO, FACETTXT, SOLIDC, SOLIDC,
+static GRAPHICS tech_vartxt = {LAYERO, CELLTXT, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
 	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
@@ -57,7 +57,7 @@ static void      tech_shortenmostrans(NODEINST*, POLYGON*, TECH_POLYGON*, INTBIG
 static INTBIG    tech_displayableanyvars(WINDOWPART *win, NODEPROTO *np, POLYLOOP *pl);
 static VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 					INTBIG ly, INTBIG hy, INTBIG addr, INTBIG type, TECHNOLOGY *tech,
-					WINDOWPART *win, NODEPROTO *facet, VARIABLE **varnoeval, POLYLOOP *pl);
+					WINDOWPART *win, NODEPROTO *cell, VARIABLE **varnoeval, POLYLOOP *pl);
 
 /******************** GENERAL ********************/
 
@@ -161,7 +161,7 @@ BOOLEAN tech_doaddportsandvars(TECHNOLOGY *tech)
 			if (portinst[j].addr != NOPORTPROTO)
 			{
 				ttyputerr(_("Warning: node %s of technology %s shares port descriptions"),
-					nty->creation->primname, tech->techname);
+					nty->creation->protoname, tech->techname);
 			}
 			portinst[j].addr = db_newprimportproto(nty->creation,
 				(ARCPROTO **)&portinst[j].portarcs[1], portinst[j].protoname);
@@ -248,9 +248,9 @@ void tech_convertmocmoslib(LIBRARY *lib)
 		{
 			if (ni->proto->primindex == 0) continue;
 			if (ni->proto->tech != mocmostech) continue;
-			if (namesame(ni->proto->primname, x_("S-Active-Pin")) == 0 ||
-				namesame(ni->proto->primname, x_("S-Transistor")) == 0 ||
-				namesame(ni->proto->primname, x_("Metal-1-S-Active-Con")) == 0)
+			if (namesame(ni->proto->protoname, x_("S-Active-Pin")) == 0 ||
+				namesame(ni->proto->protoname, x_("S-Transistor")) == 0 ||
+				namesame(ni->proto->protoname, x_("Metal-1-S-Active-Con")) == 0)
 			{
 				undogeom(ni->geom, np);
 				ni->lowx -= 2 * lambda;
@@ -282,7 +282,7 @@ void tech_convertmocmoslib(LIBRARY *lib)
 		return;
 	}
 
-	/* adjust facet sizes */
+	/* adjust cell sizes */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		np->temp1 = 0;
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -292,7 +292,7 @@ void tech_convertmocmoslib(LIBRARY *lib)
 	ttyputmsg(M_("  contacts, S-Transistors, and Metal-1-Substrate"));
 	ttyputmsg(M_("  contacts from the MOSIS CMOS technology in this"));
 	ttyputmsg(M_("  library have been adjusted."));
-	ttyputmsg(M_("NOW DO A -debug check-database TO ADJUST FACET SIZES"));
+	ttyputmsg(M_("NOW DO A -debug check-database TO ADJUST CELL SIZES"));
 }
 
 void db_adjusttree(NODEPROTO *np)
@@ -302,7 +302,7 @@ void db_adjusttree(NODEPROTO *np)
 	INTBIG lx, hx, ly, hy, offx, offy;
 	XARRAY trans;
 
-	/* descend the hierarchy to get the bottom facets first */
+	/* descend the hierarchy to get the bottom cells first */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
@@ -310,12 +310,12 @@ void db_adjusttree(NODEPROTO *np)
 		db_adjusttree(ni->proto);
 	}
 
-	/* now adjust the facet size */
+	/* now adjust the cell size */
 	np->temp1++;
-	db_boundfacet(np, &lx, &hx, &ly, &hy);
+	db_boundcell(np, &lx, &hx, &ly, &hy);
 	if (lx == np->lowx && hx == np->highx && ly == np->lowy && hy == np->highy) return;
 
-	/* adjust all instances of the facet */
+	/* adjust all instances of the cell */
 	for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
 	{
 		undogeom(ni->geom, ni->parent);
@@ -951,17 +951,10 @@ void tech_filltrans(POLYGON *poly, TECH_POLYGON **lay, TECH_SERPENT *laylist,
 				yr = othery + mult(sine(ang), rwid);
 				switch (angle)
 				{
-#if 0	/* make nonoverlapping: */
-					case 0:    thisxr = thisxl = maxi(xl,xr);   break;
-					case 1800: thisxr = thisxl = mini(xl,xr);   break;
-					case 900:  thisyr = thisyl = maxi(yl,yr);   break;
-					case 2700: thisyr = thisyl = mini(yl,yr);   break;
-#else	/* make overlapping: */
 					case 0:    thisxr = thisxl = mini(xl,xr);   break;
 					case 1800: thisxr = thisxl = maxi(xl,xr);   break;
 					case 900:  thisyr = thisyl = mini(yl,yr);   break;
 					case 2700: thisyr = thisyl = maxi(yl,yr);   break;
-#endif
 				}
 			} else	      /* NonManhattan */
 			{
@@ -1083,7 +1076,7 @@ void tech_filltransport(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans
 	REGISTER PORTPROTO *lpp;
 
 	/* see if the transistor has serpentine information */
-	var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+	var = gettrace(ni);
 	if (var != NOVARIABLE)
 	{
 		/* trace data is there: make sure there are enough points */
@@ -1242,7 +1235,7 @@ INTBIG tech_displayablenvars(NODEINST *ni, WINDOWPART *win, POLYLOOP *pl)
 VARIABLE *tech_filldisplayablenvar(NODEINST *ni, POLYGON *poly, WINDOWPART *win,
 	VARIABLE **varnoeval, POLYLOOP *pl)
 {
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER VARIABLE *var;
 	REGISTER INTBIG lx, hx, ly, hy;
 	INTBIG olx, ohx, oly, ohy;
@@ -1259,18 +1252,18 @@ VARIABLE *tech_filldisplayablenvar(NODEINST *ni, POLYGON *poly, WINDOWPART *win,
 	db_lastonobjectaddr = (INTBIG)ni;
 	db_lastonobjecttype = VNODEINST;
 
-	facet = ni->parent;
+	cell = ni->parent;
 	pl->numvar = ni->numvar;
 	pl->firstvar = ni->firstvar;
-	if (facet->tech == NOTECHNOLOGY)
-		facet->tech = whattech(facet);
+	if (cell->tech == NOTECHNOLOGY)
+		cell->tech = whattech(cell);
 	lx = ni->lowx;   hx = ni->highx;
 	ly = ni->lowy;   hy = ni->highy;
 	nodesizeoffset(ni, &olx, &oly, &ohx, &ohy);
 	lx += olx;   hx -= ohx;
 	ly += oly;   hy -= ohy;
 	var = tech_filldisplayableanyvar(poly, lx, hx, ly, hy, (INTBIG)ni, VNODEINST,
-		facet->tech, win, facet, varnoeval, pl);
+		cell->tech, win, cell, varnoeval, pl);
 	db_onanobject = oldonobjectstate;
 	return(var);
 }
@@ -1278,11 +1271,11 @@ VARIABLE *tech_filldisplayablenvar(NODEINST *ni, POLYGON *poly, WINDOWPART *win,
 /*
  * routine to compute the number of displayable polygons on nodeproto "np"
  */
-INTBIG tech_displayablefacetvars(NODEPROTO *np, WINDOWPART *win, POLYLOOP *pl)
+INTBIG tech_displayablecellvars(NODEPROTO *np, WINDOWPART *win, POLYLOOP *pl)
 {
 	pl->numvar = np->numvar;
 	pl->firstvar = np->firstvar;
-	if ((us_useroptions&HIDETXTFACET) != 0) return(0);
+	if ((us_useroptions&HIDETXTCELL) != 0) return(0);
 	return(tech_displayableanyvars(win, np, pl));
 }
 
@@ -1290,14 +1283,14 @@ INTBIG tech_displayablefacetvars(NODEPROTO *np, WINDOWPART *win, POLYLOOP *pl)
  * routine to fill polygon "poly" with the next displayable variable
  * on nodeproto "np".  Returns the address of the variable just filled.
  */
-VARIABLE *tech_filldisplayablefacetvar(NODEPROTO *np, POLYGON *poly, WINDOWPART *win,
+VARIABLE *tech_filldisplayablecellvar(NODEPROTO *np, POLYGON *poly, WINDOWPART *win,
 	VARIABLE **varnoeval, POLYLOOP *pl)
 {
 	pl->numvar = np->numvar;
 	pl->firstvar = np->firstvar;
 	if (np->tech == NOTECHNOLOGY) np->tech = whattech(np);
 
-	/* facet variables are offset from (0,0) */
+	/* cell variables are offset from (0,0) */
 	return(tech_filldisplayableanyvar(poly, 0, 0, 0, 0, (INTBIG)np,
 		VNODEPROTO, np->tech, win, np, varnoeval, pl));
 }
@@ -1412,9 +1405,9 @@ VARIABLE *tech_filldisplayableportvar(PORTPROTO *pp, POLYGON *poly, WINDOWPART *
 	INTBIG x, y;
 	REGISTER INTSML saverot, savetrn;
 	REGISTER NODEINST *ni;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 
-	facet = pp->parent;
+	cell = pp->parent;
 	ni = pp->subnodeinst;
 	saverot = ni->rotation;   savetrn = ni->transpose;
 	ni->rotation = ni->transpose = 0;
@@ -1422,10 +1415,10 @@ VARIABLE *tech_filldisplayableportvar(PORTPROTO *pp, POLYGON *poly, WINDOWPART *
 	ni->rotation = saverot;   ni->transpose = savetrn;
 	pl->numvar = pp->numvar;
 	pl->firstvar = pp->firstvar;
-	if (facet->tech == NOTECHNOLOGY)
-		facet->tech = whattech(facet);
+	if (cell->tech == NOTECHNOLOGY)
+		cell->tech = whattech(cell);
 	return(tech_filldisplayableanyvar(poly, x, x, y, y,
-		(INTBIG)pp, VPORTPROTO, facet->tech, win, facet, varnoeval, pl));
+		(INTBIG)pp, VPORTPROTO, cell->tech, win, cell, varnoeval, pl));
 }
 
 /******************** ARCINST DESCRIPTION ********************/
@@ -1588,7 +1581,7 @@ void tech_makearrow(ARCINST *ai, POLYGON *poly)
 	poly->style = VECTORS;
 	poly->layer = -1;
 	poly->desc = &tech_arrow;
-	tech_arrow.col = el_colfacet;
+	tech_arrow.col = el_colcell;
 	poly->count = 2;
 	poly->xv[0] = x1;   poly->yv[0] = y1;
 	poly->xv[1] = x2;   poly->yv[1] = y2;
@@ -1776,7 +1769,7 @@ INTBIG tech_displayableavars(ARCINST *ai, WINDOWPART *win, POLYLOOP *pl)
 VARIABLE *tech_filldisplayableavar(ARCINST *ai, POLYGON *poly, WINDOWPART *win,
 	VARIABLE **varnoeval, POLYLOOP *pl)
 {
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER VARIABLE *var;
 	REGISTER BOOLEAN oldonobjectstate;
 
@@ -1791,14 +1784,14 @@ VARIABLE *tech_filldisplayableavar(ARCINST *ai, POLYGON *poly, WINDOWPART *win,
 	db_lastonobjectaddr = (INTBIG)ai;
 	db_lastonobjecttype = VARCINST;
 
-	facet = ai->parent;
+	cell = ai->parent;
 	pl->numvar = ai->numvar;
 	pl->firstvar = ai->firstvar;
-	if (facet->tech == NOTECHNOLOGY)
-		facet->tech = whattech(facet);
+	if (cell->tech == NOTECHNOLOGY)
+		cell->tech = whattech(cell);
 	var = tech_filldisplayableanyvar(poly, ai->geom->lowx, ai->geom->highx,
-		ai->geom->lowy, ai->geom->highy, (INTBIG)ai, VARCINST, facet->tech,
-			win, facet, varnoeval, pl);
+		ai->geom->lowy, ai->geom->highy, (INTBIG)ai, VARCINST, cell->tech,
+			win, cell, varnoeval, pl);
 	db_onanobject = oldonobjectstate;
 	return(var);
 }
@@ -1809,7 +1802,7 @@ VARIABLE *tech_filldisplayableavar(ARCINST *ai, POLYGON *poly, WINDOWPART *win,
  * routine to compute the number of displayable polygons in the pair "tech_numvar/
  * tech_firstvar"
  */
-INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *facet, POLYLOOP *pl)
+INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *cell, POLYLOOP *pl)
 {
 	REGISTER INTBIG i, total;
 	REGISTER VARIABLE *var;
@@ -1823,7 +1816,7 @@ INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *facet, POLYLOOP *pl)
 		if (TDGETINTERIOR(var->textdescript) != 0 ||
 			TDGETINHERIT(var->textdescript) != 0)
 		{
-			if (win != NOWINDOWPART && facet != win->curnodeproto) continue;
+			if (win != NOWINDOWPART && cell != win->curnodeproto) continue;
 		}
 		if ((var->type&VISARRAY) == 0) total++; else
 			total += getlength(var);
@@ -1837,7 +1830,7 @@ INTBIG tech_displayableanyvars(WINDOWPART *win, NODEPROTO *facet, POLYLOOP *pl)
  */
 VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 	INTBIG ly, INTBIG hy, INTBIG addr, INTBIG type, TECHNOLOGY *tech,
-		WINDOWPART *win, NODEPROTO *facet, VARIABLE **varnoeval, POLYLOOP *pl)
+		WINDOWPART *win, NODEPROTO *cell, VARIABLE **varnoeval, POLYLOOP *pl)
 {
 	REGISTER INTBIG len, language, whichindex;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
@@ -1870,7 +1863,7 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 		if ((var->type&VDISPLAY) != 0 &&
 			((TDGETINTERIOR(var->textdescript) == 0 && TDGETINHERIT(var->textdescript) == 0) ||
 				win == NOWINDOWPART ||
-					facet == win->curnodeproto))
+					cell == win->curnodeproto))
 		{
 			TDCOPY(descript, var->textdescript);
 			language = var->type & (VCODE1|VCODE2);
@@ -1927,7 +1920,7 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 
 	adjustdisoffset(addr, type, tech, poly, descript);
 	poly->desc = &tech_vartxt;
-	tech_vartxt.col = el_colfacettxt;
+	tech_vartxt.col = el_colcelltxt;
 	poly->layer = -1;
 	(void)setvariablewindow(oldwin);
 	return(var);
