@@ -44,8 +44,8 @@
 #include "usrdiacom.h"
 
 /* the DRC tool table */
-static COMCOMP dr_drccp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, x_(" \t"), M_("facet to be rechecked"), M_("check current facet")};
+static COMCOMP dr_drccp = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
+	INPUTOPT, x_(" \t"), M_("cell to be rechecked"), M_("check current cell")};
 static KEYWORD drcnotopt[] =
 {
 	{x_("verbose"),        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -54,10 +54,10 @@ static KEYWORD drcnotopt[] =
 };
 static COMCOMP drcnotp = {drcnotopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 	INPUTOPT, x_(" \t"), M_("Design Rule Checker negative action"), 0};
-static COMCOMP drcfip = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, x_(" \t"), M_("facet to ignored for short check DRC"), 0};
-static COMCOMP drcfup = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, x_(" \t"), M_("facet to un-ignored for short check DRC"), 0};
+static COMCOMP drcfip = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
+	INPUTOPT, x_(" \t"), M_("cell to ignored for short check DRC"), 0};
+static COMCOMP drcfup = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
+	INPUTOPT, x_(" \t"), M_("cell to un-ignored for short check DRC"), 0};
 static KEYWORD drcfopt[] =
 {
 	{x_("select-run"),   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -108,7 +108,7 @@ COMCOMP dr_drcp = {drcopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 
 typedef struct Idcheck
 {
-	NODEPROTO *facet;					/* facet containing object to be checked */
+	NODEPROTO *cell;					/* cell containing object to be checked */
 	INTBIG     entrytype;				/* type of check */
 	void      *entryaddr;				/* object being checked */
 	struct Idcheck *nextdcheck;			/* next in list */
@@ -176,22 +176,21 @@ CHAR *dr_variablenames[] =
 
 /* prototypes for local routines */
 static DCHECK    *dr_allocdcheck(void);
-static NODEPROTO *dr_checkthisfacet(INTBIG, CHAR*);
+static NODEPROTO *dr_checkthiscell(INTBIG, CHAR*);
 static void       dr_freedcheck(DCHECK*);
 static void       dr_optionsdlog(void);
 static void       dr_rulesdloghook(void);
 static void       dr_queuecheck(void*, NODEPROTO*, INTBIG);
-static void       dr_setignore(GEOM*, GEOM*);
 static void       dr_unignore(NODEPROTO*, BOOLEAN, void*);
 static void       dr_unqueuecheck(LIBRARY *lib);
-static INTBIG     dr_examinefacet(NODEPROTO *np, BOOLEAN report);
+static INTBIG     dr_examinecell(NODEPROTO *np, BOOLEAN report);
 static void       dr_schdocheck(GEOM *geom);
-static void       dr_checkentirefacet(NODEPROTO *facet, INTBIG count, NODEINST **nodestocheck,
+static void       dr_checkentirecell(NODEPROTO *cell, INTBIG count, NODEINST **nodestocheck,
 					BOOLEAN *validity, BOOLEAN justarea);
 static BOOLEAN    dr_schcheckcolinear(ARCINST *ai, ARCINST *oai);
 static void       dr_schcheckobjectvicinity(GEOM *topgeom, GEOM *geom, XARRAY trans);
-static void       dr_checkschematicfacet(NODEPROTO *facet, BOOLEAN justthis);
-static void       dr_checkschematicfacetrecursively(NODEPROTO *facet);
+static void       dr_checkschematiccell(NODEPROTO *cell, BOOLEAN justthis);
+static void       dr_checkschematiccellrecursively(NODEPROTO *cell);
 static BOOLEAN    dr_schcheckpoly(GEOM *geom, POLYGON *poly, GEOM *otopgeom, GEOM *ogeom, XARRAY otrans, BOOLEAN cancross);
 static BOOLEAN    dr_schcheckpolygonvicinity(GEOM *geom, POLYGON *poly);
 static BOOLEAN    dr_checkpolyagainstpoly(GEOM *geom, POLYGON *poly, GEOM *ogeom, POLYGON *opoly, BOOLEAN cancross);
@@ -283,7 +282,7 @@ void dr_set(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("forget-ignored-errors"), l) == 0)
 	{
-		np = dr_checkthisfacet(count, par[1]);
+		np = dr_checkthiscell(count, par[1]);
 		if (np == NONODEPROTO) return;
 
 		/* erase all ignore lists on all objects */
@@ -305,18 +304,18 @@ void dr_set(INTBIG count, CHAR *par[])
 			return;
 		}
 
-		np = dr_checkthisfacet(count, par[1]);
+		np = dr_checkthiscell(count, par[1]);
 		if (np == NONODEPROTO) return;
-		errs = dr_examinefacet(np, TRUE);
+		errs = dr_examinecell(np, TRUE);
 		return;
 	}
 
 	if (namesamen(pp, x_("ecadcheck"), l) == 0)
 	{
-		np = getcurfacet();
+		np = getcurcell();
 		if (np == NONODEPROTO)
 		{
-			ttyputerr(_("Must be editing a facet to check with ECAD's Dracula"));
+			ttyputerr(_("Must be editing a cell to check with ECAD's Dracula"));
 			return;
 		}
 		tech = np->tech;
@@ -344,12 +343,12 @@ void dr_set(INTBIG count, CHAR *par[])
 			pp = ((CHAR **)var->addr)[i];
 			if (estrncmp(pp, x_(" PRIMARY ="), 10) == 0)
 			{
-				xprintf(f, x_(" PRIMARY = %s\n"), np->cell->cellname);
+				xprintf(f, x_(" PRIMARY = %s\n"), np->protoname);
 				continue;
 			}
 			if (estrncmp(pp, x_(" INDISK ="), 9) == 0)
 			{
-				xprintf(f, x_(" INDISK = %s.cif\n"), np->cell->cellname);
+				xprintf(f, x_(" INDISK = %s.cif\n"), np->protoname);
 				continue;
 			}
 			xprintf(f, x_("%s\n"), pp);
@@ -357,14 +356,14 @@ void dr_set(INTBIG count, CHAR *par[])
 
 		/* finished with control deck */
 		xclose(f);
-		ttyputverbose(M_("Wrote 'ecaddrc.RUL'.  Now generating CIF for facet %s"), describenodeproto(np));
+		ttyputverbose(M_("Wrote 'ecaddrc.RUL'.  Now generating CIF for cell %s"), describenodeproto(np));
 
 		/* tell I/O to write CIF */
 		newpar[0] = x_("cif");
 		newpar[1] = x_("output");
 		newpar[2] = x_("include-cloak-layer");
 		telltool(io_tool, 3, newpar);
-		(void)asktool(io_tool, x_("write"), (INTBIG)np->cell->lib, (INTBIG)x_("cif"));
+		(void)asktool(io_tool, x_("write"), (INTBIG)np->lib, (INTBIG)x_("cif"));
 		newpar[0] = x_("cif");
 		newpar[1] = x_("output");
 		newpar[2] = x_("ignore-cloak-layer");
@@ -391,11 +390,11 @@ void dr_set(INTBIG count, CHAR *par[])
 				return;
 			}
 
-			/* make sure there is a facet to check */
-			np = getcurfacet();
+			/* make sure there is a cell to check */
+			np = getcurcell();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("No current facet"));
+				ttyputerr(_("No current cell"));
 				return;
 			}
 
@@ -420,11 +419,11 @@ void dr_set(INTBIG count, CHAR *par[])
 				return;
 			}
 
-			/* make sure there is a facet to check */
-			np = getcurfacet();
+			/* make sure there is a cell to check */
+			np = getcurcell();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("No current facet"));
+				ttyputerr(_("No current cell"));
 				return;
 			}
 
@@ -442,14 +441,14 @@ void dr_set(INTBIG count, CHAR *par[])
 		{
 			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				options | DRCFIRSTERROR, VINTEGER);
-			ttyputmsg(M_("Hierarchical DRC will stop after first error in a facet"));
+			ttyputmsg(M_("Hierarchical DRC will stop after first error in a cell"));
 			return;
 		}
 		if (namesamen(pp, x_("all-errors"), l) == 0)
 		{
 			(void)setvalkey((INTBIG)dr_tool, VTOOL, dr_optionskey,
 				options & ~DRCFIRSTERROR, VINTEGER);
-			ttyputmsg(M_("Hierarchical DRC will find all errors in a facet"));
+			ttyputmsg(M_("Hierarchical DRC will find all errors in a cell"));
 			return;
 		}
 		if (namesamen(pp, x_("reset-check-dates"), l) == 0)
@@ -464,27 +463,27 @@ void dr_set(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("quick-check"), l) == 0 && l >= 7)
 	{
-		/* get the current facet */
-		np = getcurfacet();
+		/* get the current cell */
+		np = getcurcell();
 		if (np == NONODEPROTO)
 		{
-			ttyputerr(_("No current facet"));
+			ttyputerr(_("No current cell"));
 			return;
 		}
-		dr_checkentirefacet(np, 0, 0, 0, FALSE);
+		dr_checkentirecell(np, 0, 0, 0, FALSE);
 		return;
 	}
 
 	if (namesamen(pp, x_("quick-select-check"), l) == 0 && l >= 7)
 	{
-		/* get the current facet */
-		np = getcurfacet();
+		/* get the current cell */
+		np = getcurcell();
 		if (np == NONODEPROTO)
 		{
-			ttyputerr(_("No current facet"));
+			ttyputerr(_("No current cell"));
 			return;
 		}
-		dr_checkentirefacet(np, 0, 0, 0, TRUE);
+		dr_checkentirecell(np, 0, 0, 0, TRUE);
 		return;
 	}
 
@@ -506,14 +505,14 @@ void dr_set(INTBIG count, CHAR *par[])
 				ttyputerr(M_("...now reissue the DRC command"));
 				return;
 			}
-			dr_flatwrite(getcurfacet());
+			dr_flatwrite(getcurcell());
 			return;
 		}
 		if (namesamen(pp, x_("ignore"), l) == 0)
 		{
 			if (count < 3)
 			{
-				ttyputusage(x_("telltool drc shortcheck ignore FACET"));
+				ttyputusage(x_("telltool drc shortcheck ignore CELL"));
 				return;
 			}
 			dr_flatignore(par[2]);
@@ -523,7 +522,7 @@ void dr_set(INTBIG count, CHAR *par[])
 		{
 			if (count < 3)
 			{
-				ttyputusage(x_("telltool drc shortcheck unignore FACET"));
+				ttyputusage(x_("telltool drc shortcheck unignore CELL"));
 				return;
 			}
 			dr_flatunignore(par[2]);
@@ -568,11 +567,11 @@ void dr_set(INTBIG count, CHAR *par[])
 
 /*
  * make request of the DRC tool:
- * "check-instances" TAKES: FACET, COUNT, NODEINST array, BOOLEAN validity-array
+ * "check-instances" TAKES: CELL, COUNT, NODEINST array, BOOLEAN validity-array
  */
 INTBIG dr_request(CHAR *command, va_list ap)
 {
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER NODEINST **nodelist;
 	REGISTER BOOLEAN *validity;
 	REGISTER INTBIG arg1, arg2, arg3, arg4, count;
@@ -585,11 +584,11 @@ INTBIG dr_request(CHAR *command, va_list ap)
 		arg3 = va_arg(ap, INTBIG);
 		arg4 = va_arg(ap, INTBIG);
 
-		facet = (NODEPROTO *)arg1;
+		cell = (NODEPROTO *)arg1;
 		count = arg2;
 		nodelist = (NODEINST **)arg3;
 		validity = (BOOLEAN *)arg4;
-		dr_checkentirefacet(facet, count, nodelist, validity, FALSE);
+		dr_checkentirecell(cell, count, nodelist, validity, FALSE);
 		return(0);
 	}
 	return(0);
@@ -599,7 +598,7 @@ void dr_examinenodeproto(NODEPROTO *np)
 {
 	REGISTER INTBIG i, errs;
 	REGISTER CHAR *pt;
-	if (dr_examinefacet(np, FALSE) != 0)
+	if (dr_examinecell(np, FALSE) != 0)
 	{
 		errs = numerrors();
 		for(i=0; i<errs; i++)
@@ -614,9 +613,9 @@ void dr_examinenodeproto(NODEPROTO *np)
 }
 
 /*
- * Routine to examine facet "np" nonhierarchically and return the number of errors found.
+ * Routine to examine cell "np" nonhierarchically and return the number of errors found.
  */
-INTBIG dr_examinefacet(NODEPROTO *np, BOOLEAN report)
+INTBIG dr_examinecell(NODEPROTO *np, BOOLEAN report)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -625,7 +624,7 @@ INTBIG dr_examinefacet(NODEPROTO *np, BOOLEAN report)
 	if (stopping(STOPREASONDRC)) return(0);
 
 	/* do not check things in hidden libraries (such as the clipboard) */
-	if ((np->cell->lib->userbits&HIDDENLIBRARY) != 0) return(0);
+	if ((np->lib->userbits&HIDDENLIBRARY) != 0) return(0);
 
 	/* make sure network tool is on */
 	if ((net_tool->toolstate&TOOLON) == 0) return(0);
@@ -633,7 +632,7 @@ INTBIG dr_examinefacet(NODEPROTO *np, BOOLEAN report)
 	/* handle schematics separately */
 	if (np->cellview == el_schematicview || np->tech == sch_tech)
 	{
-		dr_checkschematicfacet(np, TRUE);
+		dr_checkschematiccell(np, TRUE);
 		return(0);
 	}
 
@@ -647,7 +646,7 @@ INTBIG dr_examinefacet(NODEPROTO *np, BOOLEAN report)
 		(void)drcb_checkincremental(ai->geom, TRUE);
 	errorcount = numerrors();
 	if (report)
-		ttyputmsg(_("Facet %s checked at this level only (%ld errors)"),
+		ttyputmsg(_("Cell %s checked at this level only (%ld errors)"),
 			describenodeproto(np), errorcount);
 	termerrorlogging(TRUE);
 	return(errorcount);
@@ -685,9 +684,9 @@ void dr_slice(void)
 	for(d = dr_firstdcheck; d != NODCHECK; d = d->nextdcheck)
 	{
 		if (d->entrytype == NODEMOD || d->entrytype == NODEKILL)
-			dr_unignore(d->facet, TRUE, d->entryaddr);
+			dr_unignore(d->cell, TRUE, d->entryaddr);
 		if (d->entrytype == ARCMOD || d->entrytype == ARCKILL)
-			dr_unignore(d->facet, FALSE, d->entryaddr);
+			dr_unignore(d->cell, FALSE, d->entryaddr);
 	}
 
 	/* clear errors */
@@ -707,7 +706,7 @@ void dr_slice(void)
 				ni = (NODEINST *)d->entryaddr;
 				if ((ni->userbits&DEADN) == 0)
 				{
-					if (d->facet != np)
+					if (d->cell != np)
 					{
 						np = ni->parent;
 						drcb_initincrementalcheck(np);
@@ -723,7 +722,7 @@ void dr_slice(void)
 				ai = (ARCINST *)d->entryaddr;
 				if ((ai->userbits&DEADA) == 0)
 				{
-					if (d->facet != np)
+					if (d->cell != np)
 					{
 						np = ai->parent;
 						drcb_initincrementalcheck(np);
@@ -851,12 +850,12 @@ void dr_freedcheck(DCHECK *d)
 	dr_dcheckfree = d;
 }
 
-void dr_queuecheck(void *addr, NODEPROTO *facet, INTBIG function)
+void dr_queuecheck(void *addr, NODEPROTO *cell, INTBIG function)
 {
 	REGISTER DCHECK *d;
 
 	/* do not examine anything in a hidden library (such as the clipboard) */
-	if ((facet->cell->lib->userbits&HIDDENLIBRARY) != 0) return;
+	if ((cell->lib->userbits&HIDDENLIBRARY) != 0) return;
 
 	d = dr_allocdcheck();
 	if (d == NODCHECK)
@@ -865,7 +864,7 @@ void dr_queuecheck(void *addr, NODEPROTO *facet, INTBIG function)
 		return;
 	}
 	d->entrytype = function;
-	d->facet = facet;
+	d->cell = cell;
 	d->entryaddr = addr;
 	d->nextdcheck = dr_firstdcheck;
 	dr_firstdcheck = d;
@@ -883,7 +882,7 @@ void dr_unqueuecheck(LIBRARY *lib)
 	for(d = dr_firstdcheck; d != NODCHECK; d = nextd)
 	{
 		nextd = d->nextdcheck;
-		if (d->facet == NONODEPROTO || d->facet->cell->lib == lib)
+		if (d->cell == NONODEPROTO || d->cell->lib == lib)
 		{
 			if (lastd == NODCHECK) dr_firstdcheck = nextd; else
 				lastd->nextdcheck = nextd;
@@ -894,56 +893,6 @@ void dr_unqueuecheck(LIBRARY *lib)
 	}
 }
 
-/*
- * routine to add DRC ignore information to object "pos1" so that it will
- * ignore errors with object "pos2" (if "pos2" is not NOGEOM)
- */
-void dr_setignore(GEOM *pos1, GEOM *pos2)
-{
-	REGISTER GEOM **ignorelist, *p1, *p2;
-	GEOM *dummylist[2];
-	REGISTER VARIABLE *var;
-	REGISTER INTBIG i, len;
-	REGISTER NODEPROTO *np;
-
-	np = geomparent(pos1);
-	var = getvalkey((INTBIG)np, VNODEPROTO, VGEOM|VISARRAY, dr_ignore_listkey);
-
-	/* if the list is empty: create it with one entry */
-	if (var == NOVARIABLE)
-	{
-		dummylist[0] = pos1;   dummylist[1] = pos2;
-		(void)setvalkey((INTBIG)np, VNODEPROTO, dr_ignore_listkey, (INTBIG)dummylist,
-			VGEOM|VISARRAY|(2<<VLENGTHSH)|VDONTSAVE);
-		return;
-	}
-
-	/* search list to see if this entry is on it */
-	len = getlength(var);
-	for(i=0; i<len; i += 2)
-	{
-		p1 = ((GEOM **)var->addr)[i];
-		p2 = ((GEOM **)var->addr)[i+1];
-		if (pos1 == p1 && pos2 == p2) return;
-		if (pos1 == p2 && pos2 == p1) return;
-	}
-
-	/* entry not in list: add it */
-	ignorelist = (GEOM **)emalloc(((len+2) * (sizeof (GEOM *))), el_tempcluster);
-	if (ignorelist == 0)
-	{
-		ttyputnomemory();
-		return;
-	}
-
-	/* update the list */
-	for(i=0; i<len; i++) ignorelist[i] = ((GEOM **)var->addr)[i];
-	ignorelist[len] = pos1;   ignorelist[len+1] = pos2;
-	(void)setvalkey((INTBIG)np, VNODEPROTO, dr_ignore_listkey, (INTBIG)ignorelist,
-		(INTBIG)(VGEOM|VISARRAY|((len+2)<<VLENGTHSH)|VDONTSAVE));
-	efree((CHAR *)ignorelist);
-}
-
 /*
  * routine to delete DRC ignore information on object "pos"
  */
@@ -998,25 +947,25 @@ void dr_unignore(NODEPROTO *np, BOOLEAN objisnode, void *addr)
  * there were "count" parameters to the command and that "name" should be in
  * the second).  Returns NONODEPROTO if there is an error.
  */
-NODEPROTO *dr_checkthisfacet(INTBIG count, CHAR *name)
+NODEPROTO *dr_checkthiscell(INTBIG count, CHAR *name)
 {
 	REGISTER NODEPROTO *np;
 
 	if (count < 2)
 	{
-		np = getcurfacet();
-		if (np == NONODEPROTO) ttyputerr(_("No current facet"));
+		np = getcurcell();
+		if (np == NONODEPROTO) ttyputerr(_("No current cell"));
 		return(np);
 	}
 	np = getnodeproto(name);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("No facet named %s"), name);
+		ttyputerr(_("No cell named %s"), name);
 		return(NONODEPROTO);
 	}
 	if (np->primindex != 0)
 	{
-		ttyputerr(_("Can only check facets, not primitives"));
+		ttyputerr(_("Can only check cells, not primitives"));
 		return(NONODEPROTO);
 	}
 	return(np);
@@ -1058,40 +1007,40 @@ void dr_reset_dates(void)
 }
 
 /*
- * Routine to check all of facet "facet".  Returns number of errors found.
+ * Routine to check all of cell "cell".  Returns number of errors found.
  */
-void dr_checkentirefacet(NODEPROTO *facet, INTBIG count, NODEINST **nodestocheck, BOOLEAN *validity,
+void dr_checkentirecell(NODEPROTO *cell, INTBIG count, NODEINST **nodestocheck, BOOLEAN *validity,
 	BOOLEAN justarea)
 {
 	REGISTER LIBRARY *lib;
 	REGISTER NODEPROTO *np;
 	REGISTER INTBIG errorcount;
 
-	if (facet->cellview == el_schematicview || facet->tech == sch_tech)
+	if (cell->cellview == el_schematicview || cell->tech == sch_tech)
 	{
 		/* hierarchical check of schematics */
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 				np->temp1 = 0;
 		initerrorlogging(_("Schematic DRC"));
-		dr_checkschematicfacetrecursively(facet);
+		dr_checkschematiccellrecursively(cell);
 		errorcount = numerrors();
 		if (errorcount != 0) ttyputmsg(_("TOTAL OF %ld ERRORS FOUND"), errorcount);
 		termerrorlogging(TRUE);
 		return;
 	}
-	dr_quickcheck(facet, count, nodestocheck, validity, justarea);
+	dr_quickcheck(cell, count, nodestocheck, validity, justarea);
 }
 
 /****************************** SCHEMATIC DRC ******************************/
 
-void dr_checkschematicfacetrecursively(NODEPROTO *facet)
+void dr_checkschematiccellrecursively(NODEPROTO *cell)
 {
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *cnp;
 
-	facet->temp1 = 1;
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	cell->temp1 = 1;
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
 		cnp = contentsview(ni->proto);
@@ -1099,17 +1048,17 @@ void dr_checkschematicfacetrecursively(NODEPROTO *facet)
 		if (cnp->temp1 != 0) continue;
 
 		/* ignore documentation icon */
-		if (cnp->cell == facet->cell) continue;
+		if (isiconof(ni->proto, cell)) continue;
 
-		dr_checkschematicfacetrecursively(cnp);
+		dr_checkschematiccellrecursively(cnp);
 	}
 
-	/* now check this facet */
-	ttyputmsg(_("Checking schematic facet %s"), describenodeproto(facet));
-	dr_checkschematicfacet(facet, FALSE);
+	/* now check this cell */
+	ttyputmsg(_("Checking schematic cell %s"), describenodeproto(cell));
+	dr_checkschematiccell(cell, FALSE);
 }
 
-void dr_checkschematicfacet(NODEPROTO *facet, BOOLEAN justthis)
+void dr_checkschematiccell(NODEPROTO *cell, BOOLEAN justthis)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -1118,9 +1067,9 @@ void dr_checkschematicfacet(NODEPROTO *facet, BOOLEAN justthis)
 
 	if (justthis) initerrorlogging(_("Schematic DRC"));
 	initialerrorcount = numerrors();
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		dr_schdocheck(ni->geom);
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		dr_schdocheck(ai->geom);
 	errorcount = numerrors();
 	thiserrors = errorcount - initialerrorcount;
@@ -1136,19 +1085,20 @@ void dr_checkschematicfacet(NODEPROTO *facet, BOOLEAN justthis)
  */
 void dr_schdocheck(GEOM *geom)
 {
-	REGISTER NODEPROTO *facet, *np;
+	REGISTER NODEPROTO *cell, *np;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	ARCINST **thearcs;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTPROTO *pp;
 	REGISTER VARIABLE *var, *fvar;
+	REGISTER BOOLEAN checkdangle;
 	REGISTER INTBIG i, j, fun, signals, portwidth, nodesize;
 	INTBIG x, y;
 	void *err, *infstr;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
 
-	facet = geomparent(geom);
+	cell = geomparent(geom);
 	if (geom->entryisnode)
 	{
 		ni = geom->entryaddr.ni;
@@ -1164,7 +1114,7 @@ void dr_schdocheck(GEOM *geom)
 					if (pi->conarcinst->proto == sch_busarc) break;
 				if (pi == NOPORTARCINST)
 				{
-					err = logerror(_("Bus pin does not connect to any bus arcs"), facet, 0);
+					err = logerror(_("Bus pin does not connect to any bus arcs"), cell, 0);
 					addgeomtoerror(err, geom, TRUE, 0, 0);
 					return;
 				}
@@ -1176,7 +1126,7 @@ void dr_schdocheck(GEOM *geom)
 				if (pi->conarcinst->proto == sch_wirearc) i++;
 			if (i > 1)
 			{
-				err = logerror(_("Wire arcs cannot connect through a bus pin"), facet, 0);
+				err = logerror(_("Wire arcs cannot connect through a bus pin"), cell, 0);
 				addgeomtoerror(err, geom, TRUE, 0, 0);
 				for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 					if (pi->conarcinst->proto == sch_wirearc)
@@ -1199,7 +1149,7 @@ void dr_schdocheck(GEOM *geom)
 				}
 				if (i >= ni->numvar)
 				{
-					err = logerror(_("Stranded pin (not connected or exported)"), facet, 0);
+					err = logerror(_("Stranded pin (not connected or exported)"), cell, 0);
 					addgeomtoerror(err, geom, TRUE, 0, 0);
 					return;
 				}
@@ -1207,14 +1157,14 @@ void dr_schdocheck(GEOM *geom)
 
 			if (isinlinepin(ni, &thearcs))
 			{
-				err = logerror(_("Unnecessary pin (between 2 arcs)"), facet, 0);
+				err = logerror(_("Unnecessary pin (between 2 arcs)"), cell, 0);
 				addgeomtoerror(err, geom, TRUE, 0, 0);
 				return;
 			}
 
 			if (invisiblepinwithoffsettext(ni, &x, &y, FALSE))
 			{
-				err = logerror(_("Invisible pin has text in different location"), facet, 0);
+				err = logerror(_("Invisible pin has text in different location"), cell, 0);
 				addgeomtoerror(err, geom, TRUE, 0, 0);
 				addlinetoerror(err, (ni->lowx+ni->highx)/2, (ni->lowy+ni->highy)/2, x, y);
 				return;
@@ -1241,11 +1191,11 @@ void dr_schdocheck(GEOM *geom)
 				}
 				if (j >= np->numvar)
 				{
-					/* this node's parameter is no longer on the facet: delete from instance */
+					/* this node's parameter is no longer on the cell: delete from instance */
 					infstr = initinfstr();
 					formatinfstr(infstr, _("Parameter '%s' on node %s is invalid and has been deleted"),
 						truevariablename(var), describenodeinst(ni));
-					err = logerror(returninfstr(infstr), facet, 0);
+					err = logerror(returninfstr(infstr), cell, 0);
 					addgeomtoerror(err, geom, TRUE, 0, 0);
 					startobjectchange((INTBIG)ni, VNODEINST);
 					(void)delvalkey((INTBIG)ni, VNODEINST, var->key);
@@ -1253,13 +1203,13 @@ void dr_schdocheck(GEOM *geom)
 					i--;
 				} else
 				{
-					/* this node's parameter is still on the facet: make sure units are OK */
+					/* this node's parameter is still on the cell: make sure units are OK */
 					if (TDGETUNITS(var->textdescript) != TDGETUNITS(fvar->textdescript))
 					{
 						infstr = initinfstr();
 						formatinfstr(infstr, _("Parameter '%s' on node %s had incorrect units (now fixed)"),
 							truevariablename(var), describenodeinst(ni));
-						err = logerror(returninfstr(infstr), facet, 0);
+						err = logerror(returninfstr(infstr), cell, 0);
 						addgeomtoerror(err, geom, TRUE, 0, 0);
 						startobjectchange((INTBIG)ni, VNODEINST);
 						TDCOPY(descript, var->textdescript);
@@ -1276,7 +1226,7 @@ void dr_schdocheck(GEOM *geom)
 							infstr = initinfstr();
 							formatinfstr(infstr, _("Parameter '%s' on node %s should not be visible (now fixed)"),
 								truevariablename(var), describenodeinst(ni));
-							err = logerror(returninfstr(infstr), facet, 0);
+							err = logerror(returninfstr(infstr), cell, 0);
 							addgeomtoerror(err, geom, TRUE, 0, 0);
 							startobjectchange((INTBIG)ni, VNODEINST);
 							var->type &= ~VDISPLAY;
@@ -1289,7 +1239,7 @@ void dr_schdocheck(GEOM *geom)
 							infstr = initinfstr();
 							formatinfstr(infstr, _("Parameter '%s' on node %s should be visible (now fixed)"),
 								truevariablename(var), describenodeinst(ni));
-							err = logerror(returninfstr(infstr), facet, 0);
+							err = logerror(returninfstr(infstr), cell, 0);
 							addgeomtoerror(err, geom, TRUE, 0, 0);
 							startobjectchange((INTBIG)ni, VNODEINST);
 							var->type |= VDISPLAY;
@@ -1305,7 +1255,17 @@ void dr_schdocheck(GEOM *geom)
 
 		/* check for being floating if it does not have a visible name on it */
 		var = getvalkey((INTBIG)ai, VARCINST, -1, el_arc_name_key);
-		if (var == NOVARIABLE || (var->type&VDISPLAY) == 0)
+		if (var == NOVARIABLE || (var->type&VDISPLAY) == 0) checkdangle = TRUE; else
+			checkdangle = FALSE;
+		if (checkdangle)
+		{
+			/* do not check for dangle when busses are on named networks */
+			if (ai->proto == sch_busarc)
+			{
+				if (ai->network->namecount > 0 && ai->network->tempname == 0) checkdangle = FALSE;
+			}
+		}
+		if (checkdangle)
 		{
 			/* check to see if this arc is floating */
 			for(i=0; i<2; i++)
@@ -1323,8 +1283,8 @@ void dr_schdocheck(GEOM *geom)
 				if (ni->firstportarcinst == NOPORTARCINST) continue;
 				if (ni->firstportarcinst->nextportarcinst != NOPORTARCINST) continue;
 
-				/* the arc floats */
-				err = logerror(_("Arc floats"), facet, 0);
+				/* the arc dangles */
+				err = logerror(_("Arc dangles"), cell, 0);
 				addgeomtoerror(err, geom, TRUE, 0, 0);
 				return;
 			}
@@ -1332,8 +1292,11 @@ void dr_schdocheck(GEOM *geom)
 
 
 		/* check to see if its width is sensible */
-		signals = ai->network->buswidth;
-		if (signals < 1) signals = 1;
+		if (ai->network == NONETWORK) signals = 1; else
+		{
+			signals = ai->network->buswidth;
+			if (signals < 1) signals = 1;
+		}
 		for(i=0; i<2; i++)
 		{
 			ni = ai->end[i].nodeinst;
@@ -1341,6 +1304,16 @@ void dr_schdocheck(GEOM *geom)
 			np = contentsview(ni->proto);
 			if (np == NONODEPROTO) np = ni->proto;
 			pp = equivalentport(ni->proto, ai->end[i].portarcinst->proto, np);
+			if (pp == NOPORTPROTO)
+			{
+				infstr = initinfstr();
+				formatinfstr(infstr, _("Arc %s connects to port %s of node %s, but there is no equivalent port in cell %s"),
+					describearcinst(ai), ai->end[i].portarcinst->proto->protoname, describenodeinst(ni), describenodeproto(np));
+				err = logerror(returninfstr(infstr), cell, 0);
+				addgeomtoerror(err, geom, TRUE, 0, 0);
+				addgeomtoerror(err, ni->geom, TRUE, 0, 0);
+				continue;
+			}
 			portwidth = pp->network->buswidth;
 			if (portwidth < 1) portwidth = 1;
 			nodesize = ni->arraysize;
@@ -1350,7 +1323,7 @@ void dr_schdocheck(GEOM *geom)
 				infstr = initinfstr();
 				formatinfstr(infstr, _("Arc %s (%ld wide) connects to port %s of node %s (%ld wide)"),
 					describearcinst(ai), signals, pp->protoname, describenodeinst(ni), portwidth);
-				err = logerror(returninfstr(infstr), facet, 0);
+				err = logerror(returninfstr(infstr), cell, 0);
 				addgeomtoerror(err, geom, TRUE, 0, 0);
 				addgeomtoerror(err, ni->geom, TRUE, 0, 0);
 			}
@@ -1422,7 +1395,7 @@ BOOLEAN dr_schcheckpolygonvicinity(GEOM *geom, POLYGON *poly)
 {
 	REGISTER NODEINST *ni, *oni;
 	REGISTER ARCINST *ai, *oai;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER GEOM *ogeom;
 	REGISTER PORTARCINST *pi;
 	REGISTER NETWORK *net;
@@ -1437,9 +1410,9 @@ BOOLEAN dr_schcheckpolygonvicinity(GEOM *geom, POLYGON *poly)
 		poly->style == TEXTBOTRIGHT || poly->style == TEXTBOX ||
 		poly->style == GRIDDOTS) return(FALSE);
 
-	facet = geomparent(geom);
+	cell = geomparent(geom);
 	if (geom->entryisnode) ni = geom->entryaddr.ni; else ai = geom->entryaddr.ai;
-	sea = initsearch(geom->lowx, geom->highx, geom->lowy, geom->highy, facet);
+	sea = initsearch(geom->lowx, geom->highx, geom->lowy, geom->highy, cell);
 	for(;;)
 	{
 		ogeom = nextobject(sea);
@@ -1456,14 +1429,14 @@ BOOLEAN dr_schcheckpolygonvicinity(GEOM *geom, POLYGON *poly)
 			if (geom->entryisnode)
 			{
 				/* this is node, nearby is node: see if two nodes touch */
-				for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+				for(net = cell->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 					net->temp1 = 0;
 				for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 					pi->conarcinst->network->temp1 |= 1;
 				for(pi = oni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 					pi->conarcinst->network->temp1 |= 2;
-				for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
-					if (net->temp1 = 3) break;
+				for(net = cell->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+					if (net->temp1 == 3) break;
 				if (net != NONETWORK) continue;
 			} else
 			{			
@@ -1691,7 +1664,7 @@ BOOLEAN dr_schcheckcolinear(ARCINST *ai, ARCINST *oai)
 
 	/* add information that shows the arcs */
 	ang = (ang + 900) % 3600;
-	dist = ai->parent->cell->lib->lambda[ai->parent->tech->techindex] * 2;
+	dist = ai->parent->lib->lambda[ai->parent->tech->techindex] * 2;
 	gdist = dist / 2;
 	ca = cosine(ang);   sa = sine(ang);
 	frx = fx + mult(dist, ca);
@@ -1735,7 +1708,7 @@ static DIALOGITEM dr_optionsdialogitems[] =
  /*  8 */ {0, {64,8,80,169}, MESSAGE, N_("Hierarchical DRC:")},
  /*  9 */ {0, {248,8,264,169}, MESSAGE, N_("Dracula DRC Interface:")},
  /* 10 */ {0, {112,32,128,192}, BUTTON, N_("Clear valid DRC dates")},
- /* 11 */ {0, {88,32,104,228}, CHECK, N_("Just 1 error per facet")},
+ /* 11 */ {0, {88,32,104,228}, CHECK, N_("Just 1 error per cell")},
  /* 12 */ {0, {216,32,232,296}, CHECK, N_("Ignore center cuts in large contacts")},
  /* 13 */ {0, {192,48,208,212}, MESSAGE, N_("Number of processors:")},
  /* 14 */ {0, {168,32,184,217}, CHECK, N_("Use multiple processors")},
@@ -1751,7 +1724,7 @@ static DIALOG dr_optionsdialog = {{50,75,387,381}, N_("DRC Options"), 0, 18, dr_
 #define DDRO_DRCON         5		/* Incremental DRC is on (check) */
 #define DDRO_NUMPROC       6		/* Number of processors to use (edit text) */
 #define DDRO_CLEARDATES   10		/* Clear valid DRC dates (button) */
-#define DDRO_JUST1ERROR   11		/* Find 1 error per facet (check) */
+#define DDRO_JUST1ERROR   11		/* Find 1 error per cell (check) */
 #define DDRO_FEWERCUTS    12		/* Ignore center cuts in large contacts (check) */
 #define DDRO_USEMULTIPROC 14		/* Use multiple processors (check) */
 
