@@ -37,7 +37,7 @@
 #include "efunction.h"
 #include "egraphics.h"
 
-#define MAX_DRC_FLATIGNORE 100				/* max facets to ignore */
+#define MAX_DRC_FLATIGNORE 100				/* max cells to ignore */
 #define FLATDRCNAME        x_("ffindshort")		/* fast short program */
 #define SFLATDRCNAME       x_("findshort")		/* slow short program */
 #define SORTNAME           x_("sort")			/* sort program */
@@ -61,52 +61,52 @@ static void    dr_flatdesc_poly(POLYGON*, INTBIG, XARRAY, TECHNOLOGY*, NODEPROTO
 static void    dr_flatprop(ARCINST*, INTBIG);
 
 /*
- * routine to flag facet "facet" as ignorable for flat DRC
+ * routine to flag cell "cell" as ignorable for flat DRC
  */
-void dr_flatignore(CHAR *facet)
+void dr_flatignore(CHAR *cell)
 {
 	INTBIG i;
 	REGISTER NODEPROTO *np;
 
-	np = getnodeproto(facet);
+	np = getnodeproto(cell);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("No facet called %s"), facet);
+		ttyputerr(_("No cell called %s"), cell);
 		return;
 	}
 	if (np->primindex != 0)
 	{
-		ttyputerr(_("Can only ignore facets, not primitives"));
+		ttyputerr(_("Can only ignore cells, not primitives"));
 		return;
 	}
 	for(i=0; i<dr_nflat_ignored; i++) if (dr_flatignored[i] == np)
 		return;
 	if (dr_nflat_ignored == MAX_DRC_FLATIGNORE)
 	{
-		ttyputerr(_("Too many facets"));
+		ttyputerr(_("Too many cells"));
 		return;
 	}
 	dr_flatignored[dr_nflat_ignored++] = np;
-	ttyputmsg(_("Facet %s will be ignored from flat DRC"), describenodeproto(np));
+	ttyputmsg(_("Cell %s will be ignored from flat DRC"), describenodeproto(np));
 }
 
 /*
- * routine to flag facet "facet" as not ignorable for flat DRC
+ * routine to flag cell "cell" as not ignorable for flat DRC
  */
-void dr_flatunignore(CHAR *facet)
+void dr_flatunignore(CHAR *cell)
 {
 	INTBIG i;
 	REGISTER NODEPROTO *np;
 
-	np = getnodeproto(facet);
+	np = getnodeproto(cell);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("No facet called %s"), facet);
+		ttyputerr(_("No cell called %s"), cell);
 		return;
 	}
 	if (np->primindex != 0)
 	{
-		ttyputerr(_("Can only unignore facets, not primitives"));
+		ttyputerr(_("Can only unignore cells, not primitives"));
 		return;
 	}
 	for(i=0; i<dr_nflat_ignored && dr_flatignored[i] != np; i++) ;
@@ -118,7 +118,7 @@ void dr_flatunignore(CHAR *facet)
 	for(; i<dr_nflat_ignored; i++)
 		dr_flatignored[i-1] = dr_flatignored[i];
 	dr_nflat_ignored--;
-	ttyputmsg(_("Facet %s will be included in flat DRC"), describenodeproto(np));
+	ttyputmsg(_("Cell %s will be included in flat DRC"), describenodeproto(np));
 }
 
 void dr_flatwrite(NODEPROTO *simnp)
@@ -133,19 +133,19 @@ void dr_flatwrite(NODEPROTO *simnp)
 
 	if (simnp == NONODEPROTO)
 	{
-		ttyputerr(_("No facet to flatten for DRC"));
+		ttyputerr(_("No cell to flatten for DRC"));
 		return;
 	}
 	dr_maintech = simnp->tech;
 
 	/* create output file names */
-	(void)esnprintf(dr_flatdrcfile, 132, x_("%s"), simnp->cell->cellname);
+	(void)esnprintf(dr_flatdrcfile, 132, x_("%s"), simnp->protoname);
 	(void)estrcat(dr_flatdrcfile, x_(".drc"));
 
-	(void)esnprintf(dr_yminfile, 132, x_("%s"), simnp->cell->cellname);
+	(void)esnprintf(dr_yminfile, 132, x_("%s"), simnp->protoname);
 	(void)estrcat(dr_yminfile, x_("_miny.drc"));
 
-	(void)esnprintf(dr_ymaxfile, 132, x_("%s"), simnp->cell->cellname);
+	(void)esnprintf(dr_ymaxfile, 132, x_("%s"), simnp->protoname);
 	(void)estrcat(dr_ymaxfile, x_("_maxy.drc"));
 
 	/* create the file */
@@ -158,7 +158,7 @@ void dr_flatwrite(NODEPROTO *simnp)
 	ttyputmsg(_("Writing flattened %s circuit into '%s'..."),
 		dr_maintech->techname, dr_flatdrcfile);
 
-	/* re-assign net-list values, starting at each port of the top facet */
+	/* re-assign net-list values, starting at each port of the top cell */
 	dr_index = 1;
 	for(pp = simnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
@@ -322,10 +322,10 @@ BOOLEAN dr_readshorterrors(EProcess &process)
 }
 
 /*
- * routine to flatten hierarchy from facet "facet" down, printing boxes and
- * net numbers.  The transformation into the facet is "mytrans".
+ * routine to flatten hierarchy from cell "cell" down, printing boxes and
+ * net numbers.  The transformation into the cell is "mytrans".
  */
-void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
+void dr_flatprint(NODEPROTO *cell, XARRAY mytrans)
 {
 	REGISTER INTBIG i;
 	REGISTER ARCINST *ai;
@@ -339,18 +339,18 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 
 	if (stopping(STOPREASONDRC)) return;
 
-	/* see if this facet is to be ignored */
-	for(i = 0; i < dr_nflat_ignored; i++) if (facet == dr_flatignored[i]) return;
+	/* see if this cell is to be ignored */
+	for(i = 0; i < dr_nflat_ignored; i++) if (cell == dr_flatignored[i]) return;
 
 	/* make sure there is a polygon */
 	(void)needstaticpolygon(&poly, 4, dr_tool->cluster);
 
 	/* reset the arcinst node values */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		ai->temp2 = 0;
 
-	/* propagate port numbers to arcs in the facet */
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	/* propagate port numbers to arcs in the cell */
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		/* find a connecting arc on the node that this port comes from */
 		for(pi = pp->subnodeinst->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -364,23 +364,23 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 	}
 
 	/* set node numbers on arcs that are local */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		if (ai->temp2 == 0) dr_flatprop(ai, dr_index++);
 
-	/* write every arc in the facet */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	/* write every arc in the cell */
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->proto->tech != dr_maintech) continue;
 		n = arcpolys(ai, NOWINDOWPART);
 		for(i = 0; i < n; i++)
 		{
 			shapearcpoly(ai, i, poly);
-			dr_flatdesc_poly(poly, ai->temp2, mytrans, ai->proto->tech, facet);
+			dr_flatdesc_poly(poly, ai->temp2, mytrans, ai->proto->tech, cell);
 		}
 	}
 
-	/* write every node in the facet */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* write every node in the cell */
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* initialize network numbers on every port on this node */
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -427,7 +427,7 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 					if (poly->portproto == NOPORTPROTO) continue;
 					dr_transistor_hack(poly, ni);
 					xformpoly(poly, subtrans);
-					dr_flatdesc_poly(poly, poly->portproto->temp2, mytrans, ni->proto->tech, facet);
+					dr_flatdesc_poly(poly, poly->portproto->temp2, mytrans, ni->proto->tech, cell);
 				}
 			}
 		} else
@@ -519,7 +519,7 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 		st = &thistn->ele[i];
 		active_overlap = st->lwidth + st->rwidth;
 		i=0; do lay = &thistn->ele[i++].basics; while (lay->portnum != 0);
-		gate_min_distance = drcmindistance(ni->proto->tech, ni->parent->cell->lib,
+		gate_min_distance = drcmindistance(ni->proto->tech, ni->parent->lib,
 			lay->layernum, 0, lay->layernum, 0, FALSE, FALSE, &edge, 0);
 		if (active_overlap > gate_min_distance)
 		{
@@ -568,7 +568,7 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
  * number is "net".  The polygon is transformed by "trans" and is from
  * technology "tech".
  */
-void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech, NODEPROTO *facet)
+void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech, NODEPROTO *cell)
 {
 	INTBIG lx, hx, ly, hy, lxb, hxb, lyb, hyb;
 	REGISTER INTBIG xv, yv;
@@ -579,7 +579,7 @@ void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech,
 	if (*(((CHAR **)tech->temp1)[poly->layer]) == 0) return;
 
 	/* ignore layers that have no design rules */
-	if (maxdrcsurround(tech, facet->cell->lib, poly->layer) < 0) return;
+	if (maxdrcsurround(tech, cell->lib, poly->layer) < 0) return;
 
 	xformpoly(poly, trans);
 	getbbox(poly, &lxb, &hxb, &lyb, &hyb);
