@@ -112,12 +112,7 @@ static INTBIG gra_badcoord(WINDOWFRAME *wf, INTBIG x, INTBIG y, CHAR *where )
 
 	if (x < 0 || x >= wf->swid || y < 0 || y >= height)
 	{
-#if 0		/* for debugging bad coordinates */
-		printf(_("Bad coordinate from %s: (%ld,%ld), window is %ldx%ld\n"), where,
-			x, y, wf->swid, height);
-#else
 		Q_UNUSED( where );
-#endif
 		return(1);
 	}
 	return(0);
@@ -651,12 +646,12 @@ void gra_drawbox(WINDOWPART *win, INTBIG lowx, INTBIG highx, INTBIG lowy, INTBIG
 	GRAPHICS *desc)
 {
 	REGISTER WINDOWFRAME *wf;
-	INTBIG col, mask, style, x, y, left, right, bottom, top, pat;
-	UCHAR1 *thisrow;
+	REGISTER INTBIG style, x, y, left, right, bottom, top, pat;
+	REGISTER UCHAR1 *thisrow, mask, col;
 
 	/* get graphics parameters */
 	wf = win->frame;
-	col = desc->col;   mask = ~desc->bits;
+	col = (UCHAR1)desc->col;   mask = (UCHAR1)(~desc->bits);
 	style = desc->colstyle & NATURE;
 	left = lowx;                  right = highx + 1;
 	bottom = wf->revy-lowy + 1;   top = wf->revy-highy;
@@ -671,20 +666,24 @@ void gra_drawbox(WINDOWPART *win, INTBIG lowx, INTBIG highx, INTBIG lowy, INTBIG
 		{
 			pat = desc->raster[y&15];
 			if (pat == 0) continue;
-			thisrow = wf->rowstart[y];
+			thisrow = &wf->rowstart[y][left];
 			for(x=left; x<right; x++)
 			{
 				if ((pat & (1 << (15-(x&15)))) != 0)
-					thisrow[x] = (UCHAR1)((thisrow[x] & mask) | col);
+					*thisrow = (*thisrow & mask) | col;
+				thisrow++;
 			}
 		}
 	} else
 	{
 		for(y=top; y<bottom; y++)
 		{
-			thisrow = wf->rowstart[y];
+			thisrow = &wf->rowstart[y][left];
 			for(x=left; x<right; x++)
-				thisrow[x] = (UCHAR1)((thisrow[x] & mask) | col);
+			{
+				*thisrow = (*thisrow & mask) | col;
+				thisrow++;
+			}
 		}
 	}
 	gra_setrect(wf, left, right, top, bottom);
