@@ -41,8 +41,6 @@
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
 #endif
 
 #if LANGTCL
@@ -97,7 +95,7 @@ BOOL CElectricApp::InitInstance()
 #endif
 
 	/* change the registry key under which our settings are stored */
-	SetRegistryKey(_T("Static-Free-Software"));
+	SetRegistryKey(x_("Static-Free-Software"));
 
 	/* load standard INI file options (including MRU) */
 	LoadStdProfileSettings();
@@ -138,38 +136,38 @@ BOOL CElectricApp::InitInstance()
 		return FALSE;
 
 	/* get former location of Electric window (presume maximized if nothing saved) */
-	char *pt, tmp[256], subkey[256], value[256];
+	CHAR *pt, tmp[256], subkey[256], value[256];
 	WINDOWPLACEMENT wndpl;
 	int top, left, bottom, right, fullscreen;
-	INTBIG gra_getregistry(HKEY key, char *subkey, char *value, char *result);
+	INTBIG gra_getregistry(HKEY key, CHAR *subkey, CHAR *value, CHAR *result);
 	pMainFrame->GetWindowPlacement(&wndpl);
-	strcpy(subkey, "Software\\Static Free Software\\Electric");
-	strcpy(value, "Window_Location");
+	estrcpy(subkey, x_("Software\\Static Free Software\\Electric"));
+	estrcpy(value, x_("Window_Location"));
 	if (gra_getregistry(HKEY_LOCAL_MACHINE, subkey, value, tmp) == 0)
 	{
 		/* key has the format: T,L,B,R,MAX */
 		pt = tmp;
-		top = atoi(pt);
+		top = eatoi(pt);
 		while(*pt != ',' && *pt != 0) pt++;
 		if (*pt == ',')
 		{
 			pt++;
-			left = atoi(pt);
+			left = eatoi(pt);
 			while(*pt != ',' && *pt != 0) pt++;
 			if (*pt == ',')
 			{
 				pt++;
-				bottom = atoi(pt);
+				bottom = eatoi(pt);
 				while(*pt != ',' && *pt != 0) pt++;
 				if (*pt == ',')
 				{
 					pt++;
-					right = atoi(pt);
+					right = eatoi(pt);
 					while(*pt != ',' && *pt != 0) pt++;
 					if (*pt == ',')
 					{
 						pt++;
-						fullscreen = atoi(pt);
+						fullscreen = eatoi(pt);
 					}
 				}
 			}
@@ -199,18 +197,18 @@ BOOL CElectricApp::InitInstance()
 	/* primary initialization of Electric */
 	osprimaryosinit();
 
+	/* secondary initialization of Electric */
+	INTBIG argc;
+	CHAR1 *argv[4];
+	argc = 1;
+	argv[0] = b_("electric");
+	ossecondaryinit(argc, argv);
+
 #if LANGTCL
 	/* initialize TCL here */
 	if (gra_initializetcl() == TCL_ERROR)
 		error(_("TCL initialization failed: %s\n"), tcl_interp->result);
 #endif
-
-	/* secondary initialization of Electric */
-	INTBIG argc;
-	char *argv[4];
-	argc = 1;
-	argv[0] = "electric";
-	ossecondaryinit(argc, argv);
 	return TRUE;
 }
 
