@@ -147,16 +147,6 @@ int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
 		return -1;      /* fail to create */
 	}
 
-#if 0	/* make a floating window */
-	RECT r;
-	r.left = 1150;   r.right = 1250;
-	r.top = 20;    r.bottom = 600;
-	m_wndComponentMenu = new CFrameWnd();
-	m_wndComponentMenu->Create(NULL, x_("Components"),
-		WS_OVERLAPPED|WS_CAPTION, r, this, NULL, WS_EX_TOOLWINDOW, NULL);
-	m_wndComponentMenu->ShowWindow(SW_SHOW);
-#endif
-
 	/* count off tenths of a second */
 	SetTimer(1, 100, 0);
 
@@ -273,7 +263,7 @@ void CMainFrame::OnMenuSelect(UINT nItemID, UINT nFlags, HMENU hSysMenu)
 	for(i=0; i<gra_pulldownmenucount; i++)
 	{
 		/*
-		 * For some reason, the newest version of Visual Studio (.NET)
+		 * For some reason, the first version of Visual Studio (.NET)
 		 * does not pass the HMENU as the 3rd argument to this routine,
 		 * but instead passes the CMenu*.
 		 *
@@ -281,10 +271,13 @@ void CMainFrame::OnMenuSelect(UINT nItemID, UINT nFlags, HMENU hSysMenu)
 		 *
 		 * This means that different code must be used to look up the value.
 		 *
-		 * To tell whether this is Visual Studio .NET, look at the compiler version
-		 * It is 1200 for Visual Studio 6, and 1300 for Visual Studio .NET
+		 * To tell whether this is the first version of Visual Studio .NET,
+		 * look at the compiler version.  It is:
+		 *   1200 for Visual Studio 6,
+		 *   1300 for the first version of Visual Studio .NET
+		 *   1310 for the second version of Visual Studio .NET
 		 */
-#if _MSC_VER > 1200
+#if _MSC_VER == 1300
 		if ((CMenu *)hSysMenu == gra_pulldownmenus[i])
 #else
 		if (hSysMenu == gra_pulldownmenus[i]->m_hMenu)
