@@ -203,17 +203,4 @@ void CElectricMsgView::LoadColors(void)
 	ctrl->SetSelectionCharFormat(cf);
 	ctrl->SetSel(startsel, endsel);
 	ctrl->SetDefaultCharFormat(cf);
-
-#if 0		/* code for changing background color of messages window */
-	int pos = ctrl->GetLimitText();
-	ctrl->SetSel(pos, pos);
-	ctrl->ReplaceSel(x_("Color changes\r\n"));
-	ctrl->SetRedraw(TRUE);
-	ctrl->Invalidate();
-	GdiFlush();
-	extern CChildFrame *gra_messageswindow;
-	gra_messageswindow->ShowWindow(SW_RESTORE);
-	gra_messageswindow->BringWindowToTop();
-	gra_activateframe(gra_messageswindow, true);
-#endif
 }
