@@ -50,10 +50,9 @@
 /* CHARPIXMAP - use 32-bit QPixmap instead of 1-bit QBitmap for glyph drawing */
 #  define CHARPIXMAP
 #  define MESSMENU /* menu in messages window */
+#  define DOUBLESELECT
 #endif
 
-#define ACTIVATION
-
 //#define USEMDI
 
 #ifndef Q_ASSERT
@@ -91,6 +90,7 @@ public slots:
     void lineEntered();
     void setIcons();
 protected:
+	void windowActivationChange( bool oldActive );
     void keyPressEvent( QKeyEvent *e );
     bool eventFilter( QObject *watched, QEvent *e ); 
 private:
@@ -113,6 +113,7 @@ public:
     void focusOutEvent( QFocusEvent *e );
     void paintEvent( QPaintEvent *e );
     void keyPressEvent( QKeyEvent *e );
+	void keyReleaseEvent( QKeyEvent *e );
     void mouseDoubleClickEvent( QMouseEvent *e );
     void mouseMoveEvent( QMouseEvent *e );
     void mousePressEvent( QMouseEvent *e );
@@ -120,12 +121,10 @@ public:
     void resizeEvent( QResizeEvent *e );
     void wheelEvent( QWheelEvent * e);
     bool eventFilter( QObject *watched, QEvent *e ); 
-#ifdef ACTIVATION
 protected:
 	void windowActivationChange( bool oldActive );
-#endif
 private:
-    BOOLEAN keepCursorPos( QPoint pos );
+    void keepCursorPos( QPoint pos );
     void buttonPressed( QPoint pos, INTSML but );
     void recalcSize();
 public:
@@ -133,6 +132,8 @@ public:
     int colorvalue[256];
     /* offscreen data is in "image" and drawn by "graphdraw.c" */
     QImage image;
+private:
+	bool metaheld; // Unix Meta key mod doesn't come through in key modifier state
 };
 
 class EMainWindow: public QMainWindow
@@ -173,11 +174,15 @@ class EApplication: public QApplication
 public:
     EApplication( int &argc, char **argv);
     ~EApplication();
+	bool notify( QObject *receiver, QEvent *e );
 	EMessages *messages;
 	EApplicationWindow *mw;
     static char *localize (QString qstr);
     static char *localizeFilePath (QString filePath, bool addSeparator );
     int translatekey(QKeyEvent *e, INTBIG *special);
+#ifdef DOUBLESELECT
+	void activationChange();
+#endif
     
     QBitmap textbits;
 #ifdef CHARPIXMAP
