@@ -450,6 +450,7 @@ EDialog::~EDialog()
     itemdesc->windowRect.top += disp.y();
     itemdesc->windowRect.bottom += disp.y();
 
+	d->dia = 0;
     d->deleteLater();
 	gra->toolTimeSlice();
 }
@@ -1453,6 +1454,13 @@ EDialogPrivate::EDialogPrivate(QWidget *parent, const char *name )
 {
 }
 
+EDialogPrivate::~EDialogPrivate()
+{
+#ifdef DOUBLESELECT
+	gra->activationChange();
+#endif
+}
+
 void EDialogPrivate::init( EDialog *dia, bool modal )
 {
 	INTBIG i, j, itemtype, x, y, wid, hei;
@@ -1866,7 +1874,8 @@ void EDialogPrivate::action(int id)
     INTBIG item;
 
     item = ((int)id) & 0xFFFF;
-    dia->itemHitAction( item+1 );
+	if ( dia )
+		dia->itemHitAction( item+1 );
 }
 
 void EDialogPrivate::closeEvent( QCloseEvent *e )
@@ -1877,7 +1886,7 @@ void EDialogPrivate::closeEvent( QCloseEvent *e )
 void EDialogPrivate::keyPressEvent( QKeyEvent *e )
 {
     /* handle escape key (fakes a click on item 2 */
-    if( e->key() == Key_Escape && isModal() )
+    if( e->key() == Key_Escape && isModal() && dia )
 	{
 		dia->itemHitAction(2);
 		return;
