@@ -62,7 +62,7 @@ typedef struct
 
 /***************** FOR THE TEXT-TO-GRAPHICS SYSTEM *************/
 
-extern NODEPROTO *cli_curfacet;		/* the current facet being equated to text */
+extern NODEPROTO *cli_curcell;		/* the current cell being equated to text */
 extern BOOLEAN    cli_ownchanges;	/* true if changes are internally generated */
 extern INTBIG     cli_textlines;	/* number of declaration/connection lines */
 extern BOOLEAN    cli_texton;		/* true if text/graphics system is on */
@@ -73,8 +73,8 @@ extern BOOLEAN    cli_texton;		/* true if text/graphics system is on */
 #define LINEDECL   2				/* line is a "declare" statement */
 #define LINECONN   3				/* line is a "connect" statement */
 #define LINEEXPORT 4				/* line is an "export" statement */
-#define LINEBEGIN  5				/* line is a "beginfacet" statement */
-#define LINEEND    6				/* line is a "endfacet" statement */
+#define LINEBEGIN  5				/* line is a "begincell" statement */
+#define LINEEND    6				/* line is a "endcell" statement */
 
 /***************** ADDITIONAL ATTRIBUTES *************/
 
@@ -209,7 +209,7 @@ extern COMCOMP cli_linconp;
 
 /***************** PROTOTYPES FOR INTERMODULE ROUTINES *************/
 
-void cli_maketextfacet(NODEPROTO*);
+void cli_maketextcell(NODEPROTO*);
 void cli_highlightequivalent(GEOM*);
 void cli_eq_solve(void);
 void cli_eq_newnode(NODEINST*);
@@ -227,19 +227,19 @@ INTBIG cli_linetype(CHAR*);
 COMPONENTDEC *cli_parsecomp(CHAR*, BOOLEAN);
 void cli_deletecomponentdec(COMPONENTDEC*);
 WINDOWPART *cli_makeeditorwindow(CHAR*, INTBIG*, INTBIG*);
-void cli_replaceendfacet(CHAR*, WINDOWPART*);
+void cli_replaceendcell(CHAR*, WINDOWPART*);
 EXPORT *cli_parseexport(CHAR*, BOOLEAN);
 void cli_deleteexport(EXPORT*);
 CONNECTION *cli_parseconn(CHAR*, BOOLEAN);
 void cli_deleteconnection(CONNECTION*);
 ARCINST *cli_findarcname(CHAR*);
 NODEINST *cli_findnodename(CHAR*);
-CHAR *cli_parsebeginfacet(CHAR*, BOOLEAN);
+CHAR *cli_parsebegincell(CHAR*, BOOLEAN);
 void cli_replacename(CHAR*, CHAR*);
 BOOLEAN cli_pickwire(CONNECTION*, NODEINST**, PORTPROTO**, NODEINST**, PORTPROTO**, ARCPROTO**, INTBIG*, ARCINST*, NODEINST*, NODEINST*);
 void cli_deletearcconstraint(ARCINST*, INTBIG, INTBIG, INTBIG);
 BOOLEAN cli_addarcconstraint(ARCINST*, INTBIG, INTBIG, INTBIG, INTBIG);
-void cli_solvefacet(NODEPROTO*, BOOLEAN, BOOLEAN);
+void cli_solvecell(NODEPROTO*, BOOLEAN, BOOLEAN);
 BOOLEAN cli_uniqueport(NODEINST*, PORTPROTO*);
 void cli_deleteequivcon(ARCINST*);
 void cli_changeequivcomp(NODEINST*);
