@@ -34,8 +34,6 @@ extern "C"
 {
 #endif
 
-#define HASHCELLNAMES 1					/* define to use hash table for cell names */
-
 /*************************** FLAG BIT SETTINGS ****************************/
 
 #define MARKN             040				/* NODEINST->userbits: nodeinst is marked */
@@ -43,8 +41,8 @@ extern "C"
 
 #define FIXEDMOD   0100000000				/* ARCINST->userbits: fixed arc was changed */
 
-#define FACETMOD      0400000				/* NODEPROTO->userbits: facet is changed */
-#define FACETNOMOD   01000000				/* NODEPROTO->userbits: facet is not changed */
+#define CELLMOD       0400000				/* NODEPROTO->userbits: cell is changed */
+#define CELLNOMOD    01000000				/* NODEPROTO->userbits: cell is not changed */
 
 /*************************** CHANGES ****************************/
 
@@ -93,14 +91,14 @@ typedef struct Ichange
 
 /*************************** CHANGE BATCHES ****************************/
 
-#define NOCHANGEFACET	((CHANGEFACET *)-1)
+#define NOCHANGECELL	((CHANGECELL *)-1)
 
-typedef struct Ichangefacet
+typedef struct Ichangecell
 {
-	NODEPROTO           *changefacet;		/* the facet that changed */
+	NODEPROTO           *changecell;		/* the cell that changed */
 	BOOLEAN              forcedlook;		/* true if library must be re-examined */
-	struct Ichangefacet *nextchangefacet;	/* next in list */
-} CHANGEFACET;
+	struct Ichangecell  *nextchangecell;	/* next in list */
+} CHANGECELL;
 
 
 #define NOCHANGEBATCH	((CHANGEBATCH *)-1)
@@ -111,7 +109,7 @@ typedef struct Ichangebatch
 	CHANGE              *changetail;		/* tail of list of things to change */
 	struct Ichangebatch *nextchangebatch;	/* next in list */
 	struct Ichangebatch *lastchangebatch;	/* last in list */
-	CHANGEFACET         *firstchangefacet;	/* the facet in which this change was made */
+	CHANGECELL          *firstchangecell;	/* the cell in which this change was made */
 	TOOL                *tool;				/* tool that made this batch */
 	CHAR                *activity;			/* description of activity */
 	INTBIG               batchnumber;		/* identifying index of this batch */
@@ -174,14 +172,14 @@ typedef struct Ipolylisthead
 #define DBBADENDAP     13					/* bad end A position */
 #define DBBADENDBP     14					/* bad end B position */
 #define DBBADNEWWID    15					/* bad new width */
-#define DBBADFACET     16					/* bad facet */
+#define DBBADCELL      16					/* bad cell */
 #define DBBADLIB       17					/* bad library */
 #define DBBADSIZE      18					/* bad size */
 #define DBBADOBJECT    19					/* bad object type */
 #define DBBADSUBPORT   20					/* bad sub port */
 #define DBHASARCS      21					/* still has arcs */
 #define DBHASPORTS     22					/* still has ports */
-#define DBHASINSTANCES 23					/* facet has instances */
+#define DBHASINSTANCES 23					/* cell has instances */
 #define DBRECURSIVE    24					/* recursive call */
 #define DBNOTINPORT    25					/* arc not in port */
 #define DBCONFLICT     26					/* conflicts with primitive */
@@ -200,52 +198,51 @@ typedef struct Ipolylisthead
 #define DBADDTECHNOLOGY			(2<<16)
 #define DBADDTOINFSTR			(3<<16)
 #define DBALLOCARCINST			(4<<16)
-#define DBALLOCCELL				(5<<16)
-#define DBALLOCGEOM				(6<<16)
-#define DBALLOCLIBRARY			(7<<16)
-#define DBALLOCNODEINST			(8<<16)
-#define DBALLOCNODEPROTO		(9<<16)
-#define DBALLOCPOLYGON			(10<<16)
-#define DBALLOCPORTARCINST		(11<<16)
-#define DBALLOCPORTEXPINST		(12<<16)
-#define DBALLOCPORTPROTO		(13<<16)
-#define DBALLOCSTRING			(14<<16)
-#define DBALLOCTECHNOLOGY		(15<<16)
-#define DBALLOCVIEW				(16<<16)
-#define DBCOPYNODEPROTO			(17<<16)
-#define DBDELIND				(18<<16)
-#define DBDELINDKEY				(19<<16)
-#define DBDELVALKEY				(20<<16)
-#define DBDESCRIBEVARIABLE		(21<<16)
-#define DBEXTENDPOLYGON			(22<<16)
-#define DBINITINFSTR			(23<<16)
-#define DBINITOBJLIST			(24<<16)
-#define DBINSIND				(25<<16)
-#define DBINSINDKEY				(26<<16)
-#define DBKILLARCINST			(27<<16)
-#define DBKILLLIBRARY			(28<<16)
-#define DBKILLNODEINST			(29<<16)
-#define DBKILLNODEPROTO			(30<<16)
-#define DBKILLPORTPROTO			(31<<16)
-#define DBKILLTECHNOLOGY		(32<<16)
-#define DBMAKEKEY				(33<<16)
-#define DBMODIFYARCINST			(34<<16)
-#define DBMOVEPORTPROTO			(35<<16)
-#define DBNEWARCINST			(36<<16)
-#define DBNEWLIBRARY			(37<<16)
-#define DBNEWNODEINST			(38<<16)
-#define DBNEWNODEPROTO			(39<<16)
-#define DBNEWPORTPROTO			(40<<16)
-#define DBNEWVIEW				(41<<16)
-#define DBREPLACEARCINST		(42<<16)
-#define DBREPLACENODEINST		(43<<16)
-#define DBRETURNINFSTR			(44<<16)
-#define DBSETIND				(45<<16)
-#define DBSETINDKEY				(46<<16)
-#define DBSETVAL				(47<<16)
-#define DBSETVALKEY				(48<<16)
-#define DBTRANSMULT				(49<<16)
-#define DBXFORM					(50<<16)
+#define DBALLOCGEOM				(5<<16)
+#define DBALLOCLIBRARY			(6<<16)
+#define DBALLOCNODEINST			(7<<16)
+#define DBALLOCNODEPROTO		(8<<16)
+#define DBALLOCPOLYGON			(9<<16)
+#define DBALLOCPORTARCINST		(10<<16)
+#define DBALLOCPORTEXPINST		(11<<16)
+#define DBALLOCPORTPROTO		(12<<16)
+#define DBALLOCSTRING			(13<<16)
+#define DBALLOCTECHNOLOGY		(14<<16)
+#define DBALLOCVIEW				(15<<16)
+#define DBCOPYNODEPROTO			(16<<16)
+#define DBDELIND				(17<<16)
+#define DBDELINDKEY				(18<<16)
+#define DBDELVALKEY				(19<<16)
+#define DBDESCRIBEVARIABLE		(20<<16)
+#define DBEXTENDPOLYGON			(21<<16)
+#define DBINITINFSTR			(22<<16)
+#define DBINITOBJLIST			(23<<16)
+#define DBINSIND				(24<<16)
+#define DBINSINDKEY				(25<<16)
+#define DBKILLARCINST			(26<<16)
+#define DBKILLLIBRARY			(27<<16)
+#define DBKILLNODEINST			(28<<16)
+#define DBKILLNODEPROTO			(29<<16)
+#define DBKILLPORTPROTO			(30<<16)
+#define DBKILLTECHNOLOGY		(31<<16)
+#define DBMAKEKEY				(32<<16)
+#define DBMODIFYARCINST			(33<<16)
+#define DBMOVEPORTPROTO			(34<<16)
+#define DBNEWARCINST			(35<<16)
+#define DBNEWLIBRARY			(36<<16)
+#define DBNEWNODEINST			(37<<16)
+#define DBNEWNODEPROTO			(38<<16)
+#define DBNEWPORTPROTO			(39<<16)
+#define DBNEWVIEW				(40<<16)
+#define DBREPLACEARCINST		(41<<16)
+#define DBREPLACENODEINST		(42<<16)
+#define DBRETURNINFSTR			(43<<16)
+#define DBSETIND				(44<<16)
+#define DBSETINDKEY				(45<<16)
+#define DBSETVAL				(46<<16)
+#define DBSETVALKEY				(47<<16)
+#define DBTRANSMULT				(48<<16)
+#define DBXFORM					(49<<16)
 
 extern INTBIG       db_lasterror;			/* last error message */
 extern BOOLEAN      db_printerrors;			/* flag for printing internal errors */
@@ -283,13 +280,14 @@ extern INTBIG  db_lastonobjecttype;		/* the type of the last object that we were
 void         db_addportarcinst(NODEINST*, PORTARCINST*);
 void         db_addportexpinst(NODEINST*, PORTEXPINST*);
 BOOLEAN      db_addtortnode(UINTBIG, RTNODE*, NODEPROTO*);
-void         db_boundfacet(NODEPROTO*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
-void         db_buildcellhashtable(LIBRARY*);
+void         db_boundcell(NODEPROTO*, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
+void         db_buildnodeprotohashtable(LIBRARY *lib);
 void         db_buildportprotohashtable(NODEPROTO*);
 CHANGE      *db_change(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void         db_changeport(PORTPROTO*, NODEINST*, PORTPROTO*);
 void         db_checkallmemoryfree(void);
-void         db_clearportcache(NODEPROTO *facet);
+void         db_clearportcache(NODEPROTO *cell);
+void         db_correctcellgroups(NODEPROTO *cell);;
 VARIABLE    *db_dummyvariable(void);
 void         db_endbatch(void);
 void         db_enterarcinst(ARCINST*);
@@ -297,7 +295,7 @@ void         db_enternodeinst(NODEINST*);
 void         db_enterportproto(PORTPROTO*);
 BOOLEAN      db_enterwindowpart(WINDOWPART *w);
 INTBIG       db_error(INTBIG);
-CELL        *db_findcellname(CHAR*, LIBRARY*);
+NODEPROTO   *db_findnodeprotoname(CHAR *name, VIEW *view, LIBRARY *lib);
 void         db_forcehierarchicalanalysis(NODEPROTO*);
 void         db_freearcproto(ARCPROTO *ap);
 void         db_freechangememory(void);
@@ -340,7 +338,8 @@ NODEPROTO   *db_newprimnodeproto(CHAR*, INTBIG, INTBIG, INTBIG, TECHNOLOGY*);
 PORTPROTO   *db_newprimportproto(NODEPROTO*, ARCPROTO**, CHAR*);
 void         db_printclusterarena(CHAR*);
 void         db_printrtree(RTNODE*, RTNODE*, INTBIG);
-void         db_removechangefacet(NODEPROTO*);
+void         db_removecellfromgroup(NODEPROTO*);
+void         db_removechangecell(NODEPROTO*);
 void         db_removeportexpinst(PORTPROTO*);
 void         db_retractarcinst(ARCINST*);
 void         db_retractnodeinst(NODEINST*);
@@ -348,7 +347,7 @@ void         db_retractnodeproto(NODEPROTO*);
 void         db_retractportproto(PORTPROTO*);
 void         db_retractwindowpart(WINDOWPART *w);
 void         db_rtnbbox(RTNODE*, INTBIG, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
-void         db_setchangefacet(NODEPROTO*);
+void         db_setchangecell(NODEPROTO*);
 void         db_setcurrenttool(TOOL*);
 BOOLEAN      db_stillinport(ARCINST*, INTBIG, INTBIG, INTBIG);
 void         db_termlanguage(void);
