@@ -37,7 +37,7 @@ extern "C"
 /* #define SURROUNDRULES 1 */		/* uncomment to add surround rule code (not ready yet) */
 
 /* the meaning of "DRC_options" */
-#define DRCFIRSTERROR              2		/* set to stop after first error in a facet */
+#define DRCFIRSTERROR              2		/* set to stop after first error in a cell */
 #define DRCREASONABLE              4		/* set to only examine "reasonable" number of polygons per node */
 #define DRCMULTIPROC             010		/* set to use multiple processors for DRC */
 #define DRCNUMPROC          07777760		/* number of processors to use for DRC */
@@ -154,12 +154,12 @@ void      dr_cachevalidlayers(TECHNOLOGY *tech);
 INTBIG    dr_adjustedmindist(TECHNOLOGY *tech, LIBRARY *lib, INTBIG layer1, INTBIG size1,
 			INTBIG layer2, INTBIG size2, BOOLEAN con, BOOLEAN multi, INTBIG *edge, CHAR **rule);
 
-INTBIG    drcb_check(NODEPROTO *facet, BOOLEAN report, BOOLEAN justarea);
-void      drcb_initincrementalcheck(NODEPROTO *facet);
+INTBIG    drcb_check(NODEPROTO *cell, BOOLEAN report, BOOLEAN justarea);
+void      drcb_initincrementalcheck(NODEPROTO *cell);
 void      drcb_checkincremental(GEOM *geom, BOOLEAN partial);
 void      drcb_term(void);
 
-void      dr_quickcheck(NODEPROTO *facet, INTBIG count, NODEINST **nodestocheck, BOOLEAN *validity, BOOLEAN justarea);
+void      dr_quickcheck(NODEPROTO *cell, INTBIG count, NODEINST **nodestocheck, BOOLEAN *validity, BOOLEAN justarea);
 void      dr_quickterm(void);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
