@@ -67,8 +67,8 @@ extern "C"
 #define CYAN     0026			/* cyan                                  */
 #define MAGENTA  0032			/* magenta                               */
 #define YELLOW   0036			/* yellow                                */
-#define FACETTXT 0042			/* facet and port names                  */
-#define FACETOUT 0046			/* facet outline                         */
+#define CELLTXT  0042			/* cell and port names                   */
+#define CELLOUT  0046			/* cell outline                          */
 #define WINBOR   0052			/* window border color                   */
 #define HWINBOR  0056			/* highlighted window border color       */
 #define MENBOR   0062			/* menu border color                     */
@@ -102,8 +102,8 @@ extern "C"
 
 /* variables with the acutal colors to use for special graphics */
 extern INTBIG el_maplength;		/* number of entries in color map */
-extern INTBIG el_colfacettxt;	/* color to use for facet text and port names */
-extern INTBIG el_colfacet;		/* color to use for facet outline */
+extern INTBIG el_colcelltxt;	/* color to use for cell text and port names */
+extern INTBIG el_colcell;		/* color to use for cell outline */
 extern INTBIG el_colwinbor;		/* color to use for window border */
 extern INTBIG el_colhwinbor;	/* color to use for highlighted window border */
 extern INTBIG el_colmenbor;		/* color to use for menu border */
