@@ -39,7 +39,9 @@ extern "C"
 /* #define REPORTCONVERSION 1 */		/* uncomment to report on library conversion */
 
 /* successive versions of the binary file have smaller numbers */
-#define MAGIC11              -1593		/* current magic number: version 11 */
+#define MAGIC13              -1597		/* current magic number: version 13 */
+#define MAGIC12              -1595		/* older magic number: version 12 */
+#define MAGIC11              -1593		/* older magic number: version 11 */
 #define MAGIC10              -1591		/* older magic number: version 10 */
 #define MAGIC9               -1589		/* older magic number: version 9 */
 #define MAGIC8               -1587		/* older magic number: version 8 */
@@ -110,7 +112,7 @@ extern "C"
 #define PSCOLOR2       02000000000		/* 0: second bit for color PostScript output */
 #define GDSOUTUC       04000000000		/* 0: bit set to force GDS output to be upper case */
 #define PLOTFOCUSDPY  010000000000		/* 0: bit set to focus plot output on display */
-#define SKILLNOHIER   020000000000		/* 0: bit set to ignore subfacets in SKILL */
+#define SKILLNOHIER   020000000000		/* 0: bit set to ignore subcells in SKILL */
 #define CIFRESHIGH              01		/* 1: bit set for CIF resolution errors to highlight */
 #define SKILLFLATHIER           02		/* 1: bit set to flatten hierarchy in SKILL */
 #define CDLNOBRACKETS           04		/* 1: bit set to convert brackets in CDL */
@@ -122,6 +124,15 @@ extern "C"
 #define DEFAULTPSHEIGHT        825		/* default PostScript page height (11.0" at 75dpi) */
 #define DEFAULTPSMARGIN         56		/* default PostScript page height (0.75" at 75dpi) */
 
+
+#define NOFAKECELL          ((FAKECELL *)-1)
+
+typedef struct Ifakecell
+{
+	CHAR              *cellname;			/* name of this fakecell */
+	struct Inodeproto *firstincell;			/* first nodeproto in list */
+} FAKECELL;
+
 /* miscellaneous */
 extern FILE        *io_fileout;			/* channel for output */
 extern jmp_buf      io_filerror;		/* nonlocal jump when I/O fails */
@@ -129,7 +140,7 @@ extern INTBIG       io_cifbase;			/* index used when writing CIF */
 extern INTBIG       io_postscriptfilenamekey;/* key for "IO_postscript_filename" */
 extern INTBIG       io_postscriptfiledatekey;/* key for "IO_postscript_filedate" */
 extern INTBIG       io_postscriptepsscalekey;/* key for "IO_postscript_EPS_scale" */
-extern INTBIG       io_verbose;			/* 0: silent  1:verbose  -1:display facets during input */
+extern INTBIG       io_verbose;			/* 0: silent  1:verbose  -1:display cells during input */
 extern INTBIG       io_filetypeblib;	/* Binary library disk file descriptor */
 extern INTBIG       io_filetypecif;		/* CIF disk file descriptor */
 extern INTBIG       io_filetypedef;		/* DEF disk file descriptor */
@@ -161,6 +172,7 @@ INTBIG io_request(CHAR*, va_list);
 void io_slice(void);
 
 /* prototypes for intratool interface */
+void       io_buildcellgrouppointersfromnames(LIBRARY*);
 INTBIG    *io_getstatebits(void);
 void       io_setstatebits(INTBIG *bits);
 PORTPROTO *io_convertoldportname(CHAR *portname, NODEPROTO *np);
