@@ -34,17 +34,24 @@ extern "C"
 {
 #endif
 
-#define NEWNCC	1		/* comment out to remove last-minute changes */
-
 /* the meaning of tool:network.NET_options */
-#define NETCONPWRGND          1		/* set to connect power and ground */
-#define NETCONCOMMONNAME      2		/* set to connect commonly named nets */
-#define NETDEFBUSBASE1      010		/* set to have default bus base at 1 (instead of 0) */
-#define NETDEFBUSBASEDESC   020		/* set to have default busses numbered descending */
-#define NETIGNORERESISTORS  040		/* set to ignore resistors */
-#define NETDEFAULTABBREVLEN   8		/* default length of cell name abbreviations on nodes */
+#define NETCONPWRGND                   1		/* set to connect power and ground */
+#define NETCONCOMMONNAME               2		/* set to connect commonly named nets */
+#define NETDEFBUSBASE1               010		/* set to have default bus base at 1 (instead of 0) */
+#define NETDEFBUSBASEDESC            020		/* set to have default busses numbered descending */
+#define NETIGNORERESISTORS           040		/* set to ignore resistors */
+#define NETDEFAULTABBREVLEN            8		/* default length of cell name abbreviations on nodes */
 
-#define HASHTYPE        INTHUGE		/* the size of hash values */
+#define HASHTYPE                 INTHUGE		/* the size of hash values */
+
+/* the meaning of NODEPROTO->temp1 by various network tools */
+#define NETNCCCHECKSTATE              03		/* state of NCC check for this cell */
+#define NETNCCNOTCHECKED               0		/*    NCC not checked for this cell */
+#define NETNCCCHECKEDGOOD             01		/*    NCC checked successfully for this cell */
+#define NETNCCCHECKEDBAD              02		/*    NCC checked unsuccessfully for this cell */
+#define NETGLOBALCHECKED              04		/* global analysis flag for this cell */
+#define NETCELLCODE           0777777770		/* coding for this cell when matching without expansion */
+#define NETCELLCODESH                  3		/* right shift of NETCELLCODE */
 
 extern INTBIG      net_options;					/* cached value for "NET_options" */
 extern INTBIG      net_unifystringskey;			/* key for "NET_unify_strings" */
@@ -55,7 +62,9 @@ extern INTBIG      net_ncc_optionskey;			/* key for "NET_ncc_options" */
 extern INTBIG      net_ncc_comptolerancekey;	/* key for "NET_ncc_component_tolerance" */
 extern INTBIG      net_ncc_comptoleranceamtkey;	/* key for "NET_ncc_component_tolerance_amt" */
 extern INTBIG      net_ncc_matchkey;			/* key for "NET_ncc_match" */
+extern INTBIG      net_ncc_forcedassociationkey;/* key for "NET_ncc_forcedassociation" */
 extern INTBIG      net_ncc_processors_key;		/* key for "NET_ncc_num_processors" */
+extern INTBIG      net_ncc_function_key;		/* key for "NET_ncc_function" */
 extern INTBIG      net_ncc_options;				/* options to use in NCC */
 
 /* the meaning of tool:network.NET_ncc_options */
@@ -66,29 +75,38 @@ extern INTBIG      net_ncc_options;				/* options to use in NCC */
 #define NCCIGNOREPWRGND              020		/* set to ignore power/ground during NCC */
 #define NCCRECURSE                   040		/* set to do NCC recursively */
 #define NCCHIDEMATCHTAGS            0200		/* set to hide "NCCMatch" tags */
-#ifdef NEWNCC
 #define NCCINCLUDENOCOMPNETS        0400		/* set to include no-component nets */
-#endif
 #define NCCCHECKSIZE               01000		/* set to check component size during NCC */
 #define NCCNOMERGEPARALLEL         04000		/* set to not merge parallel components during NCC */
-#define NCCNOMERGEPARALLELOVER    010000		/* set to override parallel component nonmerge for a facet */
+#define NCCNOMERGEPARALLELOVER    010000		/* set to override parallel component nonmerge for a cell */
 #define NCCMERGESERIES            020000		/* set to merge series transistors during NCC */
-#define NCCMERGESERIESOVER        040000		/* set to override series transistors merge for a facet */
+#define NCCMERGESERIESOVER        040000		/* set to override series transistors merge for a cell */
 #define NCCHIERARCHICALOVER      0100000		/* set to override hierarchy expansion during NCC */
 #define NCCEXPERIMENTAL          0200000		/* set to use experimental NCC */
 #define NCCGRAPHICPROGRESS       0400000		/* set to show NCC progress graphically */
+#define NCCDISLOCAFTERMATCH     01000000		/* set to disable local processing after NCC match */
+#define NCCENAFOCSYMGRPFRE      02000000		/* set to enable focus on "fresh" symmetry groups during NCC */
+#define NCCSUPALLAMBREP         04000000		/* set to supress all ambiguous messages during NCC */
+#define NCCENAFOCSYMGRPPRO     010000000		/* set to enable focus on "promising" symmetry groups during NCC */
+#define NCCENASTATISTICS       020000000		/* set to enable statistics during NCC */
+#define NCCRESISTINCLUSION    0140000000		/* how to treat resistors during NCC */
+#define NCCRESISTLEAVE                 0		/*    leave current state alone */
+#define NCCRESISTINCLUDE       040000000		/*    make sure they are included */
+#define NCCRESISTEXCLUDE      0100000000		/*    make sure they are excluded */
 
-/*********************** NET FACET PRIVATE ************************/
+/*********************** NET CELL PRIVATE ************************/
 
 #ifdef __cplusplus
 
-#define CHECKARITY                          /* data structures to speed up check of bus names arity */
+#if 1
+#  define NEWRENUM                            /* new network renumbering algorithm */
+#endif
 
-class NetFacetPrivate;                      /* private network data */
+class NetCellPrivate;                       /* private network data */
 class NetName;                              /* name of network */
-class NetFacetShorts;                       /* electrical shortcuts between exports inside facet */
+class NetCellShorts;                        /* electrical shortcuts between exports inside cell */
 
-class NetFacetPrivate
+class NetCellPrivate
 {
 	friend class NetName;
 public:
@@ -98,24 +116,33 @@ public:
 #ifndef MACOS
 	void operator delete( void *obj, CLUSTER *cluster );
 #endif
-	NetFacetPrivate( NODEPROTO *np, CLUSTER *cluster );
-	~NetFacetPrivate();
+	NetCellPrivate( NODEPROTO *np, CLUSTER *cluster );
+	~NetCellPrivate();
 	BOOLEAN updateShorts();
-	NetFacetShorts *netshorts() { return _netshorts; };
+	NetCellShorts *netshorts() { return _netshorts; };
 	NetName *findNetName( CHAR *name, BOOLEAN insert );
-	void check();
+	void docheck();
+#ifdef NEWRENUM
+	void clearConns();
+	void calcConns(INTBIG *count);
+	void showConns(INTBIG *deepmap);
+#endif
+	CLUSTER *cluster() { return _cluster; };
 private:
 	void rehashNetNames();
 	void insertNetName( NetName *nn, INTBIG hash );
+#ifdef NEWRENUM
+	NetName *addNetName( CHAR *name );
+#endif
 	NODEPROTO *_np;
 	CLUSTER *_cluster;
 	NetName **_netnamehash;
 	INTBIG _netnametotal;
 	INTBIG _netnamecount;
-	NetFacetShorts *_netshorts;
+	NetCellShorts *_netshorts;
 };
 
-class NetFacetShorts
+class NetCellShorts
 {
 public:
 	void* operator new( size_t size );
@@ -124,14 +151,20 @@ public:
 #ifndef MACOS
 	void operator delete( void *obj, CLUSTER *cluster );
 #endif
-	NetFacetShorts( NODEPROTO *np, CLUSTER *cluster );
-	~NetFacetShorts();
+	NetCellShorts( NODEPROTO *np, CLUSTER *cluster );
+	~NetCellShorts();
 	BOOLEAN isConsistent();
 	void printf();
 	INTBIG portwidth( INTBIG portno );
 	INTBIG portcount() { return _portcount; };
 	INTBIG globalcount() { return _portbeg[0]; };
 	INTBIG portdeepcount() { return _portbeg[_portcount] - _portbeg[0]; };
+#ifdef NEWRENUM
+	INTBIG portbeg(INTBIG i) { return _portbeg[i]; }
+	CHAR *globalname(INTBIG i) { return _globalnames[i]; }
+	BOOLEAN isolated(INTBIG portno) { return _isolated[portno]; };
+	INTBIG portdeepmap(INTBIG portno) { return _portdeepmap[portno]; };
+#endif
 	INTBIG portshallowmap(INTBIG portno) { return _portshallowmap[portno]; };
 	BOOLEAN globalshort() { return _globalshort; };
 private:
@@ -139,6 +172,9 @@ private:
 	NODEPROTO *_np;
 	INTBIG _portcount;
 	INTBIG *_portbeg;
+#ifdef NEWRENUM
+	BOOLEAN *_isolated;
+#endif
 	CHAR **_globalnames;
 	INTBIG *_portshallowmap;
 	INTBIG *_portdeepmap;
@@ -149,7 +185,7 @@ private:
 
 class NetName
 {
-	friend class NetFacetPrivate;
+	friend class NetCellPrivate;
 public:
 	void* operator new( size_t size );
 	void* operator new( size_t size, CLUSTER *cluster );
@@ -157,25 +193,33 @@ public:
 #ifndef MACOS
 	void operator delete( void *obj, CLUSTER *cluster );
 #endif
-	NetName( NetFacetPrivate *npd, CHAR *name );
+	NetName( NetCellPrivate *npd, CHAR *name );
 	~NetName();
 	NETWORK *firstNet();
 	void addNet(NETWORK *net);
 	void removeNet(NETWORK *net);
 	CHAR *name() { return _name; };
-#ifdef CHECKARITY
 	void checkArity();
+#ifdef NEWRENUM
+	INTBIG busWidth() { return _busWidth; };
+	class NetName *subName(INTBIG i) { return _netNameList[i]; };
+	void setBusWidth( INTBIG busWidth, CHAR **strings );
+	INTBIG conn() { return _conn; }
+	void markConn();
 #endif
 private:
-	void check();
+	void docheck();
 	void checkNet(NETWORK *net);
-	NetFacetPrivate *_npd;
+	NetCellPrivate *_npd;
 	CHAR *_name;
 	INTBIG _netcount;
 	INTBIG _netaddr;
-#ifdef CHECKARITY
 	class NetName *_baseNetName;
 	INTBIG _baseRefCount;
+#ifdef NEWRENUM
+	INTBIG    _busWidth;			/* width of bus */
+	class NetName **_netNameList;			/* list of single-wire netnames on bus */
+	INTBIG _conn;                   /* connection index */
 #endif
 };        
 
@@ -212,6 +256,7 @@ typedef struct Ipcomp
 	INTSML           wirecount;			/* number of unconnected ports (wires) */
 	INTSML           truewirecount;		/* number of unconnected ports, excluding ignored Pwr&Gnd */
 	INTBIG           timestamp;			/* time stamp for entry into symmetry group */
+	INTBIG           forcedassociation;	/* extra factor used to force associations */
 	HASHTYPE         hashvalue;			/* hash value for NCC */
 	CHAR            *hashreason;		/* the explanation of the hash value */
 	float            length;			/* length/size of component */
@@ -220,12 +265,15 @@ typedef struct Ipcomp
 	PORTPROTO      **portlist;			/* PORTPROTOs on each wire */
 	struct Ipnet   **netnumbers;		/* initial netnumbers for each wire */
 	INTSML          *state;				/* information about the connection */
+	void            *symgroup;			/* symmetry group (used during NCC) */
 	struct Ipcomp   *nextpcomp;			/* next in list of pseudocomponents */
 } PCOMP;
 extern PCOMP *net_pcompfree;
 
 /*********************** PNET MODULES ***********************/
 
+/* #define PATHTOPNET 1 */			/* uncomment to preserve and show the path to a net */
+
 #define NOPNET ((PNET *)-1)
 
 /* meaning of PNET->flags */
@@ -243,13 +291,20 @@ typedef struct Ipnet
 	INTSML         realportcount;	/* number of top-level exports on this net */
 	void          *realportlist;	/* top-level export(s) on this net */
 	NETWORK       *network;			/* real network that this references */
+#ifdef PATHTOPNET
+	NODEINST     **hierpath;		/* hierarchical path to this */
+	INTBIG        *hierindex;		/* hierarchical path index to this */
+	INTBIG         hierpathcount;	/* length of hierarchical path */
+#endif
 	HASHTYPE       hashvalue;		/* hash value for NCC */
 	CHAR          *hashreason;		/* the explanation of the hash value */
 	INTBIG         timestamp;		/* time stamp for entry into symmetry group */
 	INTBIG         nodecount;		/* number of pnodes on this network */
 	INTBIG         nodetotal;		/* allocated space for pnodes and wires on this network */
+	INTBIG         forcedassociation;/* extra factor used to force associations */
 	PCOMP        **nodelist;		/* list of pnodes on this network */
 	INTBIG        *nodewire;		/* list of which wire on the pnode attaches to network */
+	void          *symgroup;		/* symmetry group (used during NCC) */
 	struct Ipnet  *nextpnet;		/* next in list */
 } PNET;
 extern PNET *net_pnetfree;
@@ -311,7 +366,7 @@ AREAPERIM *net_gathergeometry(NETWORK *net, TRANSISTORINFO **p_gate, TRANSISTORI
 			TRANSISTORINFO **p_active, TRANSISTORINFO **n_active, BOOLEAN recurse);
 BOOLEAN    net_equate(BOOLEAN);
 INTBIG	   net_getequivalentnet(NETWORK *net, NETWORK ***equiv, INTBIG *numequiv, BOOLEAN allowchild);
-BOOLEAN    net_compare(BOOLEAN preanalyze, BOOLEAN interactive, NODEPROTO *facet1, NODEPROTO *facet2);
+BOOLEAN    net_compare(BOOLEAN preanalyze, BOOLEAN interactive, NODEPROTO *cell1, NODEPROTO *cell2);
 INTBIG     net_buswidth(CHAR*);
 INTBIG     net_evalbusname(INTBIG, CHAR*, CHAR***, ARCINST*, NODEPROTO*, INTBIG);
 void       net_freediffmemory(void);
@@ -325,7 +380,7 @@ CHAR      *net_describepnet(PNET *pn);
 CHAR      *net_describepcomp(PCOMP *pc);
 HASHTYPE   net_getcomphash(PCOMP *pc, INTBIG verbose);
 HASHTYPE   net_getnethash(PNET *pn, INTBIG verbose);
-NETWORK   *net_getnetwork(CHAR *netname, NODEPROTO *facet);
+NETWORK   *net_getnetwork(CHAR *netname, NODEPROTO *cell);
 void       net_redoprim(void);
 void       net_initnetprivate(NODEPROTO*);
 void       net_freenetprivate(NODEPROTO*);
@@ -337,21 +392,21 @@ void       net_freenetwork(NETWORK*, NODEPROTO*);
 void       net_conv_to_internal(NODEPROTO *np);
 void       net_removeassociations(void);
 void       net_fillinnetpointers(PCOMP *pcomplist, PNET *pnetlist);
-BOOLEAN    net_nccalreadydone(NODEPROTO *facet1, NODEPROTO *facet2);
+BOOLEAN    net_nccalreadydone(NODEPROTO *cell1, NODEPROTO *cell2);
 void       net_nccremovematches(NODEPROTO *np);
 INTBIG     net_ncchasmatch(NODEPROTO *np);
-void	   net_nccmatchinfo(NODEPROTO *np, NODEPROTO **facetmatch, UINTBIG *facetdate);
-void       net_parsenccresult(NODEPROTO *np, VARIABLE *var, NODEPROTO **facetmatch,
-			UINTBIG *facetdate);
+void	   net_nccmatchinfo(NODEPROTO *np, NODEPROTO **cellmatch, UINTBIG *celldate);
+void       net_parsenccresult(NODEPROTO *np, VARIABLE *var, NODEPROTO **cellmatch,
+			UINTBIG *celldate);
 VARIABLE  *net_nccfindmatch(NODEPROTO *np, NODEPROTO *onp, UINTBIG *matchdate);
 void       net_setnodewidth(NODEINST *ni);
 INTBIG     net_gathernodenames(NODEPROTO *np, CHAR ***namelist);
-BOOLEAN    net_getfacets(NODEPROTO**, NODEPROTO**);
+BOOLEAN    net_getcells(NODEPROTO**, NODEPROTO**);
 void       net_listnccoverrides(BOOLEAN usetemp1);
 BOOLEAN    net_componentequalvalue(float v1, float v2);
 INTBIG     net_findglobalnet(NODEPROTO *np, CHAR *name);
 #ifdef FORCESUNTOOLS
-BOOLEAN    net_analyzefacet(void);
+BOOLEAN    net_analyzecell(void);
 void       net_freeexpdiffmemory(void);
 INTBIG     net_doexpgemini(PCOMP *pcomp1, PNET *pnet1, PCOMP *pcomp2, PNET *pnet2,
 			BOOLEAN checksize, BOOLEAN checkexportnames, BOOLEAN ignorepwrgnd);
