@@ -50,10 +50,10 @@
 #define ANDLEFTVDD  3					/* Vdd on left of AND plane */
 #define ORTOPVDD    4					/* Vdd on top of OR plane */
 #define ORRIGHTGND  5					/* Gnd on right of OR plane */
-#define INFACETGND  6					/* Gnd within input facets */
-#define INFACETVDD  7					/* Vdd within input facets */
-#define OUTFACETGND 8					/* Gnd within output facets */
-#define OUTFACETVDD 9					/* Vdd within output facets */
+#define INCELLGND   6					/* Gnd within input cells */
+#define INCELLVDD   7					/* Vdd within input cells */
+#define OUTCELLGND  8					/* Gnd within output cells */
+#define OUTCELLVDD  9					/* Vdd within output cells */
 
 
 #define DIFF        0					/* Three arc types */
@@ -65,7 +65,7 @@
 #define INFILE      x_("program")			/* default file name */
 #define NULLSTR     x_("")
 
-/* Define String Names for the PLA Facets */
+/* Define String Names for the PLA cells */
 #define nmosInput   x_("nmos_Input")
 #define nmosOutput  x_("nmos_Output")
 #define nmosPullup  x_("nmos_Pullup")
@@ -79,7 +79,7 @@ extern NODEPROTO *pla_out_proto;		/* Output Prototype */
 extern NODEPROTO *pla_prog_proto;		/* Programming Transistor Prototype */
 extern NODEPROTO *pla_connect_proto;	/* Connect Prototype */
 
-extern NODEPROTO *pla_facet;			/* The PLA itself */
+extern NODEPROTO *pla_cell;				/* The PLA itself */
 
 extern NODEPROTO *pla_md_proto;			/* Metal-Diff contact */
 extern NODEPROTO *pla_mp_proto;			/* Metal-Poly contact */
@@ -128,19 +128,19 @@ typedef struct progtrans
 } PROGTRANS;
 
 
-#define NOFACETIST ((FACETIST *) 0)
+#define NOCELLIST ((CELLIST *) 0)
 
-typedef struct facetist
+typedef struct cellist
 {
-	INTBIG         findex;				/* Facet number */
-	NODEINST      *facetinst;			/* The facet itself */
+	INTBIG         findex;				/* cell number */
+	NODEINST      *cellinst;			/* The cell itself */
 	PORT          *lport;				/* Left column port */
 	PORT          *rport;				/* Right column port */
 	PORT          *gport;				/* Ground port */
 	PROGTRANS     *lcoltrans;			/* The two programming transistors */
-	PROGTRANS     *rcoltrans;			/* connected to this facet */
-  struct facetist *nextfacet;			/* Next facet on this list */
-} FACETIST;
+	PROGTRANS     *rcoltrans;			/* connected to this cell */
+  struct cellist *nextcell;				/* Next cell on this list */
+} CELLIST;
 
 
 #define NOVDDGND ((VDDGND *) 0)
@@ -160,7 +160,7 @@ extern INTBIG  pla_inputs, pla_outputs, pla_pterms;
 extern INTBIG  pla_VddWidth;			/* VDD width in use */
 extern INTBIG  pla_GndWidth;			/* Vdd and Gnd Widths in use */
 extern CHAR    pla_infile[100];			/* Name of the input file */
-extern CHAR    pla_name[32];			/* Name of the PLA facet */
+extern CHAR    pla_name[32];			/* Name of the PLA cell */
 
 /*   Miscellaneous global variables  */
 extern INTBIG  pla_halfVdd, pla_halfGnd;   /* To save repeated division by 2 */
@@ -169,10 +169,10 @@ extern VDDGND *pla_atg;					/* And top Gnd points */
 extern VDDGND *pla_arg;					/* And right Gnd points */
 extern VDDGND *pla_otv;					/* Or top Vdd points */
 extern VDDGND *pla_org;					/* Or right Gnd points */
-extern VDDGND *pla_icg;					/* Input facet Gnd points */
-extern VDDGND *pla_icv;					/* Input facet Vdd points */
-extern VDDGND *pla_ocg;					/* Output facet Gnd points */
-extern VDDGND *pla_ocv;					/* Output facet Vdd points */
+extern VDDGND *pla_icg;					/* Input cell Gnd points */
+extern VDDGND *pla_icv;					/* Input cell Vdd points */
+extern VDDGND *pla_ocg;					/* Output cell Gnd points */
+extern VDDGND *pla_ocv;					/* Output cell Vdd points */
 extern FILE   *pla_fin;					/* Pointer to the input file */
 
 /*
@@ -223,5 +223,5 @@ INTBIG pla_GetKeyWord(CHAR*);
 VDDGND *pla_MkVddGnd(INTBIG, VDDGND**);
 PORT *pla_AssignPort(NODEINST*, INTBIG, INTBIG);
 PORTPROTO *pla_FindPort(NODEINST*, INTBIG, INTBIG);
-void pla_ConnectPlanes(INTBIG, INTBIG, INTBIG, FACETIST*, FACETIST*, FACETIST*, FACETIST*, NODEPROTO*);
+void pla_ConnectPlanes(INTBIG, INTBIG, INTBIG, CELLIST*, CELLIST*, CELLIST*, CELLIST*, NODEPROTO*);
 void pla_RunVddGnd(INTBIG, INTBIG, NODEPROTO*);
