@@ -50,6 +50,7 @@ extern "C"
 #define MIMICUNROUTES         0100			/* bit set if mimic can unroute */
 #define MIMICIGNOREPORTS      0200			/* bit set if mimic ignores ports */
 #define MIMICONSIDERARCCOUNT 01000			/* bit set if mimic considers arc count */
+#define MIMICOTHARCTHISDIR   02000			/* bit set if mimic allows other arcs in this direction */
 
 extern TOOL     *ro_tool;				/* the Router tool object */
 extern INTBIG    ro_statekey;			/* variable key for "ROUT_state" */
@@ -98,9 +99,9 @@ extern INTBIG ro_mazeboundary;
 /****************************** ROUTINES ******************************/
 
 /* prototypes for tool interface */
-void ro_init(INTBIG*, char*[], TOOL*);
+void ro_init(INTBIG*, CHAR1*[], TOOL*);
 void ro_done(void);
-void ro_set(INTBIG, char*[]);
+void ro_set(INTBIG, CHAR*[]);
 void ro_slice(void);
 void ro_startbatch(TOOL*, BOOLEAN);
 void ro_endbatch(void);
@@ -116,6 +117,7 @@ void    ro_autostitch(void);
 INTBIG  ro_findnetends(NETWORK *net, NODEINST ***nilist, PORTPROTO ***pplist,
 		INTBIG **xplist, INTBIG **yplist);
 void    ro_freemazememory(void);
+void    ro_freeautomemory(void);
 void    ro_freemimicmemory(void);
 void    ro_freerivermemory(void);
 void    ro_freercheck(RCHECK*);
