@@ -760,17 +760,17 @@ int Sc_route(int, CHAR*[]);
 void Sc_schematic(void);
 int Sc_simulation(int, CHAR*[]);
 int Sc_verify(void);
-CHAR *Sc_find_leaf_facet(CHAR*);
+CHAR *Sc_find_leaf_cell(CHAR*);
 CHAR *Sc_first_leaf_port(CHAR*);
 CHAR *Sc_next_leaf_port(CHAR*);
 int Sc_leaf_port_type(CHAR*);
 int Sc_leaf_port_bits(CHAR*);
 CHAR *Sc_leaf_port_name(CHAR*);
-void Sc_leaf_facet_get_nums(CHAR*, SCCELLNUMS*);
+void Sc_leaf_cell_get_nums(CHAR*, SCCELLNUMS*);
 void Sc_extract_print_nodes(SCCELL*);
 void Sc_route_print_channel(SCROUTECHANNEL*);
-CHAR *Sc_leaf_facet_name(CHAR*);
-int Sc_leaf_facet_set_nums(CHAR*, SCCELLNUMS*);
+CHAR *Sc_leaf_cell_name(CHAR*);
+int Sc_leaf_cell_set_nums(CHAR*, SCCELLNUMS*);
 SCNITREE **Sc_findni(SCNITREE**, CHAR*);
 CHAR *Sc_find_leaf_port(CHAR*, CHAR*);
 int *Sc_leaf_port_bits_address(CHAR*);
@@ -781,8 +781,8 @@ void Sc_leaf_port_set_first(CHAR*, CHAR*);
 void Sc_remove_inst_from_itree(SCNITREE**, SCNITREE*);
 void Sc_make_nilist(SCNITREE*, SCCELL*);
 int Sc_seterrmsg(int, ...);
-int Sc_leaf_facet_xsize(CHAR*);
-int Sc_leaf_facet_ysize(CHAR*);
+int Sc_leaf_cell_xsize(CHAR*);
+int Sc_leaf_cell_ysize(CHAR*);
 int Sc_leaf_port_xpos(CHAR*);
 int Sc_leaf_port_ypos(CHAR*);
 void Sc_initialize(void);
@@ -792,7 +792,7 @@ SCNIPORT *Sc_findpp(SCNITREE*, CHAR*);
 SCNITREE *Sc_new_instance(CHAR*, int);
 int Sc_conlist(SCNITREE*, SCNIPORT*, SCNITREE*, SCNIPORT*);
 CHAR *Sc_cpu_time(int);
-CHAR *Sc_create_leaf_facet(CHAR*);
+CHAR *Sc_create_leaf_cell(CHAR*);
 int Sc_setup_for_maker(ARCPROTO*, ARCPROTO*);
 CHAR *Sc_create_leaf_instance(CHAR*, CHAR*, int, int, int, int, int, int, CHAR*);
 CHAR *Sc_create_layer2_node(int, int, int, int, CHAR*);
@@ -807,12 +807,12 @@ int Sc_free_placement(SCPLACE*);
 int Sc_free_route(SCROUTE*);
 int Sc_leaf_port_direction(CHAR*);
 SCNIPORT *Sc_new_instance_port(SCNITREE*);
-CHAR **Sc_leaf_facet_sim_info(CHAR*);
-int Sc_leaf_facet_set_sim(SCSIM*, CHAR*);
-CHAR *Sc_first_leaf_facet(void);
-CHAR *Sc_next_leaf_facet(CHAR*);
-int *Sc_leaf_facet_bits_address(CHAR*);
-int Sc_leaf_facet_bits(CHAR*);
+CHAR **Sc_leaf_cell_sim_info(CHAR*);
+int Sc_leaf_cell_set_sim(SCSIM*, CHAR*);
+CHAR *Sc_first_leaf_cell(void);
+CHAR *Sc_next_leaf_cell(CHAR*);
+int *Sc_leaf_cell_bits_address(CHAR*);
+int Sc_leaf_cell_bits(CHAR*);
 INTBIG ScGetParameter(INTBIG paramnum);
 void ScSetParameter(INTBIG paramnum, INTBIG addr);
 
