@@ -50,6 +50,7 @@ extern "C"
 #define FASTHENRY 11					/* FastHenry (INP format) */
 #define IRSIM     12					/* IRSIM from Stanford (SIM format) */
 #define CDL       13					/* CDL (SPICE with no headers or parameters) */
+#define MAXWELL   14					/* MAXWELL (electromagnetic simulation) */
 
 /* the meaning of "SIM_dontrun" */
 #define SIMRUNYES       -1				/* run simulation, show output */
@@ -65,7 +66,7 @@ extern INTBIG     sim_dontrunkey;		/* key for "SIM_dontrun" */
 extern INTBIG     sim_weaknodekey;		/* key for "SIM_weak_node" */
 extern INTBIG     sim_spice_partskey;	/* key for "SIM_spice_parts" */
 extern CHAR      *sim_spice_parts;		/* cached value for "SIM_spice_parts" */
-extern NODEPROTO *sim_simnt;			/* facet being simulated */
+extern NODEPROTO *sim_simnt;			/* cell being simulated */
 #if defined(__cplusplus)
 extern EProcess  *sim_process;          /* process of simulator */
 #endif
@@ -89,6 +90,7 @@ extern INTBIG     sim_filetyperawspiceout; /* SPICE raw output disk file descrip
 extern INTBIG     sim_filetypesrawspiceout; /* SmartSPICE raw output disk file descriptor */
 extern INTBIG     sim_filetypecdl;		/* CDL output file descriptor */
 extern INTBIG     sim_filetypectemp;	/* CDL template disk file descriptor */
+extern INTBIG     sim_filetypemaxwell;	/* MAXWELL output file descriptor */
 extern INTBIG     sim_filetypetegas;	/* Tegas netlist disk file descriptor */
 extern INTBIG     sim_filetypetegastab;	/* Tegas table disk file descriptor */
 extern INTBIG     sim_filetypeverilog;	/* Verilog disk file descriptor */
@@ -134,11 +136,27 @@ extern INTBIG     sim_filetypeverilogvcd;	/* Verilog VCD dump file descriptor */
 #define SIMENGINECURVERILOG 04000		/*   current window has Verilog simulation */
 #define SIMENGINECURSPICE  010000		/*   current window has SPICE simulation */
 
-extern INTBIG  sim_window_statekey;		/* key for "SIM_window_state" */
-extern INTBIG  sim_window_state;		/* cached value of "SIM_window_state" */
+extern INTBIG  sim_window_statekey;			/* key for "SIM_window_state" */
+extern INTBIG  sim_window_state;			/* cached value of "SIM_window_state" */
 extern INTBIG  sim_window_signalorder_key;	/* key for "SIM_window_signalorder" */
-extern INTBIG  sim_window_hierpos_key;	/* key for "SIM_window_hierarchy_pos" */
-extern INTBIG  sim_window_format;		/* type of simulation in window */
+extern INTBIG  sim_window_hierpos_key;		/* key for "SIM_window_hierarchy_pos" */
+extern INTBIG  sim_window_format;			/* type of simulation in window */
+extern INTBIG  sim_colorstrengthoff;		/* color of off-strength */
+extern INTBIG  sim_colorstrengthnode;		/* color of node-strength */
+extern INTBIG  sim_colorstrengthgate;		/* color of gate-strength */
+extern INTBIG  sim_colorstrengthpower;		/* color of power-strength */
+extern INTBIG  sim_colorlevellow;			/* color of low-levels */
+extern INTBIG  sim_colorlevelhigh;			/* color of high-levels */
+extern INTBIG  sim_colorlevelundef;			/* color of undefined levels */
+extern INTBIG  sim_colorlevelzdef;			/* color of Z levels */
+extern INTBIG  sim_colorstrengthoff_key;	/* key for "SIM_window_color_str0" */
+extern INTBIG  sim_colorstrengthnode_key;	/* key for "SIM_window_color_str1" */
+extern INTBIG  sim_colorstrengthgate_key;	/* key for "SIM_window_color_str2" */
+extern INTBIG  sim_colorstrengthpower_key;	/* key for "SIM_window_color_str3" */
+extern INTBIG  sim_colorlevellow_key;		/* key for "SIM_window_color_low" */
+extern INTBIG  sim_colorlevelhigh_key;		/* key for "SIM_window_color_high" */
+extern INTBIG  sim_colorlevelundef_key;		/* key for "SIM_window_color_X" */
+extern INTBIG  sim_colorlevelzdef_key;		/* key for "SIM_window_color_Z" */
 
 /* prototypes */
 void    sim_window_init(void);
@@ -157,7 +175,8 @@ void    sim_window_settopvisframe(INTBIG count);
 INTBIG  sim_window_gettopvisframe(void);
 void    sim_window_savegraph(void);
 void    sim_window_writespicecmd(void);
-void    sim_window_displaycolor(INTBIG strength, INTBIG color);
+void    sim_window_setdisplaycolor(INTBIG strength, INTBIG color);
+INTBIG  sim_window_getdisplaycolor(INTBIG strength);
 INTBIG  sim_window_newtrace(INTBIG, CHAR*, INTBIG);
 BOOLEAN sim_window_buscommand(void);
 INTBIG  sim_window_makebus(INTBIG count, INTBIG *traces, CHAR *busname);
@@ -183,7 +202,6 @@ void    sim_window_addhighlighttrace(INTBIG);
 void    sim_window_deletehighlighttrace(INTBIG);
 INTBIG  sim_window_gethighlighttrace(void);
 INTBIG *sim_window_gethighlighttraces(void);
-void    sim_window_clearframehighlight(void);
 void    sim_window_showhighlightedtraces(void);
 void    sim_window_setmaincursor(double);
 double  sim_window_getmaincursor(void);
@@ -202,10 +220,11 @@ void    sim_window_zoom_frame(INTBIG frameno);
 void    sim_window_zoomout_frame(INTBIG frameno);
 void    sim_window_shiftup_frame(INTBIG frameno);
 void    sim_window_shiftdown_frame(INTBIG frameno);
-void    sim_window_grabcachedsignalsonfacet(NODEPROTO *facet);
+void    sim_window_grabcachedsignalsoncell(NODEPROTO *cell);
 INTBIG  sim_window_getcachedsignals(CHAR ***strings);
 void    sim_window_supresstraceprefix(CHAR *prefix);
 void    sim_window_renumberlines(void);
+void    sim_window_advancetime(void);
 
 /********************* for ESIM *********************/
 
@@ -237,12 +256,15 @@ void    sim_window_renumberlines(void);
 
 extern INTBIG sim_verilog_statekey;		/* key for "SIM_verilog_state" */
 
-void        sim_verlevel_up(NODEPROTO *facet);
-void        sim_verlevel_set(CHAR *instname, NODEPROTO *facet);
-void        sim_verparsefile(CHAR*);
+void        sim_verlevel_up(NODEPROTO *cell);
+void        sim_verlevel_set(CHAR *instname, NODEPROTO *cell);
+void        sim_verparsefile(CHAR*, NODEPROTO *cell);
 BOOLEAN     sim_vertopofinstances(CHAR **c);
 CHAR       *sim_vernextinstance(void);
 CHAR       *sim_verlevel_cur(void);
+void        sim_verreportsignals(WINDOWPART *simwin, void *(*addbranch)(CHAR*, void*),
+				void *(*findbranch)(CHAR*, void*), void *(*addleaf)(CHAR*, void*), CHAR *(*nodename)(void*));
+void        sim_veraddhighlightednet(CHAR *signame);
 
 /********************* for SPICE *********************/
 
@@ -260,7 +282,7 @@ CHAR       *sim_verlevel_cur(void);
 #define SPICEGNUCAP           0100      /*   gnucap */
 #define SPICESMARTSPICE       0120      /*   smartspice */
 #define SPICEGLOBALPG         0200		/* set to use global power and ground */
-#define SPICEFACETPARAM      01000		/* set to use facet parameters */
+#define SPICECELLPARAM       01000		/* set to use cell parameters */
 #define SPICEUSELAMBDAS      02000		/* set to use lambdas instead of microns for transistor sizes */
 #define SPICEOUTPUT         034000		/* mask for output format */
 #define SPICEOUTPUTNORM          0		/*   normal */
@@ -274,6 +296,10 @@ extern INTBIG sim_spice_nameuniqueid;	/* key for "SIM_spice_nameuniqueid" */
 extern INTBIG sim_spice_listingfilekey;	/* key for "SIM_listingfile" */
 extern INTBIG sim_spice_runargskey;		/* key for "SIM_spice_runarguments" */
 
+void sim_spicereportsignals(WINDOWPART *simwin, void *(*addbranch)(CHAR*, void*),
+	void *(*findbranch)(CHAR*, void*), void *(*addleaf)(CHAR*, void*), CHAR *(*nodename)(void*));
+void     sim_spice_addhighlightednet(CHAR *name, BOOLEAN);
+
 /********************* for FASTHENRY *********************/
 
 /* the meaning of "tool:sim.SIM_fasthenry_state" */
@@ -323,6 +349,7 @@ void        sim_freewindowmemory(void);
 void        sim_freespicememory(void);
 void        sim_freespicerun_memory(void);
 void        sim_freeirsimmemory(void);
+void        sim_freemaxwellmemory(void);
 void        sim_freeverilogmemory(void);
 void        sim_spice_xprintf(FILE*, BOOLEAN, CHAR*, ...);
 NETWORK    *sim_spice_networkfromname(CHAR *name);
@@ -334,6 +361,7 @@ void        sim_fasthenryinit(void);
 void        sim_writesim(NODEPROTO*, INTBIG);
 void        sim_writeirsim(NODEPROTO*);
 void        sim_writepalnetlist(NODEPROTO*);
+void        sim_writemaxwell(NODEPROTO*);
 void        sim_writemossim(NODEPROTO*);
 void        sim_writetexnetlist(NODEPROTO*);
 void        sim_writespice(NODEPROTO*, BOOLEAN);
@@ -344,6 +372,10 @@ INTBIG      sim_alsclockdlog(CHAR *paramstart[]);
 void        sim_initbussignals(void);
 void        sim_addbussignal(INTBIG signal);
 INTBIG      sim_getbussignals(INTBIG **signallist);
+void        sim_reportsignals(WINDOWPART *simwin, void *(*addbranch)(CHAR*, void*),
+				void *(*findbranch)(CHAR*, void*), void *(*addleaf)(CHAR*, void*), CHAR *(*nodename)(void*));
+void        sim_addsignal(WINDOWPART *simwin, CHAR *sig, BOOLEAN overlay);
+CHAR       *sim_signalseparator(void);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
