@@ -274,6 +274,8 @@ void      simals_vector_command(INTBIG, CHAR*[]);
 BOOLEAN   simals_startsimulation(NODEPROTO *np);
 BOOLEAN   simals_charhandlerschem(WINDOWPART*, INTSML, INTBIG);
 BOOLEAN   simals_charhandlerwave(WINDOWPART*, INTSML, INTBIG);
+void      simals_reportsignals(WINDOWPART *simwin, void *(*addbranch)(CHAR*, void*),
+			void *(*findbranch)(CHAR*, void*), void *(*addleaf)(CHAR*, void*), CHAR *(*nodename)(void*));
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
