@@ -39,11 +39,11 @@ extern TECHNOLOGY *gen_tech;				/* the technology */
 extern NODEPROTO  *gen_univpinprim;			/* Universal Pin */
 extern NODEPROTO  *gen_invispinprim;		/* Invisible Pin */
 extern NODEPROTO  *gen_unroutedpinprim;		/* Unrouted Pin */
-extern NODEPROTO  *gen_facetcenterprim;		/* Facet center */
+extern NODEPROTO  *gen_cellcenterprim;		/* Cell Center */
 extern NODEPROTO  *gen_portprim;			/* Port */
 extern NODEPROTO  *gen_drcprim;				/* DRC Node */
 extern NODEPROTO  *gen_essentialprim;		/* Essential area marker */
-
+extern NODEPROTO  *gen_simprobeprim;		/* Simulation probe */
 
 extern ARCPROTO   *gen_universalarc;		/* universal arc */
 extern ARCPROTO   *gen_invisiblearc;		/* invisible arc */
