@@ -101,16 +101,21 @@ extern "C"
 #define K20   (WHOLE*20)	/* 20.0  */
 #define H20   (K20+H0)		/* 20.5  */
 #define K21   (WHOLE*21)	/* 21.0  */
+#define H21   (K21+H0)		/* 21.5  */
 #define K22   (WHOLE*22)	/* 22.0  */
 #define H22   (K22+H0)		/* 22.5  */
 #define K23   (WHOLE*23)	/* 23.0  */
 #define H23   (K23+H0)		/* 23.5  */
 #define K24   (WHOLE*24)	/* 24.0  */
+#define H24   (K24+H0)		/* 24.5  */
 #define K25   (WHOLE*25)	/* 25.0  */
+#define H25   (K25+H0)		/* 25.5  */
 #define K26   (WHOLE*26)	/* 26.0  */
+#define H26   (K26+H0)		/* 26.5  */
 #define K27   (WHOLE*27)	/* 27.0  */
 #define H27   (K27+H0)		/* 27.5  */
 #define K28   (WHOLE*28)	/* 28.0  */
+#define H28   (K28+H0)		/* 28.5  */
 #define K29   (WHOLE*29)	/* 29.0  */
 #define K30   (WHOLE*30)	/* 30.0  */
 #define K31   (WHOLE*31)	/* 31.0  */
@@ -121,6 +126,7 @@ extern "C"
 #define K39   (WHOLE*39)	/* 39.0  */
 #define K44   (WHOLE*44)	/* 44.0  */
 #define K55   (WHOLE*55)	/* 55.0  */
+#define K57   (WHOLE*57)	/* 57.0  */
 #define K135  (WHOLE*135)	/* 135.0 */
 
 /******************** DIMENSIONS CONVERTED TO EDGES ********************/
@@ -481,8 +487,8 @@ INTBIG    tech_inittrans(INTBIG, NODEINST*, POLYLOOP*);
 BOOLEAN   tech_pinusecount(NODEINST*, WINDOWPART*);
 INTBIG    tech_displayablenvars(NODEINST*, WINDOWPART*, POLYLOOP*);
 VARIABLE *tech_filldisplayablenvar(NODEINST*, POLYGON*, WINDOWPART*, VARIABLE**, POLYLOOP*);
-INTBIG    tech_displayablefacetvars(NODEPROTO *np, WINDOWPART *win, POLYLOOP *pl);
-VARIABLE *tech_filldisplayablefacetvar(NODEPROTO *np, POLYGON *poly, WINDOWPART *win,
+INTBIG    tech_displayablecellvars(NODEPROTO *np, WINDOWPART *win, POLYLOOP *pl);
+VARIABLE *tech_filldisplayablecellvar(NODEPROTO *np, POLYGON *poly, WINDOWPART *win,
 			VARIABLE **varnoeval, POLYLOOP *pl);
 INTBIG    tech_displayableportvars(PORTPROTO *pp, WINDOWPART *win, POLYLOOP *pl);
 VARIABLE *tech_filldisplayableportvar(PORTPROTO *pp, POLYGON *poly, WINDOWPART *win,
