@@ -46,7 +46,7 @@ extern "C"
 #define WANTEXP               020000		/* if on, nodeinst wants to be (un)expanded */
 #define TEMPFLG               040000		/* temporary flag for nodeinst display */
 #define HARDSELECTN          0100000		/* set if hard to select */
-#define NVISIBLEINSIDE     040000000		/* set if node only visible inside facet */
+#define NVISIBLEINSIDE     040000000		/* set if node only visible inside cell */
 
 /* the meaning of ARCINST->userbits: (bits 0-1, 4-24 (0177777763) used globally) */
 #define KILLA             0200000000		/* if on, this arcinst is marked for death */
@@ -88,41 +88,42 @@ extern "C"
 #define TERMNOINTERRUPT  02000000000		/* set to disable interrupts */
 
 /* the meaning of "tool:user.USER_optionflags" */
-#define NOTEXTSELECT              01		/* set to disable selection of ALL text unless "special" option used */
-#define DRAWTINYFACETS            02		/* clear to "hash-out" tiny facets */
-#define CHECKDATE                 04		/* set to check facet dates */
-#define NOEXTRASOUND             010		/* set to disable extra sounds (like arc-creation clicks) */
-#define NOPRIMCHANGES            020		/* set to lock lockable primitives */
-#define PORTLABELS              0700		/* bits for port labels */
-#define PORTLABELSSH               6		/* right shift for port labels */
-#define PORTSFULL                  0		/* ports as complete text */
-#define PORTSCROSS              0100		/* ports drawn as crosses */
-#define PORTSSHORT              0300		/* ports drawn as shortened text */
+#define NOTEXTSELECT                  01	/* set to disable selection of ALL text unless "special" option used */
+#define DRAWTINYCELLS                 02	/* clear to "hash-out" tiny cells */
+#define CHECKDATE                     04	/* set to check cell dates */
+#define NOEXTRASOUND                 010	/* set to disable extra sounds (like arc-creation clicks) */
+#define NOPRIMCHANGES                020	/* set to lock lockable primitives */
+#define PORTLABELS                  0700	/* bits for port labels */
+#define PORTLABELSSH                   6	/* right shift for port labels */
+#define PORTSFULL                      0	/* ports as complete text */
+#define PORTSCROSS                  0100	/* ports drawn as crosses */
+#define PORTSSHORT                  0300	/* ports drawn as shortened text */
 
-#define NOINSTANCESELECT       02000		/* set to disable selection of instances unless "special" option used */
-#define NOMOVEAFTERDUP         04000		/* set to disable moving of objects after duplication */
-#define DUPCOPIESPORTS        010000		/* set to have duplication/array/extract copy ports */
-#define NO3DPERSPECTIVE       020000		/* set to turn off perspective in 3D view */
-#define EXPANDEDDIALOGSDEF    040000		/* set to have expanded dialogs default to expanded */
-#define CENTEREDPRIMITIVES   0100000		/* set to place primitives by centers */
-#define AUTOSWITCHTECHNOLOGY 0200000		/* set to switch technology when facet changes */
-#define EXPORTLABELS        01400000		/* bits for export labels */
-#define EXPORTLABELSSH            17		/* right shift for export labels */
-#define EXPORTSFULL                0		/* exports drawn as complete text */
-#define EXPORTSCROSS         0400000		/* exports drawn as crosses */
-#define EXPORTSSHORT        01400000		/* exports drawn as shortened text */
-#define MOVENODEWITHEXPORT  02000000		/* move node when export text is moved */
-#define NODATEORVERSION     04000000		/* set to supress date/version in output files */
-#define BEEPAFTERLONGJOB   010000000		/* set to beep after a long job */
-#define FACETCENTERALWAYS  020000000		/* set to place facet-center in new facets */
-#define MUSTENCLOSEALL     040000000		/* set to force area-selection to completely enclose objects */
-#define HIDETXTNODE       0100000000		/* set to supress node text */
-#define HIDETXTARC        0200000000		/* set to supress arc text */
-#define HIDETXTPORT       0400000000		/* set to supress port text */
-#define HIDETXTEXPORT    01000000000		/* set to supress export text */
-#define HIDETXTNONLAY    02000000000		/* set to supress nonlayout text */
-#define HIDETXTINSTNAME  04000000000		/* set to supress instance name text */
-#define HIDETXTFACET    010000000000		/* set to supress facet text */
+#define NOINSTANCESELECT           02000	/* set to disable selection of instances unless "special" option used */
+#define NOMOVEAFTERDUP             04000	/* set to disable moving of objects after duplication */
+#define DUPCOPIESPORTS            010000	/* set to have duplication/array/extract copy ports */
+#define NO3DPERSPECTIVE           020000	/* set to turn off perspective in 3D view */
+#define EXPANDEDDIALOGSDEF        040000	/* set to have expanded dialogs default to expanded */
+#define CENTEREDPRIMITIVES       0100000	/* set to place primitives by centers */
+#define AUTOSWITCHTECHNOLOGY     0200000	/* set to switch technology when cell changes */
+#define EXPORTLABELS            01400000	/* bits for export labels */
+#define EXPORTLABELSSH                17	/* right shift for export labels */
+#define EXPORTSFULL                    0	/* exports drawn as complete text */
+#define EXPORTSCROSS             0400000	/* exports drawn as crosses */
+#define EXPORTSSHORT            01400000	/* exports drawn as shortened text */
+#define MOVENODEWITHEXPORT      02000000	/* move node when export text is moved */
+#define NODATEORVERSION         04000000	/* set to supress date/version in output files */
+#define BEEPAFTERLONGJOB       010000000	/* set to beep after a long job */
+#define CELLCENTERALWAYS       020000000	/* set to place cell-center in new cells */
+#define MUSTENCLOSEALL         040000000	/* set to force area-selection to completely enclose objects */
+#define HIDETXTNODE           0100000000	/* set to supress node text */
+#define HIDETXTARC            0200000000	/* set to supress arc text */
+#define HIDETXTPORT           0400000000	/* set to supress port text */
+#define HIDETXTEXPORT        01000000000	/* set to supress export text */
+#define HIDETXTNONLAY        02000000000	/* set to supress nonlayout text */
+#define HIDETXTINSTNAME      04000000000	/* set to supress instance name text */
+#define HIDETXTCELL         010000000000	/* set to supress cell text */
+#define NOPROMPTBEFOREWRITE 020000000000	/* set to disable file name dialog before writing output files */
 
 /* the meaning of "JAVA_flags" on the user tool object */
 #define JAVANOCOMPILER             1		/* disable compiler */
@@ -219,7 +220,7 @@ extern "C"
 #define SNAPMODEINTER          01600		/* snapping mode: any intersection */
 #define NONOVERLAPPABLEDISPLAY 04000		/* set to disallow overlappable layers in display */
 #define NONPERSISTENTCURNODE  010000		/* clear to have current node be persistent */
-#define CURFACETCHANGED       020000		/* set if current facet changed */
+#define CURCELLCHANGED        020000		/* set if current cell changed */
 #define MEASURINGDISTANCE     040000		/* set if measuring distance */
 #define MEASURINGDISTANCEINI 0100000		/* set if measurement initializing */
 
@@ -284,6 +285,7 @@ extern INTBIG       us_tinylambdaperpixelkey;	/* variable key for "USER_tiny_lam
 extern INTBIG       us_ignoreoptionchangeskey;	/* variable key for "USER_ignore_option_changes" */
 extern INTBIG       us_displayunitskey;		/* variable key for "USER_display_units" */
 extern INTBIG       us_electricalunitskey;	/* variable key for "USER_electrical_units" */
+extern INTBIG       us_motiondelaykey;		/* variable key for "USER_motion_delay" */
 extern INTBIG       us_java_flags_key;		/* variable key for "JAVA_flags" */
 extern INTBIG       us_edtec_option_key;	/* variable key for "EDTEC_option" */
 
@@ -310,8 +312,8 @@ extern INTBIG       us_alignment_ratio;		/* current alignment in fractional unit
 extern INTBIG       us_edgealignment_ratio;	/* current edge alignment in fractional units */
 extern BOOLEAN      us_dupdistset;			/* true if duplication distance is valid */
 extern NODEINST    *us_dupnode;				/* a node that was duplicated */
-extern LIBRARY     *us_clipboardlib;		/* library with cut/copy/paste facet */
-extern NODEPROTO   *us_clipboardfacet;		/* facet with cut/copy/paste objects */
+extern LIBRARY     *us_clipboardlib;		/* library with cut/copy/paste cell */
+extern NODEPROTO   *us_clipboardcell;		/* cell with cut/copy/paste objects */
 extern INTBIG       us_dupx, us_dupy;		/* amount to move duplicated objects */
 extern WINDOWFRAME *us_menuframe;			/* window frame on which menu resides */
 #ifndef USEQT
@@ -326,7 +328,7 @@ extern INTBIG       us_menulx,us_menuhx;	/* X: low and high of menu area */
 extern INTBIG       us_menuly,us_menuhy;	/* Y: low and high of menu area */
 extern INTBIG       us_lastmeasurex, us_lastmeasurey;	/* last measured distance */
 extern BOOLEAN      us_validmesaure;		/* true if a measure was done */
-extern INTBIG       us_explorerratio;		/* percentage of window used by facet explorer */
+extern INTBIG       us_explorerratio;		/* percentage of window used by cell explorer */
 extern FILE        *us_logrecord;			/* logging record file */
 extern FILE        *us_logplay;				/* logging playback file */
 extern FILE        *us_termaudit;			/* messages window auditing file */
@@ -343,7 +345,7 @@ extern CHAR       **us_lastcommandpar;		/* the keywords for the last command set
 /*
  * Highlight modules contain the following:
  *
- *  status   fromgeom  fromport   frompoint  fromvar     facet        what is selected
+ *  status   fromgeom  fromport   frompoint  fromvar     cell         what is selected
  * ========  ========  =========  =========  ========  =========  ============================
  * HIGHFROM  nodeinst  ---------  ---------  --------  nodeproto  node
  * HIGHFROM  arcinst   ---------  ---------  --------  nodeproto  arc
@@ -352,7 +354,7 @@ extern CHAR       **us_lastcommandpar;		/* the keywords for the last command set
  * HIGHTEXT  nodeinst  ---------  ---------  variable  nodeproto  displayable variable on node
  * HIGHTEXT  arcinst   ---------  ---------  variable  nodeproto  displayable variable on arc
  * HIGHTEXT  nodeinst  portproto  ---------  variable  nodeproto  displayable variable on port
- * HIGHTEXT  --------  ---------  ---------  variable  nodeproto  displayable variable on facet
+ * HIGHTEXT  --------  ---------  ---------  variable  nodeproto  displayable variable on cell
  * HIGHTEXT  nodeinst  portproto  ---------  --------  nodeproto  port name
  * HIGHTEXT  nodeinst  ---------  ---------  --------  nodeproto  node name
  * HIGHBBOX  --------  ---------  ---------  --------  nodeproto  bounding box
@@ -375,7 +377,7 @@ typedef struct Ihighlight
 {
 	struct Ihighlight *nexthighlight;		/* next in linked list */
 	INTBIG            status;				/* nature of this highlighting (see above) */
-	NODEPROTO        *facet;				/* the facet containing this highlight */
+	NODEPROTO        *cell;					/* the cell containing this highlight */
 	GEOM             *fromgeom;				/* "from" object: geometry module */
 	PORTPROTO        *fromport;				/* "from" object: port on node */
 	INTBIG            frompoint;			/* "from" object: polygon vertex */
@@ -495,8 +497,8 @@ typedef struct
 extern STATUSFIELD *us_statusalign;			/* current node alignment */
 extern STATUSFIELD *us_statusangle;			/* current placement angle */
 extern STATUSFIELD *us_statusarc;			/* current arc prototype */
-extern STATUSFIELD *us_statusfacet;			/* current facet */
-extern STATUSFIELD *us_statusfacetsize;		/* current facet size */
+extern STATUSFIELD *us_statuscell;			/* current cell */
+extern STATUSFIELD *us_statuscellsize;		/* current cell size */
 extern STATUSFIELD *us_statusselectcount;	/* current selection count */
 extern STATUSFIELD *us_statusgridsize;		/* current grid size */
 extern STATUSFIELD *us_statuslambda;		/* current lambda */
@@ -559,6 +561,14 @@ extern struct commandinfo us_lcommand[];
 
 extern KEYWORD *us_pathiskey;				/* the current keyword list */
 
+/******************** MIRRORING VARIABLES ********************/
+
+typedef struct
+{
+	INTBIG  *key;
+	INTBIG  *value;
+} VARMIRROR;
+
 /******************** PROTOTYPES ********************/
 
 /* prototypes for tool interface */
@@ -591,14 +601,14 @@ void us_bind(INTBIG, CHAR*[]);
 void us_color(INTBIG, CHAR*[]);
 void us_commandfile(INTBIG, CHAR*[]);
 void us_constraint(INTBIG, CHAR*[]);
-void us_copyfacet(INTBIG, CHAR*[]);
+void us_copycell(INTBIG, CHAR*[]);
 void us_create(INTBIG, CHAR*[]);
 void us_debug(INTBIG, CHAR*[]);
 void us_defarc(INTBIG, CHAR*[]);
 void us_defnode(INTBIG, CHAR*[]);
 void us_duplicate(INTBIG, CHAR*[]);
 void us_echo(INTBIG, CHAR*[]);
-void us_editfacet(INTBIG, CHAR*[]);
+void us_editcell(INTBIG, CHAR*[]);
 void us_erase(INTBIG, CHAR*[]);
 void us_find(INTBIG, CHAR*[]);
 void us_getproto(INTBIG, CHAR*[]);
@@ -607,7 +617,7 @@ void us_help(INTBIG, CHAR*[]);
 void us_if(INTBIG, CHAR*[]);
 void us_interpret(INTBIG, CHAR*[]);
 void us_iterate(INTBIG, CHAR*[]);
-void us_killfacet(INTBIG, CHAR*[]);
+void us_killcell(INTBIG, CHAR*[]);
 void us_lambda(INTBIG, CHAR*[]);
 void us_library(INTBIG, CHAR*[]);
 void us_macbegin(INTBIG, CHAR*[]);
@@ -678,13 +688,13 @@ void           us_3dstartdrawing(WINDOWPART*);
 void           us_3dzoomview(WINDOWPART *win, float z);
 void           us_abortcommand(CHAR*, ...);
 void           us_abortedmsg(void);
-void           us_addfacetcenter(NODEINST *ni);
+void           us_addcellcenter(NODEINST *ni);
 void           us_addhighlight(HIGHLIGHT*);
 void           us_addparameter(NODEINST *ni, INTBIG key, INTBIG addr, INTBIG type, UINTBIG *descript);
 void           us_addpossiblearcconnections(void*);
 void           us_adjustdisplayabletext(NODEINST*);
 void           us_adjustelectricalunits(LIBRARY *lib, INTBIG newunits);
-void           us_adjustfornodeinfacet(NODEPROTO *prim, NODEPROTO *facet, INTBIG *cx, INTBIG *cy);
+void           us_adjustfornodeincell(NODEPROTO *prim, NODEPROTO *cell, INTBIG *cx, INTBIG *cy);
 BOOLEAN        us_adjustparameterlocations(NODEINST *ni);
 void           us_adjustperpendicularsnappoints(HIGHLIGHT*, HIGHLIGHT*);
 void           us_adjustquickkeys(VARIABLE *var, BOOLEAN warnofchanges);
@@ -705,10 +715,10 @@ void           us_buttonhandler(WINDOWPART*, INTBIG, INTBIG, INTBIG);
 BOOLEAN        us_cantedit(NODEPROTO*, NODEINST*, BOOLEAN);
 BOOLEAN        us_charhandler(WINDOWPART*, INTSML, INTBIG);
 void           us_chatportproto(NODEINST*, PORTPROTO*);
-void           us_check_facet_date(NODEPROTO*, UINTBIG);
+void           us_check_cell_date(NODEPROTO*, UINTBIG);
 void           us_checkdatabase(BOOLEAN);
 void           us_checkspiceparts(void);
-BOOLEAN        us_cleanupfacet(NODEPROTO*, BOOLEAN);
+BOOLEAN        us_cleanupcell(NODEPROTO*, BOOLEAN);
 void           us_clearclipboard(void);
 void           us_clearhighlightcount(void);
 void           us_clearwindow(WINDOWPART*);
@@ -717,11 +727,11 @@ void           us_computearcfartextbit(ARCINST *ai);
 void           us_computenodefartextbit(NODEINST *ni);
 UINTBIG        us_computewipestate(NODEINST *ni);
 void           us_continuesessionlogging(void);
-NODEPROTO     *us_convertfacet(NODEPROTO*, TECHNOLOGY*);
+NODEPROTO     *us_convertcell(NODEPROTO*, TECHNOLOGY*);
 CHAR          *us_convertmactoworld(CHAR *buf);
 CHAR          *us_convertworldtomac(CHAR *buf);
 void           us_copyexplorerwindow(void);
-void           us_copylisttofacet(GEOM**, NODEPROTO*, NODEPROTO*, BOOLEAN, BOOLEAN, BOOLEAN);
+void           us_copylisttocell(GEOM**, NODEPROTO*, NODEPROTO*, BOOLEAN, BOOLEAN, BOOLEAN);
 void           us_copyobjects(WINDOWPART*);
 NODEPROTO     *us_copyrecursively(NODEPROTO*, CHAR*, LIBRARY*, VIEW*, BOOLEAN, BOOLEAN, CHAR*, BOOLEAN, BOOLEAN, BOOLEAN);
 void           us_coverimplant(void);
@@ -733,17 +743,17 @@ INTBIG         us_curvearcaboutpoint(ARCINST *ai, INTBIG xcur, INTBIG ycur);
 INTBIG         us_curvearcthroughpoint(ARCINST *ai, INTBIG xcur, INTBIG ycur);
 void           us_cutobjects(WINDOWPART*);
 void           us_deleteexplorerstruct(WINDOWPART*);
-void           us_delfacetmessage(NODEPROTO*);
+void           us_delcellmessage(NODEPROTO*);
 void           us_delhighlight(HIGHLIGHT*);
 void           us_delnodeprotocenter(NODEPROTO*);
-void           us_deltecedlayerfacet(NODEPROTO *np);
-void           us_deltecednodefacet(NODEPROTO *np);
+void           us_deltecedlayercell(NODEPROTO *np);
+void           us_deltecednodecell(NODEPROTO *np);
 BOOLEAN        us_demandxy(INTBIG*, INTBIG*);
 CHAR          *us_describeboundkey(INTSML key, INTBIG special, INTBIG readable);
 void           us_describecontents(NODEPROTO*);
 CHAR          *us_describefont(INTBIG);
 CHAR          *us_describemenunode(COMMANDBINDING *commandbinding);
-CHAR          *us_describenodeinsttype(NODEPROTO *np, INTBIG bits);
+CHAR          *us_describenodeinsttype(NODEPROTO *np, NODEINST *ni, INTBIG bits);
 CHAR          *us_describestyle(INTBIG);
 CHAR          *us_describetextdescript(UINTBIG*);
 void           us_dialogeditor(void);
@@ -751,15 +761,15 @@ CHAR          *us_displayedportname(PORTPROTO *pp, INTBIG dispstyle);
 void           us_docommands(FILE*, BOOLEAN, CHAR*);
 void           us_doexpand(NODEINST*, INTBIG, INTBIG);
 void           us_dofillet(void);
-void           us_dokillfacet(NODEPROTO *np);
+void           us_dokillcell(NODEPROTO *np);
 void           us_dopeek(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, WINDOWPART*);
 void           us_doubchanges(void);
 void           us_dounexpand(NODEINST*);
 INTBIG         us_drawarcinst(ARCINST*, INTBIG, XARRAY, INTBIG, WINDOWPART*);
 void           us_drawdispwindowsliders(WINDOWPART *w);
 void           us_drawexplorericon(WINDOWPART *w, INTBIG lx, INTBIG ly);
-INTBIG         us_drawfacet(NODEINST*, INTBIG, XARRAY, INTBIG, WINDOWPART*);
-void           us_drawfacetvariable(VARIABLE *var, NODEPROTO *np);
+INTBIG         us_drawcell(NODEINST*, INTBIG, XARRAY, INTBIG, WINDOWPART*);
+void           us_drawcellvariable(VARIABLE *var, NODEPROTO *np);
 void           us_drawhorizontalslider(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_drawhorizontalsliderthumb(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_drawmenu(INTBIG, WINDOWFRAME*);
@@ -767,15 +777,16 @@ void           us_drawmenuentry(INTBIG, INTBIG, CHAR*);
 INTBIG         us_drawnodeinst(NODEINST*, INTBIG, XARRAY, INTBIG, WINDOWPART*);
 void           us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w, BOOLEAN ignoreinherit);
 void           us_drawportprotovariables(PORTPROTO *pp, INTBIG on, XARRAY trans, WINDOWPART *w, BOOLEAN ignoreinherit);
-void           us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy);
+void           us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, BOOLEAN drawtopright);
 void           us_drawverticalslider(WINDOWPART*, INTBIG, INTBIG, INTBIG, BOOLEAN);
 void           us_drawverticalsliderthumb(WINDOWPART*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_drawwindow(WINDOWPART*, INTBIG);
+void           us_drawwindowicon(WINDOWPART *w, INTBIG lx, INTBIG ly, INTBIG *dots);
 void           us_dumppulldownmenus(void);
 void           us_editvariabletext(VARIABLE*, INTBIG, INTBIG, CHAR*);
 void           us_emitcopyright(FILE *f, CHAR *prefix, CHAR *postfix);
 void           us_endchanges(WINDOWPART*);
-void           us_ensurepropertechnology(NODEPROTO *facet, CHAR *forcedtechnology, BOOLEAN always);
+void           us_ensurepropertechnology(NODEPROTO *cell, CHAR *forcedtechnology, BOOLEAN always);
 void           us_ensurewindow(NODEPROTO*);
 void           us_erasegeometry(NODEPROTO*);
 void           us_erasenodeinst(NODEINST*);
@@ -796,8 +807,8 @@ CHAR          *us_explorerreadoutnext(WINDOWPART *w, INTBIG *indent, INTBIG *sty
 void           us_exploreredisphandler(WINDOWPART*);
 int            us_exportnameindexascending(const void *e1, const void *e2);
 int            us_exportnametypeascending(const void *e1, const void *e2);
-BOOLEAN        us_facetedithandler(WINDOWPART*, INTSML, INTBIG);
-BOOLEAN        us_facetfromtech(NODEPROTO *facet, TECHNOLOGY *tech);
+BOOLEAN        us_celledithandler(WINDOWPART*, INTSML, INTBIG);
+BOOLEAN        us_cellfromtech(NODEPROTO *cell, TECHNOLOGY *tech);
 BOOLEAN        us_figuredrawpath(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, PORTPROTO *toport,
 				INTBIG *xcur, INTBIG *ycur);
 void           us_figuregrabpoint(UINTBIG*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
@@ -871,7 +882,7 @@ INTBIG         us_gettextsize(CHAR*, INTBIG);
 void           us_gettruewindowbounds(WINDOWPART *w, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy);
 BOOLEAN        us_gettwoobjects(GEOM**, PORTPROTO**, GEOM**, PORTPROTO**);
 BOOLEAN        us_getvar(CHAR*, INTBIG*, INTBIG*, CHAR**, BOOLEAN*, INTBIG*);
-void           us_graphfacets(NODEPROTO *top);
+void           us_graphcells(NODEPROTO *top);
 void           us_gridset(WINDOWPART*, INTBIG);
 BOOLEAN        us_hasotherwindowpart(INTBIG x, INTBIG y, WINDOWPART *ow);
 void           us_highlighteverywhere(GEOM*, PORTPROTO*, INTBIG, BOOLEAN, INTBIG, BOOLEAN);
@@ -879,7 +890,7 @@ void           us_highlighthaschanged(void);
 void           us_highlightmenu(INTBIG, INTBIG, INTBIG);
 void           us_highlightwindow(WINDOWPART*, BOOLEAN);
 TECHNOLOGY    *us_hightech(HIGHLIGHT *high);
-NODEPROTO     *us_highfacet(HIGHLIGHT *high);
+NODEPROTO     *us_highcell(HIGHLIGHT *high);
 void           us_hsvtorgb(float, float, float, INTBIG*, INTBIG*, INTBIG*);
 void           us_identifyports(INTBIG, NODEINST**, NODEPROTO*, INTBIG, BOOLEAN);
 void           us_illustratecommandset(void);
@@ -904,10 +915,10 @@ ARCINST       *us_makeconnection(NODEINST*, PORTPROTO*, ARCPROTO*, NODEINST*, PO
 				ARCPROTO*, NODEPROTO*, INTBIG, INTBIG,
 				ARCINST**, ARCINST**, NODEINST**, NODEINST**,
 				INTBIG, BOOLEAN, INTBIG*, BOOLEAN);
-CHAR          *us_makefacetline(NODEPROTO*, INTBIG);
+CHAR          *us_makecellline(NODEPROTO*, INTBIG);
 BOOLEAN        us_makehighlight(CHAR*, HIGHLIGHT*);
 CHAR          *us_makehighlightstring(HIGHLIGHT*);
-NODEPROTO     *us_makeiconfacet(PORTPROTO*, CHAR*, CHAR*, LIBRARY*);
+NODEPROTO     *us_makeiconcell(PORTPROTO*, CHAR*, CHAR*, LIBRARY*);
 PORTPROTO     *us_makenewportproto(NODEPROTO*, NODEINST*, PORTPROTO*, CHAR*, INTBIG, INTBIG, UINTBIG*);
 BOOLEAN        us_makescreen(INTBIG*, INTBIG*, INTBIG*, INTBIG*, WINDOWPART*);
 void           us_maketextpoly(CHAR*, WINDOWPART*, INTBIG, INTBIG, NODEINST*, TECHNOLOGY*, UINTBIG*, POLYGON*);
@@ -916,14 +927,14 @@ BOOLEAN        us_matchpurecommand(CHAR *command, CHAR *purecommand);
 INTBIG         us_modarcbits(INTBIG, BOOLEAN, CHAR*, GEOM**);
 void           us_modifytextdescript(HIGHLIGHT*, UINTBIG*);
 void           us_moveselectedtext(INTBIG numtexts, CHAR **textlist, GEOM**, INTBIG odx, INTBIG ody);
-NODEPROTO     *us_needfacet(void);
+NODEPROTO     *us_needcell(void);
 BOOLEAN        us_needwindow(void);
 void           us_nettravel(NODEINST*, INTBIG);
 MACROPACK     *us_newmacropack(CHAR*);
 NODEPROTO     *us_newnodeproto(CHAR *name, LIBRARY *lib);
 CHAR          *us_nextvars(void);
 BOOLEAN        us_nodemoveswithtext(HIGHLIGHT *high);
-NODEPROTO     *us_nodetocreate(BOOLEAN getcontents, NODEPROTO *facet);
+NODEPROTO     *us_nodetocreate(BOOLEAN getcontents, NODEPROTO *cell);
 void           us_nulldisplayroutine(POLYGON*, WINDOWPART*);
 void           us_parsebinding(CHAR*, COMMANDBINDING*);
 INTBIG         us_parsecommand(CHAR*, CHAR*[]);
@@ -959,8 +970,8 @@ void           us_regridselected(void);
 CHAR          *us_removeampersand(CHAR *name);
 void           us_removeubchange(NODEPROTO*);
 void           us_renameport(PORTPROTO*, CHAR*);
-void           us_renametecedcell(CELL *c, CHAR *oldname);
-void           us_replaceallarcs(NODEPROTO *facet, GEOM **list, ARCPROTO *ap, BOOLEAN connected, BOOLEAN thisfacet);
+void           us_renametecedcell(NODEPROTO *np, CHAR *oldname);
+void           us_replaceallarcs(NODEPROTO *cell, GEOM **list, ARCPROTO *ap, BOOLEAN connected, BOOLEAN thiscell);
 void           us_replacecircuittext(WINDOWPART *win, CHAR *replace);
 void           us_replacelibraryreferences(LIBRARY *oldlib, LIBRARY *newlib);
 NODEINST      *us_replacenodeinst(NODEINST *oldni, NODEPROTO *newnp, BOOLEAN ignoreportnames, BOOLEAN allowdeletedports);
@@ -988,9 +999,9 @@ void           us_setarcproto(ARCPROTO*, BOOLEAN);
 void           us_setcolorentry(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, BOOLEAN);
 void           us_setcursorpos(WINDOWFRAME*, INTBIG, INTBIG);
 void           us_setdescriptoffset(UINTBIG*, INTBIG, INTBIG);
-void           us_setessentialbounds(NODEPROTO *facet);
-void           us_setfacetname(WINDOWPART *w);
-void           us_setfacetsize(WINDOWPART *w);
+void           us_setessentialbounds(NODEPROTO *cell);
+void           us_setcellname(WINDOWPART *w);
+void           us_setcellsize(WINDOWPART *w);
 void           us_setfind(HIGHLIGHT*, INTBIG, INTBIG, INTBIG, INTBIG);
 void           us_setfloatvariablevalue(GEOM *geom, INTBIG key, VARIABLE *oldvar, float value);
 void           us_setgridsize(WINDOWPART *w);
@@ -1004,7 +1015,7 @@ void           us_setmultiplehighlight(CHAR*, BOOLEAN);
 void           us_setnodeangle(WINDOWFRAME*);
 void           us_setnodeproto(NODEPROTO*);
 void           us_setnodeprotocenter(INTBIG, INTBIG, NODEPROTO*);
-NODEPROTO     *us_setscrolltocurrentfacet(INTBIG scrollitem, BOOLEAN curinstance, BOOLEAN curfacet,
+NODEPROTO     *us_setscrolltocurrentcell(INTBIG scrollitem, BOOLEAN curinstance, BOOLEAN curcell,
 					BOOLEAN forcecurlib, BOOLEAN justcells, void *dia);
 void           us_setselectioncount(void);
 void           us_settechname(WINDOWFRAME*);
@@ -1019,14 +1030,14 @@ void           us_shadownodeproto(WINDOWFRAME*, NODEPROTO*);
 void           us_showallhighlight(void);
 void           us_showcurrentarcproto(void);
 void           us_showcurrentnodeproto(void);
-void           us_showlayercoverage(NODEPROTO *facet);
+void           us_showlayercoverage(NODEPROTO *cell);
 void           us_showpoly(POLYGON*, WINDOWPART*);
 void           us_showwindowmode(WINDOWPART *w);
 NODEPROTO     *us_skeletonize(NODEPROTO *np, CHAR *newname, LIBRARY *newlib, BOOLEAN quiet);
 void           us_slideleft(INTBIG);
 void           us_slideup(INTBIG);
 int            us_sortarcsbyname(const void *e1, const void *e2);
-NODEPROTO    **us_sortlib(LIBRARY*, CHAR*, BOOLEAN);
+NODEPROTO    **us_sortlib(LIBRARY*, CHAR*);
 int            us_sortnodesbyname(const void *e1, const void *e2);
 int            us_sortpopupmenuascending(const void *e1, const void *e2);
 WINDOWPART    *us_splitcurrentwindow(INTBIG, BOOLEAN, WINDOWPART**, INTBIG);
@@ -1036,21 +1047,22 @@ void           us_squarescreen(WINDOWPART*, WINDOWPART*, BOOLEAN, INTBIG*, INTBI
 INTBIG         us_stretchtonodes(ARCPROTO *typ, INTBIG wid, NODEINST *ni1, PORTPROTO *pp1, INTBIG otherx, INTBIG othery);
 CHAR          *us_stripampersand(CHAR*);
 WINDOWPART    *us_subwindow(INTBIG, INTBIG, INTBIG, INTBIG, WINDOWPART*);
-void           us_switchtofacet(NODEPROTO*, INTBIG, INTBIG, INTBIG, INTBIG, NODEINST*, PORTPROTO*, BOOLEAN, BOOLEAN, BOOLEAN);
+void           us_switchtocell(NODEPROTO*, INTBIG, INTBIG, INTBIG, INTBIG, NODEINST*, PORTPROTO*, BOOLEAN, BOOLEAN, BOOLEAN);
 void           us_switchtolibrary(LIBRARY*);
 void           us_tecedaddfunstring(void*, INTBIG);
-void           us_teceddeletelayerfacet(NODEPROTO *np);
-void           us_teceddeletenodefacet(NODEPROTO *np);
+void           us_teceddeletelayercell(NODEPROTO *np);
+void           us_teceddeletenodecell(NODEPROTO *np);
 void           us_tecedentry(INTBIG, CHAR*[]);
 INTBIG         us_tecedgetoption(NODEINST*);
 void           us_tecedrenamecell(CHAR *oldname, CHAR *newname);
+CHAR          *us_teceddescribenode(NODEINST *ni);
 CHAR          *us_techname(NODEPROTO *np);
 CHAR          *us_tempoptionslibraryname(void);
-void           us_textfacetchanges(WINDOWPART*, INTBIG, CHAR*, CHAR*, INTBIG);
+void           us_textcellchanges(WINDOWPART*, INTBIG, CHAR*, CHAR*, INTBIG);
 void           us_toolturnedon(TOOL *tool);
 BOOLEAN        us_topofallthings(CHAR**);
 BOOLEAN        us_topofarcnodes(CHAR**);
-BOOLEAN        us_topofcellfacets(CHAR**);
+BOOLEAN        us_topofcells(CHAR**);
 BOOLEAN        us_topofcommands(CHAR**);
 BOOLEAN        us_topofconstraints(CHAR**);
 BOOLEAN        us_topofcports(CHAR**);
@@ -1072,8 +1084,8 @@ void           us_translationdlog(void);
 CHAR          *us_trueattributename(VARIABLE *var);
 void           us_undisplayobject(GEOM*);
 void           us_undoportproto(NODEINST*, PORTPROTO*);
-void           us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np);
-CHAR          *us_uniqueobjectname(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclude);
+void           us_undrawcellvariable(VARIABLE *var, NODEPROTO *np);
+CHAR          *us_uniqueobjectname(CHAR *name, NODEPROTO *cell, INTBIG type, void *exclude);
 CHAR          *us_uniqueportname(CHAR*, NODEPROTO*);
 void           us_unknowncommand(void);
 void           us_unqueueredraw(LIBRARY *lib);
