@@ -46,18 +46,18 @@ INTBIG us_attributesdlog(void);
 INTBIG us_attrparamdlog(void);
 INTBIG us_attrreportdlog(void);
 BOOLEAN us_colormixdlog(CHAR *overlayernames[], INTBIG layercount, CHAR **layernames, INTBIG *printcolors);
-INTBIG us_copyfacetdlog(CHAR*);
+INTBIG us_copycelldlog(CHAR*);
 INTBIG us_copyrightdlog(void);
 INTBIG us_createtodlog(CHAR*[]);
 INTBIG us_defarcdlog(void);
 INTBIG us_defnodedlog(void);
 INTBIG us_deftextdlog(CHAR*);
 INTBIG us_dependentlibdlog(void);
-INTBIG us_editfacetdlog(CHAR*);
+INTBIG us_editcelldlog(CHAR*);
 INTBIG us_examineoptionsdlog(void);
-INTBIG us_facetdlog(void);
-INTBIG us_facetlist(void);
-INTBIG us_facetselect(CHAR*, CHAR*[], INTBIG);
+INTBIG us_celldlog(void);
+INTBIG us_celllist(void);
+INTBIG us_cellselect(CHAR*, CHAR*[], INTBIG);
 INTBIG us_findoptionsdlog(void);
 INTBIG us_findtextdlog(void);
 INTBIG us_frameoptionsdlog(void);
@@ -84,7 +84,7 @@ INTBIG us_patterndlog(void);
 INTBIG us_placetextdlog(void);
 INTBIG us_plotoptionsdlog(void);
 INTBIG us_portdisplaydlog(void);
-INTBIG us_portdlog(CHAR*[]);
+INTBIG us_portdlog(void);
 INTBIG us_purelayernodedlog(CHAR*[]);
 INTBIG us_quickkeydlog(void);
 INTBIG us_quitdlog(CHAR*, INTBIG);
