@@ -35,39 +35,39 @@ extern "C"
 #endif
 
 /* the meaning of "EDTEC_option" on nodes */
-#define LAYERCOLOR      1					/* color (layer facet) */
-#define LAYERSTYLE      2					/* style (layer facet) */
-#define LAYERCIF        3					/* CIF name (layer facet) */
-#define LAYERFUNCTION   4					/* function (layer facet) */
-#define LAYERLETTERS    5					/* letters (layer facet) */
-#define LAYERPATTERN    6					/* pattern (layer facet) */
-#define LAYERPATCONT    7					/* pattern control (layer facet) */
-#define LAYERPATCH      8					/* patch of layer (node/arc facet) */
-#define ARCFUNCTION     9					/* function (arc facet) */
-#define NODEFUNCTION   10					/* function (node facet) */
-#define ARCFIXANG      11					/* fixed-angle (arc facet) */
-#define ARCWIPESPINS   12					/* wipes pins (arc facet) */
-#define ARCNOEXTEND    13					/* end extension (arc facet) */
-#define TECHLAMBDA     14					/* lambda (info facet) */
-#define TECHDESCRIPT   15					/* description (info facet) */
-#define NODESERPENTINE 16					/* serpentine MOS trans (node facet) */
-#define LAYERDRCMINWID 17					/* DRC minimum width (layer facet, OBSOLETE) */
-#define PORTOBJ        18					/* port object (node facet) */
-#define HIGHLIGHTOBJ   19					/* highlight object (node/arc facet) */
-#define LAYERGDS       20					/* Calma GDS-II layer (layer facet) */
-#define NODESQUARE     21					/* square node (node facet) */
-#define NODEWIPES      22					/* pin node can disappear (node facet) */
-#define ARCINC         23					/* increment for arc angles (arc facet) */
-#define NODEMULTICUT   24					/* separation of multiple contact cuts (node facet) */
-#define NODELOCKABLE   25					/* lockable primitive (node facet) */
-#define CENTEROBJ      26					/* grab point object (node facet) */
-#define LAYERSPIRES    27					/* SPICE resistance (layer facet) */
-#define LAYERSPICAP    28					/* SPICE capacitance (layer facet) */
-#define LAYERSPIECAP   29					/* SPICE edge capacitance (layer facet) */
-#define LAYERDXF       30					/* DXF layer (layer facet) */
-#define LAYER3DHEIGHT  31					/* 3D height (layer facet) */
-#define LAYER3DTHICK   32					/* 3D thickness (layer facet) */
-#define LAYERPRINTCOL  33					/* print colors (layer facet) */
+#define LAYERCOLOR      1					/* color (layer cell) */
+#define LAYERSTYLE      2					/* style (layer cell) */
+#define LAYERCIF        3					/* CIF name (layer cell) */
+#define LAYERFUNCTION   4					/* function (layer cell) */
+#define LAYERLETTERS    5					/* letters (layer cell) */
+#define LAYERPATTERN    6					/* pattern (layer cell) */
+#define LAYERPATCONT    7					/* pattern control (layer cell) */
+#define LAYERPATCH      8					/* patch of layer (node/arc cell) */
+#define ARCFUNCTION     9					/* function (arc cell) */
+#define NODEFUNCTION   10					/* function (node cell) */
+#define ARCFIXANG      11					/* fixed-angle (arc cell) */
+#define ARCWIPESPINS   12					/* wipes pins (arc cell) */
+#define ARCNOEXTEND    13					/* end extension (arc cell) */
+#define TECHLAMBDA     14					/* lambda (info cell) */
+#define TECHDESCRIPT   15					/* description (info cell) */
+#define NODESERPENTINE 16					/* serpentine MOS trans (node cell) */
+#define LAYERDRCMINWID 17					/* DRC minimum width (layer cell, OBSOLETE) */
+#define PORTOBJ        18					/* port object (node cell) */
+#define HIGHLIGHTOBJ   19					/* highlight object (node/arc cell) */
+#define LAYERGDS       20					/* Calma GDS-II layer (layer cell) */
+#define NODESQUARE     21					/* square node (node cell) */
+#define NODEWIPES      22					/* pin node can disappear (node cell) */
+#define ARCINC         23					/* increment for arc angles (arc cell) */
+#define NODEMULTICUT   24					/* separation of multiple contact cuts (node cell) */
+#define NODELOCKABLE   25					/* lockable primitive (node cell) */
+#define CENTEROBJ      26					/* grab point object (node cell) */
+#define LAYERSPIRES    27					/* SPICE resistance (layer cell) */
+#define LAYERSPICAP    28					/* SPICE capacitance (layer cell) */
+#define LAYERSPIECAP   29					/* SPICE edge capacitance (layer cell) */
+#define LAYERDXF       30					/* DXF layer (layer cell) */
+#define LAYER3DHEIGHT  31					/* 3D height (layer cell) */
+#define LAYER3DTHICK   32					/* 3D thickness (layer cell) */
+#define LAYERPRINTCOL  33					/* print colors (layer cell) */
 
 /* the strings that appear in the technology editor */
 #define TECEDNODETEXTCOLOR      x_("Color: ")
@@ -196,14 +196,27 @@ typedef struct Itechvar
 
 extern TECHVAR us_knownvars[];
 
+/* for describing special text in a cell */
+typedef struct
+{
+	NODEINST *ni;
+	void     *value;
+	INTBIG    x, y;
+	INTBIG    funct;
+} SPECIALTEXTDESCR;
+extern SPECIALTEXTDESCR us_tecednodetexttable[];
+extern SPECIALTEXTDESCR us_tecedarctexttable[];
+extern SPECIALTEXTDESCR us_tecedmisctexttable[];
+
 /* the globals that define a technology */
 extern INTBIG           us_teceddrclayers;
 extern CHAR           **us_teceddrclayernames;
 
-extern LIST us_teclayer_functions[];
-extern LIST us_tecarc_functions[];
+extern LIST             us_teclayer_functions[];
+extern LIST             us_tecarc_functions[];
 
 /* prototypes for intramodule routines */
+void       us_tecedcompact(NODEPROTO *cell);
 void       us_tecedgetbbox(NODEINST *ni, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy);
 EXAMPLE   *us_tecedgetexamples(NODEPROTO *np, BOOLEAN isnode);
 INTBIG     us_teceditfindsequence(LIBRARY **dependentlibs, INTBIG dependentlibcount,
@@ -226,7 +239,7 @@ void       us_tecedmakenode(NODEPROTO *np, INTBIG func, BOOLEAN serp, BOOLEAN sq
 void       us_tecedpointout(NODEINST *ni, NODEPROTO *np);
 CHAR      *us_tecedsamplename(NODEPROTO *layernp);
 void       us_tecedswapports(INTBIG *p1, INTBIG *p2, TECH_NODES *tlist);
-void       us_tecfromlibinit(LIBRARY *lib, CHAR *techname, BOOLEAN dumpc);
+void       us_tecfromlibinit(LIBRARY *lib, CHAR *techname, INTBIG dumpformat);
 void       us_tecedfreeexamples(EXAMPLE *ne);
 void       us_tecedgetlayernamelist(void);
 void       us_tecedloaddrcmessage(DRCRULES *rules, LIBRARY *lib);
@@ -234,6 +247,7 @@ void       us_teceditgetdrcarrays(VARIABLE *var, DRCRULES *rules);
 NODEPROTO *us_tecedgetlayer(NODEINST *ni);
 CHAR      *us_tecedgetportname(NODEINST *ni);
 void       us_teceditgetprintcol(VARIABLE *var, INTBIG *r, INTBIG *g, INTBIG *b, INTBIG *o, INTBIG *f);
+void       us_tecedfindspecialtext(NODEPROTO *np, SPECIALTEXTDESCR *table);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
