@@ -68,11 +68,10 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	INTBIG i, a, n, p, magic, aacount, techcount, nodepprotoindex,
 		portprotoindex, portpprotoindex, arcprotoindex, nodeprotoindex, nodeindex,
 		arcindex, geomindex, curnodeproto, cellindex,
-		*curstate, facetshere, filestatus;
+		*curstate, cellshere, filestatus;
 	BOOLEAN err, createit;
 	time_t olddate;
 	INTBIG year, month, mday, hour, minute, second;
-	INTSML save;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCPROTO *ap;
 	REGISTER PORTPROTO *pp;
@@ -85,7 +84,6 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	REGISTER CHAR *rename, *istrue, *dotaddr, *msg, *ext;
 	CHAR *truename, *name, *arg[3], datesuffix[30];
 	UCHAR1 wordsize;
-	REGISTER CELL *c;
 	REGISTER VIEW *v;
 	REGISTER void *infstr;
 
@@ -254,8 +252,8 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	/* first flush all changes so that database is clean */
 	noundoallowed();
 
-	/* initialize the file (writing version 11) */
-	magic = MAGIC11;
+	/* initialize the file (writing version 13) */
+	magic = MAGIC13;
 	io_putout(&magic, 4);
 	wordsize = SIZEOFINTSML;   io_putout(&wordsize, 1);
 	wordsize = SIZEOFINTBIG;   io_putout(&wordsize, 1);
@@ -269,9 +267,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	nodeindex = portprotoindex = nodeprotoindex = arcindex = nodepprotoindex =
 		portpprotoindex = arcprotoindex = cellindex = 0;
 
-	/* count and number the cells, facets, nodes, arcs, and ports in this library */
-	for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
-		c->temp1 = cellindex++;
+	/* count and number the cells, nodes, arcs, and ports in this library */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		np->temp1 = nodeprotoindex++;
@@ -282,15 +278,13 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 			ni->temp1 = nodeindex++;
 	}
-	facetshere = nodeprotoindex;
+	cellshere = nodeprotoindex;
 
-	/* prepare to locate references to facets in other libraries */
+	/* prepare to locate references to cells in other libraries */
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 	{
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp2 = 0;
-		for(c = olib->firstcell; c != NOCELL; c = c->nextcell)
-			c->temp2 = 0;
 	}
 
 	/* scan for all cross-library references */
@@ -311,8 +305,6 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	}
 	for(v = el_views; v != NOVIEW; v = v->nextview)
 		io_findxlibvariables(v->firstvar, v->numvar);
-	for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
-		io_findxlibvariables(c->firstvar, c->numvar);
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		io_findxlibvariables(np->firstvar, np->numvar);
@@ -328,14 +320,13 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 			if (ni->proto->primindex == 0)
 			{
 				ni->proto->temp2 = 1;
-				ni->proto->cell->temp2 = 1;
 			}
 		}
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 			io_findxlibvariables(ai->firstvar, ai->numvar);
 	}
 
-	/* count and number the facets and cells in other libraries */
+	/* count and number the cells in other libraries */
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 	{
 		if (olib == lib) continue;
@@ -346,10 +337,6 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				pp->temp1 = portprotoindex++;
 		}
-		for(c = olib->firstcell; c != NOCELL; c = c->nextcell)
-		{
-			if (c->temp2 != 0) c->temp1 = cellindex++;
-		}
 	}
 
 	/* count and number the primitive node and port prototypes */
@@ -374,9 +361,8 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	io_putoutbig(&portprotoindex);
 	io_putoutbig(&arcindex);
 	io_putoutbig(&geomindex);
-	io_putoutbig(&cellindex);
 
-	/* write the current facet */
+	/* write the current cell */
 	if (lib->curnodeproto == NONODEPROTO) curnodeproto = -1; else
 		curnodeproto = lib->curnodeproto->temp1;
 	io_putoutbig(&curnodeproto);
@@ -386,7 +372,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 		ttyputmsg(M_("Writing %ld tools, %ld technologies"), aacount, techcount);
 		ttyputmsg(M_("        %ld prim nodes, %ld prim ports, %ld arc protos"),
 			nodepprotoindex, portpprotoindex, arcprotoindex);
-		ttyputmsg(M_("        %ld cells %ld facets, %ld ports, %ld nodes, %ld arcs"),
+		ttyputmsg(M_("        %ld cells %ld cells, %ld ports, %ld nodes, %ld arcs"),
 			cellindex, nodeprotoindex, portprotoindex, nodeindex, arcindex);
 	}
 
@@ -422,7 +408,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 		io_putstring(v->sviewname);
 	}
 
-	/* write total number of arcinsts, nodeinsts, and ports in each facet */
+	/* write total number of arcinsts, nodeinsts, and ports in each cell */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		for(a = 0, ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst) a++;
@@ -431,11 +417,11 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 		io_putoutbig(&n);
 		for(p = 0, pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto) p++;
 		io_putoutbig(&p);
-		if (io_verbose > 0) ttyputmsg(M_("Facet %s has %ld arcs, %ld nodes, %ld ports"),
+		if (io_verbose > 0) ttyputmsg(M_("Cell %s has %ld arcs, %ld nodes, %ld ports"),
 			describenodeproto(np), a, n, p);
 	}
 
-	/* write dummy numbers of arcinsts and nodeinst; count ports for external facets */
+	/* write dummy numbers of arcinsts and nodeinst; count ports for external cells */
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 	{
 		if (olib == lib) continue;
@@ -463,7 +449,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 		for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
 			/* write the primitive node prototype name */
-			io_putstring(np->primname);
+			io_putstring(np->protoname);
 			for(pp = np->firstportproto, i=0; pp != NOPORTPROTO; pp = pp->nextportproto) i++;
 			io_putoutbig(&i);
 			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -530,46 +516,14 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 		io_writevariables(v->firstvar, v->numvar, VVIEW);
 	}
 
-	/* write all of the cell names in this library */
-	for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
-	{
-		if (stopping(STOPREASONBINARY)) longjmp(io_filerror, 1);
-
-		/* write the cell name */
-		io_putstring(c->cellname);
-
-		/* write variable information */
-		io_writevariables(c->firstvar, c->numvar, VCELL);
-
-		if (io_verbose > 0) ttyputmsg(M_("Wrote cell %s"), c->cellname);
-	}
-
-	/* write all of the cell names in external libraries */
-	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
-	{
-		if (olib == lib) continue;
-		for(c = olib->firstcell; c != NOCELL; c = c->nextcell)
-		{
-			if (c->temp2 == 0) continue;
-
-			/* write the cell name */
-			io_putstring(c->cellname);
-
-			/* write dummy variable information */
-			save = c->numvar;   c->numvar = 0;
-			io_writevariables(c->firstvar, c->numvar, VCELL);
-			c->numvar = save;
-		}
-	}
-
-	/* write all of the facets in this library */
+	/* write all of the cells in this library */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		if (stopping(STOPREASONBINARY)) longjmp(io_filerror, 1);
 		io_writenodeproto(np, TRUE);
 	}
 
-	/* write all of the facets in external libraries */
+	/* write all of the cells in external libraries */
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 	{
 		if (olib == lib) continue;
@@ -595,7 +549,7 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 			io_writenodeinst(ni);
 			n++;
 		}
-		if (io_verbose > 0) ttyputmsg(M_("Wrote %ld arcs and %ld nodes in facet %s"),
+		if (io_verbose > 0) ttyputmsg(M_("Wrote %ld arcs and %ld nodes in cell %s"),
 			a, n, describenodeproto(np));
 	}
 
@@ -615,12 +569,12 @@ BOOLEAN io_writebinlibrary(LIBRARY *lib, BOOLEAN nobackup)
 	if ((lib->userbits&HIDDENLIBRARY) == 0)
 	{
 		ttyputmsg(_("%s written on %s (%ld %s)"), name,
-			timetostring(getcurrenttime()), facetshere,
-				makeplural(_("facet"), nodeprotoindex));
+			timetostring(getcurrenttime()), cellshere,
+				makeplural(_("cell"), nodeprotoindex));
 #ifdef ONUNIX
 		efprintf(stdout, _("%s written on %s (%ld %s)\n"), name,
-			timetostring(getcurrenttime()), facetshere,
-				makeplural(_("facet"), nodeprotoindex));
+			timetostring(getcurrenttime()), cellshere,
+				makeplural(_("cell"), nodeprotoindex));
 #endif
 	}
 	lib->userbits = (lib->userbits & ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR)) | READFROMDISK;
@@ -647,9 +601,13 @@ void io_writenodeproto(NODEPROTO *np, BOOLEAN thislib)
 	INTBIG i;
 	REGISTER PORTPROTO *pp;
 	REGISTER LIBRARY *instlib;
+	static INTBIG nullptr = -1;
 
-	/* write facet information */
-	io_putoutbig(&np->cell->temp1);
+	/* write cell information */
+	io_putstring(np->protoname);
+	io_putoutbig(&np->nextcellgrp->temp1);
+	if (np->nextcont != NONODEPROTO) io_putoutbig(&np->nextcont->temp1); else
+		io_putoutbig(&nullptr);
 	io_putoutbig(&np->cellview->temp1);
 	i = np->version;   io_putoutbig(&i);
 	io_putoutbig(&np->creationdate);
@@ -663,7 +621,7 @@ void io_writenodeproto(NODEPROTO *np, BOOLEAN thislib)
 
 	if (!thislib)
 	{
-		instlib = np->cell->lib;
+		instlib = np->lib;
 		io_putstring(instlib->libfile);
 	}
 
@@ -680,8 +638,8 @@ void io_writenodeproto(NODEPROTO *np, BOOLEAN thislib)
 			/* write the connecting subnodeinst for this portproto */
 			if (pp->subnodeinst != NONODEINST) i = pp->subnodeinst->temp1; else
 			{
-				ttyputmsg(_("ERROR: Library %s, facet %s, export %s has no node"),
-					np->cell->lib->libname, describenodeproto(np), pp->protoname);
+				ttyputmsg(_("ERROR: Library %s, cell %s, export %s has no node"),
+					np->lib->libname, describenodeproto(np), pp->protoname);
 				i = -1;
 			}	
 			io_putoutbig(&i);
@@ -693,8 +651,8 @@ void io_writenodeproto(NODEPROTO *np, BOOLEAN thislib)
 			} else
 			{
 				if (pp->subportproto != NOPORTPROTO)
-					ttyputmsg(_("ERROR: Library %s, facet %s, export %s has no subport"),
-						np->cell->lib->libname, describenodeproto(np), pp->protoname);
+					ttyputmsg(_("ERROR: Library %s, cell %s, export %s has no subport"),
+						np->lib->libname, describenodeproto(np), pp->protoname);
 				i = -1;
 			}
 			io_putoutbig(&i);
@@ -727,12 +685,49 @@ void io_writenodeproto(NODEPROTO *np, BOOLEAN thislib)
 		io_writevariables(np->firstvar, np->numvar, VNODEPROTO);
 	}
 
-	if (io_verbose > 0) ttyputmsg(M_("Wrote facet %s"), describenodeproto(np));
+	if (io_verbose > 0) ttyputmsg(M_("Wrote cell %s"), describenodeproto(np));
+}
+
+void io_getnodedisplayposition(NODEINST *ni, INTBIG *xpos, INTBIG *ypos);
+
+/*
+ * Similar to "us_getnodedisplayposition()"
+ */
+void io_getnodedisplayposition(NODEINST *ni, INTBIG *xpos, INTBIG *ypos)
+{
+	REGISTER NODEPROTO *np;
+	INTBIG cox, coy;
+	REGISTER INTBIG dx, dy, cx, cy;
+	REGISTER VARIABLE *var;
+	XARRAY trans;
+
+	np = ni->proto;
+	if ((us_useroptions&CENTEREDPRIMITIVES) == 0)
+	{
+		corneroffset(ni, np, ni->rotation, ni->transpose, &cox, &coy, FALSE);
+		*xpos = ni->lowx+cox;
+		*ypos = ni->lowy+coy;
+	} else
+	{
+		var = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center_key);
+		cx = cy = 0;
+		if (var != NOVARIABLE)
+		{
+			cx = ((INTBIG *)var->addr)[0];
+			cy = ((INTBIG *)var->addr)[1];
+		}
+		dx = cx + (ni->lowx+ni->highx)/2 - (np->lowx+np->highx)/2;
+		dy = cy + (ni->lowy+ni->highy)/2 - (np->lowy+np->highy)/2;
+		makerot(ni, trans);
+		xform(dx, dy, &cox, &coy, trans);
+		*xpos = cox;
+		*ypos = coy;
+	}
 }
 
 void io_writenodeinst(NODEINST *ni)
 {
-	INTBIG i;
+	INTBIG i, x, y;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
@@ -745,8 +740,20 @@ void io_writenodeinst(NODEINST *ni)
 	io_putoutbig(&ni->lowy);
 	io_putoutbig(&ni->highx);
 	io_putoutbig(&ni->highy);
-	i = ni->transpose;   io_putoutbig(&i);
-	i = ni->rotation;    io_putoutbig(&i);
+
+	/* if writing a cell reference, include the anchor point */
+	if (ni->proto->primindex == 0)
+	{
+		/* write the anchor point of the cell */
+		io_getnodedisplayposition(ni, &x, &y);
+		io_putoutbig(&x);
+		io_putoutbig(&y);
+	}
+
+	if (ni->transpose != 0) i = 1; else i = 0;
+	io_putoutbig(&i);
+	i = ni->rotation;
+	io_putoutbig(&i);
 
 	io_putoutbig(&ni->textdescript[0]);
 	io_putoutbig(&ni->textdescript[1]);
@@ -889,7 +896,6 @@ void io_findxlibvariables(VARIABLE *firstvar, INTSML numvar)
 				if (np != NONODEPROTO && np->primindex == 0)
 				{
 					np->temp2 = 1;
-					np->cell->temp2 = 1;
 				}
 			}
 		} else
@@ -898,7 +904,6 @@ void io_findxlibvariables(VARIABLE *firstvar, INTSML numvar)
 			if (np != NONODEPROTO && np->primindex == 0)
 			{
 				np->temp2 = 1;
-				np->cell->temp2 = 1;
 			}
 		}
 	}
