@@ -49,7 +49,6 @@ typedef struct Icifcell
 	INTBIG           cindex;		/* cell index given in the define statement */
 	INTBIG           l, r, t, b;	/* bounding box of cell */
 	NODEPROTO       *addr;			/* the address of the cif cell */
-	struct Icifcell *nextcell;		/* the next cif cell in the list */
 } CIFCELL;
 
 static CIFCELL **io_cifcells = (CIFCELL **)NOSTRING; /* hash table of 'cifcells' */
@@ -148,7 +147,7 @@ static CTRANS *io_curctrans;				/* current transformation description */
 /**************************** MISCELLANEOUS ****************************/
 
 static CHAR       *io_curnodeprotoname;		/* name of the current cell */
-static NODEPROTO  *io_incell;				/* address of facet being defined */
+static NODEPROTO  *io_incell;				/* address of cell being defined */
 static NODEPROTO **io_cifnodes = 0;			/* nodeprotos associated with CIF names */
 static INTBIG      io_varlength;			/* the length of all attribute arrays */
 static VARIABLE   *io_cifnames;				/* cif names for the current technology */
@@ -293,7 +292,7 @@ BOOLEAN io_listtonodes(LIBRARY *lib)
 				break;
 			case C_END:
 				/* make cell size right */
-				db_boundfacet(io_incell, &io_incell->lowx, &io_incell->highx,
+				db_boundcell(io_incell, &io_incell->lowx, &io_incell->highx,
 					&io_incell->lowy, &io_incell->highy);
 				lib->curnodeproto = io_incell;
 				io_incell = NONODEPROTO;
@@ -383,7 +382,7 @@ BOOLEAN io_nodes_box(void)
 		scalefromdispunit((float)hy, DISPUNITCMIC), 0, r, io_curcell->addr) == NONODEINST)
 	{
 		layname = layername(el_curtech, cb->lay);
-		ttyputerr(_("Problems creating a box on layer %s in facet %s"), layname,
+		ttyputerr(_("Problems creating a box on layer %s in cell %s"), layname,
 			describenodeproto(io_curcell->addr));
 		return(TRUE);
 	}
@@ -413,7 +412,7 @@ BOOLEAN io_nodes_poly(void)
 			scalefromdispunit((float)hy, DISPUNITCMIC), 0, 0, io_curcell->addr);
 	if (newni == NONODEINST)
 	{
-		ttyputerr(_("Problems creating a polygon on layer %ld in facet %s"), cp->lay,
+		ttyputerr(_("Problems creating a polygon on layer %ld in cell %s"), cp->lay,
 			describenodeproto(io_curcell->addr));
 		return(TRUE);
 	}
@@ -491,7 +490,7 @@ BOOLEAN io_nodes_call(void)
 			scalefromdispunit((float)t, DISPUNITCMIC), trans, rot, io_curcell->addr) ==
 				NONODEINST)
 	{
-		ttyputerr(_("Problems creating an instance of cell %s in facet %s"),
+		ttyputerr(_("Problems creating an instance of cell %s in cell %s"),
 			describenodeproto(cell->addr), describenodeproto(io_curcell->addr));
 		return(TRUE);
 	}
