@@ -48,15 +48,15 @@ static UINTBIG    io_cifcrctab[256];			/* for CRC checksum */
 static INTBIG     io_cif_resolution;			/* for resolution tests */
 static INTBIG     io_cif_polypoints;			/* for points on a polygon tests */
 static INTBIG    *io_cifoutputstate;			/* current output state */
-static INTBIG     io_cifoutoffx;				/* offset for current facet - for highlight */
-static INTBIG     io_cifoutoffy;				/* offset for current facet - for highlight */
-static NODEPROTO *io_cifoutcurnp;				/* node proto of facet being written */
+static INTBIG     io_cifoutoffx;				/* offset for current cell - for highlight */
+static INTBIG     io_cifoutoffy;				/* offset for current cell - for highlight */
+static NODEPROTO *io_cifoutcurnp;				/* node proto of cell being written */
 static BOOLEAN    io_zero_offset;				/* Set if there is no centering */
 static BOOLEAN    io_cif_highlightreserr;		/* Set to highlight resolution errors */
 static INTBIG     io_reserr_count;				/* count the resolution errors */
 static CHAR       io_cifoutcurlayer[200];		/* current layer name written out */
-static INTBIG     io_cifoutfacetnumber;			/* count of facets being written out */
-static INTBIG     io_cifoutjobsize;				/* number of facets to write out */
+static INTBIG     io_cifoutcellnumber;			/* count of cells being written out */
+static INTBIG     io_cifoutjobsize;				/* number of cells to write out */
 
 /* layer requests for grouping output layers */
 #define NOLAYERREQ ((LAYERREQ *)-1)
@@ -76,7 +76,7 @@ static INTBIG     io_ciflayerreqlisttotal = 0;
 static void      *io_cifmerge;			/* for merging geometry */
 
 /* prototypes for local routines */
-static void io_cifwritefacet(NODEPROTO*, BOOLEAN, void*);
+static void io_cifwritecell(NODEPROTO*, BOOLEAN, void*);
 static void io_outputcifpoly(TECHNOLOGY*, POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY, GEOM*);
 static void io_cifprintf(CHAR *msg, ...);
 static void io_cifreserror(GEOM*, INTBIG, INTBIG, INTBIG, INTBIG, XARRAY);
@@ -90,6 +90,7 @@ static void io_writeciflayer(CHAR *layername);
 static void io_cifoptionsdlog(void);
 static INTBIG io_ciffindhighestlayer(NODEPROTO *np, INTBIG x, INTBIG y);
 static int io_ciflayerreqascending(const void *e1, const void *e2);
+static CHAR *io_cif_cellname(NODEPROTO *cell);
 
 /*
  * Routine to free all memory associated with this module.
@@ -139,10 +140,10 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 	/* create the proper disk file for the CIF */
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr(_("Must be editing a facet to generate CIF output"));
+		ttyputerr(_("Must be editing a cell to generate CIF output"));
 		return(TRUE);
 	}
-	(void)estrcpy(file, lib->curnodeproto->cell->cellname);
+	(void)estrcpy(file, lib->curnodeproto->protoname);
 	if (estrcmp(&file[estrlen(file)-4],x_(".cif")) != 0) (void)estrcat(file, x_(".cif"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypecif, _("CIF File"), &truename);
@@ -155,13 +156,13 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 	/* write header information */
 	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
-		xprintf(io_fileout, _("( Electric VLSI Design System, version %s )\n"), el_version);
-		xprintf(io_fileout, x_("( %s )\n\n"), timetostring(getcurrenttime()));
+		xprintf(io_fileout, _("( Electric VLSI Design System, version %s );\n"), el_version);
+		xprintf(io_fileout, x_("( %s );\n\n"), timetostring(getcurrenttime()));
 	} else
 	{
-		xprintf(io_fileout, _("( Electric VLSI Design System )\n"));
+		xprintf(io_fileout, _("( Electric VLSI Design System );\n"));
 	}
-	us_emitcopyright(io_fileout, x_("( "), x_(" )"));
+	us_emitcopyright(io_fileout, x_("( "), x_(" );"));
 
 	/* get current output state */
 	io_cifoutputstate = io_getstatebits();
@@ -226,25 +227,25 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 		if (tech == gen_tech && (io_cifoutputstate[0]&CIFOUTADDDRC) == 0) tech->temp1 = 0;
 	}
 
-	/* figure out how many facets will be written */
-	io_cifoutfacetnumber = 0;
+	/* figure out how many cells will be written */
+	io_cifoutcellnumber = 0;
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
-	io_cifwritefacet(lib->curnodeproto, TRUE, 0);
-	io_cifoutjobsize = io_cifoutfacetnumber;
+	io_cifwritecell(lib->curnodeproto, TRUE, 0);
+	io_cifoutjobsize = io_cifoutcellnumber;
 	dia = DiaInitProgress(_("Writing CIF..."), 0);
 	if (dia == 0) return(TRUE);
 	DiaSetProgress(dia, 0, io_cifoutjobsize);
 
 	/* write the CIF */
-	io_cifoutfacetnumber = 0;
+	io_cifoutcellnumber = 0;
 	io_reserr_count = 0;
 	io_cifbase = 100;
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
-	io_cifwritefacet(lib->curnodeproto, FALSE, dia);
+	io_cifwritecell(lib->curnodeproto, FALSE, dia);
 
 	/* clean up */
 	if ((io_cifoutputstate[0]&CIFOUTNOTOPCALL) == 0)
@@ -294,7 +295,7 @@ BOOLEAN io_writeciflibrary(LIBRARY *lib)
 	return(FALSE);
 }
 
-void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
+void io_cifwritecell(NODEPROTO *np, BOOLEAN fake, void *dia)
 {
 	REGISTER NODEINST *subni;
 	REGISTER ARCINST *ai;
@@ -313,7 +314,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, io_tool->cluster);
 
-	io_cifoutfacetnumber++;
+	io_cifoutcellnumber++;
 	if (!fake)
 	{
 		/* stop if requested */
@@ -323,29 +324,29 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		infstr = initinfstr();
 		formatinfstr(infstr, _("Writing %s"), describenodeproto(np));
 		DiaSetTextProgress(dia, returninfstr(infstr));
-		DiaSetProgress(dia, io_cifoutfacetnumber, io_cifoutjobsize);
+		DiaSetProgress(dia, io_cifoutcellnumber, io_cifoutjobsize);
 	}
 
-	/* if there are any sub-facets that have not been written, write them */
+	/* if there are any sub-cells that have not been written, write them */
 	for(subni = np->firstnodeinst; subni != NONODEINST; subni = subni->nextnodeinst)
 	{
 		subnt = subni->proto;
 		if (subnt->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (subnt->cell == np->cell) continue;
+		if (isiconof(subnt, np)) continue;
 
 		if ((subni->userbits & NEXPAND) == 0 && (io_cifoutputstate[0]&CIFOUTEXACT) != 0) continue;
 
-		/* convert body facets to contents facets */
+		/* convert body cells to contents cells */
 		onp = contentsview(subnt);
 		if (onp != NONODEPROTO) subnt = onp;
 
-		/* don't recurse if this facet has already been written */
+		/* don't recurse if this cell has already been written */
 		if (subnt->temp1 != 0) continue;
 
 		/* recurse to the bottom */
-		io_cifwritefacet(subnt, fake, dia);
+		io_cifwritecell(subnt, fake, dia);
 	}
 
 	np->temp1 = ++io_cifbase;
@@ -353,7 +354,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 
 	io_cifoutcurnp = np;			/* set global for highlighting */
 
-	/* prepare to write the facet */
+	/* prepare to write the cell */
 	if (io_zero_offset)
 	{
 		grabpoint(np, &io_cifoutoffx, &io_cifoutoffy);
@@ -365,14 +366,14 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		offy = io_cifoutoffy = (np->lowy + np->highy) / 2;
 	}
 	io_cifprintf(x_("DS %ld 1 1;\n"), io_cifbase);
-	io_cifprintf(x_("9 %s; (from library %s);\n"), nldescribenodeproto(np), np->cell->lib->libname);
+	io_cifprintf(x_("9 %s; (from library %s);\n"), io_cif_cellname(np), np->lib->libname);
 
 	io_cifoutcurlayer[0] = 0;
 	if ((io_cifoutputstate[0]&CIFOUTMERGE) == 0)
 	{
 		/* no polygon merging: sort by layer */
 
-		/* determine which layers exist in this facet */
+		/* determine which layers exist in this cell */
 		while (io_ciflayerreq != NOLAYERREQ)
 		{
 			req = io_ciflayerreq;
@@ -432,7 +433,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		{
 			if (req->layername == 0 || *req->layername == 0) continue;
 
-			/* write all primitive nodes in the facet */
+			/* write all primitive nodes in the cell */
 			for(subni = np->firstnodeinst; subni != NONODEINST; subni = subni->nextnodeinst)
 			{
 				/* don't draw anything if the node is wiped out */
@@ -458,7 +459,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 				}
 			}
 
-			/* write all of the arcs in the facet */
+			/* write all of the arcs in the cell */
 			for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 			{
 				if (ai->proto->tech != req->tech) continue;
@@ -502,7 +503,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 			}
 		}
 
-		/* write all of the arcs in the facet */
+		/* write all of the arcs in the cell */
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		{
 			i = arcpolys(ai, NOWINDOWPART);
@@ -518,18 +519,18 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		mergeextract(io_cifmerge, io_cif_write_polygon);
 		mergedelete(io_cifmerge);
 #else
-		mrgdonefacet(io_cif_write_polygon);
+		mrgdonecell(io_cif_write_polygon);
 #endif
 	}
 
-	/* write all facet instances */
+	/* write all cell instances */
 	for(subni = np->firstnodeinst; subni != NONODEINST; subni = subni->nextnodeinst)
 	{
 		subnt = subni->proto;
 		if (subnt->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (subnt->cell == np->cell) continue;
+		if (isiconof(subnt, np)) continue;
 
 		i = subni->rotation;
 		if (subni->transpose != 0) i = (i + 900) % 3600;
@@ -537,7 +538,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		ry = ((sine(i)>>14) * 100) >> 16;
 		makerot(subni, trans);
 
-		/* determine offset of facet */
+		/* determine offset of cell */
 		if (io_zero_offset)
 		{
 			grabpoint(subni->proto, &bx, &by);
@@ -565,13 +566,13 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 				}
 			}
 
-			/* write a call to a facet */
+			/* write a call to a cell */
 			io_cifprintf(x_("C %ld R %ld %ld"), subnt->temp1, rx, ry);
 			if (subni->transpose != 0) io_cifprintf(x_(" M Y"));
 			io_cifprintf(x_(" T %ld %ld;\n"), io_cif_outscale(xpos), io_cif_outscale(ypos));
 		} else
 		{
-			/* write the vectors that describe an unexpanded facet */
+			/* write the vectors that describe an unexpanded cell */
 			io_cifprintf(x_("0V %ld %ld %ld %ld %ld %ld %ld %ld %ld %ld;\n"),
 				io_cif_outscale(subni->lowx-offx), io_cif_outscale(subni->lowy-offy),
 					io_cif_outscale(subni->lowx-offx), io_cif_outscale(subni->highy-offy),
@@ -667,7 +668,7 @@ void io_cifwritefacet(NODEPROTO *np, BOOLEAN fake, void *dia)
 		if (validport != 0)
 		{
 			if (toplayerfound == 0)
-				ttyputmsg(_("Warning: facet %s, export '%s' obscured by higher layer"),
+				ttyputmsg(_("Warning: cell %s, export '%s' obscured by higher layer"),
 					describenodeproto(np), pp->protoname);
 			var = getval((INTBIG)pp, VPORTPROTO, VSTRING, x_("EXPORT_reference_name"));
 			type = describeportbits(pp->userbits);
@@ -904,45 +905,6 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 			}
 			return;
 	}
-
-#if 0		/* code to handle certain polygons without valid CIF layers */
-	switch (poly->style)
-	{
-		case CLOSEDRECT:
-			xformpoly(poly, trans);
-			getbbox(poly, &xl,&xh, &yl,&yh);
-			io_cifprintf(x_("0V %ld %ld"), io_cif_outscale(xl-offx), io_cif_outscale(yl-offy));
-			io_cifprintf(x_(" %ld %ld"), io_cif_outscale(xl-offx), io_cif_outscale(yh-offy));
-			io_cifprintf(x_(" %ld %ld"), io_cif_outscale(xh-offx), io_cif_outscale(yh-offy));
-			io_cifprintf(x_(" %ld %ld;\n"), io_cif_outscale(xh-offx), io_cif_outscale(yl-offy));
-			return;
-
-		case OPENED:
-		case OPENEDT1:
-		case OPENEDT2:
-		case OPENEDT3:
-		case CLOSED:
-			xformpoly(poly, trans);
-			io_cifprintf(x_("0V"));
-			for(k=0; k<poly->count; k++)
-				io_cifprintf(x_(" %ld %ld"), io_cif_outscale(poly->xv[k]-offx), io_cif_outscale(poly->yv[k]-offy));
-			if (poly->style == CLOSED)
-				io_cifprintf(x_(" %ld %ld"), io_cif_outscale(poly->xv[k]-offx), io_cif_outscale(poly->yv[k]-offy));
-			io_cifprintf(x_(";\n"));
-			return;
-
-		case VECTORS:
-			xformpoly(poly, trans);
-			for(k=0; k<poly->count; k += 2)
-			{
-				io_cifprintf(x_("0V %ld %ld"), io_cif_outscale(poly->xv[k]-offx),
-					io_cif_outscale(poly->yv[k]-offy));
-				io_cifprintf(x_(" %ld %ld;\n"), io_cif_outscale(poly->xv[k+1]-offx),
-					io_cif_outscale(poly->yv[k+1]-offy));
-			}
-			return;
-	}
-#endif
 }
 
 /*
@@ -1095,6 +1057,14 @@ void io_cif_write_polygon(INTBIG layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 	}
 }
 
+CHAR *io_cif_cellname(NODEPROTO *cell)
+{
+	CHAR *name;
+
+	name = describenodeproto(cell);
+	return(name);
+}
+
 void io_cif_show_reserror(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
 {
 	REGISTER void *err, *infstr;
