@@ -68,25 +68,25 @@ static BOOLEAN    io_defignoreblock(FILE *f, CHAR *command);
 static BOOLEAN    io_defignoretosemicolon(FILE *f, CHAR *command);
 static BOOLEAN    io_defreadfile(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_defreadpropertydefinitions(FILE *f);
-static BOOLEAN    io_defreadnets(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options);
-static BOOLEAN    io_defreadpins(FILE *f, NODEPROTO *facet);
-static BOOLEAN    io_defreadcomponents(FILE *f, NODEPROTO *facet);
-static BOOLEAN    io_defreadvias(FILE *f, NODEPROTO *facet);
-static BOOLEAN    io_defreadcomponent(FILE *f, NODEPROTO *facet);
+static BOOLEAN    io_defreadnets(FILE *f, NODEPROTO *cell, BOOLEAN special, INTBIG options);
+static BOOLEAN    io_defreadpins(FILE *f, NODEPROTO *cell);
+static BOOLEAN    io_defreadcomponents(FILE *f, NODEPROTO *cell);
+static BOOLEAN    io_defreadvias(FILE *f, NODEPROTO *cell);
+static BOOLEAN    io_defreadcomponent(FILE *f, NODEPROTO *cell);
 static BOOLEAN    io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y);
 static NODEPROTO *io_defgetnodeproto(CHAR *name, LIBRARY *curlib);
-static BOOLEAN    io_defreadpin(FILE *f, NODEPROTO *facet);
+static BOOLEAN    io_defreadpin(FILE *f, NODEPROTO *cell);
 static BOOLEAN    io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans);
 static void       io_defgetlayernodes(CHAR *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO **arc);
 static BOOLEAN    io_defreadunits(FILE *f);
 static CHAR      *io_defmustgetkeyword(FILE *f, CHAR *where);
 static BOOLEAN    io_defreadvia(FILE *f);
-static BOOLEAN    io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options);
+static BOOLEAN    io_defreadnet(FILE *f, NODEPROTO *cell, BOOLEAN special, INTBIG options);
 static void       io_definerror(CHAR *command, ...);
-static BOOLEAN    io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
+static BOOLEAN    io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *cell,
 					NODEINST **theni, PORTPROTO **thepp);
 static void       io_defoptionsdlog(void);
-static BOOLEAN    io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
+static BOOLEAN    io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *cell,
 					NODEINST *noti, NODEINST **theni, PORTPROTO **thepp);
 
 /*
@@ -153,7 +153,7 @@ BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 	REGISTER CHAR *key, *cellname;
 	REGISTER INTBIG *options;
 	CHAR curkey[200];
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 
 	options = io_getstatebits();
 
@@ -181,10 +181,10 @@ BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 		{
 			cellname = io_defmustgetkeyword(f, x_("DESIGN"));
 			if (cellname == 0) return(TRUE);
-			facet = us_newnodeproto(cellname, lib);
-			if (facet == NONODEPROTO)
+			cell = us_newnodeproto(cellname, lib);
+			if (cell == NONODEPROTO)
 			{
-				io_definerror(_("Cannot create facet '%s'"), cellname);
+				io_definerror(_("Cannot create cell '%s'"), cellname);
 				return(TRUE);
 			}
 			if (io_defignoretosemicolon(f, _("DESIGN"))) return(TRUE);
@@ -205,31 +205,31 @@ BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 
 		if (namesame(key, x_("VIAS")) == 0)
 		{
-			if (io_defreadvias(f, facet)) return(TRUE);
+			if (io_defreadvias(f, cell)) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, x_("COMPONENTS")) == 0)
 		{
-			if (io_defreadcomponents(f, facet)) return(TRUE);
+			if (io_defreadcomponents(f, cell)) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, x_("PINS")) == 0)
 		{
-			if (io_defreadpins(f, facet)) return(TRUE);
+			if (io_defreadpins(f, cell)) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, x_("SPECIALNETS")) == 0)
 		{
-			if (io_defreadnets(f, facet, TRUE, options[0])) return(TRUE);
+			if (io_defreadnets(f, cell, TRUE, options[0])) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, x_("NETS")) == 0)
 		{
-			if (io_defreadnets(f, facet, FALSE, options[0])) return(TRUE);
+			if (io_defreadnets(f, cell, FALSE, options[0])) return(TRUE);
 			continue;
 		}
 
@@ -244,7 +244,7 @@ BOOLEAN io_defreadfile(FILE *f, LIBRARY *lib)
 
 /*************** VIAS ***************/
 
-BOOLEAN io_defreadvias(FILE *f, NODEPROTO *facet)
+BOOLEAN io_defreadvias(FILE *f, NODEPROTO *cell)
 {
 	REGISTER CHAR *key;
 	CHAR curkey[200];
@@ -351,7 +351,7 @@ BOOLEAN io_defreadvia(FILE *f)
 
 /*************** COMPONENTS ***************/
 
-BOOLEAN io_defreadcomponents(FILE *f, NODEPROTO *facet)
+BOOLEAN io_defreadcomponents(FILE *f, NODEPROTO *cell)
 {
 	REGISTER CHAR *key;
 	CHAR curkey[200];
@@ -364,7 +364,7 @@ BOOLEAN io_defreadcomponents(FILE *f, NODEPROTO *facet)
 		if (key == 0) return(TRUE);
 		if (namesame(key, x_("-")) == 0)
 		{
-			if (io_defreadcomponent(f, facet)) return(TRUE);
+			if (io_defreadcomponent(f, cell)) return(TRUE);
 			continue;
 		}
 
@@ -381,7 +381,7 @@ BOOLEAN io_defreadcomponents(FILE *f, NODEPROTO *facet)
 	return(FALSE);
 }
 
-BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
+BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *cell)
 {
 	REGISTER CHAR *key;
 	INTBIG x, y, cx, cy;
@@ -401,8 +401,8 @@ BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 	if (key == 0) return(TRUE);
 	estrcpy(modelname, key);
 
-	/* find the named facet */
-	np = io_defgetnodeproto(modelname, facet->cell->lib);
+	/* find the named cell */
+	np = io_defgetnodeproto(modelname, cell->lib);
 	if (np == NONODEPROTO)
 	{
 		io_definerror(_("Unknown cell (%s)"), modelname);
@@ -429,7 +429,7 @@ BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 				corneroffset(NONODEINST, np, 0, 0, &cx, &cy, FALSE);
 				lx = x - cx;   hx = lx + sx;
 				ly = y - cy;   hy = ly + sy;
-				ni = newnodeinst(np, lx, hx, ly, hy, trans, rot, facet);
+				ni = newnodeinst(np, lx, hx, ly, hy, trans, rot, cell);
 				if (ni == NONODEINST)
 				{
 					io_definerror(_("Unable to create node"));
@@ -453,7 +453,7 @@ BOOLEAN io_defreadcomponent(FILE *f, NODEPROTO *facet)
 
 /*************** PINS ***************/
 
-BOOLEAN io_defreadpins(FILE *f, NODEPROTO *facet)
+BOOLEAN io_defreadpins(FILE *f, NODEPROTO *cell)
 {
 	REGISTER CHAR *key;
 	CHAR curkey[200];
@@ -466,7 +466,7 @@ BOOLEAN io_defreadpins(FILE *f, NODEPROTO *facet)
 		if (key == 0) return(TRUE);
 		if (namesame(key, x_("-")) == 0)
 		{
-			if (io_defreadpin(f, facet)) return(TRUE);
+			if (io_defreadpin(f, cell)) return(TRUE);
 			continue;
 		}
 
@@ -483,7 +483,7 @@ BOOLEAN io_defreadpins(FILE *f, NODEPROTO *facet)
 	return(FALSE);
 }
 
-BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
+BOOLEAN io_defreadpin(FILE *f, NODEPROTO *cell)
 {
 	REGISTER CHAR *key;
 	INTBIG lx, hx, ly, hy, x, y;
@@ -591,14 +591,14 @@ BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
 		ly += y;   hy += y;
 
 		/* make the pin */
-		ni = newnodeinst(np, lx, hx, ly, hy, trn, rot, facet);
+		ni = newnodeinst(np, lx, hx, ly, hy, trn, rot, cell);
 		if (ni == NONODEINST)
 		{
 			io_definerror(_("Unable to create pin"));
 			return(TRUE);
 		}
 		endobjectchange((INTBIG)ni, VNODEINST);
-		pp = newportproto(facet, ni, np->firstportproto, pinname);
+		pp = newportproto(cell, ni, np->firstportproto, pinname);
 		if (pp == NOPORTPROTO)
 		{
 			io_definerror(_("Unable to create pin name"));
@@ -611,7 +611,7 @@ BOOLEAN io_defreadpin(FILE *f, NODEPROTO *facet)
 
 /*************** NETS ***************/
 
-BOOLEAN io_defreadnets(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options)
+BOOLEAN io_defreadnets(FILE *f, NODEPROTO *cell, BOOLEAN special, INTBIG options)
 {
 	REGISTER CHAR *key;
 	CHAR curkey[200];
@@ -623,7 +623,7 @@ BOOLEAN io_defreadnets(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG option
 		if (key == 0) return(TRUE);
 		if (namesame(key, x_("-")) == 0)
 		{
-			if (io_defreadnet(f, facet, special, options)) return(TRUE);
+			if (io_defreadnet(f, cell, special, options)) return(TRUE);
 			continue;
 		}
 		if (namesame(key, x_("END")) == 0)
@@ -639,7 +639,7 @@ BOOLEAN io_defreadnets(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG option
 	return(FALSE);
 }
 
-BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options)
+BOOLEAN io_defreadnet(FILE *f, NODEPROTO *cell, BOOLEAN special, INTBIG options)
 {
 	REGISTER CHAR *key;
 	INTBIG lx, hx, ly, hy, plx, ply, phx, phy, sx, sy, fx, fy, tx, ty;
@@ -756,7 +756,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				/* find the export */
 				key = io_defmustgetkeyword(f, x_("NET"));
 				if (key == 0) return(TRUE);
-				pp = getportproto(facet, key);
+				pp = getportproto(cell, key);
 				if (pp == NOPORTPROTO)
 				{
 					io_definerror(_("Warning: unknown pin '%s'"), key);
@@ -767,7 +767,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				pp = pp->subportproto;
 			} else
 			{
-				for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+				for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 				{
 					var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 					if (var == NOVARIABLE) continue;
@@ -808,7 +808,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				portposition(lastlogni, lastlogpp, &tx, &ty);
 				bits = us_makearcuserbits(gen_unroutedarc);
 				ai = newarcinst(gen_unroutedarc, defaultarcwidth(gen_unroutedarc), bits,
-					ni, pp, fx, fy, lastlogni, lastlogpp, tx, ty, facet);
+					ni, pp, fx, fy, lastlogni, lastlogpp, tx, ty, cell);
 				if (ai == NOARCINST)
 				{
 					io_definerror(_("Could not create unrouted arc"));
@@ -927,13 +927,13 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 			/* see if there is a connection point here when starting a path */
 			if (pathstart != 0)
 			{
-				if (!io_deffindconnection(curx, cury, routap, facet, NONODEINST,
+				if (!io_deffindconnection(curx, cury, routap, cell, NONODEINST,
 					&lastni, &lastpp)) lastni = NONODEINST;
 			}
 
 			/* create the via */
-			nodeprotosizeoffset(vd->via, &plx, &ply, &phx, &phy, facet);
-			ni = newnodeinst(vd->via, lx-plx, hx+phx, ly-ply, hy+phy, 0, 0, facet);
+			nodeprotosizeoffset(vd->via, &plx, &ply, &phx, &phy, cell);
+			ni = newnodeinst(vd->via, lx-plx, hx+phx, ly-ply, hy+phy, 0, 0, cell);
 			if (ni == NONODEINST)
 			{
 				io_definerror(_("Unable to create via layer"));
@@ -952,7 +952,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 						width = var->addr;
 				}
 				ai = newarcinst(routap, width, us_makearcuserbits(routap),
-					lastni, lastpp, curx, cury, ni, pp, curx, cury, facet);
+					lastni, lastpp, curx, cury, ni, pp, curx, cury, cell);
 				if (ai == NOARCINST)
 				{
 					io_definerror(_("Unable to create net starting point"));
@@ -970,7 +970,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 		} else
 		{
 			/* no via mentioned: just make a pin */
-			if (io_defgetpin(curx, cury, routap, facet, &ni, &pp)) return(TRUE);
+			if (io_defgetpin(curx, cury, routap, cell, &ni, &pp)) return(TRUE);
 			placedvia = 0;
 		}
 		if (!foundcoord) continue;
@@ -987,7 +987,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 				defaultnodesize(np, &sx, &sy);
 				lx = curx - sx / 2;   hx = lx + sx;
 				ly = cury - sy / 2;   hy = ly + sy;
-				ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, facet);
+				ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, cell);
 				if (ni == NONODEINST)
 				{
 					io_definerror(_("Unable to create net pin"));
@@ -1005,7 +1005,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 					width = var->addr;
 			}
 			ai = newarcinst(routap, width, us_makearcuserbits(routap),
-				lastni, lastpp, lastx, lasty, ni, pp, curx, cury, facet);
+				lastni, lastpp, lastx, lasty, ni, pp, curx, cury, cell);
 			if (ai == NOARCINST)
 			{
 				io_definerror(_("Unable to create net path"));
@@ -1035,7 +1035,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 		if (namesame(key, x_("NEW")) == 0 || namesame(key, x_(";")) == 0)
 		{
 			/* see if there is a connection point here when starting a path */
-			if (!io_deffindconnection(curx, cury, routap, facet, ni, &nextni, &nextpp))
+			if (!io_deffindconnection(curx, cury, routap, cell, ni, &nextni, &nextpp))
 				nextni = NONODEINST;
 
 			/* if the path starts with a via, wire it */
@@ -1048,7 +1048,7 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 						width = var->addr;
 				}
 				ai = newarcinst(routap, width, us_makearcuserbits(routap),
-					ni, pp, curx, cury, nextni, nextpp, curx, cury, facet);
+					ni, pp, curx, cury, nextni, nextpp, curx, cury, cell);
 				if (ai == NOARCINST)
 				{
 					io_definerror(_("Unable to create net ending point"));
@@ -1062,11 +1062,11 @@ BOOLEAN io_defreadnet(FILE *f, NODEPROTO *facet, BOOLEAN special, INTBIG options
 }
 
 /*
- * Routine to look for a connection to arcs of type "ap" in facet "facet"
+ * Routine to look for a connection to arcs of type "ap" in cell "cell"
  * at (x, y).  The connection can not be on "not" (if it is not NONODEINST).
  * If found, return true and places the node and port in "theni" and "thepp".
  */
-BOOLEAN io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet, NODEINST *noti,
+BOOLEAN io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *cell, NODEINST *noti,
 	NODEINST **theni, PORTPROTO **thepp)
 {
 	REGISTER INTBIG sea, i;
@@ -1078,7 +1078,7 @@ BOOLEAN io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
 	/* get polygons */
 	(void)needstaticpolygon(&poly, 4, us_tool->cluster);
 
-	sea = initsearch(x, x, y, y, facet);
+	sea = initsearch(x, x, y, y, cell);
 	for(;;)
 	{
 		geom = nextobject(sea);
@@ -1105,11 +1105,11 @@ BOOLEAN io_deffindconnection(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
 }
 
 /*
- * Routine to look for a connection to arcs of type "ap" in facet "facet"
+ * Routine to look for a connection to arcs of type "ap" in cell "cell"
  * at (x, y).  If nothing is found, create a pin.  In any case, return
  * the node and port in "theni" and "thepp".  Returns true on error.
  */
-BOOLEAN io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
+BOOLEAN io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *cell,
 	NODEINST **theni, PORTPROTO **thepp)
 {
 	INTBIG sx, sy;
@@ -1118,14 +1118,14 @@ BOOLEAN io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
 	REGISTER NODEPROTO *pin;
 
 	/* if there is an existing connection, return it */
-	if (io_deffindconnection(x, y, ap, facet, NONODEINST, theni, thepp)) return(FALSE);
+	if (io_deffindconnection(x, y, ap, cell, NONODEINST, theni, thepp)) return(FALSE);
 
 	/* nothing found at this location: create a pin */
 	pin = getpinproto(ap);
 	defaultnodesize(pin, &sx, &sy);
 	lx = x - sx / 2;   hx = lx + sx;
 	ly = y - sy / 2;   hy = ly + sy;
-	ni = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
+	ni = newnodeinst(pin, lx, hx, ly, hy, 0, 0, cell);
 	if (ni == NONODEINST)
 	{
 		io_definerror(_("Unable to create net pin"));
@@ -1203,20 +1203,20 @@ NODEPROTO *io_defgetnodeproto(CHAR *name, LIBRARY *curlib)
 	REGISTER NODEPROTO *np, *newnp;
 	REGISTER LIBRARY *lib;
 
-	/* first see if this facet is in the current library */
+	/* first see if this cell is in the current library */
 	for(np = curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-		if (namesame(name, np->cell->cellname) == 0) return(np);
+		if (namesame(name, np->protoname) == 0) return(np);
 
 	/* now look in other libraries */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
 		if (lib == curlib) continue;
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			if (namesame(name, np->cell->cellname) == 0) break;
+			if (namesame(name, np->protoname) == 0) break;
 		if (np != NONODEPROTO)
 		{
-			/* must copy the facet */
-			newnp = us_copyrecursively(np, np->cell->cellname, curlib, np->cellview,
+			/* must copy the cell */
+			newnp = us_copyrecursively(np, np->protoname, curlib, np->cellview,
 				FALSE, FALSE, x_(""), FALSE, FALSE, FALSE);
 			return(newnp);
 		}
