@@ -76,8 +76,8 @@ static INTBIG            io_dxfreadpolylines, io_dxfreadlines, io_dxfreadcircles
 static CHAR              io_dxfline[MAXCHARSPERLINE];
 static DXFLAYER         *io_dxffirstlayer = 0;
 static FORWARDREF       *io_dxffirstforwardref;
-static NODEPROTO        *io_dxfmainfacet;
-static NODEPROTO        *io_dxfcurfacet;
+static NODEPROTO        *io_dxfmaincell;
+static NODEPROTO        *io_dxfcurcell;
 static CHAR            **io_dxfheadertext;
 static INTSML           *io_dxfheaderid;
 static INTBIG            io_dxfinputmode;			/* 0: pairs not read, 1: normal pairs, 2: blank lines */
@@ -98,7 +98,7 @@ static CHAR      *io_dxfblockname(CHAR *name);
 static void       io_dxfclearacceptablelayers(void);
 static void       io_dxfclearlayers(void);
 static INTBIG     io_dxfextractinsert(NODEPROTO *onp, INTBIG x, INTBIG y, float xsca, float ysca, INTBIG rot, NODEPROTO *np);
-static NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca);
+static NODEPROTO *io_dxfgetscaledcell(NODEPROTO *onp, float xsca, float ysca);
 static DXFLAYER  *io_dxfgetlayer(CHAR *name);
 static INTBIG     io_dxfgetnextline(FILE *io, CHAR *text, INTBIG canBeBlank);
 static INTBIG     io_dxfgetnextpair(FILE *io, INTBIG *groupID, CHAR **text);
@@ -125,8 +125,8 @@ static INTBIG     io_dxfreadtextentity(FILE *io, INTBIG *lx, INTBIG *hx, INTBIG
 static BOOLEAN    io_dxfreadtablessection(FILE *io);
 static INTBIG     io_dxfread3dfaceentity(FILE *io, INTBIG *x1, INTBIG *y1, INTBIG *z1, INTBIG *x2, INTBIG *y2,
 					INTBIG *z2, INTBIG *x3, INTBIG *y3, INTBIG *z3, INTBIG *x4, INTBIG *y4, INTBIG *z4, DXFLAYER **layer);
-static void       io_dxfwritefacet(NODEPROTO *np, INTBIG subfacets);
-static CHAR      *io_dxffacetname(NODEPROTO *np);
+static void       io_dxfwritecell(NODEPROTO *np, INTBIG subcells);
+static CHAR      *io_dxfcellname(NODEPROTO *np);
 static void       io_dxfsetcurunits(void);
 #ifdef PRESERVEDXF
   static void  *io_dxfpreservestringarray = 0;
@@ -185,10 +185,10 @@ BOOLEAN io_writedxflibrary(LIBRARY *lib)
 	if (io_dxflayerkey == 0) io_dxflayerkey = makekey(x_("IO_dxf_layer"));
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr(_("Must be editing a facet to generate DXF output"));
+		ttyputerr(_("Must be editing a cell to generate DXF output"));
 		return(TRUE);
 	}
-	(void)estrcpy(file, lib->curnodeproto->cell->cellname);
+	(void)estrcpy(file, lib->curnodeproto->protoname);
 	if (estrcmp(&file[estrlen(file)-4],x_(".dxf")) != 0) (void)estrcat(file, x_(".dxf"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypedxf, _("DXF File"), &truename);
@@ -240,7 +240,7 @@ BOOLEAN io_writedxflibrary(LIBRARY *lib)
 		efprintf(io_fileout, x_("  0\nENDSEC\n"));
 	}
 
-	/* write any subfacets */
+	/* write any subcells */
 	io_dxfentityhandle = 0x100;
 	efprintf(io_fileout, x_("  0\nSECTION\n"));
 	efprintf(io_fileout, x_("  2\nBLOCKS\n"));
@@ -250,14 +250,14 @@ BOOLEAN io_writedxflibrary(LIBRARY *lib)
 	for(ni = lib->curnodeproto->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		np = ni->proto;
-		if (np->primindex == 0 && np->temp1 == 0) io_dxfwritefacet(np, 1);
+		if (np->primindex == 0 && np->temp1 == 0) io_dxfwritecell(np, 1);
 	}
 	efprintf(io_fileout, x_("  0\nENDSEC\n"));
 
-	/* write the objects in the facet */
+	/* write the objects in the cell */
 	efprintf(io_fileout, x_("  0\nSECTION\n"));
 	efprintf(io_fileout, x_("  2\nENTITIES\n"));
-	io_dxfwritefacet(lib->curnodeproto, 0);
+	io_dxfwritecell(lib->curnodeproto, 0);
 	efprintf(io_fileout, x_("  0\nENDSEC\n"));
 
 	efprintf(io_fileout, x_("  0\nEOF\n"));
@@ -267,10 +267,10 @@ BOOLEAN io_writedxflibrary(LIBRARY *lib)
 }
 
 /*
- * routine to write the contents of facet "np".  If "subfacets" is nonzero, do a recursive
- * descent through the subfacets in this facet, writing out "block" definitions.
+ * routine to write the contents of cell "np".  If "subcells" is nonzero, do a recursive
+ * descent through the subcells in this cell, writing out "block" definitions.
  */
-void io_dxfwritefacet(NODEPROTO *np, INTBIG subfacets)
+void io_dxfwritecell(NODEPROTO *np, INTBIG subcells)
 {
 	REGISTER CHAR *layername;
 	REGISTER INTBIG i, j, len, xc, yc;
@@ -281,16 +281,16 @@ void io_dxfwritefacet(NODEPROTO *np, INTBIG subfacets)
 	XARRAY trans;
 	static POLYGON *poly = NOPOLYGON;
 
-	if (subfacets != 0)
+	if (subcells != 0)
 	{
 		np->temp1 = 1;
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			if (ni->proto->primindex == 0 && ni->proto->temp1 == 0)
-				io_dxfwritefacet(ni->proto, 1);
+				io_dxfwritecell(ni->proto, 1);
 		}
 		efprintf(io_fileout, x_("  0\nBLOCK\n"));
-		efprintf(io_fileout, x_("  2\n%s\n"), io_dxffacetname(np));
+		efprintf(io_fileout, x_("  2\n%s\n"), io_dxfcellname(np));
 		efprintf(io_fileout, x_(" 10\n0\n"));
 		efprintf(io_fileout, x_(" 20\n0\n"));
 		efprintf(io_fileout, x_(" 30\n0\n"));
@@ -305,7 +305,7 @@ void io_dxfwritefacet(NODEPROTO *np, INTBIG subfacets)
 			efprintf(io_fileout, x_("  0\nINSERT\n"));
 			efprintf(io_fileout, x_("  8\nUNKNOWN\n"));
 			efprintf(io_fileout, x_("  5\n%3lX\n"), io_dxfentityhandle++);
-			efprintf(io_fileout, x_("  2\n%s\n"), io_dxffacetname(ni->proto));
+			efprintf(io_fileout, x_("  2\n%s\n"), io_dxfcellname(ni->proto));
 			xc = (ni->lowx + ni->highx - (ni->proto->lowx + ni->proto->highx)) / 2;
 			yc = (ni->lowy + ni->highy - (ni->proto->lowy + ni->proto->highy)) / 2;
 			efprintf(io_fileout, x_(" 10\n%g\n"), scaletodispunit(xc, io_dxfdispunit));
@@ -379,7 +379,7 @@ void io_dxfwritefacet(NODEPROTO *np, INTBIG subfacets)
 			ni->proto == art_closedpolygonprim)
 		{
 			makerot(ni, trans);
-			var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+			var = gettrace(ni);
 			len = getlength(var);
 			if (len == 4 && ni->proto != art_closedpolygonprim)
 			{
@@ -430,29 +430,29 @@ void io_dxfwritefacet(NODEPROTO *np, INTBIG subfacets)
 			}
 		}
 	}
-	if (subfacets != 0)
+	if (subcells != 0)
 		efprintf(io_fileout, x_("  0\nENDBLK\n"));
 }
 
-CHAR *io_dxffacetname(NODEPROTO *np)
+CHAR *io_dxfcellname(NODEPROTO *np)
 {
 	REGISTER CHAR *buf;
 	REGISTER INTBIG i, leng;
-	REGISTER CELL *cell;
+	REGISTER NODEPROTO *onp;
 	REGISTER void *infstr;
 
-	if (namesame(np->cell->cellname, np->cell->lib->libname) == 0)
+	if (namesame(np->protoname, np->lib->libname) == 0)
 	{
 		/* use another name */
-		leng = estrlen(np->cell->cellname) + 4;
+		leng = estrlen(np->protoname) + 4;
 		buf = (CHAR *)emalloc(leng * SIZEOFCHAR, io_tool->cluster);
-		if (buf == 0) return(np->cell->cellname);
+		if (buf == 0) return(np->protoname);
 		for(i=1; i<1000; i++)
 		{
-			esnprintf(buf, leng, x_("%s%ld"), np->cell->cellname, i);
-			for(cell = np->cell->lib->firstcell; cell != NOCELL; cell = cell->nextcell)
-				if (namesame(cell->cellname, buf) == 0) break;
-			if (cell == NOCELL) break;
+			esnprintf(buf, leng, x_("%s%ld"), np->protoname, i);
+			for(onp = np->lib->firstnodeproto; onp != NONODEPROTO; onp = onp->nextnodeproto)
+				if (namesame(onp->protoname, buf) == 0) break;
+			if (onp == NONODEPROTO) break;
 		}
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, buf);
@@ -461,7 +461,7 @@ CHAR *io_dxffacetname(NODEPROTO *np)
 	}
 
 	/* just return the cell name */
-	return(np->cell->cellname);
+	return(np->protoname);
 }
 
 /****************************************** READING DXF ******************************************/
@@ -513,11 +513,11 @@ BOOLEAN io_readdxflibrary(LIBRARY *lib)
 		DiaSetProgress(io_dxfprogressdialog, 0,  io_dxflength);
 	}
 
-	/* make the only facet in this library */
-	io_dxfmainfacet = us_newnodeproto(lib->libname, lib);
-	if (io_dxfmainfacet == NONODEPROTO) return(TRUE);
-	lib->curnodeproto = io_dxfmainfacet;
-	io_dxfcurfacet = io_dxfmainfacet;
+	/* make the only cell in this library */
+	io_dxfmaincell = us_newnodeproto(lib->libname, lib);
+	if (io_dxfmaincell == NONODEPROTO) return(TRUE);
+	lib->curnodeproto = io_dxfmaincell;
+	io_dxfcurcell = io_dxfmaincell;
 	io_dxfheadercount = 0;
 	if (io_dxfignoredlayerstringarray == 0)
 	{
@@ -609,7 +609,7 @@ BOOLEAN io_readdxflibrary(LIBRARY *lib)
 
 		/* have to search by hand because of weird prototype names */
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			if (estrcmp(np->cell->cellname, fr->refname) == 0) break;
+			if (estrcmp(np->protoname, fr->refname) == 0) break;
 		if (np == NONODEPROTO)
 		{
 			ttyputmsg(_("Cannot find block '%s'"), fr->refname);
@@ -622,7 +622,7 @@ BOOLEAN io_readdxflibrary(LIBRARY *lib)
 			{
 				if (fr->xsca != 1.0 || fr->ysca != 1.0)
 				{
-					np = io_dxfgetscaledfacet(np, fr->xsca, fr->ysca);
+					np = io_dxfgetscaledcell(np, fr->xsca, fr->ysca);
 					if (np == NONODEPROTO) return(TRUE);
 				}
 				ni = newnodeinst(np, fr->x+np->lowx, fr->x+np->highx, fr->y+np->lowy, fr->y+np->highy,
@@ -945,7 +945,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 			if (sangle >= 360.0) sangle -= 360.0;
 			iangle = rounddouble(sangle * 10.0);
 			ni = newnodeinst(art_circleprim, x1-rad, x1+rad, y1-rad, y1+rad, 0, iangle%3600,
-				io_dxfcurfacet);
+				io_dxfcurcell);
 			if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 			io_dxfstoredxf(ni);
@@ -975,8 +975,8 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 			if (io_dxfreadblock(io, &msg) != 0) return(1);
 			if (msg != 0)
 			{
-				io_dxfcurfacet = us_newnodeproto(io_dxfblockname(msg), lib);
-				if (io_dxfcurfacet == NONODEPROTO) return(1);
+				io_dxfcurcell = us_newnodeproto(io_dxfblockname(msg), lib);
+				if (io_dxfcurcell == NONODEPROTO) return(1);
 				efree(msg);
 			}
 			continue;
@@ -985,7 +985,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 		{
 			if (io_dxfreadcircleentity(io, &x1,&y1,&z1, &rad, &layer) != 0) return(1);
 			if (io_dxfacceptablelayer(layer) == 0) continue;
-			ni = newnodeinst(art_circleprim, x1-rad, x1+rad, y1-rad, y1+rad, 0, 0, io_dxfcurfacet);
+			ni = newnodeinst(art_circleprim, x1-rad, x1+rad, y1-rad, y1+rad, 0, 0, io_dxfcurcell);
 			if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 			io_dxfstoredxf(ni);
@@ -997,7 +997,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 		if (estrcmp(text, x_("ENDBLK")) == 0)
 		{
 			if (io_dxfignoreentity(io) != 0) return(1);
-			io_dxfcurfacet = io_dxfmainfacet;
+			io_dxfcurcell = io_dxfmaincell;
 			continue;
 		}
 		if (estrcmp(text, x_("ENDSEC")) == 0)
@@ -1020,13 +1020,13 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 
 				/* have to search by hand because of weird prototype names */
 				for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-					if (estrcmp(np->cell->cellname, pt) == 0) break;
+					if (estrcmp(np->protoname, pt) == 0) break;
 				if (np == NONODEPROTO)
 				{
 					fr = (FORWARDREF *)emalloc(sizeof (FORWARDREF), io_tool->cluster);
 					if (fr == 0) return(1);
 					(void)allocstring(&fr->refname, pt, io_tool->cluster);
-					fr->parent = io_dxfcurfacet;
+					fr->parent = io_dxfcurcell;
 					fr->x = x1;		fr->y = y1;
 					fr->rot = rot;
 					fr->xrep = xrep;	fr->yrep = yrep;
@@ -1039,15 +1039,15 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 
 				if (io_dxfflatteninput != 0)
 				{
-					if (io_dxfextractinsert(np, x1, y1, xsca, ysca, rot, io_dxfcurfacet) != 0) return(1);
+					if (io_dxfextractinsert(np, x1, y1, xsca, ysca, rot, io_dxfcurcell) != 0) return(1);
 				} else
 				{
 					if (xsca != 1.0 || ysca != 1.0)
 					{
-						np = io_dxfgetscaledfacet(np, xsca, ysca);
+						np = io_dxfgetscaledcell(np, xsca, ysca);
 						if (np == NONODEPROTO) return(1);
 					}
-					ni = newnodeinst(np, x1+np->lowx, x1+np->highx, y1+np->lowy, y1+np->highy, 0, rot*10, io_dxfcurfacet);
+					ni = newnodeinst(np, x1+np->lowx, x1+np->highx, y1+np->lowy, y1+np->highy, 0, rot*10, io_dxfcurcell);
 					if (ni == NONODEINST) return(1);
 					ni->userbits |= NEXPAND;
 				}
@@ -1064,7 +1064,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 			xc  = (lx + hx) / 2;	yc = (ly + hy) / 2;
 			if (lineType == 0) np = art_openedpolygonprim; else
 				np = art_openeddashedpolygonprim;
-			ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, io_dxfcurfacet);
+			ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, io_dxfcurcell);
 			if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 			io_dxfstoredxf(ni);
@@ -1127,7 +1127,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 								iangle = rounddouble(sa);
 								rad = computedistance(xc, yc, x1, y1);
 								ni = newnodeinst(art_circleprim, xc-rad, xc+rad, yc-rad, yc+rad, 0,
-									iangle, io_dxfcurfacet);
+									iangle, io_dxfcurcell);
 								if (ni == NONODEINST) return(1);
 								startoffset = sa;
 								startoffset -= (double)iangle;
@@ -1187,7 +1187,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 							/* create the arc node */
 							iangle = rounddouble(sa);
 							ni = newnodeinst(art_circleprim, x1-rad, x1+rad, y1-rad, y1+rad, 0,
-								iangle%3600, io_dxfcurfacet);
+								iangle%3600, io_dxfcurcell);
 							if (ni == NONODEINST) return(1);
 							if (sa > ea) ea += 3600.0;
 							startoffset = sa;
@@ -1203,7 +1203,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 						xc  = (lx + hx) / 2;	yc = (ly + hy) / 2;
 						if (lineType == 0) np = art_openedpolygonprim; else
 							np = art_openeddashedpolygonprim;
-						ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, io_dxfcurfacet);
+						ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, io_dxfcurcell);
 						if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 						io_dxfstoredxf(ni);
@@ -1236,7 +1236,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 						if (lineType == 0) np = art_openedpolygonprim; else
 							np = art_openeddashedpolygonprim;
 					}
-					ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, io_dxfcurfacet);
+					ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, io_dxfcurcell);
 					if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 					io_dxfstoredxf(ni);
@@ -1271,7 +1271,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 			lx = mini(mini(x1, x2), mini(x3, x4));	hx = maxi(maxi(x1, x2), maxi(x3, x4));
 			ly = mini(mini(y1, y2), mini(y3, y4));	hy = maxi(maxi(y1, y2), maxi(y3, y4));
 			xc  = (lx + hx) / 2;	yc = (ly + hy) / 2;
-			ni = newnodeinst(art_filledpolygonprim, lx, hx, ly, hy, 0, 0, io_dxfcurfacet);
+			ni = newnodeinst(art_filledpolygonprim, lx, hx, ly, hy, 0, 0, io_dxfcurcell);
 			if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 			io_dxfstoredxf(ni);
@@ -1300,7 +1300,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 				for(pt = msg; *pt != 0; pt++) if (*pt != ' ' && *pt != '\t') break;
 				if (*pt != 0)
 				{
-					ni = newnodeinst(gen_invispinprim, lx, hx, ly, hy, 0, 0, io_dxfcurfacet);
+					ni = newnodeinst(gen_invispinprim, lx, hx, ly, hy, 0, 0, io_dxfcurcell);
 					if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 					io_dxfstoredxf(ni);
@@ -1328,7 +1328,7 @@ BOOLEAN io_dxfreadentities(FILE *io, LIBRARY *lib)
 			lx = mini(mini(x1, x2), mini(x3, x4));	hx = maxi(maxi(x1, x2), maxi(x3, x4));
 			ly = mini(mini(y1, y2), mini(y3, y4));	hy = maxi(maxi(y1, y2), maxi(y3, y4));
 			xc  = (lx + hx) / 2;	yc = (ly + hy) / 2;
-			ni = newnodeinst(art_closedpolygonprim, lx, hx, ly, hy, 0, 0, io_dxfcurfacet);
+			ni = newnodeinst(art_closedpolygonprim, lx, hx, ly, hy, 0, 0, io_dxfcurcell);
 			if (ni == NONODEINST) return(1);
 #ifdef PRESERVEDXF
 			io_dxfstoredxf(ni);
@@ -1808,10 +1808,10 @@ INTBIG io_dxfextractinsert(NODEPROTO *onp, INTBIG x, INTBIG y, float xsca, float
 		if (ni->proto->primindex == 0)
 		{
 			ttyputmsg(_("Cannot insert block '%s'...it has inserts in it"),
-				onp->cell->cellname);
+				onp->protoname);
 			return(1);
 		}
-		if (ni->proto == gen_facetcenterprim) continue;
+		if (ni->proto == gen_cellcenterprim) continue;
 		sx = roundfloat((float)(ni->highx-ni->lowx) * xsca);
 		sy = roundfloat((float)(ni->highy-ni->lowy) * ysca);
 		cx = x + roundfloat((float)(ni->highx+ni->lowx) * xsca / 2.0f);
@@ -1824,7 +1824,7 @@ INTBIG io_dxfextractinsert(NODEPROTO *onp, INTBIG x, INTBIG y, float xsca, float
 			ni->proto == art_openedpolygonprim || ni->proto == art_openeddashedpolygonprim)
 		{
 			/* copy trace information */
-			var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+			var = gettrace(ni);
 			if (var != NOVARIABLE)
 			{
 				len = (var->type&VLENGTH) >> VLENGTHSH;
@@ -1861,9 +1861,9 @@ INTBIG io_dxfextractinsert(NODEPROTO *onp, INTBIG x, INTBIG y, float xsca, float
 	return(0);
 }
 
-NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca)
+NODEPROTO *io_dxfgetscaledcell(NODEPROTO *onp, float xsca, float ysca)
 {
-	CHAR sviewname[100], fviewname[100], facetname[200];
+	CHAR sviewname[100], fviewname[100], cellname[200];
 	INTBIG *newtrace;
 	INTBIG i, len;
 	VIEW *view;
@@ -1882,12 +1882,12 @@ NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca)
 	}
 
 	/* find the view of this cell */
-	for(np = onp->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
+	FOR_CELLGROUP(np, onp)
 		if (np->cellview == view) return(np);
 
 	/* not found: create it */
-	esnprintf(facetname, 200, x_("%s{%s}"), onp->cell->cellname, sviewname);
-	np = us_newnodeproto(facetname, onp->cell->lib);
+	esnprintf(cellname, 200, x_("%s{%s}"), onp->protoname, sviewname);
+	np = us_newnodeproto(cellname, onp->lib);
 	if (np == NONODEPROTO) return(NONODEPROTO);
 
 	for(ni = onp->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1895,7 +1895,7 @@ NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca)
 		if (ni->proto->primindex == 0)
 		{
 			ttyputmsg(_("Cannot scale insert of block '%s'...it has inserts in it"),
-				onp->cell->cellname);
+				onp->protoname);
 			return(NONODEPROTO);
 		}
 		nni = newnodeinst(ni->proto, (INTBIG)(ni->lowx*xsca), (INTBIG)(ni->highx*xsca),
@@ -1905,7 +1905,7 @@ NODEPROTO *io_dxfgetscaledfacet(NODEPROTO *onp, float xsca, float ysca)
 			ni->proto == art_openedpolygonprim || ni->proto == art_openeddashedpolygonprim)
 		{
 			/* copy trace information */
-			var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+			var = gettrace(ni);
 			if (var != NOVARIABLE)
 			{
 				len = (var->type&VLENGTH) >> VLENGTHSH;
