@@ -62,26 +62,26 @@ typedef struct Inexteaglenet
 static EAGLENET *io_eaglefirstnet;
 
 /* prototypes for local routines */
-static INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix);
-static void io_eaglemarkfacets(NODEPROTO *curfacet);
+static INTBIG io_eagledumpcell(NODEPROTO *curcell, CHAR *prefix);
+static void io_eaglemarkcells(NODEPROTO *curcell);
 
 BOOLEAN io_writeeaglelibrary(LIBRARY *lib)
 {
 	CHAR file[100], *truename;
 	REGISTER INTBIG i, sorted, maxnetname, maxpackagename;
 	REGISTER CHAR *name;
-	REGISTER NODEPROTO *curfacet;
+	REGISTER NODEPROTO *curcell;
 	REGISTER EAGLENET *en, *lasten, *nexten;
 	REGISTER PORTPROTO *pp;
 
 	/* create the proper disk file for the EAGLE */
-	curfacet = lib->curnodeproto;
-	if (curfacet == NONODEPROTO)
+	curcell = lib->curnodeproto;
+	if (curcell == NONODEPROTO)
 	{
-		ttyputerr(_("Must be editing a facet to generate EAGLE output"));
+		ttyputerr(_("Must be editing a cell to generate EAGLE output"));
 		return(TRUE);
 	}
-	(void)estrcpy(file, curfacet->cell->cellname);
+	(void)estrcpy(file, curcell->protoname);
 	(void)estrcat(file, x_(".txt"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypeeagle, _("EAGLE File"), &truename);
@@ -93,9 +93,9 @@ BOOLEAN io_writeeaglelibrary(LIBRARY *lib)
 
 	/* recurse through the circuit, gathering network connections */
 	io_eaglefirstnet = NOEAGLENET;
-	for(pp = curfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(pp = curcell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
-	if (io_eagledumpfacet(curfacet, x_("")) != 0)
+	if (io_eagledumpcell(curcell, x_("")) != 0)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 	xprintf(io_fileout, x_(";\n"));
 
@@ -186,10 +186,10 @@ BOOLEAN io_writeeaglelibrary(LIBRARY *lib)
 }
 
 /*
- * Routine to write out all facets in the current library that are marked (temp1 != 0).
+ * Routine to write out all cells in the current library that are marked (temp1 != 0).
  * Returns nonzero if backannotation has been added.
  */
-INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
+INTBIG io_eagledumpcell(NODEPROTO *curcell, CHAR *prefix)
 {
 	CHAR *name;
 	CHAR line[50], *newprefix, *tempname;
@@ -205,29 +205,29 @@ INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 
 	/* make sure that all arcs have network names on them */
 	backannotate = 0;
-	if (asktool(net_tool, x_("name-nets"), (INTBIG)curfacet) != 0) backannotate++;
+	if (asktool(net_tool, x_("name-nets"), (INTBIG)curcell) != 0) backannotate++;
 
-	/* mark those facets that will be included in this dump */
-	io_eaglemarkfacets(curfacet);
+	/* mark those cells that will be included in this dump */
+	io_eaglemarkcells(curcell);
 
 	/* write the symbols */
 	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		if (np->temp1 == 0) continue;
 
-		/* if this is the main entry facet, pickup net names */
+		/* if this is the main entry cell, pickup net names */
 		for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 			net->temp1 = 0;
-		if (np == curfacet)
+		if (np == curcell)
 		{
-			for(pp = curfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+			for(pp = curcell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			{
 				if (pp->temp1 == 0) continue;
 				pp->network->temp1 = pp->temp1;
 			}
 		}
 
-		/* dump symbols in this facet */
+		/* dump symbols in this cell */
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			/* see if this node has a part name */
@@ -235,7 +235,7 @@ INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 			subnp = ni->proto;
 
 			/* ignore recursive references (showing icon in contents) */
-			if (subnp->cell == np->cell) continue;
+			if (isiconof(subnp, np)) continue;
 
 			varpart = getval((INTBIG)ni, VNODEINST, -1, x_("ATTR_ref_des"));
 			if (varpart == NOVARIABLE)
@@ -243,7 +243,7 @@ INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 				subcnp = contentsview(subnp);
 				if (subcnp != NONODEPROTO) subnp = subcnp;
 
-				/* compute new prefix for nets in the subfacet */
+				/* compute new prefix for nets in the subcell */
 				infstr = initinfstr();
 				addstringtoinfstr(infstr, prefix);
 				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
@@ -258,7 +258,7 @@ INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 				}
 				(void)allocstring(&newprefix, returninfstr(infstr), el_tempcluster);
 
-				/* store net names on ports for use inside the subfacet */
+				/* store net names on ports for use inside the subcell */
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					pp->temp1 = 0;
 				for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -274,10 +274,10 @@ INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 				}
 
 				/* recurse */
-				if (io_eagledumpfacet(subnp, newprefix) != 0) backannotate++;
+				if (io_eagledumpcell(subnp, newprefix) != 0) backannotate++;
 
-				/* remark the facets at the current level and clean up memory */
-				io_eaglemarkfacets(curfacet);
+				/* remark the cells at the current level and clean up memory */
+				io_eaglemarkcells(curcell);
 				efree(newprefix);
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					if (pp->temp1 != 0) efree((CHAR *)pp->temp1);
@@ -288,7 +288,7 @@ INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 				varpackagetype = getval((INTBIG)ni, VNODEINST, -1, x_("ATTR_pkg_type"));
 				if (varpackagetype == NOVARIABLE)
 				{
-					xprintf(io_fileout, x_("ADD %s '%s%s'"), ni->proto->cell->cellname,
+					xprintf(io_fileout, x_("ADD %s '%s%s'"), ni->proto->protoname,
 						prefix, name);
 				} else
 				{
@@ -348,28 +348,25 @@ INTBIG io_eagledumpfacet(NODEPROTO *curfacet, CHAR *prefix)
 }
 
 /*
- * Routine to mark the facets in the current library that should be included
- * along with "curfacet".  The facets are marked by setting their "temp1" field
- * nonzero.  These facets include all that are part of a multipage schematic.
+ * Routine to mark the cells in the current library that should be included
+ * along with "curcell".  The cells are marked by setting their "temp1" field
+ * nonzero.  These cells include all that are part of a multipage schematic.
  */
-void io_eaglemarkfacets(NODEPROTO *curfacet)
+void io_eaglemarkcells(NODEPROTO *curcell)
 {
 	REGISTER NODEPROTO *np;
 
-	/* mark those facets that will be included in this dump */
+	/* mark those cells that will be included in this dump */
 	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-	{
 		np->temp1 = 0;
-		if ((curfacet->cellview->viewstate&MULTIPAGEVIEW) != 0 ||
-			namesamen(curfacet->cellview->viewname, x_("schematic-page-"), 15) == 0)
-		{
-			/* original facet is a multipage: allow all multipage in this cell */
-			if (curfacet->cell != np->cell) continue;
-		} else
-		{
-			/* original is not multipage: allow only it */
-			if (curfacet != np) continue;
-		}
+	if ((curcell->cellview->viewstate&MULTIPAGEVIEW) != 0 ||
+		namesamen(curcell->cellview->viewname, x_("schematic-page-"), 15) == 0)
+	{
+		/* original cell is a multipage: allow all multipage in this cell */
+		FOR_CELLGROUP(np, curcell)
+			np->temp1 = 1;
+	} else
+	{
 		np->temp1 = 1;
 	}
 }
