@@ -95,7 +95,7 @@ static void io_edifwriteprim(NODEPROTO *np, INTBIG i, INTBIG fun);
 static CHAR *io_edif_orientation(NODEINST *ni);
 static CHAR *io_edifwritecompname(NODEINST *ni, INTBIG fun, INTBIG serindex);
 static void io_edif_pt(INTBIG x, INTBIG y);
-static BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external);
+static BOOLEAN io_edifwritecell(NODEPROTO *np, INTBIG external);
 static CHAR *io_edifdescribepriminst(NODEINST *ni, INTBIG fun);
 static BOOLEAN io_edifisglobal(PORTPROTO *pp);
 static INTBIG io_edifmarknetports(NODEPROTO *np);
@@ -110,7 +110,7 @@ static BOOLEAN io_edifwriteportpositions(PORTPROTO *pp, INTBIG cellx, INTBIG cel
 static CHAR *io_ediflowerstring(CHAR *str);
 static CHAR *io_edifupperstring(CHAR *str);
 static void io_edifsymbol(NODEPROTO *np);
-static void io_edifsymbol_facet(NODEINST *ni, XARRAY prevtrans);
+static void io_edifsymbol_cell(NODEINST *ni, XARRAY prevtrans);
 static void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans);
 static void io_edifsymbol_arcinst(ARCINST *ai, XARRAY trans);
 static void io_edifsetgraphic(_egraphic type);
@@ -147,7 +147,7 @@ void io_initedif(void)
 
 /*
  * routine to write a ".edif" file (or a ".foot" file for layouts)
- * describing the current facet from the library "lib"
+ * describing the current cell from the library "lib"
  */
 BOOLEAN io_writeediflibrary(LIBRARY *lib)
 {
@@ -177,7 +177,7 @@ BOOLEAN io_writeediflibrary(LIBRARY *lib)
 	np = lib->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("Must be editing a facet to generate EDIF output"));
+		ttyputerr(_("Must be editing a cell to generate EDIF output"));
 		return(TRUE);
 	}
 
@@ -192,7 +192,7 @@ BOOLEAN io_writeediflibrary(LIBRARY *lib)
 	} else
 		schematic_view = 0;
 
-	(void)estrcpy(name, io_ediftoken(np->cell->cellname));
+	(void)estrcpy(name, io_ediftoken(np->protoname));
 
 	/* If this is a layout representation, then create the footprint */
 	if (np->cellview == el_layoutview)
@@ -305,11 +305,11 @@ BOOLEAN io_writeediflibrary(LIBRARY *lib)
 			EO_close_block(edif_stream, x_("scale"));
 		}
 		EO_close_block(edif_stream, x_("technology"));
-		if (io_edifwritefacet(np, i)) backannotate = TRUE;
+		if (io_edifwritecell(np, i)) backannotate = TRUE;
 		EO_close_block(edif_stream, x_("external"));
 	}
 
-	/* now recursively write the facets expanded within the library */
+	/* now recursively write the cells expanded within the library */
 	EO_open_block(edif_stream, x_("library"));
 	EO_put_identifier(edif_stream, io_ediftoken(lib->libname));
 	EO_put_block(edif_stream, x_("edifLevel"), x_("0"));
@@ -325,14 +325,14 @@ BOOLEAN io_writeediflibrary(LIBRARY *lib)
 	}
 	EO_close_block(edif_stream, x_("technology"));
 
-	if (io_edifwritefacet(np, 0)) backannotate = TRUE;
+	if (io_edifwritecell(np, 0)) backannotate = TRUE;
 	EO_close_block(edif_stream, x_("library"));
 
 	/* post-identify the design and library */
 	EO_open_block(edif_stream, x_("design"));
-	EO_put_identifier(edif_stream, io_ediftoken(np->cell->cellname));
+	EO_put_identifier(edif_stream, io_ediftoken(np->protoname));
 	EO_open_block(edif_stream, x_("cellRef"));
-	EO_put_identifier(edif_stream, io_ediftoken(np->cell->cellname));
+	EO_put_identifier(edif_stream, io_ediftoken(np->protoname));
 	EO_put_block(edif_stream, x_("libraryRef"), io_ediftoken(lib->libname));
 
 	/* clean up */
@@ -344,7 +344,7 @@ BOOLEAN io_writeediflibrary(LIBRARY *lib)
 }
 
 /*
- * routine to count the usage of primitives hierarchically below facet "np"
+ * routine to count the usage of primitives hierarchically below cell "np"
  */
 INTBIG io_edifsearch(NODEPROTO *np)
 {
@@ -353,7 +353,7 @@ INTBIG io_edifsearch(NODEPROTO *np)
 	REGISTER PORTARCINST *pi;
 	REGISTER INTBIG i, fun, primcount;
 
-	/* do not search this facet if it is an icon */
+	/* do not search this cell if it is an icon */
 	if (np->cellview == el_iconview) return(0);
 
 	/* keep a count of the total number of primitives encountered */
@@ -382,13 +382,13 @@ INTBIG io_edifsearch(NODEPROTO *np)
 		}
 
 		/* ignore recursive references (showing icon in contents) */
-		if (ni->proto->cell == np->cell) continue;
+		if (isiconof(ni->proto, np)) continue;
 
-		/* get actual subfacet (including contents/body distinction) */
+		/* get actual subcell (including contents/body distinction) */
 		onp = contentsview(ni->proto);
 		if (onp == NONODEPROTO) onp = ni->proto;
 
-		/* search the subfacet */
+		/* search the subcell */
 		if (onp->temp1 == 0) primcount += io_edifsearch(onp);
 	}
 	np->temp1++;
@@ -396,8 +396,8 @@ INTBIG io_edifsearch(NODEPROTO *np)
 }
 
 /*
- * Routine to identify facets with external connection models hierarchically below
- * facet "np" and locate the libraries that contain their models.  Sets np->temp2
+ * Routine to identify cells with external connection models hierarchically below
+ * cell "np" and locate the libraries that contain their models.  Sets np->temp2
  * to point to the location in the external library array containing the library
  * name.
  */
@@ -417,9 +417,9 @@ void io_edifextsearch(NODEPROTO *np)
 	if (np->temp2 == 0 && np->cellview == el_iconview && onp == NONODEPROTO)
 	{
 		/* do not mention monitor_probes */
-		if (namesame(np->cell->cellname, x_("monitor_probe")) == 0) return;
+		if (namesame(np->protoname, x_("monitor_probe")) == 0) return;
 
-		/* this facet is not expanded in this library */
+		/* this cell is not expanded in this library */
 		libname = io_ediffind_path(np);
 
 		if (io_edifoextlibcount == 0) i = 1; else
@@ -444,7 +444,7 @@ void io_edifextsearch(NODEPROTO *np)
 		if (subnp->temp1 != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (subnp->cell == onp->cell) continue;
+		if (isiconof(subnp, onp)) continue;
 		io_edifextsearch(subnp);
 	}
 
@@ -472,7 +472,7 @@ CHAR *io_ediffind_path(NODEPROTO *np)
 			{
 				libpath[i] = DIRSEP;
 				libpath[i + 1] = 0;
-				estrcat(libpath, np->cell->cellname);
+				estrcat(libpath, np->protoname);
 				estrcat(libpath, DIRSEPSTR);
 				estrcat(libpath, x_("edif"));
 				estrcat(libpath, DIRSEPSTR);
@@ -514,12 +514,12 @@ void io_edifwriteprim(NODEPROTO *np, INTBIG i, INTBIG fun)
 	if (fun == NPGATEAND || fun == NPGATEOR || fun == NPGATEXOR)
 	{
 		EO_open_block(edif_stream, x_("cell"));
-		(void)esnprintf(name, 100, x_("%s%ld"), io_ediftoken(np->primname), i);
+		(void)esnprintf(name, 100, x_("%s%ld"), io_ediftoken(np->protoname), i);
 		EO_put_identifier(edif_stream, name);
 	} else
 	{
 		EO_open_block(edif_stream, x_("cell"));
-		EO_put_identifier(edif_stream, io_ediftoken(np->primname));
+		EO_put_identifier(edif_stream, io_ediftoken(np->protoname));
 	}
 
 	/* write primitive connections */
@@ -658,13 +658,13 @@ void io_edif_pt(INTBIG x, INTBIG y)
 }
 
 /*
- * Routine to recursively dump facet "np" to the EDIF file
+ * Routine to recursively dump cell "np" to the EDIF file
  * Recurses for contents if 'external' is zero, creates only
  * interface models for external elements for library number
  * 'external' if 'external' is non-zero.
  * Returns true if back-annotation was added.
  */
-BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
+BOOLEAN io_edifwritecell(NODEPROTO *np, INTBIG external)
 {
 	INTBIG i, netcount, displaytotal;
 	INTBIG fun;
@@ -675,7 +675,7 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 	PORTARCINST *pi;
 	PORTEXPINST *pe;
 	PORTPROTO *pp, *cpp;
-	NODEPROTO *onp, *cnp;
+	NODEPROTO *onp, *cnp, *lnp;
 	ARCINST *ai;
 	CHAR *pt, *iname, *oname, line[WORD+1], *direction;
 	BOOLEAN globalport;
@@ -703,7 +703,7 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 	if (schematic_view)
 		(void)needstaticpolygon(&poly, 4, io_tool->cluster);
 
-	/* recurse on sub-facets first */
+	/* recurse on sub-cells first */
 	backannotate = FALSE;
 	if (np->cellview != el_iconview)
 	{
@@ -713,34 +713,34 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 			if (ni->proto->primindex != 0) continue;
 
 			/* ignore recursive references (showing icon in contents) */
-			if (ni->proto->cell == np->cell) continue;
+			if (isiconof(ni->proto, np)) continue;
 
 			/* do not expand "monitor_probe" construct (icon) */
-			if (namesame(ni->proto->cell->cellname, x_("monitor_probe")) == 0) continue;
+			if (namesame(ni->proto->protoname, x_("monitor_probe")) == 0) continue;
 
-			/* get actual subfacet (including contents/body distinction) */
+			/* get actual subcell (including contents/body distinction) */
 			onp = contentsview(ni->proto);
 			if (onp == NONODEPROTO) onp = ni->proto;
 
-			/* write the subfacet */
+			/* write the subcell */
 			if (onp->temp1 == 0)
 			{
-				if (io_edifwritefacet(onp, external) != 0) backannotate = TRUE;
+				if (io_edifwritecell(onp, external) != 0) backannotate = TRUE;
 			}
 		}
 	}
 
-	/* check whether writing external or contents facets */
+	/* check whether writing external or contents cells */
 	if (external > 0 && np->cellview != el_iconview) return(backannotate);
 
-	/* check whether this facet is in this external library */
+	/* check whether this cell is in this external library */
 	if (external > 0 && np->temp2 != external) return(backannotate);
 
 	/* make sure that all nodes and networks have names on them */
 	if (asktool(net_tool, x_("name-nodes"), (INTBIG)np) != 0) backannotate++;
 	if (asktool(net_tool, x_("name-nets"), (INTBIG)np) != 0) backannotate++;
 
-	/* mark this facet as written */
+	/* mark this cell as written */
 	np->temp1++;
 
 	/* assign bus names to unnamed bus wires connecting bus ports on objects */
@@ -753,7 +753,7 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 
 	/* write out the cell header information */
 	EO_open_block(edif_stream, x_("cell"));
-	EO_put_identifier(edif_stream, io_ediftoken(np->cell->cellname));
+	EO_put_identifier(edif_stream, io_ediftoken(np->protoname));
 	EO_put_block(edif_stream, x_("cellType"), x_("generic"));
 	EO_open_block(edif_stream, x_("view"));
 	EO_put_identifier(edif_stream, x_("cell"));
@@ -825,11 +825,11 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 			(void)esnprintf(page, 10, x_("P%ld"), pageindex);
 
 			/* locate the next like in cell */
-			for (np = np->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
-				if (!namesame(np->cellview->sviewname, page))
+			FOR_CELLGROUP(lnp, np)
+				if (!namesame(lnp->cellview->sviewname, page))
 			{
 				/* list all ports in interface except global ports in network order */
-				(void)io_edifmarknetports(np);
+				(void)io_edifmarknetports(lnp);
 				break;
 			}
 			schematic = TRUE;
@@ -854,11 +854,11 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 					{
 						if (fun == NPUNKNOWN || fun == NPPIN || fun == NPCONTACT ||
 							fun == NPNODE || fun == NPCONNECT || fun == NPART) continue;
-					} else if (namesame(ni->proto->cell->cellname, x_("monitor_probe")) == 0)
+					} else if (namesame(ni->proto->protoname, x_("monitor_probe")) == 0)
 						continue;
 
 					/* ignore recursive references (showing icon in contents) */
-					if (ni->proto->cell == np->cell) continue;
+					if (isiconof(ni->proto, np)) continue;
 
 					EO_open_block(edif_stream, x_("instance"));
 					iname = io_edifwritecompname(ni, fun, 0);
@@ -905,7 +905,7 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 							i = 0;
 							for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 								if (pi->proto == ni->proto->firstportproto) i++;
-							(void)esnprintf(name, WORD+1, x_("%s%ld"), io_ediftoken(ni->proto->primname), i);
+							(void)esnprintf(name, WORD+1, x_("%s%ld"), io_ediftoken(ni->proto->protoname), i);
 							EO_put_identifier(edif_stream, name);
 						} else EO_put_identifier(edif_stream, io_edifdescribepriminst(ni, fun));
 						EO_put_block(edif_stream, x_("libraryRef"), x_("lib0"));
@@ -917,7 +917,7 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 						EO_open_block(edif_stream, x_("viewRef"));
 						EO_put_identifier(edif_stream, x_("cell"));
 						EO_open_block(edif_stream, x_("cellRef"));
-						EO_put_identifier(edif_stream, io_ediftoken(ni->proto->cell->cellname));
+						EO_put_identifier(edif_stream, io_ediftoken(ni->proto->protoname));
 						(void)esnprintf(name, WORD+1, x_("schem_lib_%ld"), ni->proto->temp2);
 						EO_put_block(edif_stream, x_("libraryRef"), name);
 						EO_close_block(edif_stream, x_("viewRef"));
@@ -927,8 +927,8 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 						EO_open_block(edif_stream, x_("viewRef"));
 						EO_put_identifier(edif_stream, x_("cell"));
 						EO_open_block(edif_stream, x_("cellRef"));
-						EO_put_identifier(edif_stream, io_ediftoken(ni->proto->cell->cellname));
-						EO_put_block(edif_stream, x_("libraryRef"), np->cell->lib->libname);
+						EO_put_identifier(edif_stream, io_ediftoken(ni->proto->protoname));
+						EO_put_block(edif_stream, x_("libraryRef"), np->lib->libname);
 						EO_close_block(edif_stream, x_("viewRef"));
 					}
 
@@ -1001,10 +1001,10 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 						fun = nodefunction(ni);
 						if (fun != NPUNKNOWN && fun != NPPIN && fun != NPCONTACT &&
 							fun != NPNODE && fun != NPCONNECT && fun != NPART) continue;
-					} else if (namesame(ni->proto->cell->cellname, x_("monitor_probe")) == 0) continue;
+					} else if (namesame(ni->proto->protoname, x_("monitor_probe")) == 0) continue;
 
 					/* ignore recursive references (showing icon in contents) */
-					if (ni->proto->cell == np->cell) continue;
+					if (isiconof(ni->proto, np)) continue;
 
 					for (pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					{
@@ -1038,7 +1038,7 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 
 				transid(trans);
 
-				/* if there is anything to connect, write the networks in the facet */
+				/* if there is anything to connect, write the networks in the cell */
 				for (net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 				{
 					/* skip bus networks altogether (they are done wire by wire) */
@@ -1124,7 +1124,7 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 					{
 						for (ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 						{
-							if (ni->proto->primindex == 0 && namesame(ni->proto->cell->cellname,
+							if (ni->proto->primindex == 0 && namesame(ni->proto->protoname,
 								x_("monitor_probe")) == 0) continue;
 
 							for (pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -1203,9 +1203,9 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 						} else
 						{
 							/* ignore recursive references (showing icon in contents) */
-							if (ni->proto->cell == np->cell) continue;
+							if (isiconof(ni->proto, np)) continue;
 
-							if (namesame(ni->proto->cell->cellname, x_("monitor_probe")) == 0)
+							if (namesame(ni->proto->protoname, x_("monitor_probe")) == 0)
 								continue;
 							fun = NPUNKNOWN;
 
@@ -1387,11 +1387,11 @@ BOOLEAN io_edifwritefacet(NODEPROTO *np, INTBIG external)
 				/* get next schematic */
 				pageindex++;
 				(void)esnprintf(page, 10, x_("P%ld"), pageindex);
-				for (np = np->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
-					if (!namesame(np->cellview->sviewname, page))
+				FOR_CELLGROUP(lnp, np)
+					if (!namesame(lnp->cellview->sviewname, page))
 				{
 					/* list all ports in interface except global ports in network order */
-					(void)io_edifmarknetports(np);
+					(void)io_edifmarknetports(lnp);
 					break;
 				}
 				if (np == NONODEPROTO) break;
@@ -1438,7 +1438,7 @@ CHAR *io_edifdescribepriminst(NODEINST *ni, INTBIG fun)
 			if (var != NOVARIABLE && namesamen(x_("subtap"), (CHAR *) var->addr, 6) == 0)
 				return(x_("gtap"));
 	}
-	return(io_ediftoken(ni->proto->primname));
+	return(io_ediftoken(ni->proto->protoname));
 }
 
 /*
@@ -1498,7 +1498,7 @@ INTBIG io_edifmarknetports(NODEPROTO *np)
 
 /*
  * function to incorporate external library interface data or reference file
- * for current facet into EDIF netlist - returns false if successful
+ * for current cell into EDIF netlist - returns false if successful
  */
 BOOLEAN io_edifwritelibext(NODEPROTO *np)
 {
@@ -1508,13 +1508,13 @@ BOOLEAN io_edifwritelibext(NODEPROTO *np)
 	REGISTER INTBIG count;
 	REGISTER VARIABLE *var;
 
-	/* import the external library for this facet, if it exists */
+	/* import the external library for this cell, if it exists */
 	var = getval((INTBIG) np, VNODEPROTO, VSTRING, x_("EDIF_external_lib"));
 	if (var == NOVARIABLE) return(TRUE);
 	f = xopen((CHAR *)var->addr, io_filetypeedif, x_(""), &filename);
 	if (f == NULL)
 	{
-		ttyputerr(_("Cannot find EDIF external reference file %s on facet %s"),
+		ttyputerr(_("Cannot find EDIF external reference file %s on cell %s"),
 			(CHAR *) var->addr, describenodeproto(np));
 		return(TRUE);
 	}
@@ -1628,12 +1628,12 @@ BOOLEAN io_edifwritefootprint(NODEPROTO *np, CHAR *name, INTBIG routegrid)
 	route /= 100;
 
 	/* write the header */
-	ttyputmsg(_("Writing footprint for cell %s"), io_ediftoken(np->cell->cellname));
+	ttyputmsg(_("Writing footprint for cell %s"), io_ediftoken(np->protoname));
 	xprintf(io_fileout, _("(footprint %.2fe-06\n"), route);
 
 	/* identify the layout type from the schematic 'stopExpand' property */
 	var = NOVARIABLE;
-	for (vnp = np->cell->firstincell; vnp != NONODEPROTO; vnp = vnp->nextincell)
+	FOR_CELLGROUP(vnp, np)
 		if (vnp->cellview == el_schematicview) break;
 	if (vnp != NONODEPROTO)
 		var = getval((INTBIG) vnp, VNODEPROTO, VSTRING, x_("EDIF_stopExpand"));
@@ -1652,7 +1652,7 @@ BOOLEAN io_edifwritefootprint(NODEPROTO *np, CHAR *name, INTBIG routegrid)
 
 	/* get representation type from schematic (or layout) 'repType' property */
 	var = NOVARIABLE;
-	for (vnp = np->cell->firstincell; vnp != NONODEPROTO; vnp = vnp->nextincell)
+	FOR_CELLGROUP(vnp, np)
 		if (vnp->cellview == el_schematicview) break;
 	if (vnp != NONODEPROTO)
 		var = getval((INTBIG) vnp, VNODEPROTO, VSTRING, x_("EDIF_repType"));
@@ -1668,7 +1668,7 @@ BOOLEAN io_edifwritefootprint(NODEPROTO *np, CHAR *name, INTBIG routegrid)
 	width = (np->highx - np->lowx) / routegrid;
 	height = (np->highy - np->lowy) / routegrid;
 	xprintf(io_fileout, x_("  (%s %s (%ld %ld)\n"),
-		io_ediftoken(np->cell->cellname), cellRep, height, width);
+		io_ediftoken(np->protoname), cellRep, height, width);
 
 	/* find out if all port connections are wanted */
 	var = getval((INTBIG) np, VNODEPROTO, VSTRING, x_("EDIF_placeallports"));
@@ -1847,7 +1847,7 @@ CHAR *io_edifupperstring(CHAR *str)
 
 /* module: io_edifsymbol
  * function: will output all graphic objects of a symbol (extracted from
- * us_drawfacet).
+ * us_drawcell).
  */
 void io_edifsymbol(NODEPROTO *np)
 {
@@ -1882,7 +1882,7 @@ void io_edifsymbol(NODEPROTO *np)
 
 	for (ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		io_edifsymbol_facet(ni, trans);
+		io_edifsymbol_cell(ni, trans);
 	}
 	for (ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
@@ -1894,10 +1894,10 @@ void io_edifsymbol(NODEPROTO *np)
 	EO_close_block(edif_stream, x_("symbol"));
 }
 
-/* module: io_edifsymbol_facet
- * function: will output a specific symbol facet
+/* module: io_edifsymbol_cell
+ * function: will output a specific symbol cell
  */
-void io_edifsymbol_facet(NODEINST *ni, XARRAY prevtrans)
+void io_edifsymbol_cell(NODEINST *ni, XARRAY prevtrans)
 {
 	XARRAY localtran, trans;
 
@@ -1958,7 +1958,7 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 		for (pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 		{
 			/* us_writeprotoname(pe->exportproto, on, prevtrans, LAYERO,
-			el_colfacettxt&on, w, 0, 0, 0, 0); */
+			el_colcelltxt&on, w, 0, 0, 0, 0); */
 		}
 	}
 
@@ -2002,7 +2002,7 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 		maketrans(ni, localtran);
 		transmult(localtran, prevtrans, subrot);
 
-		/* get facet rectangle */
+		/* get cell rectangle */
 		maketruerectpoly(ni->lowx, ni->highx, ni->lowy, ni->highy, poly);
 		poly->style = CLOSEDRECT;
 		xformpoly(poly, prevtrans);
@@ -2015,19 +2015,19 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 				if (pp->subnodeinst->rotation == 0 && pp->subnodeinst->transpose == 0)
 				{
 					/* EMPTY */ 
-					/* us_writeprotoname(pp, LAYERA, subrot, LAYERO, el_colfacettxt, w,
+					/* us_writeprotoname(pp, LAYERA, subrot, LAYERO, el_colcelltxt, w,
 					portcliplx, portcliphx, portcliply, portcliphy); */
 				} else
 				{
 					makerot(pp->subnodeinst, localtran);
 					transmult(localtran, subrot, trans);
-					/* us_writeprotoname(pp, LAYERA, trans, LAYERO, el_colfacettxt, w,
+					/* us_writeprotoname(pp, LAYERA, trans, LAYERO, el_colcelltxt, w,
 					portcliplx, portcliphx, portcliply, portcliphy); */
 				}
 			}
 		}
 
-		/* see if there are displayable variables on the facet */
+		/* see if there are displayable variables on the cell */
 		if ((displaytotal = tech_displayablenvars(ni, NOWINDOWPART, &tech_oneprocpolyloop)) != 0)
 			io_edifsetgraphic(EGUNKNOWN);
 		for (i = 0; i < displaytotal; i++)
@@ -2051,10 +2051,10 @@ void io_edifsymbol_nodeinst(NODEINST *ni, XARRAY prevtrans)
 				EO_close_block(edif_stream, x_("annotate"));
 		}
 
-		/* search through facet */
+		/* search through cell */
 		for (ino = np->firstnodeinst; ino != NONODEINST; ino = ino->nextnodeinst)
 		{
-			io_edifsymbol_facet(ino, subrot);
+			io_edifsymbol_cell(ino, subrot);
 		}
 		for (iar = np->firstarcinst; iar != NOARCINST; iar = iar->nextarcinst)
 		{
@@ -2548,7 +2548,7 @@ INTBIG EO_put_header(EO_STREAM_PTR stream, CHAR *program, CHAR *comment, CHAR *o
 	/* output the standard EDIF 2 0 0 header */
 	if (EO_open_block(stream, x_("edif"))) return(1);
 	np = el_curlib->curnodeproto;
-	(void)esnprintf(name, WORD+1, x_("%s"), np->cell->cellname);
+	(void)esnprintf(name, WORD+1, x_("%s"), np->protoname);
 	if (EO_put_identifier(stream, name)) return(1);
 	if (EO_put_block(stream, x_("edifVersion"), x_("2 0 0"))) return(1);
 	if (EO_put_block(stream, x_("edifLevel"), x_("0"))) return(1);
