@@ -72,7 +72,7 @@
 #include "edialogs.h"
 #include <math.h>
 
-#define NEWPATH 1		/* path and facet caching optimizations */
+#define NEWPATH 1		/* path and cell caching optimizations */
 
 /* electric specific globals */
 static LIBRARY        *io_gdslibrary = NOLIBRARY;
@@ -162,7 +162,7 @@ static CHAR *io_gdsIerror_string[] =
 	N_("Could not create text marker"),						/* 36 */
 	N_("Could not create text string"),						/* 37 */
 	N_("Failed to create structure"),						/* 38 */
-	N_("Failed to create facet center"),					/* 39 */
+	N_("Failed to create cell center"),						/* 39 */
 	N_("Failed to create NODE"),							/* 40 */
 	N_("Failed to create box"),								/* 41 */
 	N_("Failed to create outline"),							/* 42 */
@@ -1358,14 +1358,11 @@ void io_gdsIdetermine_layer(INTBIG *layer, INTBIG *sublayer)
 
 NODEPROTO *io_gdsIfindproto(CHAR *name)
 {
-	CELL *c;
+	REGISTER NODEPROTO *np;
 
-	c = db_findcellname(name, io_gdslibrary);
-	if (c == NOCELL) return(NONODEPROTO);
-	if (estrcmp(c->cellname, name))
-		ttyputmsg(_("Cell %s is used instead of cell %s"),
-			c->cellname, name);
-	return(c->firstincell);
+	for(np = io_gdslibrary->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		if (namesame(name, np->protoname) == 0) return(np);
+	return(NONODEPROTO);
 }
 
 void io_gdsIbeginstructure(void)
@@ -1906,6 +1903,12 @@ void io_gdsIdetermine_text(void)
 			io_gdsIgettoken();
 			break;
 		}
+		if (io_gdstoken == GDS_MAG)
+		{
+			io_gdsIgettoken();
+			io_gdsIgettoken();
+			continue;
+		}
 		io_gdsIonlyone(io_gdsIrecovery_set, GDS_ENDEL);
 		io_gdsIerror(26);
 		break;
@@ -1960,7 +1963,7 @@ void io_gdsIstructure(void)
 		return;
 	}
 
-	db_boundfacet(io_gdsstructure, &io_gdsstructure->lowx, &io_gdsstructure->highx,
+	db_boundcell(io_gdsstructure, &io_gdsstructure->lowx, &io_gdsstructure->highx,
 		&io_gdsstructure->lowy, &io_gdsstructure->highy);
 }
 
@@ -2099,7 +2102,7 @@ BOOLEAN io_readgdslibrary(LIBRARY *lib, INTBIG position)
 			DiaSetProgress(io_gdsprogressdialog, 0, io_gdssrefcount);
 		}
 
-		/* determine which facets need to be recomputed */
+		/* determine which cells need to be recomputed */
 		count = io_gdssrefcount;
 		for (i = 0; i < MAXLAYERS; i++)
 			count += io_gdslayertext[i] + io_gdslayerpoly[i];
@@ -2137,24 +2140,19 @@ void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 			if ((ni->highx-ni->lowx) != (ni->proto->highx-ni->proto->lowx) ||
 				(ni->highy-ni->lowy) != (ni->proto->highy-ni->proto->lowy))
 			{
-#if 0
-				if (ni->lowx == ni->highx || ni->lowy == ni->highy)
-#endif
-				{
-					makeangle(ni->rotation, ni->transpose, trans);
+				makeangle(ni->rotation, ni->transpose, trans);
 
-					/* now transform the center */
-					cx = (ni->proto->highx + ni->proto->lowx) / 2;
-					cy = (ni->proto->highy + ni->proto->lowy) / 2;
-					xform(cx, cy, &ox, &oy, trans);
+				/* now transform the center */
+				cx = (ni->proto->highx + ni->proto->lowx) / 2;
+				cy = (ni->proto->highy + ni->proto->lowy) / 2;
+				xform(cx, cy, &ox, &oy, trans);
 
-					/* calculate the offset from the original center */
-					ox -= cx;   oy -= cy;
-					ni->lowx += (ni->proto->lowx + ox);
-					ni->highx += (ni->proto->highx + ox);
-					ni->lowy += (ni->proto->lowy + oy);
-					ni->highy += (ni->proto->highy + oy);
-				}
+				/* calculate the offset from the original center */
+				ox -= cx;   oy -= cy;
+				ni->lowx += (ni->proto->lowx + ox);
+				ni->highx += (ni->proto->highx + ox);
+				ni->lowy += (ni->proto->lowy + oy);
+				ni->highy += (ni->proto->highy + oy);
 				boundobj(ni->geom, &(ni->geom->lowx), &(ni->geom->highx),
 					&(ni->geom->lowy), &(ni->geom->highy));
 			}
@@ -2173,6 +2171,6 @@ void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 		}
 	}
 
-	db_boundfacet(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
+	db_boundcell(np, &np->lowx, &np->highx, &np->lowy, &np->highy);
 	np->temp1 = 1;
 }
