@@ -116,9 +116,9 @@ static INTBIG  io_gds_layerkey;				/* key for "IO_gds_layer" */
 static INTBIG  io_gds_exportlayer;			/* layer for export text */
 
 /* working memory for "io_gds_bgnstr()" */
-static INTBIG  io_gdsfacetnamecount;
-static INTBIG  io_gdsfacetnametotal = 0;
-static CHAR  **io_gdsfacetnames;
+static INTBIG  io_gdscellnamecount;
+static INTBIG  io_gdscellnametotal = 0;
+static CHAR  **io_gdscellnames;
 
 /* prototypes for local routines */
 static void  io_gdswritecell(NODEPROTO*);
@@ -158,11 +158,11 @@ void io_freegdsoutmemory(void)
 	if (io_dbuffer != 0) efree((CHAR *)io_dbuffer);
 	if (io_empty != 0) efree((CHAR *)io_empty);
 
-	for(i=0; i<io_gdsfacetnametotal; i++)
-		if (io_gdsfacetnames[i] != 0)
-			efree((CHAR *)io_gdsfacetnames[i]);
-	if (io_gdsfacetnametotal > 0)
-		efree((CHAR *)io_gdsfacetnames);
+	for(i=0; i<io_gdscellnametotal; i++)
+		if (io_gdscellnames[i] != 0)
+			efree((CHAR *)io_gdscellnames[i]);
+	if (io_gdscellnametotal > 0)
+		efree((CHAR *)io_gdscellnames);
 }
 
 /*
@@ -180,7 +180,7 @@ BOOLEAN io_writegdslibrary(LIBRARY *lib)
 	CHAR *name, *truename, *val, *pinval, *textval;
 	REGISTER NODEPROTO *np;
 	REGISTER VARIABLE *var;
-	REGISTER INTBIG i;
+	REGISTER INTBIG i, varlen;
 	REGISTER LAYERNUMBERS *layernumbers;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER LIBRARY *olib;
@@ -189,13 +189,13 @@ BOOLEAN io_writegdslibrary(LIBRARY *lib)
 	/* create the proper disk file for the GDS II */
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr(_("Must be editing a facet to generate GDS output"));
+		ttyputerr(_("Must be editing a cell to generate GDS output"));
 		return(TRUE);
 	}
 
 	/* construct file name */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, lib->curnodeproto->cell->cellname);
+	addstringtoinfstr(infstr, lib->curnodeproto->protoname);
 	addstringtoinfstr(infstr, x_(".gds"));
 	(void)allocstring(&name, truepath(returninfstr(infstr)), el_tempcluster);
 
@@ -236,9 +236,10 @@ BOOLEAN io_writegdslibrary(LIBRARY *lib)
 		{
 			layernumbers = (LAYERNUMBERS *)emalloc(tech->layercount * (sizeof (LAYERNUMBERS)), io_tool->cluster);
 			if (layernumbers == 0) return(TRUE);
+			varlen = getlength(var);
 			for(i=0; i<tech->layercount; i++)
 			{
-				if ((var->type&VTYPE) == VSTRING)
+				if ((var->type&VTYPE) == VSTRING && i < varlen)
 				{
 					io_gds_parselayerstring(((CHAR **)tech->temp1)[i], &val, &pinval, &textval);
 					layernumbers[i].layernumber = myatoi(val);
@@ -332,7 +333,7 @@ void io_gdswritecell(NODEPROTO *np)
 		if (subnt->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (subnt->cell == np->cell) continue;
+		if (isiconof(subnt, np)) continue;
 
 		/* convert body cells to contents cells */
 		onp = contentsview(subnt);
@@ -442,7 +443,7 @@ void io_gdswritecell(NODEPROTO *np)
 			subno->temp1 = 0;
 	}
 
-	/* write all nodes in the facet */
+	/* write all nodes in the cell */
 	for(subno = np->firstnodeinst; subno != NONODEINST; subno = subno->nextnodeinst)
 	{
 		if (subno->temp1 != 0) continue;
@@ -532,7 +533,7 @@ void io_gdswritecell(NODEPROTO *np)
 		} else
 		{
 			/* ignore recursive references (showing icon in contents) */
-			if (subno->proto->cell == np->cell) continue;
+			if (isiconof(subno->proto, np)) continue;
 
 			/* write a call to a cell */
 #ifdef OLDGDS
@@ -660,9 +661,7 @@ void io_gdswritecell(NODEPROTO *np)
 				angle = (3600 - angle)%3600;
 			}
 			io_gds_header(HDR_STRANS, transvalue);
-#if 1		/* reduce the size of export text by a factor of 2 */
 			io_gds_mag(0.5);
-#endif
 			io_gds_angle(angle);
 			io_gds_int2(12);
 			io_gds_int2(HDR_XY);
@@ -686,7 +685,7 @@ void io_gdswritecell(NODEPROTO *np)
 	}
 
 	if ((io_gds_outputstate[0]&GDSOUTMERGE) != 0)
-		mrgdonefacet(io_gds_write_polygon);
+		mrgdonecell(io_gds_write_polygon);
 
 	io_gds_header(HDR_ENDSTR, 0);
 }
@@ -885,7 +884,7 @@ void io_gds_bgnlib(NODEPROTO *np)
 	io_gds_header(HDR_BGNLIB, 0);
 	io_gds_date((time_t *)&np->creationdate);
 	io_gds_date((time_t *)&np->revisiondate);
-	(void)estrcpy(name, np->cell->cellname);
+	(void)estrcpy(name, np->protoname);
 	io_gds_name(HDR_LIBNAME, io_gds_makename(name), HDR_M_ASCII);
 	io_gds_int2(HDR_N_UNITS);
 	io_gds_int2(HDR_UNITS);
@@ -898,7 +897,7 @@ CHAR *io_gds_uniquename(NODEPROTO *np)
 	REGISTER INTBIG len, index, i, newtotal;
 	REGISTER CHAR **newlist;
 
-	(void)estrcpy(name, io_gds_makename(np->cell->cellname));
+	(void)estrcpy(name, io_gds_makename(np->protoname));
 	if (np->newestversion != np)
 	{
 		len = strlen(name);
@@ -909,30 +908,30 @@ CHAR *io_gds_uniquename(NODEPROTO *np)
 	len = strlen(name);
 	for(index = 1; ; index++)
 	{
-		for(i=0; i<io_gdsfacetnamecount; i++)
-			if (namesame(name, io_gdsfacetnames[i]) == 0) break;
-		if (i >= io_gdsfacetnamecount) break;
+		for(i=0; i<io_gdscellnamecount; i++)
+			if (namesame(name, io_gdscellnames[i]) == 0) break;
+		if (i >= io_gdscellnamecount) break;
 		sprintf(&name[len], x_("_%ld"), index);
 	}
 
 	/* add this name to the list */
-	if (io_gdsfacetnamecount >= io_gdsfacetnametotal)
+	if (io_gdscellnamecount >= io_gdscellnametotal)
 	{
-		newtotal = io_gdsfacetnametotal * 2;
-		if (io_gdsfacetnamecount >= newtotal) newtotal = io_gdsfacetnamecount + 10;
+		newtotal = io_gdscellnametotal * 2;
+		if (io_gdscellnamecount >= newtotal) newtotal = io_gdscellnamecount + 10;
 		newlist = (CHAR **)emalloc(newtotal * (sizeof (CHAR *)), io_tool->cluster);
 		if (newlist == 0) return("");
-		for(i=0; i<io_gdsfacetnametotal; i++)
-			newlist[i] = io_gdsfacetnames[i];
-		for(i=io_gdsfacetnametotal; i<newtotal; i++) newlist[i] = 0;
-		if (io_gdsfacetnametotal > 0) efree((CHAR *)io_gdsfacetnames);
-		io_gdsfacetnames = newlist;
-		io_gdsfacetnametotal = newtotal;
+		for(i=0; i<io_gdscellnametotal; i++)
+			newlist[i] = io_gdscellnames[i];
+		for(i=io_gdscellnametotal; i<newtotal; i++) newlist[i] = 0;
+		if (io_gdscellnametotal > 0) efree((CHAR *)io_gdscellnames);
+		io_gdscellnames = newlist;
+		io_gdscellnametotal = newtotal;
 	}
-	if (io_gdsfacetnames[io_gdsfacetnamecount] != 0)
-		efree((CHAR *)io_gdsfacetnames[io_gdsfacetnamecount]);
-	allocstring(&io_gdsfacetnames[io_gdsfacetnamecount], name, io_tool->cluster);
-	io_gdsfacetnamecount++;
+	if (io_gdscellnames[io_gdscellnamecount] != 0)
+		efree((CHAR *)io_gdscellnames[io_gdscellnamecount]);
+	allocstring(&io_gdscellnames[io_gdscellnamecount], name, io_tool->cluster);
+	io_gdscellnamecount++;
 	return(name);
 }
 
@@ -1295,7 +1294,7 @@ static DIALOGITEM io_gdsoptionsdialogitems[] =
  /*  4 */ {0, {8,240,24,336}, MESSAGE, N_("GDS Layer(s):")},
  /*  5 */ {0, {8,340,24,444}, EDITTEXT, x_("")},
  /*  6 */ {0, {80,240,96,464}, CHECK, N_("Input Includes Text")},
- /*  7 */ {0, {104,240,120,464}, CHECK, N_("Input Expands Facets")},
+ /*  7 */ {0, {104,240,120,464}, CHECK, N_("Input Expands Cells")},
  /*  8 */ {0, {128,240,144,464}, CHECK, N_("Input Instantiates Arrays")},
  /*  9 */ {0, {176,240,192,464}, CHECK, N_("Output Merges Boxes")},
  /* 10 */ {0, {272,240,288,428}, MESSAGE, N_("Output Arc Conversion:")},
@@ -1319,7 +1318,7 @@ static DIALOG io_gdsoptionsdialog = {{50,75,395,581}, N_("GDS Options"), 0, 23,
 #define DGDO_LAYERLIST       3		/* Layer list (scroll list) */
 #define DGDO_NEWLAYER        5		/* New layer (edit text) */
 #define DGDO_IINCLUDETEXT    6		/* Input Includes Text (check) */
-#define DGDO_IEXPANDFACET    7		/* Input Expands Facets (check) */
+#define DGDO_IEXPANDCELL     7		/* Input Expands Cells (check) */
 #define DGDO_IINSTARRAY      8		/* Input Instantiates Arrays (check) */
 #define DGDO_OMERGEBOX       9		/* Output Merges Boxes (check) */
 #define DGDO_OARCANGLE      12		/* Output Arc Angle (edit text) */
@@ -1334,7 +1333,7 @@ static DIALOG io_gdsoptionsdialog = {{50,75,395,581}, N_("GDS Options"), 0, 23,
 void io_gdsoptionsdlog(void)
 {
 	REGISTER INTBIG i, v, itemHit, *curstate, newres, newsag, numberschanged,
-		explayer;
+		explayer, varlen;
 	INTBIG arcres, arcsag, newstate[NUMIOSTATEBITWORDS];
 	CHAR buf[50], **layernumbers, **pinnumbers, **textnumbers, *val, *pinval, *textval;
 	REGISTER VARIABLE *gdsvar, *expvar;
@@ -1352,10 +1351,11 @@ void io_gdsoptionsdlog(void)
 	if (textnumbers == 0) return;
 	gdsvar = getval((INTBIG)el_curtech, VTECHNOLOGY, -1, x_("IO_gds_layer_numbers"));
 	if (gdsvar != NOVARIABLE && (gdsvar->type&VISARRAY) == 0) gdsvar = NOVARIABLE;
+	if (gdsvar != NOVARIABLE) varlen = getlength(gdsvar);
 	for(i=0; i<el_curtech->layercount; i++)
 	{
 		val = pinval = textval = x_("");
-		if (gdsvar != NOVARIABLE)
+		if (gdsvar != NOVARIABLE && i < varlen)
 		{
 			if ((gdsvar->type&VTYPE) == VSTRING)
 			{
@@ -1394,7 +1394,7 @@ void io_gdsoptionsdlog(void)
 	curstate = io_getstatebits();
 	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
 	if ((curstate[0]&GDSINTEXT) != 0) DiaSetControl(dia, DGDO_IINCLUDETEXT, 1);
-	if ((curstate[0]&GDSINEXPAND) != 0) DiaSetControl(dia, DGDO_IEXPANDFACET, 1);
+	if ((curstate[0]&GDSINEXPAND) != 0) DiaSetControl(dia, DGDO_IEXPANDCELL, 1);
 	if ((curstate[0]&GDSINARRAYS) != 0) DiaSetControl(dia, DGDO_IINSTARRAY, 1);
 	if ((curstate[0]&GDSOUTMERGE) != 0) DiaSetControl(dia, DGDO_OMERGEBOX, 1);
 	if ((curstate[0]&GDSINIGNOREUKN) != 0) DiaSetControl(dia, DGDO_IIGNOREUNKNOWN, 1);
@@ -1410,7 +1410,7 @@ void io_gdsoptionsdlog(void)
 	{
 		itemHit = DiaNextHit(dia);
 		if (itemHit == OK || itemHit == CANCEL) break;
-		if (itemHit == DGDO_IINCLUDETEXT || itemHit == DGDO_IEXPANDFACET ||
+		if (itemHit == DGDO_IINCLUDETEXT || itemHit == DGDO_IEXPANDCELL ||
 			itemHit == DGDO_IINSTARRAY || itemHit == DGDO_OMERGEBOX ||
 			itemHit == DGDO_IIGNOREUNKNOWN || itemHit == DGDO_WRITEEXPORTPIN ||
 			itemHit == DGDO_OUPPERCASE)
@@ -1461,7 +1461,7 @@ void io_gdsoptionsdlog(void)
 	{
 		if (DiaGetControl(dia, DGDO_IINCLUDETEXT) != 0) newstate[0] |= GDSINTEXT; else
 			newstate[0] &= ~GDSINTEXT;
-		if (DiaGetControl(dia, DGDO_IEXPANDFACET) != 0) newstate[0] |= GDSINEXPAND; else
+		if (DiaGetControl(dia, DGDO_IEXPANDCELL) != 0) newstate[0] |= GDSINEXPAND; else
 			newstate[0] &= ~GDSINEXPAND;
 		if (DiaGetControl(dia, DGDO_IINSTARRAY) != 0) newstate[0] |= GDSINARRAYS; else
 			newstate[0] &= ~GDSINARRAYS;
