@@ -92,14 +92,14 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 	np = lib->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("No current facet to plot"));
+		ttyputerr(_("No current cell to plot"));
 		return(TRUE);
 	}
 
-	/* cannot write text-only facets */
+	/* cannot write text-only cells */
 	if ((np->cellview->viewstate&TEXTVIEW) != 0)
 	{
-		ttyputerr(_("Cannot write textual facets"));
+		ttyputerr(_("Cannot write textual cells"));
 		return(TRUE);
 	}
 
@@ -111,11 +111,11 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 	/* create the output file */
 	if (io_hpgl2 != 0)
 	{
-		(void)esnprintf(file, 100, x_("%s.hpgl2"), np->cell->cellname);
+		(void)esnprintf(file, 100, x_("%s.hpgl2"), np->protoname);
 		io_hpout = xcreate(file, io_filetypehpgl2, _("HPGL/2 File"), &truename);
 	} else
 	{
-		(void)esnprintf(file, 100, x_("%s.hpgl"), np->cell->cellname);
+		(void)esnprintf(file, 100, x_("%s.hpgl"), np->protoname);
 		io_hpout = xcreate(file, io_filetypehpgl, _("HPGL File"), &truename);
 	}
 	if (io_hpout == NULL)
@@ -228,7 +228,7 @@ BOOLEAN io_writehpgllibrary(LIBRARY *lib)
 	/* handle merged rectangles */
 	if (io_hpmerging != 0)
 	{
-		mrgdonefacet(io_hpwritepolygon);
+		mrgdonecell(io_hpwritepolygon);
 		mrgterm();
 	}
 
@@ -572,8 +572,8 @@ static CHAR *io_hppendata[] =
 	x_("0026	10	2	1	0	0	cyan"),
 	x_("0032	11	0	1	0	0	magenta"),
 	x_("0036	12	0	1	0	0	yellow"),
-	x_("0042	13	0	0	0	0	facet and port names"),
-	x_("0046	1	0	0	0	0	facet outline"),
+	x_("0042	13	0	0	0	0	cell and port names"),
+	x_("0046	1	0	0	0	0	cell outline"),
 	x_("0052	0	0	0	0	0	window border color - never used"),
 	x_("0056	0	0	0	0	0	highlighted window border color - never used"),
 	x_("0062	0	0	0	0	0	menu border color - never used"),
