@@ -80,15 +80,15 @@ static NODEPROTO *io_lefgetnode(INTBIG lfunc);
 static BOOLEAN    io_lefignoretosemicolon(FILE *f, CHAR *command);
 static void       io_lefkillpath(LEFPATH *lp);
 static LEFPATH   *io_lefnewpath(void);
-static PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *thename);
+static PORTPROTO *io_lefnewport(NODEPROTO *cell, NODEINST *ni, PORTPROTO *pp, CHAR *thename);
 static void       io_lefparselayer(CHAR *layername, INTBIG *arcfunc, INTBIG *layerfunc);
 static BOOLEAN    io_lefreadfile(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_lefreadlayer(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_lefreadmacro(FILE *f, LIBRARY *lib);
 static BOOLEAN    io_lefreadvia(FILE *f, LIBRARY *lib);
-static BOOLEAN    io_lefreadobs(FILE *f, NODEPROTO *facet);
-static BOOLEAN    io_lefreadpin(FILE *f, NODEPROTO *facet);
-static BOOLEAN    io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbits);
+static BOOLEAN    io_lefreadobs(FILE *f, NODEPROTO *cell);
+static BOOLEAN    io_lefreadpin(FILE *f, NODEPROTO *cell);
+static BOOLEAN    io_lefreadport(FILE *f, NODEPROTO *cell, CHAR *portname, INTBIG portbits);
 static void       io_leffreevias(void);
 
 /*
@@ -361,7 +361,7 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 	REGISTER INTBIG ox, oy, blx, bhx, bly, bhy, dx, dy;
 	INTBIG sx, sy;
 	float x, y;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER NODEINST *ni;
 	CHAR curkey[200];
 	REGISTER void *infstr;
@@ -376,10 +376,10 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 	addstringtoinfstr(infstr, cellname);
 	addstringtoinfstr(infstr, x_("{sk}"));
 	cellname = returninfstr(infstr);
-	facet = us_newnodeproto(cellname, lib);
-	if (facet == NONODEPROTO)
+	cell = us_newnodeproto(cellname, lib);
+	if (cell == NONODEPROTO)
 	{
-		ttyputerr(_("Cannot create facet '%s'"), cellname);
+		ttyputerr(_("Cannot create cell '%s'"), cellname);
 		return(TRUE);
 	}
 
@@ -430,18 +430,18 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 			oy = scalefromdispunit(y, DISPUNITMIC);
 			if (io_lefignoretosemicolon(f, x_("ORIGIN"))) return(TRUE);
 
-			/* create or move the facet-center node */
-			for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
-				if (ni->proto == gen_facetcenterprim) break;
+			/* create or move the cell-center node */
+			for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+				if (ni->proto == gen_cellcenterprim) break;
 			if (ni == NONODEINST)
 			{
-				defaultnodesize(gen_facetcenterprim, &sx, &sy);
+				defaultnodesize(gen_cellcenterprim, &sx, &sy);
 				blx = ox - sx/2;   bhx = blx + sx;
 				bly = oy - sy/2;   bhy = bly + sy;
-				ni = newnodeinst(gen_facetcenterprim, blx, bhx, bly, bhy, 0, 0, facet);
+				ni = newnodeinst(gen_cellcenterprim, blx, bhx, bly, bhy, 0, 0, cell);
 				if (ni == NONODEINST)
 				{
-					ttyputerr(_("Line %ld: Cannot create facet center node"), io_leflineno);
+					ttyputerr(_("Line %ld: Cannot create cell center node"), io_leflineno);
 					return(TRUE);
 				}
 				ni->userbits |= HARDSELECTN|NVISIBLEINSIDE;
@@ -493,13 +493,13 @@ BOOLEAN io_lefreadmacro(FILE *f, LIBRARY *lib)
 
 		if (namesame(key, x_("PIN")) == 0)
 		{
-			if (io_lefreadpin(f, facet)) return(TRUE);
+			if (io_lefreadpin(f, cell)) return(TRUE);
 			continue;
 		}
 
 		if (namesame(key, x_("OBS")) == 0)
 		{
-			if (io_lefreadobs(f, facet)) return(TRUE);
+			if (io_lefreadobs(f, cell)) return(TRUE);
 			continue;
 		}
 
@@ -624,7 +624,7 @@ BOOLEAN io_lefreadvia(FILE *f, LIBRARY *lib)
 	return(FALSE);
 }
 
-BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
+BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *cell)
 {
 	REGISTER CHAR *key;
 	REGISTER INTBIG portbits, usebits;
@@ -704,7 +704,7 @@ BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 		if (namesame(key, x_("PORT")) == 0)
 		{
 			if (usebits != 0) portbits = usebits;
-			if (io_lefreadport(f, facet, pinname, portbits))
+			if (io_lefreadport(f, cell, pinname, portbits))
 				return(TRUE);
 			continue;
 		}
@@ -715,7 +715,7 @@ BOOLEAN io_lefreadpin(FILE *f, NODEPROTO *facet)
 	return(FALSE);
 }
 
-BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbits)
+BOOLEAN io_lefreadport(FILE *f, NODEPROTO *cell, CHAR *portname, INTBIG portbits)
 {
 	REGISTER CHAR *key;
 	REGISTER INTBIG i, j, lx, hx, ly, hy, intx, inty, first,
@@ -827,7 +827,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbit
 			/* make the pin */
 			if (hx < lx) { j = hx;   hx = lx;   lx = j; }
 			if (hy < ly) { j = hy;   hy = ly;   ly = j; }
-			ni = newnodeinst(plnp, lx, hx, ly, hy, 0, 0, facet);
+			ni = newnodeinst(plnp, lx, hx, ly, hy, 0, 0, cell);
 			if (ni == NONODEINST)
 			{
 				ttyputerr(_("Line %ld: Cannot create pin for RECT"), io_leflineno);
@@ -839,7 +839,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbit
 			{
 				/* create the port on the first pin */
 				first = 0;
-				pp = io_lefnewport(facet, ni, plnp->firstportproto, portname);
+				pp = io_lefnewport(cell, ni, plnp->firstportproto, portname);
 				pp->userbits = (pp->userbits & ~STATEBITS) | portbits;
 			}
 			continue;
@@ -970,7 +970,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbit
 			defaultnodesize(pin, &sx, &sy);
 			lx = intx - sx / 2;   hx = lx + sx;
 			ly = inty - sy / 2;   hy = ly + sy;
-			ni = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
+			ni = newnodeinst(pin, lx, hx, ly, hy, 0, 0, cell);
 			if (ni == NONODEINST)
 			{
 				ttyputerr(_("Line %ld: Cannot create VIA for PATH"), io_leflineno);
@@ -990,7 +990,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbit
 		for(i=0; i<2; i++)
 		{
 			if (lp->ni[i] != NONODEINST) continue;
-			sea = initsearch(lp->x[i], lp->x[i], lp->y[i], lp->y[i], facet);
+			sea = initsearch(lp->x[i], lp->x[i], lp->y[i], lp->y[i], cell);
 			for(;;)
 			{
 				geom = nextobject(sea);
@@ -1029,7 +1029,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbit
 			defaultnodesize(pin, &sx, &sy);
 			lx = lp->x[i] - sx / 2;   hx = lx + sx;
 			ly = lp->y[i] - sy / 2;   hy = ly + sy;
-			lp->ni[i] = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
+			lp->ni[i] = newnodeinst(pin, lx, hx, ly, hy, 0, 0, cell);
 			if (lp->ni[i] == NONODEINST)
 			{
 				ttyputerr(_("Line %ld: Cannot create pin for PATH"), io_leflineno);
@@ -1055,7 +1055,7 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbit
 	{
 		ai = newarcinst(lp->arc, lp->width, us_makearcuserbits(lp->arc),
 			lp->ni[0], lp->ni[0]->proto->firstportproto, lp->x[0], lp->y[0],
-				lp->ni[1], lp->ni[1]->proto->firstportproto, lp->x[1], lp->y[1], facet);
+				lp->ni[1], lp->ni[1]->proto->firstportproto, lp->x[1], lp->y[1], cell);
 		if (ai == NOARCINST)
 		{
 			ttyputerr(_("Line %ld: Cannot create arc for PATH"), io_leflineno);
@@ -1068,10 +1068,10 @@ BOOLEAN io_lefreadport(FILE *f, NODEPROTO *facet, CHAR *portname, INTBIG portbit
 }
 
 /*
- * Routine to create a port called "thename" on port "pp" of node "ni" in facet "facet".
+ * Routine to create a port called "thename" on port "pp" of node "ni" in cell "cell".
  * The name is modified if it already exists.
  */
-PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *thename)
+PORTPROTO *io_lefnewport(NODEPROTO *cell, NODEINST *ni, PORTPROTO *pp, CHAR *thename)
 {
 	REGISTER PORTPROTO *ppt;
 	REGISTER INTBIG i, leng;
@@ -1081,10 +1081,10 @@ PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *th
 	newname = 0;
 	for(i=0; ; i++)
 	{
-		ppt = getportproto(facet, portname);
+		ppt = getportproto(cell, portname);
 		if (ppt == NOPORTPROTO)
 		{
-			ppt = newportproto(facet, ni, pp, portname);
+			ppt = newportproto(cell, ni, pp, portname);
 			break;
 		}
 
@@ -1101,7 +1101,7 @@ PORTPROTO *io_lefnewport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *th
 	return(ppt);
 }
 
-BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
+BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *cell)
 {
 	REGISTER CHAR *key;
 	INTBIG lfunc, arcfunc;
@@ -1190,7 +1190,7 @@ BOOLEAN io_lefreadobs(FILE *f, NODEPROTO *facet)
 			/* make the pin */
 			if (hx < lx) { j = hx;   hx = lx;   lx = j; }
 			if (hy < ly) { j = hy;   hy = ly;   ly = j; }
-			ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, facet);
+			ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, cell);
 			if (ni == NONODEINST)
 			{
 				ttyputerr(_("Line %ld: Cannot create node for RECT"), io_leflineno);
