@@ -42,9 +42,9 @@
 #include "efunction.h"
 
 /* prototypes for local routines */
-static void io_lefoutfacet(FILE *out, NODEPROTO *facet, BOOLEAN top, XARRAY trans);
+static void io_lefoutcell(FILE *out, NODEPROTO *cell, BOOLEAN top, XARRAY trans);
 static CHAR *io_lefoutlayername(TECHNOLOGY *tech, INTBIG layer);
-static void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore);
+static void io_lefoutspread(FILE *out, NODEPROTO *cell, NETWORK *net, NODEINST *ignore);
 static void io_lefwritepoly(FILE *out, POLYGON *poly, XARRAY trans, TECHNOLOGY *tech);
 
 static CHAR io_lefoutcurlayer[200];
@@ -69,10 +69,10 @@ BOOLEAN io_writeleflibrary(LIBRARY *lib)
 	np = lib->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("Must be editing a facet to generate LEF output"));
+		ttyputerr(_("Must be editing a cell to generate LEF output"));
 		return(TRUE);
 	}
-	(void)estrcpy(file, np->cell->cellname);
+	(void)estrcpy(file, np->protoname);
 	(void)estrcat(file, x_(".lef"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypelef, _("LEF File"), &truename);
@@ -126,13 +126,13 @@ BOOLEAN io_writeleflibrary(LIBRARY *lib)
 	xprintf(io_fileout, x_("  TYPE MASTERSLICE ;\n"));
 	xprintf(io_fileout, x_("END NDIFF\n\n"));
 
-	/* write main facet header */
-	xprintf(io_fileout, x_("MACRO %s\n"), np->cell->cellname);
-	xprintf(io_fileout, x_("  FOREIGN %s ;\n"), np->cell->cellname);
+	/* write main cell header */
+	xprintf(io_fileout, x_("MACRO %s\n"), np->protoname);
+	xprintf(io_fileout, x_("  FOREIGN %s ;\n"), np->protoname);
 	xs = scaletodispunit(np->highx-np->lowx, DISPUNITMIC);
 	ys = scaletodispunit(np->highy-np->lowy, DISPUNITMIC);
 	xprintf(io_fileout, x_("  SIZE %g BY %g ;\n"), xs, ys);
-	xprintf(io_fileout, x_("  SITE %s ;\n"), np->cell->cellname);
+	xprintf(io_fileout, x_("  SITE %s ;\n"), np->protoname);
 
 	/* write all of the metal geometry and ports */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst) ni->temp1 = 0;
@@ -174,11 +174,11 @@ BOOLEAN io_writeleflibrary(LIBRARY *lib)
 	/* write the obstructions (all of the metal) */
 	xprintf(io_fileout, x_("\n  OBS\n"));
 	io_lefoutcurlayer[0] = 0;
-	io_lefoutfacet(io_fileout, np, TRUE, el_matid);
+	io_lefoutcell(io_fileout, np, TRUE, el_matid);
 	xprintf(io_fileout, x_("  END\n\n"));
 
 	/* clean up */
-	xprintf(io_fileout, x_("END %s\n\n"), np->cell->cellname);
+	xprintf(io_fileout, x_("END %s\n\n"), np->protoname);
 	xprintf(io_fileout, x_("END LIBRARY\n"));
 	xclose(io_fileout);
 
@@ -188,10 +188,10 @@ BOOLEAN io_writeleflibrary(LIBRARY *lib)
 }
 
 /*
- * Routine to write all geometry in facet "facet" that is on network "net"
+ * Routine to write all geometry in cell "cell" that is on network "net"
  * to file "out".  Does not write node "ignore".
  */
-void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore)
+void io_lefoutspread(FILE *out, NODEPROTO *cell, NETWORK *net, NODEINST *ignore)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -202,7 +202,7 @@ void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore
 
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, io_tool->cluster);
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex == 0) continue;
 		if (ni == ignore) continue;
@@ -225,7 +225,7 @@ void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore
 	}
 
 	/* write metal layers for all arcs */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->network != net) continue;
 		ai->temp1 = 1;
@@ -239,10 +239,10 @@ void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore
 }
 
 /*
- * Routine to write all geometry in facet "facet" to file "out".  The
- * hierarchy is flattened.  The current facet is transformed by "trans".
+ * Routine to write all geometry in cell "cell" to file "out".  The
+ * hierarchy is flattened.  The current cell is transformed by "trans".
  */
-void io_lefoutfacet(FILE *out, NODEPROTO *facet, BOOLEAN top, XARRAY trans)
+void io_lefoutcell(FILE *out, NODEPROTO *cell, BOOLEAN top, XARRAY trans)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -252,16 +252,16 @@ void io_lefoutfacet(FILE *out, NODEPROTO *facet, BOOLEAN top, XARRAY trans)
 
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, io_tool->cluster);
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (top && ni->temp1 != 0) continue;
 		makerot(ni, localrot);   transmult(localrot, trans, thisrot);
 		if (ni->proto->primindex == 0)
 		{
-			/* subfacet: recurse */
+			/* subcell: recurse */
 			maketrans(ni, localtran);
 			transmult(localtran, thisrot, subrot);
-			io_lefoutfacet(out, ni->proto, FALSE, subrot);
+			io_lefoutcell(out, ni->proto, FALSE, subrot);
 		} else
 		{
 			/* primitive: find the metal layers */
@@ -275,7 +275,7 @@ void io_lefoutfacet(FILE *out, NODEPROTO *facet, BOOLEAN top, XARRAY trans)
 	}
 
 	/* write metal layers for all arcs */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (top && ai->temp1 != 0) continue;
 		tot = arcpolys(ai, NOWINDOWPART);
