@@ -72,7 +72,7 @@ static struct
 };
 
 /* prototypes for local routines */
-static INTBIG io_l_writefacet(NODEPROTO*);
+static INTBIG io_l_writecell(NODEPROTO*);
 static CHAR *io_l_name(NODEINST*);
 static CHAR *io_l_fixname(CHAR*);
 static INTBIG io_l_nodetype(NODEINST*);
@@ -87,10 +87,10 @@ BOOLEAN io_writellibrary(LIBRARY *lib)
 	/* create the proper disk file for the L */
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr(_("Must be editing a facet to generate L output"));
+		ttyputerr(_("Must be editing a cell to generate L output"));
 		return(TRUE);
 	}
-	(void)estrcpy(file, lib->curnodeproto->cell->cellname);
+	(void)estrcpy(file, lib->curnodeproto->protoname);
 	(void)estrcat(file, x_(".L"));
 	name = truepath(file);
 	io_fileout = xcreate(name, io_filetypel, _("L File"), &truename);
@@ -106,7 +106,7 @@ BOOLEAN io_writellibrary(LIBRARY *lib)
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
-	if (io_l_writefacet(lib->curnodeproto) != 0)
+	if (io_l_writecell(lib->curnodeproto) != 0)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	/* clean up */
@@ -119,9 +119,9 @@ BOOLEAN io_writellibrary(LIBRARY *lib)
 }
 
 /*
- * Routine to write "L" for facet "np".  Returns nonzero if back-annotation was added.
+ * Routine to write "L" for cell "np".  Returns nonzero if back-annotation was added.
  */
-INTBIG io_l_writefacet(NODEPROTO *np)
+INTBIG io_l_writecell(NODEPROTO *np)
 {
 	REGISTER NODEINST *subno, *oni;
 	REGISTER ARCINST *subar, *oar;
@@ -136,7 +136,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	INTBIG xpos, ypos, len, wid, lx, hx, ly, hy;
 	REGISTER ARCPROTO **aplist;
 
-	/* if there are any sub-facets that have not been written, write them */
+	/* if there are any sub-cells that have not been written, write them */
 	backannotate = 0;
 	for(subno = np->firstnodeinst; subno != NONODEINST; subno = subno->nextnodeinst)
 	{
@@ -144,30 +144,30 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		if (subnt->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (subnt->cell == np->cell) continue;
+		if (isiconof(subnt, np)) continue;
 
-		/* convert body facets to contents facets */
+		/* convert body cells to contents cells */
 		onp = contentsview(subnt);
 		if (onp != NONODEPROTO) subnt = onp;
 
-		/* don't recurse if this facet has already been written */
+		/* don't recurse if this cell has already been written */
 		if (subnt->temp1 != 0) continue;
 
 		/* recurse to the bottom */
-		if (io_l_writefacet(subnt) != 0) backannotate = 1;
+		if (io_l_writecell(subnt) != 0) backannotate = 1;
 	}
 	np->temp1 = 1;
 
 	/* make sure that all nodes have names on them */
 	if (asktool(net_tool, x_("name-nodes"), (INTBIG)np) != 0) backannotate++;
 
-	/* write the facet header */
+	/* write the cell header */
 	xprintf(io_fileout, x_("\n"));
 	if (np->cellview == el_layoutview) xprintf(io_fileout, x_("LAYOUT "));
 	if (np->cellview == el_schematicview) xprintf(io_fileout, x_("SCHEMATIC "));
 	if (np->cellview == el_iconview) xprintf(io_fileout, x_("ICON "));
 	if (np->cellview == el_skeletonview) xprintf(io_fileout, x_("BBOX "));
-	xprintf(io_fileout, x_("CELL %s ( )\n{\n"), io_l_fixname(np->cell->cellname));
+	xprintf(io_fileout, x_("CELL %s ( )\n{\n"), io_l_fixname(np->protoname));
 
 	/* write the bounding box */
 	xprintf(io_fileout, x_("#bbox: ll= (%s,%s) ur= (%s,%s)\n"),
@@ -197,7 +197,7 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 	}
 	xprintf(io_fileout, x_("\n"));
 
-	/* number all components in the facet */
+	/* number all components in the cell */
 	i = 1;
 	for(subno = np->firstnodeinst; subno != NONODEINST; subno = subno->nextnodeinst)
 		subno->temp1 = i++;
@@ -209,16 +209,16 @@ INTBIG io_l_writefacet(NODEPROTO *np)
 		subnt = subno->proto;
 
 		/* determine type of component */
-		type = subnt->primname;
+		type = subnt->protoname;
 		if (subnt->primindex == 0)
 		{
 			/* ignore recursive references (showing icon in contents) */
-			if (subnt->cell == np->cell) continue;
+			if (isiconof(subnt, np)) continue;
 
-			/* convert body facets to contents facets */
+			/* convert body cells to contents cells */
 			onp = contentsview(subnt);
 			if (onp != NONODEPROTO) subnt = onp;
-			type = subnt->cell->cellname;
+			type = subnt->protoname;
 			xprintf(io_fileout, x_("\tINST %s %s"), type, io_l_name(subno));
 		} else
 		{
@@ -491,7 +491,7 @@ CHAR *io_l_fixname(CHAR *name)
  * Routine to determine the type of node "ni".  Returns:
  *    TRUEPIN    if a true pin (exactly two connections)
  *    TRANSISTOR if a transistor
- *    INSTANCE   if a facet instance
+ *    INSTANCE   if a cell instance
  *    OTHERNODE  otherwise.
  */
 INTBIG io_l_nodetype(NODEINST *ni)
