@@ -291,8 +291,8 @@ static void    io_pscircle(INTBIG, INTBIG, INTBIG, INTBIG);
 static void    io_psdisc(INTBIG, INTBIG, INTBIG, INTBIG, GRAPHICS*);
 static void    io_psdot(INTBIG, INTBIG);
 static void    io_psdumpcontents(NODEPROTO *np);
-static void    io_psdumpfacets(NODEPROTO *np);
-static CHAR   *io_psfacetname(NODEPROTO *np);
+static void    io_psdumpcells(NODEPROTO *np);
+static CHAR   *io_pscellname(NODEPROTO *np);
 static void    io_psline(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static CHAR    io_pspattern(GRAPHICS*);
 static void    io_pspoly(POLYGON*, WINDOWPART*);
@@ -303,7 +303,7 @@ static void    io_pssendfiletoprinter(CHAR *file);
 static void    io_pstext(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, CHAR*, UINTBIG*);
 static INTBIG  io_pstruefontsize(INTBIG font, WINDOWPART *w, TECHNOLOGY *tech);
 static void    io_pswriteexplorer(WINDOWPART *win, BOOLEAN printit);
-static BOOLEAN io_pswritefacet(NODEPROTO*, CHAR*, BOOLEAN);
+static BOOLEAN io_pswritecell(NODEPROTO*, CHAR*, BOOLEAN);
 static void    io_psxform(INTBIG, INTBIG, INTBIG*, INTBIG*);
 
 /*
@@ -356,15 +356,15 @@ BOOLEAN io_writepostscriptlibrary(LIBRARY *lib, BOOLEAN printit)
 			io_pswriteexplorer(el_curwindowpart, printit);
 			return(TRUE);
 		}
-		ttyputerr(_("No current facet to plot"));
+		ttyputerr(_("No current cell to plot"));
 		return(TRUE);
 	}
 
-	/* just write the current facet if no synchronization needed */
+	/* just write the current cell if no synchronization needed */
 	if (synchother == 0)
-		return(io_pswritefacet(np, 0, printit));
+		return(io_pswritecell(np, 0, printit));
 
-	/* synchronize all facets */
+	/* synchronize all cells */
 	numsyncs = 0;
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -380,17 +380,17 @@ BOOLEAN io_writepostscriptlibrary(LIBRARY *lib, BOOLEAN printit)
 			if (np->revisiondate <= mdate)
 			{
 				/*
-				 * facet revision date is not newer than last PostScript output date
+				 * cell revision date is not newer than last PostScript output date
 				 * ignore writing this file if it already exists
 				 */
 				filestatus = fileexistence((CHAR *)var->addr);
 				if (filestatus == 1 || filestatus == 3) continue;
 			}
 		}
-		if (io_pswritefacet(np, (CHAR *)var->addr, FALSE)) return(TRUE);
+		if (io_pswritecell(np, (CHAR *)var->addr, FALSE)) return(TRUE);
 		numsyncs++;
 
-		/* this is tricky: because the "setvalkey" modifies the facet, the date must be set by hand */
+		/* this is tricky: because the "setvalkey" modifies the cell, the date must be set by hand */
 		(void)setvalkey((INTBIG)np, VNODEPROTO, io_postscriptfiledatekey,
 			(INTBIG)np->revisiondate, VINTEGER);
 		vardate = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER, io_postscriptfiledatekey);
@@ -437,7 +437,7 @@ void io_pswriteexplorer(WINDOWPART *win, BOOLEAN printit)
 
 	/* print the header */
 	io_pswrite(x_("%%!PS-Adobe-1.0\n"));
-	io_pswrite(x_("%%%%Title: Facet Explorer\n"));
+	io_pswrite(x_("%%%%Title: Cell Explorer\n"));
 	io_pswrite(x_("/Times-Roman findfont 10 scalefont setfont\n"));
 	io_pswrite(x_("/Drawline {\n"));
 	io_pswrite(x_("    newpath moveto lineto stroke} def\n"));
@@ -484,7 +484,7 @@ void io_pswriteexplorer(WINDOWPART *win, BOOLEAN printit)
 		if (ypos == pagehei - topmargin)
 		{
 			infstr = initinfstr();
-			formatinfstr(infstr, _("Facet Explorer    Page %ld"), page);
+			formatinfstr(infstr, _("Cell Explorer    Page %ld"), page);
 			header = returninfstr(infstr);
 
 			io_pswrite(x_("%ld %ld moveto "), pagewid/3, yposbox+fontHeight*2);
@@ -548,10 +548,10 @@ void io_pswriteexplorer(WINDOWPART *win, BOOLEAN printit)
 }
 
 /*
- * Routine to write the facet "np" to a PostScript file.  If "synchronize" is nonzero,
- * synchronize the facet with that file.  If "printit" is TRUE, queue this for print.
+ * Routine to write the cell "np" to a PostScript file.  If "synchronize" is nonzero,
+ * synchronize the cell with that file.  If "printit" is TRUE, queue this for print.
  */
-BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
+BOOLEAN io_pswritecell(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 {
 	CHAR file[100], *truename, *ptr;
 	INTBIG lx, hx, ly, hy, gridlx, gridly, gridx, gridy,
@@ -569,16 +569,16 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER void *infstr;
 
-	/* cannot write text-only facets */
+	/* cannot write text-only cells */
 	if ((np->cellview->viewstate&TEXTVIEW) != 0)
 	{
 		if (!printit)
 		{
-			ttyputerr(_("Cannot write textual facets"));
+			ttyputerr(_("Cannot write textual cells"));
 			return(TRUE);
 		}
 
-		/* print a textual facet */
+		/* print a textual cell */
 		estrcpy(file, x_("/tmp/ElectricPSOut.XXXXXX"));
 		io_psout = xcreate(file, io_filetypeps|FILETYPETEMPFILE, 0, &truename);
 		if (io_psout == NULL)
@@ -589,7 +589,7 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 
 		/* print the header */
 		infstr = initinfstr();
-		formatinfstr(infstr, _("Library: %s   Facet: %s\n"), np->cell->lib->libname,
+		formatinfstr(infstr, _("Library: %s   Cell: %s\n"), np->lib->libname,
 			describenodeproto(np));
 		xprintf(io_psout, returninfstr(infstr));
 
@@ -604,8 +604,8 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 		}
 		xprintf(io_psout, x_("\n\n\n"));
 
-		/* print the text of the facet */
-		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
+		/* print the text of the cell */
+		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_cell_message_key);
 		if (var != NOVARIABLE)
 		{
 			j = getlength(var);
@@ -728,13 +728,13 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 		io_psout = xcreate(file, io_filetypeps, 0, &truename);
 		if (io_psout == NULL)
 		{
-			ttyputerr(_("Cannot synchronize facet %s with file %s"),
+			ttyputerr(_("Cannot synchronize cell %s with file %s"),
 				describenodeproto(np), file);
 			return(TRUE);
 		}
 	} else
 	{
-		(void)esnprintf(file, 100, x_("%s.%s"), np->cell->cellname,
+		(void)esnprintf(file, 100, x_("%s.%s"), np->protoname,
 			epsformat ? x_("eps") : x_("ps"));
 		io_psout = xcreate(file, io_filetypeps, _("PostScript File"), &truename);
 		if (io_psout == NULL)
@@ -870,7 +870,7 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 	/* PostScript: add some debugging info */
 	if (np != NONODEPROTO)
 	{
-		io_pswrite(x_("%% facet dimensions: %ld wide x %ld high (database units)\n"),
+		io_pswrite(x_("%% cell dimensions: %ld wide x %ld high (database units)\n"),
 			np->highx-np->lowx, np->highy-np->lowy);
 		io_pswrite(x_("%% origin: %ld %ld\n"), np->lowx, np->lowy);
 	}
@@ -945,9 +945,9 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 
 	if (!hierpostscript)
 	{
-		/* flat PostScript: disable "tiny facet" removal */
+		/* flat PostScript: disable "tiny cell" removal */
 		oldoptions = us_useroptions;
-		us_useroptions |= DRAWTINYFACETS;
+		us_useroptions |= DRAWTINYCELLS;
 
 		/* count the number of polygons in the job */
 		io_pspolygoncount = 0;
@@ -986,7 +986,7 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 			(void)asktool(us_tool, x_("display-to-routine"), io_pspoly);
 		}
 
-		/* restore "tiny facet" removal option */
+		/* restore "tiny cell" removal option */
 		us_useroptions = oldoptions;
 	} else
 	{
@@ -1013,11 +1013,11 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 		/* count the number of symbols used by the code */
 		io_psopcount = 0;
 		io_psfake = TRUE;
-		io_psdumpfacets(el_curwindowpart->curnodeproto);
+		io_psdumpcells(el_curwindowpart->curnodeproto);
 		io_psfake = FALSE;
 		io_psgraphicsseencount = 0;
 
-		/* clear flags of which facets have been written */
+		/* clear flags of which cells have been written */
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			for(onp = lib->firstnodeproto; onp != NONODEPROTO; onp = onp->nextnodeproto)
 				onp->temp1 = 0;
@@ -1050,12 +1050,12 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 		io_psputheader(PSHEADERFPOLYGON);
 		io_psputheader(PSHEADERSTRING);
 
-		/* dump all necessary facets */
+		/* dump all necessary cells */
 		estrcpy(io_psprefix, x_("    "));
-		io_psdumpfacets(el_curwindowpart->curnodeproto);
+		io_psdumpcells(el_curwindowpart->curnodeproto);
 
-		/* dump the current facet */
-		io_pswrite(x_("\n%% Invocation of top-level facet\n"));
+		/* dump the current cell */
+		io_pswrite(x_("\n%% Invocation of top-level cell\n"));
 #ifdef DEBUGHIERPS
 		io_pswrite(x_("(FINISHED) dovmstats\n"));
 #else
@@ -1065,14 +1065,14 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 			{
 				io_whichlayer = io_nextplotlayer(i) + 1;
 				if (((BOOLEAN *)np->temp2)[io_whichlayer])
-					io_pswrite(x_("%s\n"), io_psfacetname(np));
+					io_pswrite(x_("%s\n"), io_pscellname(np));
 			}
 			io_whichlayer = 0;
 			if (((BOOLEAN *)np->temp2)[io_whichlayer])
-				io_pswrite(x_("%s\n"), io_psfacetname(np));
+				io_pswrite(x_("%s\n"), io_pscellname(np));
 		} else
 		{
-			io_pswrite(x_("%s\n"), io_psfacetname(np));
+			io_pswrite(x_("%s\n"), io_pscellname(np));
 		}
 #endif
 
@@ -1089,7 +1089,7 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 	/* draw the grid if requested */
 	if ((el_curwindowpart->state&(GRIDON|GRIDTOOSMALL)) == GRIDON)
 	{
-		lambda = np->cell->lib->lambda[np->tech->techindex];
+		lambda = np->lib->lambda[np->tech->techindex];
 		gridx = muldiv(el_curwindowpart->gridx, lambda, WHOLE);
 		gridy = muldiv(el_curwindowpart->gridy, lambda, WHOLE);
 		var = getvalkey((INTBIG)us_tool, VTOOL, VINTEGER, us_gridfloatskey);
@@ -1145,7 +1145,7 @@ BOOLEAN io_pswritefacet(NODEPROTO *np, CHAR *synchronize, BOOLEAN printit)
 	if (plotdates)
 	{
 		infstr = initinfstr();
-		formatinfstr(infstr, _("Facet: %s"), describenodeproto(np));
+		formatinfstr(infstr, _("Cell: %s"), describenodeproto(np));
 		io_pswrite(x_("%s%ld %ld "), io_psprefix, io_pswindow.uselx,
 			io_pswindow.usely + 2 * CORNERDATESIZE * PSSCALE);
 		io_pswritestring(returninfstr(infstr));
@@ -1224,16 +1224,16 @@ void io_pssendfiletoprinter(CHAR *file)
 }
 
 /*
- * Routine to determine the PostScript name of facet "np".
+ * Routine to determine the PostScript name of cell "np".
  */
-CHAR *io_psfacetname(NODEPROTO *np)
+CHAR *io_pscellname(NODEPROTO *np)
 {
 	REGISTER CHAR *ch;
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, x_("Facet_"));
-	addstringtoinfstr(infstr, np->cell->cellname);
+	addstringtoinfstr(infstr, x_("Cell_"));
+	addstringtoinfstr(infstr, np->protoname);
 	if (np->cellview != el_unknownview)
 	{
 		addtoinfstr(infstr, '_');
@@ -1252,9 +1252,9 @@ CHAR *io_psfacetname(NODEPROTO *np)
 }
 
 /*
- * Routine to recursively dump the contents of facet "np" and its contents.
+ * Routine to recursively dump the contents of cell "np" and its contents.
  */
-void io_psdumpfacets(NODEPROTO *np)
+void io_psdumpcells(NODEPROTO *np)
 {
 	REGISTER NODEINST *ni;
 	REGISTER INTBIG i;
@@ -1266,7 +1266,7 @@ void io_psdumpfacets(NODEPROTO *np)
 	{
 		if (ni->proto->primindex != 0) continue;
 		if ((ni->userbits&NEXPAND) == 0) continue;
-		io_psdumpfacets(ni->proto);
+		io_psdumpcells(ni->proto);
 		if (io_psusecolor && io_psfake)
 		{
 			for(i=0; i<=io_maxpslayer; i++)
@@ -1276,9 +1276,9 @@ void io_psdumpfacets(NODEPROTO *np)
 
 	if (!io_psfake)
 	{
-		io_pswrite(x_("\n%% Definition of facet %s\n"), describenodeproto(np));
+		io_pswrite(x_("\n%% Definition of cell %s\n"), describenodeproto(np));
 #ifdef DEBUGHIERPS
-		io_pswrite(x_("(%s) dovmstats\n"), np->cell->cellname);
+		io_pswrite(x_("(%s) dovmstats\n"), np->protoname);
 #endif
 	}
 	if (io_psusecolor)
@@ -1300,7 +1300,7 @@ void io_psdumpfacets(NODEPROTO *np)
 }
 
 /*
- * Routine to dump the contents of facet "np".
+ * Routine to dump the contents of cell "np".
  */
 void io_psdumpcontents(NODEPROTO *np)
 {
@@ -1316,11 +1316,11 @@ void io_psdumpcontents(NODEPROTO *np)
 
 	if (stopping(STOPREASONDECK)) return;
 	if (io_psfake) io_psopcount += 2; else
-		io_pswrite(x_("/%s {\n"), io_psfacetname(np));
+		io_pswrite(x_("/%s {\n"), io_pscellname(np));
 	(void)needstaticpolygon(&poly, 4, io_tool->cluster);
 	io_lastred = io_lastgreen = io_lastblue = -1;
 
-	/* first write calls to subfacets */
+	/* first write calls to subcells */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
@@ -1328,7 +1328,7 @@ void io_psdumpcontents(NODEPROTO *np)
 		if (io_psusecolor && !((BOOLEAN *)ni->proto->temp2)[io_whichlayer])
 			continue;
 
-		/* expanded: invoke lower level facet */
+		/* expanded: invoke lower level cell */
 		tx = (ni->lowx + ni->highx - ni->proto->lowx - ni->proto->highx)/2;
 		ty = (ni->lowy + ni->highy - ni->proto->lowy - ni->proto->highy)/2;
 		ptx = muldiv(tx, io_psmatrix[0][0], 65536) + muldiv(ty, io_psmatrix[1][0], 65536);
@@ -1339,7 +1339,7 @@ void io_psdumpcontents(NODEPROTO *np)
 			if (io_psfake) io_psopcount += 7; else
 			{
 				io_pswrite(x_("%s%ld %ld translate %s %ld %ld translate\n"),
-					io_psprefix, ptx, pty, io_psfacetname(ni->proto), -ptx, -pty);
+					io_psprefix, ptx, pty, io_pscellname(ni->proto), -ptx, -pty);
 			}
 		} else
 		{
@@ -1360,7 +1360,7 @@ void io_psdumpcontents(NODEPROTO *np)
 				if (ni->rotation != 0)
 					io_pswrite(x_(" %g rotate"), (float)ni->rotation/10.0f);
 				io_pswrite(x_(" %ld %ld translate\n"), -pcx, -pcy);
-				io_pswrite(x_("%s    %s\n"), io_psprefix, io_psfacetname(ni->proto));
+				io_pswrite(x_("%s    %s\n"), io_psprefix, io_pscellname(ni->proto));
 				io_pswrite(x_("%s%ld %ld translate"), io_psprefix, pcx, pcy);
 				if (ni->rotation != 0)
 					io_pswrite(x_(" %g rotate"), -(float)ni->rotation/10.0f);
@@ -1371,12 +1371,12 @@ void io_psdumpcontents(NODEPROTO *np)
 		}
 	}
 
-	/* now write primitives and unexpanded subfacets */
+	/* now write primitives and unexpanded subcells */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex == 0)
 		{
-			/* subfacet */
+			/* subcell */
 			if ((ni->userbits&NEXPAND) == 0)
 			{
 				if (io_psusecolor && io_psfake)
@@ -1441,7 +1441,7 @@ void io_psdumpcontents(NODEPROTO *np)
 		savepolyroutine = us_displayroutine;
 		us_displayroutine = io_pspoly;
 
-		/* write facet text */
+		/* write cell text */
 		us_drawnodeprotovariables(np, el_matid, el_curwindowpart, FALSE);
 
 		/* write port text */
@@ -1449,7 +1449,7 @@ void io_psdumpcontents(NODEPROTO *np)
 		{
 			makerot(pp->subnodeinst, trans);
 			us_writeprotoname(pp, LAYERA, trans, LAYERO,
-				el_colfacettxt, el_curwindowpart, 0, 0, 0, 0,
+				el_colcelltxt, el_curwindowpart, 0, 0, 0, 0,
 					(us_useroptions&PORTLABELS) >> PORTLABELSSH);
 			us_drawportprotovariables(pp, 1, trans, el_curwindowpart, FALSE);
 		}
@@ -1666,7 +1666,7 @@ INTBIG io_pstruefontsize(INTBIG font, WINDOWPART *w, TECHNOLOGY *tech)
 
 	/* detemine default, min, and max size of font */
 	if (w->curnodeproto == NONODEPROTO) lib = el_curlib; else
-		lib = w->curnodeproto->cell->lib;
+		lib = w->curnodeproto->lib;
 	lambda = lib->lambda[tech->techindex];
 	height = TXTGETQLAMBDA(font);
 	height = height * lambda / 4;
