@@ -196,22 +196,27 @@ static INTBIG       io_pscolor_numInstances = 0;
 static INTBIG       io_pscolor_cellnumber;
 static BOOLEAN      io_pscolor_curvewarning;
 static CHAR         io_pscolor_font[80];
+static INTBIG       io_pscolor_totalBoxes = 0;
 
 /* not used yet */
+#if 0
 static LINEL       *io_pscolor_horizsegs[MAXLAYERS];
 static OUTLINEL    *io_pscolor_flattenedoutline[MAXLAYERS];
-static INTBIG       io_pscolor_totalBoxes = 0;
+
+static LINEL       *io_pscolor_genSegments(BOXL *boxes, INTBIG dir);
+static int          io_pscolor_lineCompare(const void *a, const void *b);
+static INTBIG       io_pscolor_countBoxes(BOXL *boxes);
+static OUTLINEL    *io_pscolor_combineSegments(LINEL *horiz, LINEL *vert);
+static void         io_pscolor_checkOverlap(CELLL*, BOXL*, BOXL*, INTBIG);
+static void			io_pscolor_printBoxes(void);
+static void         io_pscolor_freeLine(LINEL*);
+#endif
 
 /* Function Prototypes */
 static void         io_pscolor_initICPlot(void);
 static void         io_pscolor_getLayerMap(TECHNOLOGY *tech);
 static void         io_pscolor_extractDatabase(NODEPROTO*);
 static void         io_pscolor_genOverlapShapesAfterFlattening(void);
-static LINEL       *io_pscolor_genSegments(BOXL *boxes, INTBIG dir);
-static int          io_pscolor_lineCompare(const void *a, const void *b);
-static INTBIG       io_pscolor_countBoxes(BOXL *boxes);
-static OUTLINEL    *io_pscolor_combineSegments(LINEL *horiz, LINEL *vert);
-static void         io_pscolor_checkOverlap(CELLL*, BOXL*, BOXL*, INTBIG);
 static void         io_pscolor_coaf1(BOXQUADTREE*, BOXQUADTREE*, INTBIG);
 static void         io_pscolor_coaf2(BOXQUADTREE*, BOXQUADTREE*, INTBIG);
 static void         io_pscolor_coaf3(BOXQUADTREE*, BOXQUADTREE*, INTBIG);
@@ -223,7 +228,6 @@ static void         io_pscolor_splitTree(INTBIG, BOXELEM*, BOXQUADTREE*, INTBIG,
 static void         io_pscolor_flatten(void);
 static void         io_pscolor_recursiveFlatten(CELLL*, float[]);
 static void         io_pscolor_writePS(NODEPROTO*, BOOLEAN, INTBIG, INTBIG, INTBIG);
-static void			io_pscolor_printBoxes(void);
 static void         io_pscolor_mergeBoxes(void);
 static INTBIG       io_pscolor_mergeBoxPair(BOXL*, BOXL*);
 static BOXL        *io_pscolor_copybox(BOXL*, float[]);
@@ -245,14 +249,13 @@ static void         io_pscolor_freeBox(BOXL*);
 static void         io_pscolor_freePoly(POLYL*);
 static void         io_pscolor_freeLabel(LABELL*);
 static void         io_pscolor_freeCellInst(CELLINSTL*);
-static void         io_pscolor_freeLine(LINEL*);
 static void         io_pscolor_plotPolygon(POLYGON *poly, CELLL *curCell);
 static INTBIG       io_pscolor_truefontsize(INTBIG font, TECHNOLOGY *tech);
 static int          io_pscolor_sortlayers(const void *e1, const void *e2);
 static void         io_pscolor_plotline(INTBIG layer, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG texture, CELLL *curCell);
 
 /*
- * Main entry point for color PostScript output.  The facet being written is "np".
+ * Main entry point for color PostScript output.  The cell being written is "np".
  * The size of the paper is "pagewid" wide and "pagehei" tall with a margin of
  * "pagemargin" (in 1/75 of an inch).  If "useplotter" is TRUE, this is an infinitely-tall
  * plotter, so height is not a consideration.  If "epsformat" is TRUE, write encapsulated
@@ -307,7 +310,7 @@ void io_pscolor_initICPlot(void)
 		io_pscolor_boxQuadTrees[i] = NULL;
 	}
 
-	/* mark all facets as "not written" */
+	/* mark all cells as "not written" */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
@@ -414,7 +417,7 @@ int io_pscolor_sortlayers(const void *e1, const void *e2)
 	return(1);
 }
 
-void io_pscolor_extractDatabase(NODEPROTO *facet)
+void io_pscolor_extractDatabase(NODEPROTO *cell)
 {
 	REGISTER NODEINST *ni;
 	REGISTER NODEPROTO *np;
@@ -431,8 +434,8 @@ void io_pscolor_extractDatabase(NODEPROTO *facet)
 	static POLYGON *poly = NOPOLYGON;
 	XARRAY trans;
 
-	/* check for subfacets that haven't been written yet */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* check for subcells that haven't been written yet */
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
 		if (ni->proto->temp1 != 0) continue;
@@ -452,10 +455,10 @@ void io_pscolor_extractDatabase(NODEPROTO *facet)
 	curCell->inst = NULL;
 	curCell->next = NULL;
 	io_pscolor_numCells++;
-	facet->temp1 = (INTBIG)curCell;
+	cell->temp1 = (INTBIG)curCell;
 
-	/* examine all nodes in the facet */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* examine all nodes in the cell */
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		np = ni->proto;
 		if (np->primindex == 0)
@@ -510,7 +513,7 @@ void io_pscolor_extractDatabase(NODEPROTO *facet)
 					curbox->pos[3] = ni->geom->highy;
 					curCell->box = io_pscolor_insertbox(curbox, curCell->box);
 
-					/* add the facet name */
+					/* add the cell name */
 					curlabel = (LABELL *)emalloc(sizeof(LABELL), io_tool->cluster);
 					(void)allocstring(&curlabel->label, describenodeproto(ni->proto), io_tool->cluster);
 					curlabel->pos[0] = ni->lowx;
@@ -580,7 +583,7 @@ void io_pscolor_extractDatabase(NODEPROTO *facet)
 	}
 
 	/* add geometry for all arcs */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		tot = arcpolys(ai, NOWINDOWPART);
 		for(i=0; i<tot; i++)
@@ -591,7 +594,7 @@ void io_pscolor_extractDatabase(NODEPROTO *facet)
 	}
 
 	/* add the name of all exports */
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		curlabel = (LABELL *)emalloc(sizeof(LABELL), io_tool->cluster);
 		(void)allocstring(&curlabel->label, pp->protoname, io_tool->cluster);
@@ -924,6 +927,7 @@ void io_pscolor_splitTree(INTBIG numBoxes, BOXELEM *boxes, BOXQUADTREE *q,
 	}
 }
 
+#if 0
 void io_pscolor_printBoxes(void)
 {
 	CELLL *c;
@@ -949,6 +953,7 @@ void io_pscolor_printBoxes(void)
 		}
 	}
 }
+#endif
 
 void io_pscolor_mergeBoxes(void)
 {
@@ -1025,6 +1030,7 @@ INTBIG io_pscolor_mergeBoxPair(BOXL *b1, BOXL *b2)
 	return 0;
 }
 
+#if 0
 void io_pscolor_checkOverlap(CELLL *c, BOXL *b1, BOXL *b2, INTBIG layerNum)
 {
 	INTBIG t[3], b[3], l[3], r[3];
@@ -1061,6 +1067,7 @@ void io_pscolor_checkOverlap(CELLL *c, BOXL *b1, BOXL *b2, INTBIG layerNum)
 		c->box = io_pscolor_insertbox(curbox, c->box);
 	}
 }
+#endif
 
 void io_pscolor_coaf1(BOXQUADTREE *q1, BOXQUADTREE *q2, INTBIG layernum)
 {
@@ -1211,7 +1218,7 @@ void io_pscolor_recursiveFlatten(CELLL *top, float m[9])
 	}
 }
 
-void io_pscolor_writePS(NODEPROTO *facet, BOOLEAN useplotter,
+void io_pscolor_writePS(NODEPROTO *cell, BOOLEAN useplotter,
 	INTBIG pageWidth, INTBIG pageHeight, INTBIG border)
 {
 	INTBIG i, j, pslx, pshx, psly, pshy, size, x, y, descenderoffset, rot, xoff, yoff,
@@ -1227,7 +1234,7 @@ void io_pscolor_writePS(NODEPROTO *facet, BOOLEAN useplotter,
 
 	/* Header info */
 	io_pswrite(x_("%%!PS-Adobe-1.0\n"));
-	io_pswrite(x_("%%Title: %s\n"), describenodeproto(facet));
+	io_pswrite(x_("%%Title: %s\n"), describenodeproto(cell));
 	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
 		io_pswrite(x_("%%%%Creator: Electric VLSI Design System (David Harris's color PostScript generator) version %s\n"), el_version);
@@ -1334,9 +1341,9 @@ void io_pscolor_writePS(NODEPROTO *facet, BOOLEAN useplotter,
 		}
 	}
 
-	/* label ports and facet instances */
+	/* label ports and cell instances */
 	l = io_pscolor_cells->label;
-	io_pswrite(x_("\n%% Port and Facet Instance Labels\n"));
+	io_pswrite(x_("\n%% Port and Cell Instance Labels\n"));
 	io_pswrite(x_("0 0 0 setrgbcolor\n"));
 	for(i=0; io_psstringheader[i] != 0; i++)
 		io_pswrite(x_("%s\n"), io_psstringheader[i]);
@@ -1726,6 +1733,7 @@ void io_pscolor_freeCellInst(CELLINSTL *b)
 	}
 }
 
+#if 0
 void io_pscolor_freeLine(LINEL *b)
 {
 	LINEL *b2;
@@ -1736,6 +1744,7 @@ void io_pscolor_freeLine(LINEL *b)
 		efree((CHAR *)b2);
 	}
 }
+#endif
 
 /********************************* OUTLINE HANDLING *********************************/
 
