@@ -104,14 +104,14 @@ BOOLEAN io_writequickdrawlibrary(LIBRARY *lib)
 			ttyputmsg(_("Cannot convert Explorer window to Quickdraw.  Export PostScript instead"));
 			return(TRUE);
 		}
-		ttyputerr(_("No current facet to plot"));
+		ttyputerr(_("No current cell to plot"));
 		return(TRUE);
 	}
 
-	/* cannot write text-only facets */
+	/* cannot write text-only cells */
 	if ((np->cellview->viewstate&TEXTVIEW) != 0)
 	{
-		ttyputerr(_("Cannot write textual facets"));
+		ttyputerr(_("Cannot write textual cells"));
 		return(TRUE);
 	}
 
@@ -333,9 +333,9 @@ BOOLEAN io_writequickdrawlibrary(LIBRARY *lib)
 		/* create the polygon if it doesn't exist */
 		(void)needstaticpolygon(&poly, 1, io_tool->cluster);
 
-		/* plot facet name */
+		/* plot cell name */
 		infstr = initinfstr();
-		formatinfstr(infstr, _("Facet: %s"), describenodeproto(np));
+		formatinfstr(infstr, _("Cell: %s"), describenodeproto(np));
 		poly->string = returninfstr(infstr);
 		poly->xv[0] = np->highx;
 		poly->yv[0] = np->lowy;
