@@ -85,7 +85,7 @@ static INTBIG sdfi_timeconvert = 1000;	/* multiplier to convert time values to p
 static INTBIG SDF_instance_key = 0;
 static INTBIG SDF_absolute_port_delay_key = 0;
 static INTBIG SDF_absolute_iopath_delay_key = 0;
-static NODEPROTO *sdfi_curfacet = NONODEPROTO;
+static NODEPROTO *sdfi_curcell = NONODEPROTO;
 
 /* prototypes for local routines */
 static BOOLEAN    sdfi_addparameter(LISPTREE *tree, INTBIG type, void *value);
@@ -133,11 +133,11 @@ BOOLEAN io_readsdflibrary(LIBRARY *lib)
 	REGISTER LISPTREE *lt;
 	void *dia;
 
-	/* make sure there is a current facet */
-	sdfi_curfacet = getcurfacet();
-	if (sdfi_curfacet == NONODEPROTO)
+	/* make sure there is a current cell */
+	sdfi_curcell = getcurcell();
+	if (sdfi_curcell == NONODEPROTO)
 	{
-		ttyputerr(_("No current facet with which to merge data, aborting SDF input"));
+		ttyputerr(_("No current cell with which to merge data, aborting SDF input"));
 		return(TRUE);
 	}
 
@@ -190,39 +190,39 @@ BOOLEAN io_readsdflibrary(LIBRARY *lib)
 	/* release tree memory */
 	sdfi_killptree(lt);
 
-	/* add SDF header info to current facet */
+	/* add SDF header info to current cell */
 	if (sdfi_sdfversion != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_sdfversion"), (INTBIG)sdfi_sdfversion, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_sdfversion"), (INTBIG)sdfi_sdfversion, VSTRING);
 
 	if (sdfi_design != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_design"), (INTBIG)sdfi_design, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_design"), (INTBIG)sdfi_design, VSTRING);
 
 	if (sdfi_date != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_date"), (INTBIG)sdfi_date, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_date"), (INTBIG)sdfi_date, VSTRING);
 
 	if (sdfi_vendor != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_vendor"), (INTBIG)sdfi_vendor, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_vendor"), (INTBIG)sdfi_vendor, VSTRING);
 
 	if (sdfi_program != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_program"), (INTBIG)sdfi_program, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_program"), (INTBIG)sdfi_program, VSTRING);
 
 	if (sdfi_version != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_version"), (INTBIG)sdfi_version, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_version"), (INTBIG)sdfi_version, VSTRING);
 
 	if (sdfi_divider != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_divider"), (INTBIG)sdfi_divider, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_divider"), (INTBIG)sdfi_divider, VSTRING);
 
 	if (sdfi_voltage != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_voltage"), (INTBIG)sdfi_voltage, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_voltage"), (INTBIG)sdfi_voltage, VSTRING);
 
 	if (sdfi_process != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_process"), (INTBIG)sdfi_process, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_process"), (INTBIG)sdfi_process, VSTRING);
 
 	if (sdfi_temperature != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_temperature"), (INTBIG)sdfi_temperature, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_temperature"), (INTBIG)sdfi_temperature, VSTRING);
 
 	if (sdfi_timescale != NULL)
-		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, x_("SDF_timescale"), (INTBIG)sdfi_timescale, VSTRING);
+		(void)setval((INTBIG)sdfi_curcell, VNODEPROTO, x_("SDF_timescale"), (INTBIG)sdfi_timescale, VSTRING);
 
 	ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
@@ -469,7 +469,7 @@ void sdfi_killptree(LISPTREE *lt)
 }
 
 /*
- * Routine to parse the entire tree and annotate current facet.
+ * Routine to parse the entire tree and annotate current cell.
  */
 BOOLEAN sdfi_parsetree(LISPTREE *lt)
 {
@@ -536,11 +536,11 @@ BOOLEAN sdfi_parsedelayfile(LISPTREE *lt)
 			sdfi_setstring(&sdfi_design, (CHAR *)scanlt->paramvalue[0]);
 			if (io_verbose > 0) ttyputmsg(_("Found DESIGN: %s"), sdfi_design);
 
-			/* check to see if design matches current facet */
-			if (namesame(sdfi_curfacet->cell->cellname, sdfi_design) != 0)
+			/* check to see if design matches current cell */
+			if (namesame(sdfi_curcell->protoname, sdfi_design) != 0)
 			{
-				ttyputerr(_("Current facet (%s) does not match DESIGN (%s).  Aborting SDF input"),
-					sdfi_curfacet->cell->cellname, sdfi_design);
+				ttyputerr(_("Current cell (%s) does not match DESIGN (%s).  Aborting SDF input"),
+					sdfi_curcell->protoname, sdfi_design);
 				return(TRUE);
 			}
 			ltdesign = scanlt;
@@ -1194,7 +1194,7 @@ NODEINST *sdfi_getcellinstance(CHAR *celltype, CHAR *instance)
 	/* at top level of hierarchy */
 	if (estrstr(instance, sdfi_divider) == NULL)
 	{
-		for(ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		for(ni = sdfi_curcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 			if (var != NOVARIABLE)
@@ -1209,7 +1209,7 @@ NODEINST *sdfi_getcellinstance(CHAR *celltype, CHAR *instance)
 			addstringtoinfstr(infstr, x_(":"));
 #else
 			addstringtoinfstr(infstr, x_("."));
-			addstringtoinfstr(infstr, sdfi_curfacet->cell->cellname);
+			addstringtoinfstr(infstr, sdfi_curcell->protoname);
 			addstringtoinfstr(infstr, x_("."));
 			addstringtoinfstr(infstr, (CHAR *)var->addr);
 #endif
@@ -1235,7 +1235,7 @@ NODEINST *sdfi_getcellinstance(CHAR *celltype, CHAR *instance)
 
 	/* find the NODEINST corresponding to bottom level of hierarchy */
 	i = 0;
-	for(ni = sdfi_curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = sdfi_curcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 		if (var != NOVARIABLE)
@@ -1254,7 +1254,7 @@ NODEINST *sdfi_getcellinstance(CHAR *celltype, CHAR *instance)
 	addstringtoinfstr(infstr, x_(":"));
 #else
 	addstringtoinfstr(infstr, x_("."));
-	addstringtoinfstr(infstr, sdfi_curfacet->cell->cellname);
+	addstringtoinfstr(infstr, sdfi_curcell->protoname);
 	addstringtoinfstr(infstr, x_("."));
 #endif
 	for (i=0; i<count-1; i++)
