@@ -209,16 +209,16 @@ static void       io_suekillnet(SUENET *sn);
 static void       io_suekillwire(SUEWIRE *sw);
 static INTBIG     io_suemakex(INTBIG x, INTBIG lambda);
 static INTBIG     io_suemakey(INTBIG y, INTBIG lambda);
-static PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *thename);
+static PORTPROTO *io_suenewexport(NODEPROTO *cell, NODEINST *ni, PORTPROTO *pp, CHAR *thename);
 static SUENET    *io_suenewnet(void);
 static SUEWIRE   *io_suenewwire(void);
-static void       io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet);
+static void       io_sueplacenets(SUENET *firstsuenet, NODEPROTO *cell);
 static CHAR      *io_sueparseexpression(CHAR *expression);
 static void       io_sueparseparameters(CHAR **keywords, INTBIG count, INTBIG *x, INTBIG *y, INTBIG lambda,
 					INTBIG *rot, INTBIG *trn, INTBIG *type, CHAR **thename, CHAR **thelabel, CHAR **thetext,
 					void *dia);
-static void       io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet, INTBIG lambda);
-static NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia);
+static void       io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *cell, INTBIG lambda);
+static NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *cellname, void *dia);
 static NODEPROTO *io_suereadfromdisk(LIBRARY *lib, CHAR *name, void *dia);
 static CHAR      *io_suesearchbusname(ARCINST *ai);
 static PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy);
@@ -249,8 +249,8 @@ void io_freesuememory(void)
 BOOLEAN io_readsuelibrary(LIBRARY *lib)
 {
 	REGISTER INTBIG len, i, filecount;
-	REGISTER NODEPROTO *topfacet;
-	CHAR facetname[300], dirname[300], topdirname[300], truesuefile[300],
+	REGISTER NODEPROTO *topcell;
+	CHAR cellname[300], dirname[300], topdirname[300], truesuefile[300],
 		*filename, **filelist;
 	void *dia;
 
@@ -262,16 +262,16 @@ BOOLEAN io_readsuelibrary(LIBRARY *lib)
 		return(TRUE);
 	}
 
-	/* determine the facet name */
+	/* determine the cell name */
 	estrcpy(truesuefile, filename);
-	estrcpy(facetname, filename);
-	len = estrlen(facetname);
-	if (namesame(&facetname[len-4], x_(".sue")) == 0)
-		facetname[len-4] = 0;
-	for(i = estrlen(facetname)-1; i>0; i--)
-		if (facetname[i] == DIRSEP) break;
+	estrcpy(cellname, filename);
+	len = estrlen(cellname);
+	if (namesame(&cellname[len-4], x_(".sue")) == 0)
+		cellname[len-4] = 0;
+	for(i = estrlen(cellname)-1; i>0; i--)
+		if (cellname[i] == DIRSEP) break;
 	i++;
-	estrcpy(facetname, &facetname[i]);
+	estrcpy(cellname, &cellname[i]);
 
 	/* initialize the number of directories that need to be searched */
 	io_suecleardirectories();
@@ -328,9 +328,9 @@ BOOLEAN io_readsuelibrary(LIBRARY *lib)
 
 	/* read the file */
 	DiaSetProgress(dia, 0, io_suefilesize);
-	topfacet = io_suereadfile(lib, facetname, dia);
-	if (topfacet != NONODEPROTO)
-		lib->curnodeproto = topfacet;
+	topcell = io_suereadfile(lib, cellname, dia);
+	if (topcell != NONODEPROTO)
+		lib->curnodeproto = topcell;
 	(void)asktool(net_tool, x_("total-re-number"));
 
 	/* clean up */
@@ -344,7 +344,7 @@ BOOLEAN io_readsuelibrary(LIBRARY *lib)
 /*
  * Routine to read the SUE file in "f"/
  */
-NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
+NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *cellname, void *dia)
 {
 	CHAR *keywords[MAXKEYWORDS], *thename, *thelabel, *thetext, *namestring;
 	CHAR suevarname[200], *pt, *cpt, *startkey, save;
@@ -359,7 +359,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 	XARRAY trans;
 	double rextent, rstart;
 	float f;
-	REGISTER NODEPROTO *facet, *schemfacet, *iconfacet, *proto, *np, *cnp;
+	REGISTER NODEPROTO *cell, *schemcell, *iconcell, *proto, *np, *cnp;
 	REGISTER PORTPROTO *pp, *ppt;
 	PORTPROTO *npp;
 	REGISTER VARIABLE *var;
@@ -375,7 +375,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 
 	firstsuewire = NOSUEWIRE;
 	firstsuenet = NOSUENET;
-	schemfacet = iconfacet = facet = NONODEPROTO;
+	schemcell = iconcell = cell = NONODEPROTO;
 	io_suelastline[0] = 0;
 	numargs = 0;
 	namestrlen = 0;
@@ -393,11 +393,11 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 		if (namesame(keywords[0], x_("proc")) == 0)
 		{
 			/* write any wires from the last proc */
-			if (facet != NONODEPROTO)
+			if (cell != NONODEPROTO)
 			{
-				io_sueplacewires(firstsuewire, firstsuenet, facet, lambda);
+				io_sueplacewires(firstsuewire, firstsuenet, cell, lambda);
 				io_suefreewires(firstsuewire);
-				io_sueplacenets(firstsuenet, facet);
+				io_sueplacenets(firstsuenet, cell);
 				io_suefreenets(firstsuenet);
 				firstsuewire = NOSUEWIRE;
 				firstsuenet = NOSUENET;
@@ -405,34 +405,34 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 
 			if (count < 2)
 			{
-				ttyputerr(_("Facet %s, line %ld: 'proc' is missing arguments: %s"),
-					facetname, io_suelineno, io_sueorigline);
+				ttyputerr(_("Cell %s, line %ld: 'proc' is missing arguments: %s"),
+					cellname, io_suelineno, io_sueorigline);
 				continue;
 			}
 
 			if (namesamen(keywords[1], x_("SCHEMATIC_"), 10) == 0)
 			{
-				/* create the schematic facet */
+				/* create the schematic cell */
 				infstr = initinfstr();
 				if (namesame(&keywords[1][10], x_("[get_file_name]")) == 0)
-					addstringtoinfstr(infstr, facetname); else
+					addstringtoinfstr(infstr, cellname); else
 						addstringtoinfstr(infstr, &keywords[1][10]);
 				addstringtoinfstr(infstr, x_("{sch}"));
-				schemfacet = facet = us_newnodeproto(returninfstr(infstr), lib);
+				schemcell = cell = us_newnodeproto(returninfstr(infstr), lib);
 				placeicon = FALSE;
 			} else if (namesamen(keywords[1], x_("ICON_"), 5) == 0)
 			{
-				/* create the icon facet */
+				/* create the icon cell */
 				infstr = initinfstr();
 				if (namesame(&keywords[1][5], x_("[get_file_name]")) == 0)
-					addstringtoinfstr(infstr, facetname); else
+					addstringtoinfstr(infstr, cellname); else
 						addstringtoinfstr(infstr, &keywords[1][5]);
 				addstringtoinfstr(infstr, x_("{ic}"));
-				iconfacet = facet = us_newnodeproto(returninfstr(infstr), lib);
+				iconcell = cell = us_newnodeproto(returninfstr(infstr), lib);
 			} else
 			{
-				ttyputerr(_("Facet %s, line %ld: unknown 'proc' statement: %s"),
-					facetname, io_suelineno, io_sueorigline);
+				ttyputerr(_("Cell %s, line %ld: unknown 'proc' statement: %s"),
+					cellname, io_suelineno, io_sueorigline);
 			}
 			continue;
 		}
@@ -442,8 +442,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 		{
 			if (count < 2)
 			{
-				ttyputerr(_("Facet %s, line %ld: 'make' is missing arguments: %s"),
-					facetname, io_suelineno, io_sueorigline);
+				ttyputerr(_("Cell %s, line %ld: 'make' is missing arguments: %s"),
+					cellname, io_suelineno, io_sueorigline);
 				continue;
 			}
 
@@ -467,7 +467,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			}
 
 			/* ignore self-references */
-			if (namesame(keywords[1], facetname) == 0)
+			if (namesame(keywords[1], cellname) == 0)
 			{
 				if (x != 0 || y != 0)
 				{
@@ -595,7 +595,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 					defaultnodesize(proto, &px, &py);
 					lx = x - px/2 + xoff;   hx = lx + px;
 					ly = y - py/2 + yoff;   hy = ly + py;
-					ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot, facet);
+					ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot, cell);
 					if (ni == NONODEINST) continue;
 					ni->userbits |= detailbits;
 					endobjectchange((INTBIG)ni, VNODEINST);
@@ -610,7 +610,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 				}
 			}
 
-			/* now check for references to facets */
+			/* now check for references to cells */
 			if (proto == NONODEPROTO)
 			{
 				/* find node or read it from disk */
@@ -618,7 +618,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 				if (proto == NONODEPROTO)
 					proto = io_suereadfromdisk(lib, keywords[1], dia);
 
-				/* set proper offsets for the facet */
+				/* set proper offsets for the cell */
 				if (proto != NONODEPROTO)
 				{
 					np = iconview(proto);
@@ -636,7 +636,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			/* stop now if SUE node is unknown */
 			if (proto == NONODEPROTO)
 			{
-				ttyputmsg(_("Cannot make '%s' in facet %s"), keywords[1], describenodeproto(facet));
+				ttyputmsg(_("Cannot make '%s' in cell %s"), keywords[1], describenodeproto(cell));
 				continue;
 			}
 
@@ -646,15 +646,15 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			py -= muldiv(yshrink, lambda, WHOLE);
 			lx = x - px/2 + xoff;   hx = lx + px;
 			ly = y - py/2 + yoff;   hy = ly + py;
-			ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot, facet);
+			ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot, cell);
 			if (ni == NONODEINST) continue;
 			ni->userbits |= detailbits;
 			ni->temp1 = invertoutput;
 			if (proto->primindex == 0 && proto->cellview == el_iconview)
 				ni->userbits |= NEXPAND;
 			endobjectchange((INTBIG)ni, VNODEINST);
-			if (facet->tech == gen_tech)
-				facet->tech = whattech(facet);
+			if (cell->tech == gen_tech)
+				cell->tech = whattech(cell);
 
 			/* add any extra wires to the node */
 			for(i=0; i<numextrawires; i++)
@@ -668,18 +668,18 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 				xform(px, py, &dx, &dy, trans);
 				defaultnodesize(sch_wirepinprim, &px, &py);
 				pinx = x + dx;   piny = y + dy;
-				nni = io_suefindpinnode(pinx, piny, facet, &npp);
+				nni = io_suefindpinnode(pinx, piny, cell, &npp);
 				if (nni == NONODEINST)
 				{
 					lx = pinx - px/2;   hx = lx + px;
 					ly = piny - py/2;   hy = ly + py;
-					nni = newnodeinst(sch_wirepinprim, lx, hx, ly, hy, 0, 0, facet);
+					nni = newnodeinst(sch_wirepinprim, lx, hx, ly, hy, 0, 0, cell);
 					if (nni == NONODEINST) continue;
 					npp = nni->proto->firstportproto;
 				}
 				bits = us_makearcuserbits(sch_wirearc);
 				if (x != pinx && y != piny) bits &= ~FIXANG;
-				ai = newarcinst(sch_wirearc, 0, bits, ni, pp, x, y, nni, npp, pinx, piny, facet);
+				ai = newarcinst(sch_wirearc, 0, bits, ni, pp, x, y, nni, npp, pinx, piny, cell);
 				if (ai == NOARCINST)
 				{
 					ttyputerr(_("Error adding extra wires to node %s"), keywords[1]);
@@ -695,11 +695,11 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 				{
 					pp = proto->firstportproto;
 					if (namesame(keywords[1], x_("output")) == 0) pp = pp->nextportproto;
-					ppt = io_suenewexport(facet, ni, pp, thename);
+					ppt = io_suenewexport(cell, ni, pp, thename);
 					if (ppt == NOPORTPROTO)
 					{
-						ttyputmsg(_("Facet %s, line %ld, could not create port %s"), 
-							facetname, io_suelineno, thename);
+						ttyputmsg(_("Cell %s, line %ld, could not create port %s"), 
+							cellname, io_suelineno, thename);
 					} else
 					{
 						defaulttextdescript(ppt->textdescript, NOGEOM);
@@ -761,8 +761,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 					esnprintf(suevarname, 200, x_("ATTR_%s"), &keywords[i][1]);
 					for(pt = suevarname; *pt != 0; pt++) if (*pt == ' ')
 					{
-						ttyputmsg(_("Facet %s, line %ld, bad variable name (%s)"), 
-							facetname, io_suelineno, suevarname);
+						ttyputmsg(_("Cell %s, line %ld, bad variable name (%s)"), 
+							cellname, io_suelineno, suevarname);
 						break;
 					}
 					xpos = 0;
@@ -846,7 +846,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 						TDSETISPARAM(var->textdescript, VTISPARAMETER);
 						TDSETDISPPART(var->textdescript, VTDISPLAYNAMEVALUE);
 
-						/* make sure the parameter exists in the facet definition */
+						/* make sure the parameter exists in the cell definition */
 						cnp = contentsview(ni->proto);
 						if (cnp == NONODEPROTO) cnp = ni->proto;
 						var = getval((INTBIG)cnp, VNODEPROTO, -1, suevarname);
@@ -890,15 +890,15 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			defaultnodesize(proto, &px, &py);
 			lx = x - px/2;   hx = lx + px;
 			ly = y - py/2;   hy = ly + py;
-			ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot%3600, facet);
+			ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot%3600, cell);
 			if (ni == NONODEINST) continue;
 			endobjectchange((INTBIG)ni, VNODEINST);
 
-			ppt = io_suenewexport(facet, ni, proto->firstportproto, suevarname);
+			ppt = io_suenewexport(cell, ni, proto->firstportproto, suevarname);
 			if (ppt == NOPORTPROTO)
 			{
-				ttyputmsg(_("Facet %s, line %ld, could not create port %s"), 
-					facetname, io_suelineno, suevarname);
+				ttyputmsg(_("Cell %s, line %ld, could not create port %s"), 
+					cellname, io_suelineno, suevarname);
 			} else
 			{
 				defaulttextdescript(ppt->textdescript, NOGEOM);
@@ -914,8 +914,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 		{
 			if (count != 9)
 			{
-				ttyputerr(_("Facet %s, line %ld: needs 9 arguments, has %ld: %s"),
-					facetname, io_suelineno, count, io_sueorigline);
+				ttyputerr(_("Cell %s, line %ld: needs 9 arguments, has %ld: %s"),
+					cellname, io_suelineno, count, io_sueorigline);
 				continue;
 			}
 			start = 0;   extent = 359;
@@ -928,7 +928,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			lx = mini(p1x, p2x);   hx = maxi(p1x, p2x);
 			ly = mini(p1y, p2y);   hy = maxi(p1y, p2y);
 
-			ni = newnodeinst(art_circleprim, lx, hx, ly, hy, 0, 0, facet);
+			ni = newnodeinst(art_circleprim, lx, hx, ly, hy, 0, 0, cell);
 			if (ni == NONODEINST) continue;
 			if (extent != 359)
 			{
@@ -966,7 +966,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 				if (outline[i*2+1] < ly) ly = outline[i*2+1];
 				if (outline[i*2+1] > hy) hy = outline[i*2+1];
 			}
-			ni = newnodeinst(art_openedpolygonprim, lx, hx, ly, hy, 0, 0, facet);
+			ni = newnodeinst(art_openedpolygonprim, lx, hx, ly, hy, 0, 0, cell);
 			if (ni == NONODEINST) return(NONODEPROTO);
 			cx = (lx + hx) / 2;  cy = (ly + hy) / 2;
 			for(i=0; i<keycount; i++)
@@ -985,8 +985,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			/* extract parameters */
 			if (namesame(keywords[1], x_("$args")) != 0)
 			{
-				ttyputerr(_("Facet %s, line %ld: has unrecognized 'icon_setup'"),
-					facetname, io_suelineno);
+				ttyputerr(_("Cell %s, line %ld: has unrecognized 'icon_setup'"),
+					cellname, io_suelineno);
 				continue;
 			}
 			pt = keywords[2];
@@ -1076,7 +1076,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			}
 			thelabel = returninfstr(infstr);
 
-			ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, facet);
+			ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, cell);
 			if (ni == NONODEINST) continue;
 			var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)thelabel, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
@@ -1096,7 +1096,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 				&type, &thename, &thelabel, &thetext, dia);
 			if (thetext == 0) continue;
 
-			ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, facet);
+			ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, cell);
 			if (ni == NONODEINST) continue;
 			var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)thetext, VSTRING|VDISPLAY);
 			if (var != NOVARIABLE)
@@ -1116,19 +1116,19 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 			continue;
 		}
 
-		ttyputerr(_("Facet %s, line %ld: unknown keyword (%s): %s"), facetname,
+		ttyputerr(_("Cell %s, line %ld: unknown keyword (%s): %s"), cellname,
 			io_suelineno, keywords[0], io_sueorigline);
 	}
 
 	/* place an icon instance in the schematic if requested */
-	if (placeicon && schemfacet != NONODEPROTO &&
-		iconfacet != NONODEPROTO)
+	if (placeicon && schemcell != NONODEPROTO &&
+		iconcell != NONODEPROTO)
 	{
-		px = iconfacet->highx - iconfacet->lowx;
-		py = iconfacet->highy - iconfacet->lowy;
+		px = iconcell->highx - iconcell->lowx;
+		py = iconcell->highy - iconcell->lowy;
 		lx = iconx - px/2;   hx = lx + px;
 		ly = icony - py/2;   hy = ly + py;
-		ni = newnodeinst(iconfacet, lx, hx, ly, hy, 0, 0, schemfacet);
+		ni = newnodeinst(iconcell, lx, hx, ly, hy, 0, 0, schemcell);
 		if (ni != NONODEINST)
 		{
 			ni->userbits |= NEXPAND;
@@ -1148,22 +1148,22 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, CHAR *facetname, void *dia)
 	}
 	if (namestrlen > 0) efree(namestring);
 
-	/* cleanup the current facet */
-	if (facet != NONODEPROTO)
+	/* cleanup the current cell */
+	if (cell != NONODEPROTO)
 	{
-		io_sueplacewires(firstsuewire, firstsuenet, facet, lambda);
+		io_sueplacewires(firstsuewire, firstsuenet, cell, lambda);
 		io_suefreewires(firstsuewire);
-		io_sueplacenets(firstsuenet, facet);
+		io_sueplacenets(firstsuenet, cell);
 		io_suefreenets(firstsuenet);
 	}
 
-	/* make sure facets are the right size */
-	if (schemfacet != NONODEPROTO) (*el_curconstraint->solve)(schemfacet);
-	if (iconfacet != NONODEPROTO) (*el_curconstraint->solve)(iconfacet);
+	/* make sure cells are the right size */
+	if (schemcell != NONODEPROTO) (*el_curconstraint->solve)(schemcell);
+	if (iconcell != NONODEPROTO) (*el_curconstraint->solve)(iconcell);
 
-	/* return the facet */
-	if (schemfacet != NONODEPROTO) return(schemfacet);
-	return(iconfacet);
+	/* return the cell */
+	if (schemcell != NONODEPROTO) return(schemcell);
+	return(iconcell);
 
 }
 
@@ -1294,23 +1294,22 @@ void io_sueparseparameters(CHAR **keywords, INTBIG count, INTBIG *x, INTBIG *y,
 }
 
 /*
- * Routine to find facet "protoname" in library "lib".
+ * Routine to find cell "protoname" in library "lib".
  */
 NODEPROTO *io_suegetnodeproto(LIBRARY *lib, CHAR *protoname)
 {
-	REGISTER CELL *c;
+	REGISTER NODEPROTO *np;
 
-	for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
-		if (namesame(protoname, c->cellname) == 0) break;
-	if (c == NOCELL) return(NONODEPROTO);
-	return(c->firstincell);
+	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		if (namesame(protoname, np->protoname) == 0) return(np);
+	return(NONODEPROTO);
 }
 
 /*
- * Routine to create a port called "thename" on port "pp" of node "ni" in facet "facet".
+ * Routine to create a port called "thename" on port "pp" of node "ni" in cell "cell".
  * The name is modified if it already exists.
  */
-PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *thename)
+PORTPROTO *io_suenewexport(NODEPROTO *cell, NODEINST *ni, PORTPROTO *pp, CHAR *thename)
 {
 	REGISTER PORTPROTO *ppt;
 	REGISTER INTBIG i;
@@ -1321,10 +1320,10 @@ PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, CHAR *
 	portname = thename;
 	for(i=0; ; i++)
 	{
-		ppt = getportproto(facet, portname);
+		ppt = getportproto(cell, portname);
 		if (ppt == NOPORTPROTO)
 		{
-			ppt = newportproto(facet, ni, pp, portname);
+			ppt = newportproto(cell, ni, pp, portname);
 			break;
 		}
 
@@ -1354,10 +1353,10 @@ INTBIG io_suemakey(INTBIG y, INTBIG lambda)
 }
 
 /*
- * Routine to place all SUE nets into the facet (they are in a linked
+ * Routine to place all SUE nets into the cell (they are in a linked
  * list headed by "firstsuenet").
  */
-void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
+void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *cell)
 {
 	SUENET *sn;
 	REGISTER INTBIG pass;
@@ -1387,7 +1386,7 @@ void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 			/* see if this is a bus */
 			if (net_buswidth(sn->label) > 1) isbus = TRUE; else isbus = FALSE;
 
-			sea = initsearch(sn->x, sn->x, sn->y, sn->y, facet);
+			sea = initsearch(sn->x, sn->x, sn->y, sn->y, cell);
 			bestai = NOARCINST;
 			for(;;)
 			{
@@ -1544,10 +1543,10 @@ CHAR *io_suesearchbusname(ARCINST *ai)
 }
 
 /*
- * Routine to place all SUE wires into the facet (they are in a linked
+ * Routine to place all SUE wires into the cell (they are in a linked
  * list headed by "firstsuewire").
  */
-void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet, INTBIG lambda)
+void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *cell, INTBIG lambda)
 {
 	SUEWIRE *sw, *osw;
 	SUENET *sn;
@@ -1593,7 +1592,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 		for(i=0; i<2; i++)
 		{
 			if (sw->ni[i] != NONODEINST) continue;
-			for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+			for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 			{
 				pp = io_suewiredport(ni, &sw->x[i], &sw->y[i], sw->x[1-i], sw->y[1-i]);
 				if (pp == NOPORTPROTO) continue;
@@ -1691,7 +1690,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 				defaultnodesize(proto, &xsize , &ysize);
 				sw->ni[i] = newnodeinst(proto, sw->x[i] - xsize/2,
 					sw->x[i] + xsize/2, sw->y[i] - ysize/2,
-					sw->y[i] + ysize/2, 0, 0, facet);
+					sw->y[i] + ysize/2, 0, 0, cell);
 				endobjectchange((INTBIG)sw->ni[i], VNODEINST);
 				sw->pp[i] = proto->firstportproto;
 			}
@@ -1717,7 +1716,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 		for(i=0; i<2; i++)
 		{
 			if (sw->ni[i] != NONODEINST) continue;
-			if (!io_suefindnode(&sw->x[i], &sw->y[i], sw->x[1-i], sw->y[1-i], facet,
+			if (!io_suefindnode(&sw->x[i], &sw->y[i], sw->x[1-i], sw->y[1-i], cell,
 				&sw->ni[i], &sw->pp[i], sw->ni[1-i], lambda))
 			{
 				if (sw->proto == sch_busarc) proto = sch_buspinprim; else
@@ -1725,7 +1724,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 				defaultnodesize(proto, &xsize , &ysize);
 				sw->ni[i] = newnodeinst(proto, sw->x[i] - xsize/2,
 					sw->x[i] + xsize/2, sw->y[i] - ysize/2, sw->y[i] + ysize/2,
-					0, 0, facet);
+					0, 0, cell);
 				endobjectchange((INTBIG)sw->ni[i], VNODEINST);
 				sw->pp[i] = sw->ni[i]->proto->firstportproto;
 			}
@@ -1753,13 +1752,13 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 					defaultnodesize(sch_buspinprim, &xsize , &ysize);
 					lx = px - xsize/2;   hx = lx + xsize;
 					ly = py - ysize/2;   hy = ly + ysize;
-					ni = newnodeinst(sch_buspinprim, lx, hx, ly, hy, 0, 0, facet);
+					ni = newnodeinst(sch_buspinprim, lx, hx, ly, hy, 0, 0, cell);
 					if (ni == NONODEINST) break;
 					endobjectchange((INTBIG)ni, VNODEINST);
 					pp = ni->proto->firstportproto;
 					ai = newarcinst(gen_unroutedarc, defaultarcwidth(gen_unroutedarc),
 						us_makearcuserbits(gen_unroutedarc), ni, pp, px, py,
-							sw->ni[i], sw->pp[i], sw->x[i], sw->y[i], facet);
+							sw->ni[i], sw->pp[i], sw->x[i], sw->y[i], cell);
 					if (ai == NOARCINST)
 					{
 						ttyputerr(_("Error making fake connection"));
@@ -1776,12 +1775,12 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 
 		ai = newarcinst(sw->proto, wid, us_makearcuserbits(sw->proto),
 			sw->ni[0], sw->pp[0], sw->x[0], sw->y[0],
-			sw->ni[1], sw->pp[1], sw->x[1], sw->y[1], facet);
+			sw->ni[1], sw->pp[1], sw->x[1], sw->y[1], cell);
 		if (ai == NOARCINST)
 		{
-			ttyputerr(_("Could not run a wire from %s to %s in facet %s"),
+			ttyputerr(_("Could not run a wire from %s to %s in cell %s"),
 				describenodeinst(sw->ni[0]), describenodeinst(sw->ni[1]),
-					describenodeproto(facet));
+					describenodeproto(cell));
 			continue;
 		}
 
@@ -1799,13 +1798,13 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 	}
 
 	/* now look for implicit connections where "offpage" connectors touch */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto != sch_offpageprim) continue;
 		if (ni->firstportarcinst != NOPORTARCINST) continue;
 		pp = ni->proto->firstportproto->nextportproto;
 		portposition(ni, pp, &x, &y);
-		sea = initsearch(x, x, y, y, facet);
+		sea = initsearch(x, x, y, y, cell);
 		for(;;)
 		{
 			geom = nextobject(sea);
@@ -1836,7 +1835,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 
 				wid = defaultarcwidth(ap);
 				bits = us_makearcuserbits(ap);
-				ai = newarcinst(ap, wid, bits, ni, pp, x, y, oni, opp, x, y, facet);
+				ai = newarcinst(ap, wid, bits, ni, pp, x, y, oni, opp, x, y, cell);
 				if (ai != NOARCINST)
 					endobjectchange((INTBIG)ai, VARCINST);
 				break;
@@ -2009,7 +2008,7 @@ NODEPROTO *io_suereadfromdisk(LIBRARY *lib, CHAR *name, void *dia)
 	REGISTER FILE *f, *savefp;
 	REGISTER NODEPROTO *proto;
 
-	/* look for another "sue" file that describes this facet */
+	/* look for another "sue" file that describes this cell */
 	for(i=0; i<io_suenumdirectories; i++)
 	{
 		estrcpy(subfilename, io_suedirectories[i]);
@@ -2047,7 +2046,7 @@ NODEPROTO *io_suereadfromdisk(LIBRARY *lib, CHAR *name, void *dia)
 			DiaSetTextProgress(dia, lastprogressmsg);
 			DiaSetProgress(dia, filepos, io_suefilesize);
 
-			/* now try to find the facet in the library */
+			/* now try to find the cell in the library */
 			proto = io_suegetnodeproto(lib, subfilename);
 			return(proto);
 		}
