@@ -54,14 +54,14 @@
 #define LONGJMPMISVIEWABR   11		/* error: Missing view abbreviation */
 #define LONGJMPBADVIEWABR   12		/* error: View abbreviation bad */
 #define LONGJMPINCVIEWABR   13		/* error: View abbreviation inconsistent */
-#define LONGJMPSECFACETNAME 14		/* error: Second facet name */
+#define LONGJMPSECCELLNAME  14		/* error: Second cell name */
 #define LONGJMPUKNTECH      15		/* error: Unknown technology */
 #define LONGJMPINVARCPROTO  16		/* error: Invalid arc prototype */
 #define LONGJMPUKNPORPROTO  17		/* error: Unknown port prototype name */
 
 /* state of input (value of "io_txtindata.textlevel") */
 #define INLIB       1
-#define INFACET     2
+#define INCELL      2
 #define INPORTPROTO 3
 #define INNODEINST  4
 #define INPOR       5
@@ -81,10 +81,10 @@
 
 typedef struct
 {
-	INTBIG      facetcount;
+	INTBIG      cellcount;
 	INTBIG      textlevel;
 	INTBIG      bitcount;
-	INTBIG      mainfacet;
+	INTBIG      maincell;
 	INTBIG      curarcend;
 	INTBIG      nodeinstcount;
 	INTBIG      arcinstcount;
@@ -95,16 +95,18 @@ typedef struct
 	INTBIG      varpos;
 	INTBIG      filelength;
 	INTBIG      fileposition;
-	INTBIG      curfacetnumber;
+	INTBIG      curcellnumber;
 	CHAR       *version;
+	INTBIG      emajor, eminor, edetail;
 	NODEINST   *curnodeinst;
 	ARCINST    *curarcinst;
 	PORTPROTO  *curportproto;
 	NODEPROTO  *curnodeproto;
+	CHAR       *cellnameread;
 	LIBRARY    *curlib;
 	TECHNOLOGY *curtech;
 	PORTPROTO **portprotolist;		/* list of portprotos for readin */
-	NODEPROTO **nodeprotolist;		/* list of facets for readin */
+	NODEPROTO **nodeprotolist;		/* list of cells for readin */
 	ARCINST   **arclist;			/* list of arcs for readin */
 	NODEINST  **nodelist;			/* list of nodes for readin */
 	FILE       *textfilein;
@@ -235,8 +237,8 @@ static struct keyroutine io_libraryroutines[] =
    {NULL, NULL}
 };
 
-/* possible keywords while reading facets */
-static struct keyroutine io_facetroutines[] =
+/* possible keywords while reading cells */
+static struct keyroutine io_cellroutines[] =
 {
 	{x_("bits"),            io_celbit},
 	{x_("userbits"),        io_celusb},
@@ -394,11 +396,10 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 	REGISTER INTBIG i, j, reportcount, lambda, errcode;
 	INTBIG num, den;
 	REGISTER INTBIG oldunit;
-	REGISTER NODEPROTO *np;
+	REGISTER NODEPROTO *np, *onp, *prevmatch;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
-	REGISTER CELL *c;
 	CHAR *filename;
 	REGISTER void *infstr;
 
@@ -460,7 +461,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 			case LONGJMPMISVIEWABR:   pp = _("Missing view abbreviation");        break;
 			case LONGJMPBADVIEWABR:   pp = _("View abbreviation bad");            break;
 			case LONGJMPINCVIEWABR:   pp = _("View abbreviation inconsistent");   break;
-			case LONGJMPSECFACETNAME: pp = _("Second facet name");                break;
+			case LONGJMPSECCELLNAME:  pp = _("Second cell name");                 break;
 			case LONGJMPUKNTECH:      pp = _("Unknown technology");               break;
 			case LONGJMPINVARCPROTO:  pp = _("Invalid arc prototype");            break;
 			case LONGJMPUKNPORPROTO:  pp = _("Unknown port prototype name");      break;
@@ -469,7 +470,11 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 		ttyputerr(_("Error: %s on line %ld, keyword '%s'"), pp,
 			io_txtindata.linenumber, io_keyword);
 		xclose(io_txtindata.textfilein);
-		if (io_verbose < 0 && io_txtindata.filelength > 0) DiaDoneProgress(io_inputprogressdialog);
+		if (io_verbose < 0 && io_txtindata.filelength > 0 && io_inputprogressdialog != 0)
+		{
+			DiaDoneProgress(io_inputprogressdialog);
+			io_inputprogressdialog = 0;
+		}
 		return(TRUE);
 	}
 
@@ -505,7 +510,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 		if (reportcount++ > REPORTRATE)
 		{
 			reportcount = 0;
-			if (io_verbose < 0 && io_txtindata.filelength > 0)
+			if (io_verbose < 0 && io_txtindata.filelength > 0 && io_inputprogressdialog != 0)
 				DiaSetProgress(io_inputprogressdialog, io_txtindata.fileposition, io_txtindata.filelength);
 		}
 
@@ -513,7 +518,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 		switch (io_txtindata.textlevel)
 		{
 			case INLIB:       table = io_libraryroutines;   break;
-			case INFACET:     table = io_facetroutines;     break;
+			case INCELL:      table = io_cellroutines;      break;
 			case INPORTPROTO: table = io_portroutines;      break;
 			case INNODEINST:  table = io_noderoutines;      break;
 			case INPOR:       table = io_portinstroutines;  break;
@@ -532,7 +537,7 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 		(*(table[i].routine))();
 	}
 	xclose(io_txtindata.textfilein);
-	if (io_verbose < 0 && io_txtindata.filelength > 0)
+	if (io_verbose < 0 && io_txtindata.filelength > 0 && io_inputprogressdialog != 0)
 	{
 		DiaSetProgress(io_inputprogressdialog, 999, 1000);
 		DiaSetTextProgress(io_inputprogressdialog, _("Cleaning up..."));
@@ -542,7 +547,6 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 	nextchangequiet();
 	(void)setval((INTBIG)io_txtindata.curlib, VLIBRARY, x_("LIB_former_version"),
 		(INTBIG)io_txtindata.version, VSTRING|VDONTSAVE);
-	efree(io_txtindata.version);
 
 	/* fill in any lambda values that are not specified */
 	oldunit = ((io_txtindata.curlib->userbits & LIBUNITS) >> LIBUNITSSH) << INTERNALUNITSSH;
@@ -559,6 +563,43 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 		io_txtindata.curlib->lambda[tech->techindex] = lambda;
 	}
 
+	/* see if cellgroup information was included */
+	for(np = io_txtindata.curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		if (np->temp1 == -1) break;
+	if (np != NONODEPROTO)
+	{
+		/* missing cellgroup information, construct it from names */
+		if (io_txtindata.emajor > 7 ||
+			(io_txtindata.emajor == 7 && io_txtindata.eminor > 0) ||
+			(io_txtindata.emajor == 7 && io_txtindata.eminor == 0 && io_txtindata.edetail > 11))
+		{
+			ttyputmsg(M_("Unusual!  Version %s library has no cellgroup information"), io_txtindata.version);
+		}
+		io_buildcellgrouppointersfromnames(io_txtindata.curlib);
+	} else if (io_txtindata.curlib->firstnodeproto != NONODEPROTO)
+	{
+		/* convert numbers to cellgroup pointers */
+		if (io_txtindata.emajor < 7 ||
+			(io_txtindata.emajor == 7 && io_txtindata.eminor == 0 && io_txtindata.edetail <= 11))
+		{
+			ttyputmsg(M_("Unusual!  Version %s library has cellgroup information"), io_txtindata.version);
+		}
+		for(np = io_txtindata.curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			np->nextcellgrp = NONODEPROTO;
+		for(np = io_txtindata.curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		{
+			if (np->nextcellgrp != NONODEPROTO) continue;
+			prevmatch = np;
+			for(onp = np->nextnodeproto; onp != NONODEPROTO; onp = onp->nextnodeproto)
+			{
+				if (onp->temp1 != prevmatch->temp1) continue;
+				prevmatch->nextcellgrp = onp;
+				prevmatch = onp;
+			}
+			prevmatch->nextcellgrp = np;
+		}
+	}
+
 	/* if converting MOSIS CMOS technologies, store lambda in the right place */
 	if (io_txtindata.convertmosiscmostechnologies != 0)
 		io_txtindata.curlib->lambda[mocmos_tech->techindex] =
@@ -569,14 +610,6 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 		for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 			changetechnologylambda(tech, io_txtindata.curlib->lambda[tech->techindex]);
 
-	/* create clusters for the cells */
-	for(c = io_txtindata.curlib->firstcell; c != NOCELL; c = c->nextcell)
-	{
-		c->cluster = alloccluster(c->cellname);
-		if (c->cluster == NOCLUSTER)
-			longjmp(io_filerror, LONGJMPNOMEM);
-	}
-
 	/* warn if the MOSIS CMOS technologies were converted */
 	if (io_txtindata.convertmosiscmostechnologies != 0)
 	{
@@ -613,15 +646,20 @@ BOOLEAN io_doreadtextlibrary(LIBRARY *lib, BOOLEAN newprogress)
 	if (io_txtindata.libraryerror != 0)
 		ttyputmsg(_("Warning: %ld LIBRARY pointers not restored"), io_txtindata.libraryerror);
 
-	if (io_txtindata.mainfacet != -1 && io_txtindata.mainfacet < io_txtindata.facetcount)
-		io_txtindata.curlib->curnodeproto = io_txtindata.nodeprotolist[io_txtindata.mainfacet]; else
+	if (io_txtindata.maincell != -1 && io_txtindata.maincell < io_txtindata.cellcount)
+		io_txtindata.curlib->curnodeproto = io_txtindata.nodeprotolist[io_txtindata.maincell]; else
 			io_txtindata.curlib->curnodeproto = NONODEPROTO;
-	if (io_txtindata.facetcount != 0) efree((CHAR *)io_txtindata.nodeprotolist);
-	if (io_verbose < 0 && io_txtindata.filelength > 0 && newprogress) DiaDoneProgress(io_inputprogressdialog);
+	if (io_txtindata.cellcount != 0) efree((CHAR *)io_txtindata.nodeprotolist);
+	if (io_verbose < 0 && io_txtindata.filelength > 0 && newprogress && io_inputprogressdialog != 0)
+	{
+		DiaDoneProgress(io_inputprogressdialog);
+		io_inputprogressdialog = 0;
+	}
 
 	/* clean up the library */
 	io_fixnewlib(io_txtindata.curlib, 0);
 	io_txtindata.curlib->userbits &= ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR);
+	efree(io_txtindata.version);
 	return(FALSE);
 }
 
@@ -764,7 +802,7 @@ void io_newlib(void)
 	REGISTER TECHNOLOGY *tech;
 
 	/* set defaults */
-	io_txtindata.mainfacet = -1;
+	io_txtindata.maincell = -1;
 	(void)allocstring(&io_txtindata.version, x_("1.00"), el_tempcluster);
 	io_txtindata.varpos = INVTOOL;
 	io_txtindata.curtech = NOTECHNOLOGY;
@@ -778,22 +816,22 @@ void io_newlib(void)
  */
 void io_versn(void)
 {
-	INTBIG emajor, eminor, edetail;
-
 	(void)reallocstring(&io_txtindata.version, io_keyword, el_tempcluster);
 
 	/* for versions before 6.03q, convert MOSIS CMOS technology names */
-	parseelectricversion(io_txtindata.version, &emajor, &eminor, &edetail);
+	parseelectricversion(io_txtindata.version, &io_txtindata.emajor, &io_txtindata.eminor,
+		&io_txtindata.edetail);
 	io_txtindata.convertmosiscmostechnologies = 0;
-	if (emajor < 6 ||
-		(emajor == 6 && eminor < 3) ||
-		(emajor == 6 && eminor == 3 && edetail < 17))
+	if (io_txtindata.emajor < 6 ||
+		(io_txtindata.emajor == 6 && io_txtindata.eminor < 3) ||
+		(io_txtindata.emajor == 6 && io_txtindata.eminor == 3 && io_txtindata.edetail < 17))
 	{
 		if ((asktech(mocmossub_tech, x_("get-state"))&MOCMOSSUBNOCONV) == 0)
 			io_txtindata.convertmosiscmostechnologies = 1;
 	}
 #ifdef REPORTCONVERSION
-	ttyputmsg(x_("Library is version %s (%ld.%ld.%ld)"), io_txtindata.version, emajor, eminor, edetail);
+	ttyputmsg(x_("Library is version %s (%ld.%ld.%ld)"), io_txtindata.version, io_txtindata.emajor,
+		io_txtindata.eminor, io_txtindata.edetail);
 	if (io_txtindata.convertmosiscmostechnologies != 0)
 		ttyputmsg(x_("   Converting MOSIS CMOS technologies (mocmossub => mocmos)"));
 #endif
@@ -890,11 +928,11 @@ void io_lambda(void)
  */
 void io_getvar(void)
 {
-	REGISTER INTBIG i, j, count, type, len, naddr, ntype, *store, key, ret;
+	REGISTER INTBIG i, j, count, type, len, naddr, ntype, thisnaddr, *store, key, ret;
 	REGISTER float *fstore;
 	REGISTER INTSML *sstore;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
-	REGISTER CHAR *pt, *start;
+	REGISTER CHAR *pt, *start, *varname;
 	REGISTER VARIABLE *var;
 	REGISTER TECHNOLOGY *t;
 	REGISTER void *infstr;
@@ -959,7 +997,12 @@ void io_getvar(void)
 			if (*pt == '(' || *pt == '[' || *pt == ':') break;
 			addtoinfstr(infstr, *pt);
 		}
-		key = makekey(returninfstr(infstr));
+		varname = returninfstr(infstr);
+		key = makekey(varname);
+
+		/* see if the variable is valid */
+		thisnaddr = naddr;
+		if (isdeprecatedvariable(naddr, ntype, varname)) thisnaddr = -1;
 
 		/* get optional length */
 		if (*pt == '(')
@@ -1059,10 +1102,10 @@ void io_getvar(void)
 					}
 				}
 			}
-			if (naddr != -1)
+			if (thisnaddr != -1)
 			{
 				nextchangequiet();
-				var = setvalkey(naddr, ntype, key, (INTBIG)store, type);
+				var = setvalkey(thisnaddr, ntype, key, (INTBIG)store, type);
 				if (var == NOVARIABLE) longjmp(io_filerror, LONGJMPNOMEM);
 				TDCOPY(var->textdescript, descript);
 
@@ -1074,10 +1117,10 @@ void io_getvar(void)
 		} else
 		{
 			ret = io_decode(io_keyword, type);
-			if (naddr != -1)
+			if (thisnaddr != -1)
 			{
 				nextchangequiet();
-				var = setvalkey(naddr, ntype, key, ret, type);
+				var = setvalkey(thisnaddr, ntype, key, ret, type);
 				if (var == NOVARIABLE) longjmp(io_filerror, LONGJMPNOMEM);
 				TDCOPY(var->textdescript, descript);
 
@@ -1123,10 +1166,6 @@ INTBIG io_decode(CHAR *name, INTBIG type)
 				*out++ = *name;
 			}
 			*out = 0;
-#if 0 /* Dump language code */
-			if ((type&(VCODE1|VCODE2)) != 0)
-				printf("Code <%s>\n", retur);
-#endif
 			return((INTBIG)retur);
 		case VFLOAT:
 		case VDOUBLE:
@@ -1190,7 +1229,7 @@ INTBIG io_decode(CHAR *name, INTBIG type)
 }
 
 /*
- * get the number of facets in this library (keyword "cellcount")
+ * get the number of cells in this library (keyword "cellcount")
  */
 void io_libcc(void)
 {
@@ -1198,22 +1237,20 @@ void io_libcc(void)
 
 	io_txtindata.varpos = INVLIBRARY;
 
-	io_txtindata.facetcount = eatoi(io_keyword);
-	if (io_txtindata.facetcount == 0)
+	io_txtindata.cellcount = eatoi(io_keyword);
+	if (io_txtindata.cellcount == 0)
 	{
 		io_txtindata.curlib->firstnodeproto = NONODEPROTO;
 		io_txtindata.curlib->tailnodeproto = NONODEPROTO;
-		io_txtindata.curlib->firstcell = NOCELL;
-		io_txtindata.curlib->tailcell = NOCELL;
-		io_txtindata.curlib->numcells = 0;
+		io_txtindata.curlib->numnodeprotos = 0;
 		return;
 	}
 
 	/* allocate a list of node prototypes for this library */
-	io_txtindata.nodeprotolist = (NODEPROTO **)emalloc(((sizeof (NODEPROTO *)) * io_txtindata.facetcount),
+	io_txtindata.nodeprotolist = (NODEPROTO **)emalloc(((sizeof (NODEPROTO *)) * io_txtindata.cellcount),
 		el_tempcluster);
 	if (io_txtindata.nodeprotolist == 0) longjmp(io_filerror, LONGJMPNOMEM);
-	for(i=0; i<io_txtindata.facetcount; i++)
+	for(i=0; i<io_txtindata.cellcount; i++)
 	{
 		io_txtindata.nodeprotolist[i] = allocnodeproto(io_txtindata.curlib->cluster);
 		if (io_txtindata.nodeprotolist[i] == NONODEPROTO)
@@ -1228,11 +1265,11 @@ void io_libcc(void)
 }
 
 /*
- * get the main facet of this library (keyword "maincell")
+ * get the main cell of this library (keyword "maincell")
  */
 void io_libms(void)
 {
-	io_txtindata.mainfacet = eatoi(io_keyword);
+	io_txtindata.maincell = eatoi(io_keyword);
 }
 
 /*
@@ -1270,35 +1307,36 @@ void io_libvie(void)
 	pt[-1] = '{';   pt[len-1] = '}';
 }
 
-/******************** FACET PARSING ROUTINES ********************/
+/******************** CELL PARSING ROUTINES ********************/
 
 /*
- * initialize for a new facet (keyword "***cell")
+ * initialize for a new cell (keyword "***cell")
  */
 void io_newcel(void)
 {
-	io_txtindata.curfacetnumber = eatoi(io_keyword);
-	io_txtindata.curnodeproto = io_txtindata.nodeprotolist[io_txtindata.curfacetnumber];
-	io_txtindata.textlevel = INFACET;
+	REGISTER CHAR *pt;
+
+	io_txtindata.curcellnumber = eatoi(io_keyword);
+	for(pt = io_keyword; *pt != 0; pt++) if (*pt == '/') break;
+	io_txtindata.curnodeproto = io_txtindata.nodeprotolist[io_txtindata.curcellnumber];
+	if (*pt == '/') io_txtindata.curnodeproto->temp1 = eatoi(pt+1); else
+		io_txtindata.curnodeproto->temp1 = -1;
+	io_txtindata.textlevel = INCELL;
 	io_txtindata.varpos = INVNODEPROTO;
 }
 
 /*
- * get the name of the current facet (keyword "name")
+ * get the name of the current cell (keyword "name")
  */
 void io_celnam(void)
 {
 	REGISTER CHAR *pt;
 	REGISTER VIEW *v;
-	CHAR *cellname;
-	REGISTER CELL *cell;
 	REGISTER void *infstr;
 
-	if (io_txtindata.curnodeproto->cell != NOCELL)
-		longjmp(io_filerror, LONGJMPSECFACETNAME);
 	if (io_verbose != 0)
 	{
-		if (io_verbose < 0 && io_txtindata.filelength > 0)
+		if (io_verbose < 0 && io_txtindata.filelength > 0 && io_inputprogressdialog != 0)
 		{
 			infstr = initinfstr();
 			formatinfstr(infstr, _("Reading %s"), io_keyword);
@@ -1311,7 +1349,7 @@ void io_celnam(void)
 	if (*pt == '{')
 	{
 		*pt = 0;
-		if (allocstring(&cellname, io_keyword,
+		if (allocstring(&io_txtindata.curnodeproto->protoname, io_keyword,
 			io_txtindata.curlib->cluster))
 				longjmp(io_filerror, LONGJMPNOMEM);
 		pt++;
@@ -1321,33 +1359,24 @@ void io_celnam(void)
 		if (v != NOVIEW) io_txtindata.curnodeproto->cellview = v;
 	} else
 	{
-		if (allocstring(&cellname, io_keyword,
+		if (allocstring(&io_txtindata.curnodeproto->protoname, io_keyword,
 			io_txtindata.curlib->cluster))
 				longjmp(io_filerror, LONGJMPNOMEM);
 	}
-	cell = db_findcellname(cellname, io_txtindata.curlib);
-	if (cell == NOCELL)
-	{
-		cell = alloccell(io_txtindata.curlib->cluster);
-		if (cell == NOCELL) longjmp(io_filerror, LONGJMPNOMEM);
-		cell->lib = io_txtindata.curlib;
-		cell->cellname = cellname;
-	} else
-		efree(cellname);
-	io_txtindata.curnodeproto->cell = cell;
-	db_insertnodeproto(io_txtindata.curnodeproto);
+	io_txtindata.curnodeproto->lib = io_txtindata.curlib;
 }
 
 /*
- * get the version of the current facet (keyword "version")
+ * get the version of the current cell (keyword "version")
  */
 void io_celver(void)
 {
 	io_txtindata.curnodeproto->version = eatoi(io_keyword);
+	db_insertnodeproto(io_txtindata.curnodeproto);
 }
 
 /*
- * get the creation date of the current facet (keyword "creationdate")
+ * get the creation date of the current cell (keyword "creationdate")
  */
 void io_celcre(void)
 {
@@ -1355,7 +1384,7 @@ void io_celcre(void)
 }
 
 /*
- * get the revision date of the current facet (keyword "revisiondate")
+ * get the revision date of the current cell (keyword "revisiondate")
  */
 void io_celrev(void)
 {
@@ -1373,7 +1402,6 @@ void io_celext(void)
 	CHAR *filename, *libfile, *oldline2, *libfilename, *libfilepath;
 	FILE *io;
 	REGISTER BOOLEAN failed;
-	REGISTER CELL *cell;
 	CHAR *cellname;
 	REGISTER NODEPROTO *np, *onp;
 	REGISTER NODEINST *ni;
@@ -1445,7 +1473,7 @@ void io_celext(void)
 
 		/* read the external library */
 		savetxtindata = io_txtindata;
-		if (io_verbose < 0 && io_txtindata.filelength > 0)
+		if (io_verbose < 0 && io_txtindata.filelength > 0 && io_inputprogressdialog != 0)
 		{
 			(void)allocstring(&oldline2, DiaGetTextProgress(io_inputprogressdialog), el_tempcluster);
 		}
@@ -1469,7 +1497,7 @@ void io_celext(void)
 			io_queuereadlibraryannouncement(elib);
 		}
 		io_txtindata = savetxtindata;
-		if (io_verbose < 0 && io_txtindata.filelength > 0)
+		if (io_verbose < 0 && io_txtindata.filelength > 0 && io_inputprogressdialog != 0)
 		{
 			DiaSetProgress(io_inputprogressdialog, io_txtindata.fileposition, io_txtindata.filelength);
 			infstr = initinfstr();
@@ -1480,81 +1508,62 @@ void io_celext(void)
 		}
 	}
 
-	/* find this facet in the external library */
+	/* find this cell in the external library */
+	cellname = io_txtindata.curnodeproto->protoname;
 	for(np = elib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
-		if (namesame(np->cell->cellname, io_txtindata.curnodeproto->cell->cellname) != 0) continue;
+		if (namesame(np->protoname, cellname) != 0) continue;
 		if (np->cellview != io_txtindata.curnodeproto->cellview) continue;
 		if (np->version != io_txtindata.curnodeproto->version) continue;
 		break;
 	}
 	if (np == NONODEPROTO)
 	{
-		/* facet not found in library: issue warning */
+		/* cell not found in library: issue warning */
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, io_txtindata.curnodeproto->cell->cellname);
+		addstringtoinfstr(infstr, cellname);
 		if (io_txtindata.curnodeproto->cellview != el_unknownview)
 		{
 			addtoinfstr(infstr, '{');
 			addstringtoinfstr(infstr, io_txtindata.curnodeproto->cellview->sviewname);
 			addtoinfstr(infstr, '}');
 		}
-		ttyputerr(_("Cannot find facet %s in library %s..creating dummy version"),
+		ttyputerr(_("Cannot find cell %s in library %s..creating dummy version"),
 			returninfstr(infstr), elib->libname);
 	} else
 	{
-		/* facet found: make sure it is valid */
+		/* cell found: make sure it is valid */
 		if (np->revisiondate != io_txtindata.curnodeproto->revisiondate ||
 			np->lowx != io_txtindata.curnodeproto->lowx ||
 			np->highx != io_txtindata.curnodeproto->highx ||
 			np->lowy != io_txtindata.curnodeproto->lowy ||
 			np->highy != io_txtindata.curnodeproto->highy)
 		{
-			ttyputerr(_("Warning: facet %s in library %s has been modified"),
+			ttyputerr(_("Warning: cell %s in library %s has been modified"),
 				describenodeproto(np), elib->libname);
 			np = NONODEPROTO;
 		}
 	}
 	if (np != NONODEPROTO)
 	{
-		/* get rid of existing facet/cell and plug in the external reference */
-		onp = io_txtindata.nodeprotolist[io_txtindata.curfacetnumber];
-		cell = onp->cell;
+		/* get rid of existing cell and plug in the external reference */
+		onp = io_txtindata.nodeprotolist[io_txtindata.curcellnumber];
 		db_retractnodeproto(onp);
-		if (cell->firstincell == NONODEPROTO)
-		{
-			efree(cell->cellname);
-			efree((CHAR *)cell);
-		}
 		freenodeproto(onp);
-		io_txtindata.nodeprotolist[io_txtindata.curfacetnumber] = np;
+		io_txtindata.nodeprotolist[io_txtindata.curcellnumber] = np;
 	} else
 	{
 		/* rename the cell */
 		np = io_txtindata.curnodeproto;
 		infstr = initinfstr();
-		formatinfstr(infstr, x_("%sFROM%s"), np->cell->cellname, elib->libname);
-		cell = np->cell;
+		formatinfstr(infstr, x_("%sFROM%s"), cellname, elib->libname);
 		db_retractnodeproto(np);
-		if (cell->firstincell == NONODEPROTO)
-		{
-			efree(cell->cellname);
-			efree((CHAR *)cell);
-		}
 
 		cellname = returninfstr(infstr);
-		cell = db_findcellname(cellname, io_txtindata.curlib);
-		if (cell == NOCELL)
-		{
-			cell = alloccell(io_txtindata.curlib->cluster);
-			if (cell == NOCELL) longjmp(io_filerror, LONGJMPNOMEM);
-			cell->lib = io_txtindata.curlib;
-			(void)allocstring(&cell->cellname, cellname, io_txtindata.curlib->cluster);
-		}
-		np->cell = cell;
+		(void)allocstring(&np->protoname, cellname, io_txtindata.curlib->cluster);
 		db_insertnodeproto(np);
 
-		/* create an artwork "Crossed box" to define the facet size */
+		/* create an artwork "Crossed box" to define the cell size */
 		ni = allocnodeinst(io_txtindata.curlib->cluster);
 		ni->proto = art_crossedboxprim;
 		ni->parent = np;
@@ -1569,7 +1578,7 @@ void io_celext(void)
 }
 
 /*
- * get the boundary of the current facet
+ * get the boundary of the current cell
  */
 void io_cellx(void)
 {
@@ -1592,7 +1601,7 @@ void io_celhy(void)
 }
 
 /*
- * get the default technology for objects in this facet (keyword "technology")
+ * get the default technology for objects in this cell (keyword "technology")
  */
 void io_tech(void)
 {
@@ -1604,7 +1613,7 @@ void io_tech(void)
 }
 
 /*
- * get the tool dirty word for the current facet (keyword "aadirty")
+ * get the tool dirty word for the current cell (keyword "aadirty")
  */
 void io_celaad(void)
 {
@@ -1613,7 +1622,7 @@ void io_celaad(void)
 }
 
 /*
- * get tool information for current facet (keyword "bits")
+ * get tool information for current cell (keyword "bits")
  */
 void io_celbit(void)
 {
@@ -1622,7 +1631,7 @@ void io_celbit(void)
 }
 
 /*
- * get tool information for current facet (keyword "userbits")
+ * get tool information for current cell (keyword "userbits")
  */
 void io_celusb(void)
 {
@@ -1630,12 +1639,12 @@ void io_celusb(void)
 }
 
 /*
- * get tool information for current facet (keyword "netnum")
+ * get tool information for current cell (keyword "netnum")
  */
 void io_celnet(void) {}
 
 /*
- * get the number of node instances in the current facet (keyword "nodes")
+ * get the number of node instances in the current cell (keyword "nodes")
  */
 void io_celnoc(void)
 {
@@ -1662,7 +1671,7 @@ void io_celnoc(void)
 		ni->firstportexpinst = NOPORTEXPINST;
 		ni->geom = geomlist[i];
 
-		/* compute linked list of nodes in this facet */
+		/* compute linked list of nodes in this cell */
 		if (io_txtindata.curnodeproto->firstnodeinst != NONODEINST)
 			io_txtindata.curnodeproto->firstnodeinst->prevnodeinst = ni;
 		ni->nextnodeinst = io_txtindata.curnodeproto->firstnodeinst;
@@ -1673,7 +1682,7 @@ void io_celnoc(void)
 }
 
 /*
- * get the number of arc instances in the current facet (keyword "arcs")
+ * get the number of arc instances in the current cell (keyword "arcs")
  */
 void io_celarc(void)
 {
@@ -1698,7 +1707,7 @@ void io_celarc(void)
 		ai->parent = io_txtindata.curnodeproto;
 		ai->geom = geomlist[i];
 
-		/* compute linked list of arcs in this facet */
+		/* compute linked list of arcs in this cell */
 		if (io_txtindata.curnodeproto->firstarcinst != NOARCINST)
 			io_txtindata.curnodeproto->firstarcinst->prevarcinst = ai;
 		ai->nextarcinst = io_txtindata.curnodeproto->firstarcinst;
@@ -1709,7 +1718,7 @@ void io_celarc(void)
 }
 
 /*
- * get the number of port prototypes in the current facet (keyword "porttypes")
+ * get the number of port prototypes in the current cell (keyword "porttypes")
  */
 void io_celptc(void)
 {
@@ -1737,7 +1746,7 @@ void io_celptc(void)
 }
 
 /*
- * close the current facet (keyword "celldone")
+ * close the current cell (keyword "celldone")
  */
 void io_celdon(void)
 {
@@ -1747,10 +1756,10 @@ void io_celdon(void)
 	REGISTER PORTARCINST *pi;
 	REGISTER GEOM *geom;
 
-	/* verify facet name */
-	if (namesame(io_keyword, io_txtindata.curnodeproto->cell->cellname) != 0)
-		ttyputmsg(_("Warning: facet '%s' wants to be '%s'"),
-			io_txtindata.curnodeproto->cell->cellname, io_keyword);
+	/* verify cell name */
+	if (namesame(io_keyword, io_txtindata.curnodeproto->protoname) != 0)
+		ttyputmsg(_("Warning: cell '%s' wants to be '%s'"),
+			io_txtindata.curnodeproto->protoname, io_keyword);
 
 	/* silly hack: convert arcinst->end->portarcinst pointers */
 	for(i=0; i<io_txtindata.nodeinstcount; i++)
@@ -1774,7 +1783,7 @@ void io_celdon(void)
 		}
 	}
 
-	/* create geometry structure in the facet */
+	/* create geometry structure in the cell */
 	if (geomstructure(io_txtindata.curnodeproto))
 		longjmp(io_filerror, LONGJMPNOMEM);
 
@@ -1797,7 +1806,7 @@ void io_celdon(void)
 		linkgeom(geom, io_txtindata.curnodeproto);
 	}
 
-	/* free the lists of objects in this facet */
+	/* free the lists of objects in this cell */
 	if (io_txtindata.nodeinstcount != 0) efree((CHAR *)io_txtindata.nodelist);
 	if (io_txtindata.portprotocount != 0) efree((CHAR *)io_txtindata.portprotolist);
 	if (io_txtindata.arcinstcount != 0) efree((CHAR *)io_txtindata.arclist);
@@ -1843,7 +1852,7 @@ void io_nodtyp(void)
 		} else tech = io_txtindata.curtech;
 		if (io_txtindata.curtech == NOTECHNOLOGY) io_txtindata.curtech = tech;
 		for(np = tech->firstnodeproto; np != NONODEPROTO;
-			np = np->nextnodeproto) if (namesame(np->primname, line) == 0)
+			np = np->nextnodeproto) if (namesame(np->protoname, line) == 0)
 		{
 			io_txtindata.curnodeinst->proto = np;
 			return;
@@ -1853,7 +1862,7 @@ void io_nodtyp(void)
 		if (estrcmp(line, x_("Active-Node")) == 0)
 		{
 			for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-				if (estrcmp(np->primname, x_("P-Active-Node")) == 0)
+				if (estrcmp(np->protoname, x_("P-Active-Node")) == 0)
 			{
 				io_txtindata.curnodeinst->proto = np;
 				return;
@@ -1941,7 +1950,47 @@ void io_nodrot(void)
  */
 void io_nodtra(void)
 {
-	io_txtindata.curnodeinst->transpose = eatoi(io_keyword);
+	REGISTER INTSML tvalue;
+
+	tvalue = eatoi(io_keyword);
+
+	/* in 7.01 and higher, allow mirror bits */
+	if (io_txtindata.emajor > 7 ||
+		(io_txtindata.emajor == 7 && io_txtindata.eminor >= 1))
+	{
+		/* new version: allow mirror bits */
+		io_txtindata.curnodeinst->transpose = 0;
+		if ((tvalue&1) != 0)
+		{
+			/* the old-style transpose bit */
+			io_txtindata.curnodeinst->transpose = 1;
+		} else
+		{
+			/* check for new style mirror bits */
+			if ((tvalue&2) != 0)
+			{
+				if ((tvalue&4) != 0)
+				{
+					/* mirror in X and Y */
+					io_txtindata.curnodeinst->rotation = (io_txtindata.curnodeinst->rotation + 1800) % 3600;
+				} else
+				{
+					/* mirror in X */
+					io_txtindata.curnodeinst->rotation = (io_txtindata.curnodeinst->rotation + 900) % 3600;
+					io_txtindata.curnodeinst->transpose = 1;
+				}
+			} else if ((tvalue&4) != 0)
+			{
+				/* mirror in Y */
+				io_txtindata.curnodeinst->rotation = (io_txtindata.curnodeinst->rotation + 2700) % 3600;
+				io_txtindata.curnodeinst->transpose = 1;
+			}
+		}
+	} else
+	{
+		/* old version: just treat it as a transpose */
+		io_txtindata.curnodeinst->transpose = tvalue;
+	}
 }
 
 /*
