@@ -32,7 +32,7 @@
 #include "global.h"
 #include "eio.h"
 
-static INTBIG io_facetnumber, io_nodeinsterror, io_portarcinsterror, io_portexpinsterror,
+static INTBIG io_cellnumber, io_nodeinsterror, io_portarcinsterror, io_portexpinsterror,
 	  io_portprotoerror, io_arcinsterror, io_geomerror, io_rtnodeerror, io_libraryerror;
 
 /* prototypes for local routines */
@@ -48,8 +48,8 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 {
 	REGISTER CHAR *name;
 	CHAR file[256], *truename;
-	REGISTER INTBIG i, j, noc, arcinst, poc, facet;
-	REGISTER NODEPROTO *np;
+	REGISTER INTBIG i, j, t, noc, arcinst, poc, cell, cellgroup;
+	REGISTER NODEPROTO *np, *onp;
 	REGISTER PORTPROTO *pp;
 	REGISTER LIBRARY *olib;
 	REGISTER NODEINST *ni;
@@ -58,7 +58,7 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	REGISTER ARCINST *ai;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER VIEW *v;
-	REGISTER NODEPROTO **facets;
+	REGISTER NODEPROTO **cells;
 
 	(void)estrcpy(file, lib->libfile);
 	name = &file[estrlen(file)-5];
@@ -82,16 +82,16 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = -1;
-	io_facetnumber = 0;
+	io_cellnumber = 0;
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (np->firstinst == NONODEINST) io_textrecurse(np);
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (np->temp1 < 0) io_textrecurse(np);
-	if (io_facetnumber > 0)
+	if (io_cellnumber > 0)
 	{
-		facets = (NODEPROTO **)emalloc((io_facetnumber * sizeof(NODEPROTO *)),
+		cells = (NODEPROTO **)emalloc((io_cellnumber * sizeof(NODEPROTO *)),
 			io_tool->cluster);
-		if (facets == 0)
+		if (cells == 0)
 		{
 			ttyputnomemory();
 			return(TRUE);
@@ -100,12 +100,24 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 		{
 			for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			{
-				if (np->temp1 >= 0 && np->temp1 < io_facetnumber)
-					facets[np->temp1] = np;
+				if (np->temp1 >= 0 && np->temp1 < io_cellnumber)
+					cells[np->temp1] = np;
 			}
 		}
 	}
 
+	/* determine cell groupings */
+	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		np->temp2 = 0;
+	cellgroup = 0;
+	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+	{
+		if (np->temp2 != 0) continue;
+		cellgroup++;
+		FOR_CELLGROUP(onp, np)
+			onp->temp2 = cellgroup;
+	}
+
 	/* write header information */
 	xprintf(io_fileout, x_("****library: \"%s\"\n"), lib->libname);
 	xprintf(io_fileout, x_("version: %s\n"), el_version);
@@ -125,7 +137,7 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	}
 	for(v = el_views; v != NOVIEW; v = v->nextview)
 		xprintf(io_fileout, x_("view: %s{%s}\n"), v->viewname, v->sviewname);
-	xprintf(io_fileout, x_("cellcount: %ld\n"), io_facetnumber);
+	xprintf(io_fileout, x_("cellcount: %ld\n"), io_cellnumber);
 	if (lib->curnodeproto != NONODEPROTO)
 		xprintf(io_fileout, x_("maincell: %ld\n"), lib->curnodeproto->temp1);
 
@@ -133,12 +145,12 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	io_writevars(lib->numvar, lib->firstvar, NONODEPROTO);
 
 	/* write the rest of the database */
-	for(facet = 0; facet < io_facetnumber; facet++)
+	for(cell = 0; cell < io_cellnumber; cell++)
 	{
 		/* write the nodeproto name */
-		np = facets[facet];
-		xprintf(io_fileout, x_("***cell: %ld\n"), np->temp1);
-		xprintf(io_fileout, x_("name: %s"), np->cell->cellname);
+		np = cells[cell];
+		xprintf(io_fileout, x_("***cell: %ld/%ld\n"), np->temp1, np->temp2);
+		xprintf(io_fileout, x_("name: %s"), np->protoname);
 		if (*np->cellview->sviewname != 0)
 			xprintf(io_fileout, x_("{%s}"), np->cellview->sviewname);
 		xprintf(io_fileout, x_("\n"));
@@ -150,11 +162,11 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 		xprintf(io_fileout, x_("lowx: %ld highx: %ld lowy: %ld highy: %ld\n"),
 			np->lowx, np->highx, np->lowy, np->highy);
 
-		/* facets in external libraries mention the library and stop */
-		if (np->cell->lib != lib)
+		/* cells in external libraries mention the library and stop */
+		if (np->lib != lib)
 		{
 			xprintf(io_fileout, x_("externallibrary: \"%s\"\n"),
-				np->cell->lib->libfile);
+				np->lib->libfile);
 			continue;
 		}
 
@@ -172,20 +184,21 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 			pp->temp1 = poc++;
 		xprintf(io_fileout, x_("nodes: %ld arcs: %ld porttypes: %ld\n"), noc, arcinst, poc);
 
-		/* write variables on the facet */
+		/* write variables on the cell */
 		io_writevars(np->numvar, np->firstvar, np);
 
-		/* write the nodes in this facet */
+		/* write the nodes in this cell */
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			xprintf(io_fileout, x_("**node: %ld\n"), ni->temp1);
 			if (ni->proto->primindex == 0)
 				xprintf(io_fileout, x_("type: [%ld]\n"), ni->proto->temp1); else
 					xprintf(io_fileout, x_("type: %s:%s\n"),
-						ni->proto->tech->techname, ni->proto->primname);
+						ni->proto->tech->techname, ni->proto->protoname);
 			xprintf(io_fileout, x_("lowx: %ld highx: %ld lowy: %ld highy: %ld\n"), ni->lowx,
 				ni->highx, ni->lowy, ni->highy);
-			xprintf(io_fileout, x_("rotation: %d transpose: %d\n"), ni->rotation, ni->transpose);
+			if (ni->transpose != 0) t = 1; else t = 0;
+			xprintf(io_fileout, x_("rotation: %d transpose: %d\n"), ni->rotation, t);
 			if (ni->proto->primindex == 0)
 			{
 				xprintf(io_fileout, x_("descript: %ld/%ld\n"), ni->textdescript[0],
@@ -217,7 +230,7 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 			}
 		}
 
-		/* write the portprotos in this facet */
+		/* write the portprotos in this cell */
 		poc = 0;
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
@@ -233,7 +246,7 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 			io_writevars(pp->numvar, pp->firstvar, np);
 		}
 
-		/* write the arcs in this facet */
+		/* write the arcs in this cell */
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		{
 			xprintf(io_fileout, x_("**arc: %ld\n"), ai->temp1);
@@ -249,16 +262,16 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 			}
 			io_writevars(ai->numvar, ai->firstvar, np);
 		}
-		xprintf(io_fileout, x_("celldone: %s\n"), np->cell->cellname);
+		xprintf(io_fileout, x_("celldone: %s\n"), np->protoname);
 	}
 
 	/* print any variable-related error messages */
 	if (io_nodeinsterror != 0)
-		ttyputmsg(x_("Warning: %ld NODEINST pointers point outside facet: not saved"), io_nodeinsterror);
+		ttyputmsg(x_("Warning: %ld NODEINST pointers point outside cell: not saved"), io_nodeinsterror);
 	if (io_arcinsterror != 0)
-		ttyputmsg(x_("Warning: %ld ARCINST pointers point outside facet: not saved"), io_arcinsterror);
+		ttyputmsg(x_("Warning: %ld ARCINST pointers point outside cell: not saved"), io_arcinsterror);
 	if (io_portprotoerror != 0)
-		ttyputmsg(x_("Warning: %ld PORTPROTO pointers point outside facet: not saved"), io_portprotoerror);
+		ttyputmsg(x_("Warning: %ld PORTPROTO pointers point outside cell: not saved"), io_portprotoerror);
 	if (io_portarcinsterror != 0)
 		ttyputmsg(x_("Warning: %ld PORTARCINST pointers could not be saved"), io_portarcinsterror);
 	if (io_portexpinsterror != 0)
@@ -274,7 +287,7 @@ BOOLEAN io_writetextlibrary(LIBRARY *lib)
 	xclose(io_fileout);
 	ttyputmsg(_("%s written"), truename);
 	lib->userbits &= ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR);
-	if (io_facetnumber > 0) efree((CHAR *)facets);
+	if (io_cellnumber > 0) efree((CHAR *)cells);
 	return(FALSE);
 }
 
@@ -292,8 +305,8 @@ void io_textrecurse(NODEPROTO *np)
 		if (ni->proto->temp1 == -1) io_textrecurse(ni->proto);
 	}
 
-	/* add this facet to the list */
-	np->temp1 = io_facetnumber++;
+	/* add this cell to the list */
+	np->temp1 = io_cellnumber++;
 }
 
 /*
@@ -310,9 +323,9 @@ INTBIG io_countvars(INTBIG numvar, VARIABLE *firstvar)
 }
 
 /*
- * routine to write the variables on an object.  The current facet is
- * "curnodeproto" such that any references to objects in a facet must be in
- * this facet.
+ * routine to write the variables on an object.  The current cell is
+ * "curnodeproto" such that any references to objects in a cell must be in
+ * this cell.
  */
 void io_writevars(INTBIG numvar, VARIABLE *firstvar, NODEPROTO *curnodeproto)
 {
@@ -485,7 +498,7 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			{
 				io_addstring(infstr, np->tech->techname);
 				addtoinfstr(infstr, ':');
-				io_addstring(infstr, np->primname);
+				io_addstring(infstr, np->protoname);
 			}
 			break;
 		case VPORTARCINST:
@@ -596,7 +609,6 @@ void io_makestringvar(void *infstr, INTBIG type, INTBIG addr, NODEPROTO *curnode
 			addstringtoinfstr(infstr, line);
 			break;
 		case VNETWORK:
-		case VCELL:
 		case VVIEW:
 		case VWINDOWPART:
 		case VGRAPHICS:
