@@ -85,17 +85,17 @@ BOOLEAN io_readvhdllibrary(LIBRARY *lib)
 
 void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 {
-	CHAR *pt, *start, text[MAXCHARS], facetname[256], endtag[256];
+	CHAR *pt, *start, text[MAXCHARS], cellname[256], endtag[256];
 	REGISTER CHAR save;
 	enum {SECTIONNONE, SECTIONCOMPONENT, SECTIONENTITY, SECTIONARCHITECTURE} sectiontype;
 	REGISTER INTBIG i, len, curLength, sectionnamelen;
-	REGISTER NODEPROTO *storagefacet;
+	REGISTER NODEPROTO *storagecell;
 	void *stringarray;
 	REGISTER VARIABLE *var;
 
 	/* read the file */
 	io_vhdlcurline = 0;
-	storagefacet = NONODEPROTO;
+	storagecell = NONODEPROTO;
 	for(;;)
 	{
 		if (stopping(STOPREASONVHDL)) break;
@@ -107,9 +107,9 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 			DiaSetProgress(dia, curLength, io_vhdllength);
 		}
 
-		if (storagefacet == NONODEPROTO)
+		if (storagecell == NONODEPROTO)
 		{
-			/* scan for start of facet */
+			/* scan for start of cell */
 			pt = text;
 			while (*pt == ' ' || *pt == '\t') pt++;
 			sectiontype = SECTIONNONE;
@@ -130,7 +130,7 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 					save = *pt;
 					*pt = 0;
 					estrcpy(endtag, start);
-					estrcpy(facetname, start);
+					estrcpy(cellname, start);
 					*pt = save;
 
 					if (sectiontype == SECTIONARCHITECTURE)
@@ -144,23 +144,23 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 							while (*pt != 0 && *pt != ' ' && *pt != '\t') pt++;
 							save = *pt;
 							*pt = 0;
-							estrcpy(facetname, start);
+							estrcpy(cellname, start);
 							*pt = save;
 						}
 					}
 
-					for(storagefacet = lib->firstnodeproto; storagefacet != NONODEPROTO;
-						storagefacet = storagefacet->nextnodeproto)
-							if (namesame(facetname, storagefacet->cell->cellname) == 0 &&
-								storagefacet->cellview == el_vhdlview) break;
+					for(storagecell = lib->firstnodeproto; storagecell != NONODEPROTO;
+						storagecell = storagecell->nextnodeproto)
+							if (namesame(cellname, storagecell->protoname) == 0 &&
+								storagecell->cellview == el_vhdlview) break;
 
-					/* see if the facet already exists */
-					if (storagefacet != NONODEPROTO)
+					/* see if the cell already exists */
+					if (storagecell != NONODEPROTO)
 					{
 						/* already there: start with the existing VHDL */
 						stringarray = newstringarray(io_tool->cluster);
-						var = getvalkey((INTBIG)storagefacet, VNODEPROTO, VSTRING|VISARRAY,
-							el_facet_message_key);
+						var = getvalkey((INTBIG)storagecell, VNODEPROTO, VSTRING|VISARRAY,
+							el_cell_message_key);
 						if (var != NOVARIABLE)
 						{
 							len = getlength(var);
@@ -170,21 +170,21 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 						}
 					} else
 					{
-						estrcat(facetname, x_("{vhdl}"));
-						storagefacet = newnodeproto(facetname, lib);
-						if (storagefacet == NONODEPROTO)
+						estrcat(cellname, x_("{vhdl}"));
+						storagecell = newnodeproto(cellname, lib);
+						if (storagecell == NONODEPROTO)
 						{
-							ttyputerr(_("Could not create facet %s"), facetname);
+							ttyputerr(_("Could not create cell %s"), cellname);
 							return;
 						}
 						stringarray = newstringarray(io_tool->cluster);
 					}
 				}
 			}
-			if (storagefacet == NONODEPROTO) continue;
+			if (storagecell == NONODEPROTO) continue;
 		}
 
-		/* save this line in the facet */
+		/* save this line in the cell */
 		addtostringarray(stringarray, text);
 
 		/* see if this is the last line */
@@ -201,9 +201,9 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 					case SECTIONCOMPONENT:
 						if (namesamen(pt, x_("component"), 9) == 0)
 						{
-							stringarraytotextfacet(stringarray, storagefacet, TRUE);
+							stringarraytotextcell(stringarray, storagecell, TRUE);
 							killstringarray(stringarray);
-							storagefacet = NONODEPROTO;
+							storagecell = NONODEPROTO;
 						}
 						break;
 					case SECTIONENTITY:
@@ -213,9 +213,9 @@ void io_vhdlreadfile(LIBRARY *lib, FILE *io, void *dia)
 						save = *pt;   *pt = 0;
 						if (namesame(start, endtag) == 0)
 						{
-							stringarraytotextfacet(stringarray, storagefacet, TRUE);
+							stringarraytotextcell(stringarray, storagecell, TRUE);
 							killstringarray(stringarray);
-							storagefacet = NONODEPROTO;
+							storagecell = NONODEPROTO;
 						}
 						*pt = save;
 						break;
