@@ -31,10 +31,10 @@
  */
 
 /*
- * When compacting facet instances, the system only examines polygons
- * within a protection frame of the facet border.  This frame is the largest
- * design rule distance in the technology.  If the facet border is irregular,
- * there may be objects that are not seen, causing the facet to overlap
+ * When compacting cell instances, the system only examines polygons
+ * within a protection frame of the cell border.  This frame is the largest
+ * design rule distance in the technology.  If the cell border is irregular,
+ * there may be objects that are not seen, causing the cell to overlap
  * more than it should.
  */
 
@@ -46,6 +46,7 @@
 #include "efunction.h"
 #include "edialogs.h"
 #include "conlay.h"
+#include "usr.h"
 
 #define DEFAULT_VAL -99999999
 #define HORIZONTAL          0
@@ -134,12 +135,12 @@ static void com_addlinedescription(void*, LINE*);
 static CHAR *com_describeobject(OBJECT*);
 static void com_createobjects(NODEINST*, INTBIG, OBJECT**, OBJECT**);
 static OBJECT *com_make_ai_object(ARCINST*, OBJECT*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-static BOOLEAN com_examineonefacet(NODEPROTO*, INTBIG, BOOLEAN);
+static BOOLEAN com_examineonecell(NODEPROTO*, INTBIG, BOOLEAN);
 static void comp_optionsdlog(void);
 
 /* the COMPACTOR tool table */
-static COMCOMP comcp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	0, x_(" \t"), M_("facet to be rechecked"), M_("default is current facet")};
+static COMCOMP comcp = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
+	0, x_(" \t"), M_("cell to be rechecked"), M_("default is current cell")};
 static KEYWORD comnotopt[] =
 {
 	{x_("spread"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -272,8 +273,9 @@ void com_slice(void)
 {
 	REGISTER BOOLEAN change;
 	REGISTER NODEPROTO *np;
+	CHAR *arg[2];
 
-	np = getcurfacet();
+	np = getcurcell();
 	if (np == NONODEPROTO) return;
 
 	/* make sure network tool is on */
@@ -284,16 +286,27 @@ void com_slice(void)
 		return;
 	}
 
+	/* special handling for technology-edit cells */
+	if (el_curwindowpart != NOWINDOWPART && np != NONODEPROTO &&
+		(el_curwindowpart->state&WINDOWMODE) == WINDOWTECEDMODE)
+	{
+		/* special compaction of a technology edit cell can be done by the tec-editor */
+		arg[0] = x_("compact-current-cell");
+		us_tecedentry(1, arg);
+		toolturnoff(com_tool, FALSE);
+		return;
+	}
+
 	/* on alternate slices, do vertical then horizontal compaction */
 	if (com_do_axis == VERTICAL) com_do_axis = HORIZONTAL; else
 		com_do_axis = VERTICAL;
 
-	change = com_examineonefacet(np, com_do_axis, TRUE);
+	change = com_examineonecell(np, com_do_axis, TRUE);
 
 	if (!change)
 	{
-		 ttyputmsg(_("No further change.  Compactor turned off"));
-		 toolturnoff(com_tool, FALSE);
+		ttyputmsg(_("No further change.  Compactor turned off"));
+		toolturnoff(com_tool, FALSE);
 	} else setactivity(_("Compaction"));
 }
 
@@ -380,26 +393,26 @@ void com_set(INTBIG count, CHAR *par[])
 			np = getnodeproto(par[2]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(M_("No facet named %s"), par[2]);
+				ttyputerr(M_("No cell named %s"), par[2]);
 				return;
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr(M_("Can only compact facets, not primitives"));
+				ttyputerr(M_("Can only compact cells, not primitives"));
 				return;
 			}
 		} else
 		{
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("No current facet"));
+				ttyputerr(_("No current cell"));
 				return;
 			}
 		}
 
-		(void)com_examineonefacet(np, com_do_axis, FALSE);
-		ttyputmsg(_("Facet %s compacted"), describenodeproto(np));
+		(void)com_examineonecell(np, com_do_axis, FALSE);
+		ttyputmsg(_("Cell %s compacted"), describenodeproto(np));
 		return;
 	}
 
@@ -423,10 +436,10 @@ void com_set(INTBIG count, CHAR *par[])
 
 /*
  * routine to do vertical compaction (if "axis" is VERTICAL) or horizontal
- * compaction (if "axis" is HORIZONTAL) to facet "np".  Displays state if
+ * compaction (if "axis" is HORIZONTAL) to cell "np".  Displays state if
  * "verbose" is nonzero.  Returns true if a change was made.
  */
-BOOLEAN com_examineonefacet(NODEPROTO *np, INTBIG axis, BOOLEAN verbose)
+BOOLEAN com_examineonecell(NODEPROTO *np, INTBIG axis, BOOLEAN verbose)
 {
 	REGISTER NODEINST *ni;
 	REGISTER PORTPROTO *pp, *opp;
@@ -441,7 +454,7 @@ BOOLEAN com_examineonefacet(NODEPROTO *np, INTBIG axis, BOOLEAN verbose)
 
 	if (np == NONODEPROTO)
 	{
-		ttyputmsg(_("No current facet to compact"));
+		ttyputmsg(_("No current cell to compact"));
 		return(FALSE);
 	}
 
@@ -449,7 +462,7 @@ BOOLEAN com_examineonefacet(NODEPROTO *np, INTBIG axis, BOOLEAN verbose)
 	com_maxboundary = 0;
 	for(i=0; i<el_curtech->layercount; i++)
 	{
-		max = maxdrcsurround(el_curtech, np->cell->lib, i);
+		max = maxdrcsurround(el_curtech, np->lib, i);
 		if (max > com_maxboundary) com_maxboundary = max;
 	}
 	if (com_maxboundary < 0) com_maxboundary = 0;
@@ -624,7 +637,7 @@ void com_createobjects(NODEINST *ni, INTBIG axis, OBJECT **thisobject,
 /*
  * routine to build a "object" structure that describes arc "ai".  If "object"
  * is NOOBJECT, this arc is at the top level, and a new OBJECT should be
- * constructed for it.  Otherwise, the arc is in a subfacet and it must be
+ * constructed for it.  Otherwise, the arc is in a subcell and it must be
  * transformed through "newtrans" and clipped to the two protection frames
  * defined by "low1", "high1" and "low2", "high2" before being added to "object".
  */
@@ -694,7 +707,7 @@ OBJECT *com_make_ai_object(ARCINST *ai, OBJECT *object, XARRAY newtrans,
 /*
  * routine to build a object describing node "ni" in axis "axis".  If "object"
  * is NOOBJECT, this node is at the top level, and a new OBJECT should be
- * constructed for it.  Otherwise, the node is in a subfacet and it must be
+ * constructed for it.  Otherwise, the node is in a subcell and it must be
  * transformed through "newtrans" and clipped to the two protection frames
  * defined by "low1" to "high1" and "low2" to "high2" before being added to
  * "object".
@@ -738,9 +751,9 @@ OBJECT *com_make_ni_object(NODEINST *ni, OBJECT *object, XARRAY newtrans,
 		transmult(t1, temp, trans);
 
 		/*
-		 * create a line for facet "ni->proto" at the current location and
+		 * create a line for cell "ni->proto" at the current location and
 		 * translation.  Put only the instances which are within com_maxboundary
-		 * of the perimeter of the facet.
+		 * of the perimeter of the cell.
 		 */
 		com_subsmash(ni->proto);
 
@@ -1025,7 +1038,7 @@ INTBIG com_findleastlow(LINE *line, INTBIG axis)
 }
 
 BOOLEAN com_compact(LINE *line, LINE *other_line, INTBIG axis, BOOLEAN change,
-	NODEPROTO *facet)
+	NODEPROTO *cell)
 {
 	REGISTER LINE *cur_line, *prev_line;
 	REGISTER OBJECT *cur_object, *thisoreason, *otheroreason;
@@ -1059,7 +1072,7 @@ BOOLEAN com_compact(LINE *line, LINE *other_line, INTBIG axis, BOOLEAN change,
 
 				/* simple object compaction */
 				this_motion = com_checkinst(cur_object, prev_line, axis,
-					&oreason, &opreason, &preason, facet);
+					&oreason, &opreason, &preason, cell);
 				if (this_motion == DEFAULT_VAL) continue;
 				if (best_motion == DEFAULT_VAL || this_motion < best_motion)
 				{
@@ -1117,7 +1130,7 @@ BOOLEAN com_compact(LINE *line, LINE *other_line, INTBIG axis, BOOLEAN change,
 }
 
 INTBIG com_checkinst(OBJECT *object, LINE *line, INTBIG axis, OBJECT **oreason,
-	COMPPOLYLIST **opreason, COMPPOLYLIST **preason, NODEPROTO *facet)
+	COMPPOLYLIST **opreason, COMPPOLYLIST **preason, NODEPROTO *cell)
 {
 	REGISTER INTBIG layer;
 	REGISTER INTBIG this_motion, best_motion;
@@ -1138,7 +1151,7 @@ INTBIG com_checkinst(OBJECT *object, LINE *line, INTBIG axis, OBJECT **oreason,
 
 		/* find distance line can move toward this poly */
 		this_motion = com_minseparate(object, layer, polys, line, axis,
-			&suboreason, &subpreason, facet);
+			&suboreason, &subpreason, cell);
 		if (this_motion == DEFAULT_VAL) continue;
 		if (best_motion == DEFAULT_VAL || this_motion < best_motion)
 		{
@@ -1161,7 +1174,7 @@ INTBIG com_checkinst(OBJECT *object, LINE *line, INTBIG axis, OBJECT **oreason,
  */
 INTBIG com_minseparate(OBJECT *object, INTBIG nlayer, COMPPOLYLIST *npolys,
 	LINE *line, INTBIG axis, OBJECT **oreason, COMPPOLYLIST **preason,
-	NODEPROTO *facet)
+	NODEPROTO *cell)
 {
 	REGISTER INTBIG bound, dist, geom_lo, ai_hi, ni_hi,
 		best_motion, this_motion, fun, minsize, nminsize;
@@ -1180,7 +1193,7 @@ INTBIG com_minseparate(OBJECT *object, INTBIG nlayer, COMPPOLYLIST *npolys,
 	nindex = npolys->networknum;
 
 	/* see how far around the box it is necessary to search */
-	bound = maxdrcsurround(tech, facet->cell->lib, nlayer);
+	bound = maxdrcsurround(tech, cell->lib, nlayer);
 
 	/* if there is no separation, allow them to sit on top of each other */
 	if (bound < 0) return(DEFAULT_VAL);
@@ -1235,7 +1248,7 @@ INTBIG com_minseparate(OBJECT *object, INTBIG nlayer, COMPPOLYLIST *npolys,
 
 					/* see how close they can get */
 					minsize = polyminsize(poly);
-					dist = drcmindistance(tech, facet->cell->lib, nlayer, nminsize,
+					dist = drcmindistance(tech, cell->lib, nlayer, nminsize,
 						layer, minsize, con, FALSE, &edge, 0);
 					if (dist < 0) continue;
 
@@ -1318,7 +1331,7 @@ INTBIG com_minseparate(OBJECT *object, INTBIG nlayer, COMPPOLYLIST *npolys,
 
 					/* see how close they can get */
 					minsize = polyminsize(poly);
-					dist = drcmindistance(tech, facet->cell->lib, nlayer, nminsize,
+					dist = drcmindistance(tech, cell->lib, nlayer, nminsize,
 						poly->layer, minsize, con, FALSE, &edge, 0);
 					if (dist < 0) continue;
 
@@ -1620,29 +1633,29 @@ INTBIG com_convertpintonode_layer(INTBIG layer, TECHNOLOGY *tech)
 }
 
 /*
- * copy network information from ports to arcs in facet "topfacet"
+ * copy network information from ports to arcs in cell "topcell"
  */
-void com_subsmash(NODEPROTO *topfacet)
+void com_subsmash(NODEPROTO *topcell)
 {
 	REGISTER PORTPROTO *pp;
 	REGISTER ARCINST *ai, *oai;
 
 	/* first erase the arc node information */
-	for(ai = topfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = topcell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		ai->temp1 = 0;
 
 	/* copy network information from ports to arcs */
-	for(ai = topfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = topcell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		/* ignore arcs that have already been numbered */
 		if (ai->temp1 != 0) continue;
 
 		/* see if this arc connects to a port */
-		for(pp = topfacet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+		for(pp = topcell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			if (pp->network == ai->network)
 		{
 			/* propagate port numbers into all connecting arcs */
-			for(oai = topfacet->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
+			for(oai = topcell->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
 				if (oai->network == ai->network) oai->temp1 = pp->temp1;
 			break;
 		}
@@ -1651,7 +1664,7 @@ void com_subsmash(NODEPROTO *topfacet)
 		if (pp == NOPORTPROTO)
 		{
 			/* copy new net number to all of these connected arcs */
-			for(oai = topfacet->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
+			for(oai = topcell->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
 				if (oai->network == ai->network) oai->temp1 = com_flatindex;
 			com_flatindex++;
 		}
