@@ -82,7 +82,7 @@ typedef struct Iwellarea
 	POLYGON           *poly;
 	INTBIG            layer;
 	TECHNOLOGY        *tech;
-	NODEPROTO         *facet;
+	NODEPROTO         *cell;
 	struct Iwellarea  *nextwellarea;
 } WELLAREA;
 
@@ -94,7 +94,7 @@ static WELLAREA *erc_firstwellarea = NOWELLAREA;
 #define DEFERCBITS      (PWELLONGROUND|NWELLONPOWER)
 
        TOOL       *erc_tool;					/* this tool */
-static NODEPROTO  *erc_facet;
+static NODEPROTO  *erc_cell;
 static INTBIG      erc_globalnetnumber;			/* global network number */
 static INTBIG      erc_optionskey;				/* key for "ERC_options" */
 static INTBIG      erc_options;					/* value of "ERC_options" */
@@ -105,7 +105,7 @@ static BOOLEAN     erc_realrun;					/* true if this is the real analysis */
 /* prototypes for local routines */
 static WELLAREA    *erc_allocwellarea(void);
 static WELLCON     *erc_allocwellcon(void);
-static void         erc_analyzefacet(NODEPROTO *facet);
+static void         erc_analyzecell(NODEPROTO *cell);
 static void         erc_freeallwellareas(void);
 static void         erc_freeallwellcons(void);
 static void         erc_gatherwells(NODEPROTO *np, XARRAY trans, void *merge, BOOLEAN gathernet);
@@ -164,16 +164,16 @@ void erc_set(INTBIG count, CHAR *par[])
 	if (namesamen(pp, x_("well-check"), l) == 0 && l >= 3)
 	{
 		/* check well and substrate layers */
-		np = getcurfacet();
-		erc_analyzefacet(np);
+		np = getcurcell();
+		erc_analyzecell(np);
 		return;
 	}
 
 	if (namesamen(pp, x_("antenna-rules"), l) == 0 && l >= 3)
 	{
 		/* do antenna-rules check */
-		np = getcurfacet();
-		erc_antcheckfacet(np);
+		np = getcurcell();
+		erc_antcheckcell(np);
 		return;
 	}
 
@@ -183,9 +183,9 @@ void erc_set(INTBIG count, CHAR *par[])
 /******************** ANALYSIS ********************/
 
 /*
- * Routine to analyze facet "facet" and build a list of ERC errors.
+ * Routine to analyze cell "cell" and build a list of ERC errors.
  */
-void erc_analyzefacet(NODEPROTO *facet)
+void erc_analyzecell(NODEPROTO *cell)
 {
 	REGISTER INTBIG errors, minsep, dist, layertype, largestnetnum, welltype,
 		desiredcontact, perareabit, lambda;
@@ -206,10 +206,10 @@ void erc_analyzefacet(NODEPROTO *facet)
 	REGISTER void *polymerge, *submerge;
 
 	initerrorlogging(_("ERC"));
-	if (facet == NONODEPROTO)
+	if (cell == NONODEPROTO)
 	{
 		termerrorlogging(TRUE);
-		ttyputerr(_("Must be editing a facet before analyzing wells"));
+		ttyputerr(_("Must be editing a cell before analyzing wells"));
 		return;
 	}
 
@@ -240,20 +240,20 @@ void erc_analyzefacet(NODEPROTO *facet)
 	/* begin counting elapsed time */
 	starttimer();
 
-	/* initialize to analyze facet */
+	/* initialize to analyze cell */
 	erc_freeallwellcons();
 	erc_freeallwellareas();
 	erc_worstpwelldist = erc_worstnwelldist = 0;
-	erc_facet = facet;
+	erc_cell = cell;
 	var = getvalkey((INTBIG)erc_tool, VTOOL, VINTEGER, erc_optionskey);
 	if (var == NOVARIABLE) erc_options = DEFERCBITS; else
 		erc_options = var->addr;
 
-	/* put global network information on the ports of this facet */
+	/* put global network information on the ports of this cell */
 	erc_globalnetnumber = 1;
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if (pp->temp1 != 0) continue;
 		pp->temp1 = erc_globalnetnumber++;
@@ -275,7 +275,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 	/* run through the work and count the number of polygons */
 	erc_polyscrunched = 0;
 	erc_realrun = FALSE;
-	erc_gatherwells(facet, el_matid, 0, FALSE);
+	erc_gatherwells(cell, el_matid, 0, FALSE);
 	erc_jobsize = erc_polyscrunched;
 
 	/* now gather all of the geometry into the polygon merging system */
@@ -283,7 +283,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 	polymerge = mergenew(erc_tool->cluster);
 	erc_realrun = TRUE;
 	erc_polyscrunched = 0;
-	erc_gatherwells(facet, el_matid, polymerge, TRUE);
+	erc_gatherwells(cell, el_matid, polymerge, TRUE);
 
 	/* delete intermediate merge information */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -353,7 +353,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 		{
 			if ((erc_options&PWELLCONOPTIONS) == perareabit)
 			{
-				err = logerror(nocontacterror, erc_facet, 0);
+				err = logerror(nocontacterror, erc_cell, 0);
 				addpolytoerror(err, wa->poly);
 			}
 		}
@@ -367,7 +367,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 		{
 			if (wc->fun == NPWELL) errormsg = _("P-Well contact is floating"); else
 				errormsg = _("N-Well contact is floating");
-			err = logerror(errormsg, erc_facet, 0);
+			err = logerror(errormsg, erc_cell, 0);
 			addpointtoerror(err, wc->x, wc->y);
 			continue;
 		}
@@ -377,14 +377,14 @@ void erc_analyzefacet(NODEPROTO *facet)
 			{
 				if ((erc_options&PWELLONGROUND) != 0)
 				{
-					err = logerror(_("P-Well contact not connected to ground"), erc_facet, 0);
+					err = logerror(_("P-Well contact not connected to ground"), erc_cell, 0);
 					addpointtoerror(err, wc->x, wc->y);
 				}
 			} else
 			{
 				if ((erc_options&NWELLONPOWER) != 0)
 				{
-					err = logerror(_("N-Well contact not connected to power"), erc_facet, 0);
+					err = logerror(_("N-Well contact not connected to power"), erc_cell, 0);
 					addpointtoerror(err, wc->x, wc->y);
 				}
 			}
@@ -396,7 +396,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (owc->netnum == wc->netnum) continue;
 			if (wc->fun == NPWELL) errormsg = _("P-Well contacts are not connected"); else
 				errormsg = _("N-Well contacts are not connected");
-			err = logerror(errormsg, erc_facet, 0);
+			err = logerror(errormsg, erc_cell, 0);
 			addpointtoerror(err, wc->x, wc->y);
 			addpointtoerror(err, owc->x, owc->y);
 			break;
@@ -410,7 +410,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (wc->fun == NPSUBSTRATE) break;
 		if (wc == NOWELLCON)
 		{
-			(void)logerror(_("No N-Well contact found in this facet"), erc_facet, 0);
+			(void)logerror(_("No N-Well contact found in this cell"), erc_cell, 0);
 		}
 	}
 
@@ -421,7 +421,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (wc->fun == NPWELL) break;
 		if (wc == NOWELLCON)
 		{
-			(void)logerror(_("No P-well contact found in this facet"), erc_facet, 0);
+			(void)logerror(_("No P-well contact found in this cell"), erc_cell, 0);
 		}
 	}
 
@@ -433,7 +433,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (wa->tech != owa->tech || wa->layer != owa->layer) continue;
 			if (wa->netnum == owa->netnum && wa->netnum >= 0) con = TRUE; else
 				con = FALSE;
-			minsep = drcmindistance(wa->tech, facet->cell->lib, wa->layer, 0, wa->layer, 0,
+			minsep = drcmindistance(wa->tech, cell->lib, wa->layer, 0, wa->layer, 0,
 				con, FALSE, &edge, 0);
 			if (minsep < 0) continue;
 			if (wa->lx > owa->hx+minsep || owa->lx > wa->hx+minsep ||
@@ -443,7 +443,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			{
 				layertype = erc_welllayer(wa->tech, wa->layer);
 				if (layertype == 0) continue;
-				lambda = lambdaoffacet(facet);
+				lambda = lambdaofcell(cell);
 				switch (layertype)
 				{
 					case 1:
@@ -463,52 +463,29 @@ void erc_analyzefacet(NODEPROTO *facet)
 							latoa(dist, lambda), latoa(minsep, lambda));
 						break;
 				}
-				err = logerror(errmsg, erc_facet, 0);
+				err = logerror(errmsg, erc_cell, 0);
 				addpolytoerror(err, wa->poly);
 				addpolytoerror(err, owa->poly);
 			}
 		}
 	}
 
-#if 0			/* debugging to show all well areas */
-	for(wa = erc_firstwellarea; wa != NOWELLAREA; wa = wa->nextwellarea)
-	{
-		layertype = erc_welllayer(wa->tech, wa->layer);
-		if (layertype == 0) continue;
-		switch (layertype)
-		{
-			case 1:
-				err = logerror(x_("P-Well area"), erc_facet, 0);
-				break;
-			case 2:
-				err = logerror(x_("N-Well area"), erc_facet, 0);
-				break;
-			case 3:
-				err = logerror(x_("P-Select area"), erc_facet, 0);
-				break;
-			case 4:
-				err = logerror(x_("N-Select area"), erc_facet, 0);
-		}
-		addpolytoerror(err, wa->poly);
-	}
-#endif
-
 	/* show the farthest distance from a well contact */
 	if (erc_worstpwelldist > 0 || erc_worstnwelldist > 0)
 	{
 		(void)asktool(us_tool, x_("clear"));
-		lambda = lambdaoffacet(facet);
+		lambda = lambdaofcell(cell);
 		if (erc_worstpwelldist > 0)
 		{
 			(void)asktool(us_tool, x_("show-line"), erc_worstpwellconx, erc_worstpwellcony,
-				erc_worstpwelledgex, erc_worstpwelledgey, erc_facet);
+				erc_worstpwelledgex, erc_worstpwelledgey, erc_cell);
 			ttyputmsg(_("Farthest distance from a P-Well contact is %s"),
 				latoa(erc_worstpwelldist, lambda));
 		}
 		if (erc_worstnwelldist > 0)
 		{
 			(void)asktool(us_tool, x_("show-line"), erc_worstnwellconx, erc_worstnwellcony,
-				erc_worstnwelledgex, erc_worstnwelledgey, erc_facet);
+				erc_worstnwelledgex, erc_worstnwelledgey, erc_cell);
 			ttyputmsg(_("Farthest distance from a N-Well contact is %s"),
 				latoa(erc_worstnwelldist, lambda));
 		}
@@ -562,7 +539,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 }
 
 /*
- * Recursive helper routine to gather all well areas in facet "np"
+ * Recursive helper routine to gather all well areas in cell "np"
  * (transformed by "trans").  If "merge" is nonzero, merge geometry into it.
  * If "gathernet" is true, follow networks, looking for special primitives and nets. 
  */
@@ -667,7 +644,7 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans, void *merge, BOOLEAN gathernet
 			maketrans(ni, localtran);
 			transmult(localtran, final, subrot);
 
-#if 1		/* recursive polygon merge is faster */
+			/* recursive polygon merge is faster */
 			if (merge != 0)
 			{
 				void *submerge;
@@ -675,7 +652,7 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans, void *merge, BOOLEAN gathernet
 				submerge = (void *)subnp->temp2;
 				if (submerge == 0)
 				{
-					/* gather the subfacet's merged information */
+					/* gather the subcell's merged information */
 					if (erc_realrun) submerge = mergenew(erc_tool->cluster); else
 						submerge = (void *)1;
 					erc_gatherwells(subnp, el_matid, submerge, FALSE);
@@ -687,9 +664,6 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans, void *merge, BOOLEAN gathernet
 			}
 			if (gathernet)
 				erc_gatherwells(subnp, subrot, 0, TRUE);
-#else
-			erc_gatherwells(subnp, subrot, merge, TRUE);
-#endif
 		} else
 		{
 			if (erc_realrun && gathernet)
@@ -723,7 +697,12 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans, void *merge, BOOLEAN gathernet
 							/* PWell: must be on ground */
 							for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 							{
+#if 1
+								if (!portisnamedground(pp) &&
+									(pp->userbits&STATEBITS) != GNDPORT) continue;
+#else
 								if ((pp->userbits&STATEBITS) != GNDPORT) continue;
+#endif
 								if (pp->network == net) break;
 							}
 							if (pp != NOPORTPROTO) wc->onproperrail = 1;
@@ -732,7 +711,12 @@ void erc_gatherwells(NODEPROTO *np, XARRAY trans, void *merge, BOOLEAN gathernet
 							/* NWell: must be on power */
 							for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 							{
+#if 1
+								if (!portisnamedpower(pp) &&
+									(pp->userbits&STATEBITS) != PWRPORT) continue;
+#else
 								if ((pp->userbits&STATEBITS) != PWRPORT) continue;
+#endif
 								if (pp->network == net) break;
 							}
 							if (pp != NOPORTPROTO) wc->onproperrail = 1;
