@@ -77,7 +77,7 @@ static TECHNOLOGY *erc_anttech;					/* current technology being considered */
 static INTBIG      erc_antlambda;				/* value of lambda for this technology */
 static INTBIG     *erc_antlayerlevel;			/* level of each layer in the technology */
 static INTBIG     *erc_antlayerforlevel;		/* layer associated with each antenna-check level */
-static NODEPROTO  *erc_anttopfacet;				/* top-level facet being checked */
+static NODEPROTO  *erc_anttopcell;				/* top-level cell being checked */
 static float       erc_antgatearea;				/* accumulated gate area */
 static float       erc_antregionarea;			/* accumulated region area */
 static void       *erc_anterror;				/* error report being generated */
@@ -103,7 +103,7 @@ static INTBIG       erc_antpathhashtablecount;		/* number of antenna objects in
 #define ERCDEFMETALLIMIT 400	/* maximum ratio of metal to gate area */
 
 /* prototypes for local routines */
-static void        erc_antcheckthisfacet(NODEPROTO *facet, INTBIG level);
+static void        erc_antcheckthiscell(NODEPROTO *cell, INTBIG level);
 static INTBIG      erc_antfollownode(NODEINST *ni, PORTPROTO *pp, INTBIG level, XARRAY trans);
 static void        erc_antgetpolygonarea(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTBIG count);
 static void        erc_antputpolygoninerror(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTBIG count);
@@ -117,13 +117,14 @@ static INTBIG      erc_antfindexports(NODEINST *ni, PORTPROTO *pp, INTBIG level,
 static void        erc_antinsertantennaobj(ANTENNAOBJ *ao);
 static INTBIG      erc_antgethash(ANTENNAOBJ *ao);
 static INTBIG      erc_antratio(INTBIG level);
+static BOOLEAN     erc_hasdiffusion(NODEINST *ni);
 
 /************************ CONTROL ***********************/
 
 /*
- * Main entry point for antenna check rules.  Checks rules in facet "facet".
+ * Main entry point for antenna check rules.  Checks rules in cell "cell".
  */
-void erc_antcheckfacet(NODEPROTO *facet)
+void erc_antcheckcell(NODEPROTO *cell)
 {
 	REGISTER LIBRARY *lib;
 	REGISTER INTBIG i, fun, level, highestlevel, lasterrorcount;
@@ -132,11 +133,11 @@ void erc_antcheckfacet(NODEPROTO *facet)
 	REGISTER ARCPROTO *ap;
 	float t;
 
-	erc_anttopfacet = facet;
-	erc_anttech = facet->tech;
+	erc_anttopcell = cell;
+	erc_anttech = cell->tech;
 	erc_antlambda = el_curlib->lambda[erc_anttech->techindex];
 
-	/* clear marks on all arcs in all facets */
+	/* clear marks on all arcs in all cells */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -217,7 +218,7 @@ void erc_antcheckfacet(NODEPROTO *facet)
 	/* initialize error logging */
 	initerrorlogging(x_("ERC antenna rules"));
 
-	/* now check the facet recursively */
+	/* now check the cell recursively */
 	lasterrorcount = 0;
 	erc_antworstratio = 0;
 #ifdef DEBUGANTENNA
@@ -229,13 +230,13 @@ void erc_antcheckfacet(NODEPROTO *facet)
 		ttyputmsg(_("Checking Antenna rules for %s..."),
 			layername(erc_anttech, erc_antlayerforlevel[level]));
 
-		/* clear timestamps on all facet */
+		/* clear timestamps on all cell */
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 				np->temp1 = 0;
 
 		/* do the check for this level */
-		erc_antcheckthisfacet(facet, level);
+		erc_antcheckthiscell(cell, level);
 		i = numerrors();
 		if (i != lasterrorcount)
 		{
@@ -278,9 +279,9 @@ void erc_antterm(void)
 }
 
 /*
- * Routine to check the contents of facet "facet", considering geometry on level "level" of antenna depth.
+ * Routine to check the contents of cell "cell", considering geometry on level "level" of antenna depth.
  */
-void erc_antcheckthisfacet(NODEPROTO *facet, INTBIG level)
+void erc_antcheckthiscell(NODEPROTO *cell, INTBIG level)
 {
 	REGISTER NODEINST *ni, *oni;
 	REGISTER INTBIG found, ratio, neededratio, i, j, tot;
@@ -292,9 +293,9 @@ void erc_antcheckthisfacet(NODEPROTO *facet, INTBIG level)
 	REGISTER void *infstr, *vmerge;
 
 	/* examine every node and follow all relevant arcs */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst) ni->temp1 = 0;
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst) ni->temp1 = 0;
 
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->temp1 != 0) continue;
 		ni->temp1 = 1;
@@ -390,13 +391,13 @@ void erc_antcheckthisfacet(NODEPROTO *facet, INTBIG level)
 							latoa((INTBIG)(erc_antregionarea/erc_antlambda), erc_antlambda),
 							latoa((INTBIG)(erc_antgatearea/erc_antlambda), erc_antlambda),
 							ratio, neededratio);
-						erc_anterror = logerror(returninfstr(infstr), facet, 0);
+						erc_anterror = logerror(returninfstr(infstr), cell, 0);
 						mergeextract(vmerge, erc_antputpolygoninerror);
 					}
 #ifdef DEBUGANTENNA
 					infstr = initinfstr();
-					formatinfstr(infstr, x_("Facet %s: Level %d: Gate size %s, Region size %s, ratio=%g"),
-						describenodeproto(facet), level-1,
+					formatinfstr(infstr, x_("Cell %s: Level %d: Gate size %s, Region size %s, ratio=%g"),
+						describenodeproto(cell), level-1,
 						latoa((INTBIG)(erc_antgatearea/erc_antlambda), erc_antlambda),
 						latoa((INTBIG)(erc_antregionarea/erc_antlambda), erc_antlambda),
 						erc_antregionarea / erc_antgatearea);
@@ -416,19 +417,19 @@ void erc_antcheckthisfacet(NODEPROTO *facet, INTBIG level)
 		}
 	}
 
-	/* now look at subfacets */
-	facet->temp1 = 1;
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* now look at subcells */
+	cell->temp1 = 1;
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
 		if (ni->proto->temp1 != 0) continue;
 
-		erc_antcheckthisfacet(ni->proto, level);
+		erc_antcheckthiscell(ni->proto, level);
 	}
 }
 
 /*
- * Routine to follow node "ni" around the facet.
+ * Routine to follow node "ni" around the cell.
  *    Returns ERCANTPATHNULL   if it found no gate or active on the path.
  *    Returns ERCANTPATHGATE   if it found gates on the path.
  *    Returns ERCANTPATHACTIVE if it found active on the path.
@@ -451,7 +452,7 @@ INTBIG erc_antfollownode(NODEINST *ni, PORTPROTO *pp, INTBIG level, XARRAY trans
 	/* keep walking along the nodes and arcs */
 	for(;;)
 	{
-		/* if this is a subfacet, recurse on it */
+		/* if this is a subcell, recurse on it */
 		ni->temp1 = 1;
 		thisni = ni;
 		while (thisni->proto->primindex == 0)
@@ -481,6 +482,7 @@ INTBIG erc_antfollownode(NODEINST *ni, PORTPROTO *pp, INTBIG level, XARRAY trans
 		} else
 		{
 			/* normal primitive: propagate */
+			if (erc_hasdiffusion(thisni)) return(ERCANTPATHACTIVE);
 			ao = erc_antallocantennaobj();
 			if (ao == NOANTENNAOBJ) return(ERCANTPATHACTIVE);
 			erc_antloadantennaobj(ao, depth, antstack);
@@ -525,6 +527,31 @@ INTBIG erc_antfollownode(NODEINST *ni, PORTPROTO *pp, INTBIG level, XARRAY trans
 	return(ret);
 }
 
+/*
+ * Routine to return TRUE if node "ni" has diffusion on it.
+ */
+BOOLEAN erc_hasdiffusion(NODEINST *ni)
+{
+	REGISTER INTBIG i, total, fun;
+	static POLYGON *poly = NOPOLYGON;
+
+	/* get polygon */
+	(void)needstaticpolygon(&poly, 4, io_tool->cluster);
+
+	/* stop if this is a pin */
+	if (nodefunction(ni) == NPPIN) return(FALSE);
+
+	/* analyze to see if there is diffusion here */
+	total = nodepolys(ni, 0, NOWINDOWPART);
+	for(i=0; i<total; i++)
+	{
+		shapenodepoly(ni, i, poly);
+		fun = layerfunction(poly->tech, poly->layer);
+		if ((fun&LFTYPE) == LFDIFF) return(TRUE);
+	}
+	return(FALSE);
+}
+
 INTBIG erc_antfindarcs(NODEINST *ni, PORTPROTO *pp, INTBIG level, INTBIG depth, NODEINST **antstack)
 {
 	REGISTER PORTARCINST *pi;
@@ -619,7 +646,7 @@ void erc_antgetpolygonarea(INTBIG layer, TECHNOLOGY *tech, INTBIG *xv, INTBIG *y
 			if (i == 0) lasti = count-1; else lasti = i-1;
 			lastx = xv[lasti];   lasty = yv[lasti];
 			x = xv[i];           y = yv[i];
-			asktool(us_tool, x_("show-line"), lastx, lasty, x, y, (INTBIG)erc_anttopfacet);
+			asktool(us_tool, x_("show-line"), lastx, lasty, x, y, (INTBIG)erc_anttopcell);
 		}
 	}
 #endif
