@@ -48,7 +48,7 @@
 static KEYWORD leopt[] =
 {
 	{x_("analyze-path"),       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{x_("analyze-facet"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("analyze-cell"),       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("analyze-network"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("show-loads"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("estimate-delay"),     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -116,22 +116,22 @@ static LENODE   *le_lenodefree;				/* list of free LE nodes */
 /* prototypes for local routines */
 static void      le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inpi);
 static LENODE   *le_alloclenode(void);
-static void      le_analyzefacet(void);
+static void      le_analyzecell(void);
 static void      le_analyzenetwork(void);
 static void      le_analyzepath(void);
 static CHAR     *le_describenode(LENODE *le);
-static void      le_estimatedelay(NODEPROTO *facet);
+static void      le_estimatedelay(NODEPROTO *cell);
 static void      le_figurebranching(void);
 static void      le_freealllenodes(void);
 static void      le_freelenode(LENODE *le);
-static void      le_gatherfacet(INTBIG show);
+static void      le_gathercell(INTBIG show);
 static void      le_gatherpath(INTBIG show);
 static double    le_getcapacitance(NETWORK *net);
 static INTBIG    le_getgatetype(NODEINST *ni, INTBIG *inputs);
 static double    le_getlogeffort(LENODE *le);
 static double    le_getparasitics(LENODE *le);
 static CHAR     *le_nextarcs(void);
-static NODEINST *le_propagate(NODEPROTO *facet, INTBIG edge);
+static NODEINST *le_propagate(NODEPROTO *cell, INTBIG edge);
 static void      le_propagatebranch(PORTARCINST *tpi, LENODE *final, double capacitance,
 					double *onpath, double *offpath);
 static void      le_setarccapacitance(ARCINST *ai, double c);
@@ -201,19 +201,19 @@ void le_set(INTBIG count, CHAR *par[])
 
 	if (count == 0)
 	{
-		ttyputusage(x_("telltool logeffort (analyze-path | analyze-facet | analyze-network | show-loads | set-options | set-capacitance | set-node-effort)"));
+		ttyputusage(x_("telltool logeffort (analyze-path | analyze-cell | analyze-network | show-loads | set-options | set-capacitance | set-node-effort)"));
 		return;
 	}
 
 	l = estrlen(pp = par[0]);
-	if (namesamen(pp, x_("analyze-facet"), l) == 0 && l >= 9)
+	if (namesamen(pp, x_("analyze-cell"), l) == 0 && l >= 9)
 	{
 		var = getvalkey((INTBIG)le_tool, VTOOL, VINTEGER, le_state_key);
 		if (var == NOVARIABLE) state = DEFAULTSTATE; else
 			state = var->addr;
-		le_gatherfacet(state & HIGHLIGHTCOMPONENTS);
+		le_gathercell(state & HIGHLIGHTCOMPONENTS);
 		if (le_firstlenode == NOLENODE) return;
-		le_analyzefacet();
+		le_analyzecell();
 		return;
 	}
 	if (namesamen(pp, x_("analyze-path"), l) == 0 && l >= 9)
@@ -228,8 +228,8 @@ void le_set(INTBIG count, CHAR *par[])
 	}
 	if (namesamen(pp, x_("estimate-delay"), l) == 0)
 	{
-		/* analyze facet */
-		np = getcurfacet();
+		/* analyze cell */
+		np = getcurcell();
 		if (np == NONODEPROTO) return;
 		le_estimatedelay(np);
 		return;
@@ -595,9 +595,9 @@ typedef struct Inetdelay
 } NETDELAY;
 
 /*
- * Routine to analyze facet "facet" and build a list of ERC errors.
+ * Routine to analyze cell "cell" and build a list of ERC errors.
  */
-void le_estimatedelay(NODEPROTO *facet)
+void le_estimatedelay(NODEPROTO *cell)
 {
 	REGISTER NETWORK *net;
 	TRANSISTORINFO *p_gate, *n_gate, *p_active, *n_active;
@@ -607,8 +607,8 @@ void le_estimatedelay(NODEPROTO *facet)
 	float numerator, coefficient, flambda;
 
 	firstnd = NONETDELAY;
-	flambda = (float)lambdaoffacet(facet);
-	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+	flambda = (float)lambdaofcell(cell);
+	for(net = cell->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 	{
 		aplist = net_gathergeometry(net, &p_gate, &n_gate, &p_active, &n_active, TRUE);
 
@@ -696,17 +696,17 @@ void le_showloads(void)
 	TRANSISTORINFO *p_gate, *n_gate, *p_active, *n_active;
 	REGISTER void *infstr;
 
-	/* get the current facet */
-	np = getcurfacet();
+	/* get the current cell */
+	np = getcurcell();
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("No current facet"));
+		ttyputerr(_("No current cell"));
 		return;
 	}
-	lambda = lambdaoffacet(np);
+	lambda = lambdaofcell(np);
 	selnets = net_gethighlightednets(FALSE);
 
-	/* gather product information for all nets in the facet */
+	/* gather product information for all nets in the cell */
 	for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 	{
 		net->temp2 = 0;
@@ -867,7 +867,7 @@ void le_analyzenetwork(void)
 			if (arpe->layer >= 0) total++;
 		if (total == 0)
 		{
-			ttyputmsg(_("No geometry on network '%s' in facet %s"), describenetwork(net),
+			ttyputmsg(_("No geometry on network '%s' in cell %s"), describenetwork(net),
 				describenodeproto(np));
 			continue;
 		}
@@ -880,9 +880,9 @@ void le_analyzenetwork(void)
 		/* sort the layers */
 		esort(arpelist, total, sizeof (AREAPERIM *), net_areaperimdepthascending);
 
-		ttyputmsg(_("For network '%s' in facet %s:"), describenetwork(net),
+		ttyputmsg(_("For network '%s' in cell %s:"), describenetwork(net),
 			describenodeproto(np));
-		lambda = lambdaoffacet(np);
+		lambda = lambdaofcell(np);
 		widest = 0;
 		for(i=0; i<total; i++)
 		{
@@ -963,13 +963,13 @@ void le_analyzenetwork(void)
 	}
 }
 
-/******************** FACET EXTRACTION ********************/
+/******************** CELL EXTRACTION ********************/
 
 /*
- * Routine to gather all relevant nodes in the current facet and build the structure
+ * Routine to gather all relevant nodes in the current cell and build the structure
  * headed by "le_firstlenode".
  */
-void le_gatherfacet(INTBIG show)
+void le_gathercell(INTBIG show)
 {
 	REGISTER INTBIG inport, oinport, which;
 	REGISTER BOOLEAN first;
@@ -985,16 +985,16 @@ void le_gatherfacet(INTBIG show)
 	double cap;
 	REGISTER void *infstr;
 
-	/* make sure there is a current facet */
+	/* make sure there is a current cell */
 	le_freealllenodes();
-	np = getcurfacet();
+	np = getcurcell();
 	if (np == NONODEPROTO) return;
 
 	/* reset to find power and ground nets */
 	for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 		net->temp1 = 0;
 
-	/* gather all relevant nodes in the facet */
+	/* gather all relevant nodes in the cell */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		type = le_getgatetype(ni, &inputs);
@@ -1140,13 +1140,13 @@ void le_gatherfacet(INTBIG show)
 	{
 		if (first) addtoinfstr(infstr, '\n');
 		first = TRUE;
-		formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
+		formatinfstr(infstr, x_("CELL=%s FROM=0%lo;-1;0"),
 			describenodeproto(np), (INTBIG)le->ni->geom);
 	}
 	(void)asktool(us_tool, x_("show-multiple"), (INTBIG)returninfstr(infstr));
 
 	/* display the connection sites */
-	arrowsize = lambdaoffacet(np) * 2;
+	arrowsize = lambdaofcell(np) * 2;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
 	{
 		if (le->piin != NOPORTARCINST)
@@ -1221,7 +1221,7 @@ void le_addlinkage(LENODE *out, PORTARCINST *outpi, LENODE *in, PORTARCINST *inp
 	in->numinputnodes++;
 }
 
-void le_analyzefacet(void)
+void le_analyzecell(void)
 {
 	REGISTER LENODE *le;
 	REGISTER PORTARCINST *pi;
@@ -1315,9 +1315,9 @@ void le_gatherpath(INTBIG show)
 	LENODE *le, *newle, *nextle, *lastle;
 	REGISTER void *infstr;
 
-	/* make sure there is a current facet */
+	/* make sure there is a current cell */
 	le_freealllenodes();
-	np = getcurfacet();
+	np = getcurcell();
 	if (np == NONODEPROTO) return;
 
 	/* get all selected objects (must be 2 nodes) */
@@ -1455,19 +1455,19 @@ void le_gatherpath(INTBIG show)
 		if (ni->temp2 == 0) continue;
 		if (first) addtoinfstr(infstr, '\n');
 		first = TRUE;
-		formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
+		formatinfstr(infstr, x_("CELL=%s FROM=0%lo;-1;0"),
 			describenodeproto(np), (INTBIG)ni->geom);
 	}
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->temp2 == 0) continue;
 		addtoinfstr(infstr, '\n');
-		formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
+		formatinfstr(infstr, x_("CELL=%s FROM=0%lo;-1;0"),
 			describenodeproto(np), (INTBIG)ai->geom);
 	}
 	(void)asktool(us_tool, x_("show-multiple"), (INTBIG)returninfstr(infstr));
 
-	arrowsize = lambdaoffacet(np) * 2;
+	arrowsize = lambdaofcell(np) * 2;
 	for(le = le_firstlenode; le != NOLENODE; le = le->nextlenode)
 	{
 		if (le->piin != NOPORTARCINST)
@@ -1500,7 +1500,7 @@ void le_gatherpath(INTBIG show)
  * Returns zero if the propagation must run more.
  * Returns a NODEINST if it has found that node at then end of the path
  */
-NODEINST *le_propagate(NODEPROTO *facet, INTBIG edge)
+NODEINST *le_propagate(NODEPROTO *cell, INTBIG edge)
 {
 	REGISTER NODEINST *ni, *oni;
 	REGISTER PORTARCINST *pi;
@@ -1508,7 +1508,7 @@ NODEINST *le_propagate(NODEPROTO *facet, INTBIG edge)
 	REGISTER INTBIG otherend, moved;
 
 	moved = 0;
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->temp1 != edge) continue;
 
@@ -1728,7 +1728,7 @@ INTBIG le_getgatetype(NODEINST *ni, INTBIG *inputs)
 		/* ignore if it is a capacitance element */
 		var = getvalkey((INTBIG)ni, VNODEINST, -1, le_attrcapacitance_key);
 		if (var == NOVARIABLE)
-			ttyputmsg(_("Sorry, Logical Effort cannot handle facets"));
+			ttyputmsg(_("Sorry, Logical Effort cannot handle cells"));
 		return(NPUNKNOWN);
 	}
 
