@@ -47,9 +47,9 @@ static void      via_to_contact( NODEINST**, INTBIG*, TECHNOLOGY*, INTBIG*, ARCI
 static BOOLEAN   contains_node( NODEINST*, NODEINST* );
 
 /*
- * Routine to convert facet "facet" from pure-layer nodes to real nodes and arcs.
+ * Routine to convert cell "cell" from pure-layer nodes to real nodes and arcs.
  */
-void net_conv_to_internal( NODEPROTO *facet )
+void net_conv_to_internal( NODEPROTO *cell )
 {
 	NODEINST *nodes;  /* head of the new node list */
 	ARCINST *arcs;  /* head of the new arc list */
@@ -69,7 +69,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 	/* count the number of PL nodes */
 	tech = NOTECHNOLOGY;
 	nodecounter = 0;
-	for(nodelooper = facet->firstnodeinst; nodelooper != NONODEINST; nodelooper = nodelooper->nextnodeinst)
+	for(nodelooper = cell->firstnodeinst; nodelooper != NONODEINST; nodelooper = nodelooper->nextnodeinst)
 	{
 		if (((nodelooper->proto->userbits & NFUNCTION) >> NFUNCTIONSH) != NPNODE) continue;
 		nodecounter++;
@@ -93,7 +93,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 	plnodelist = (NODEINST **)emalloc(nodecounter * (sizeof (NODEINST *)), net_tool->cluster);
 	if (plnodelist == 0) return;
 	nodecounter = 0;
-	for(nodelooper = facet->firstnodeinst; nodelooper != NONODEINST; nodelooper = nodelooper->nextnodeinst)
+	for(nodelooper = cell->firstnodeinst; nodelooper != NONODEINST; nodelooper = nodelooper->nextnodeinst)
 	{
 		if (((nodelooper->proto->userbits & NFUNCTION) >> NFUNCTIONSH) != NPNODE) continue;
 		plnodelist[nodecounter++] = nodelooper;
@@ -144,7 +144,7 @@ void net_conv_to_internal( NODEPROTO *facet )
 					equivlayers,
 		            &arcs,
 					&nodes,
-					facet );
+					cell );
 
 	/* convert to arcs and pins */
 	build_node_arc_list( plnodelist, &nodecounter,
@@ -152,12 +152,12 @@ void net_conv_to_internal( NODEPROTO *facet )
 						 equivlayers,
 		                 &arcs, 
 						 &nodes, 
-						 facet );
+						 cell );
 
 #if 0		/* not handling this yet */
-	arc_crossings( &arcs, &nodes, facet );
+	arc_crossings( &arcs, &nodes, cell );
 
-	t_crossings( &arcs, &nodes, facet );
+	t_crossings( &arcs, &nodes, cell );
 #endif
 
 	/* create all the nodes in the lists, and store the pointers */
@@ -237,7 +237,7 @@ void via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 					   INTBIG *equivlayers,
 					   ARCINST** arcs, 
 					   NODEINST** nodes, 
-					   NODEPROTO* facet )
+					   NODEPROTO* cell )
 {
 	/* locate vias an turn them into nodes, removing them from the parselist */
 	NODEINST *looper;
@@ -364,13 +364,13 @@ void via_to_contact( NODEINST** parselist, INTBIG *parselistcount,
 		}
 
 		/* create the new contact */
-		contact = allocnodeinst(facet->cell->cluster);
-		nodeprotosizeoffset(thisismycontact, &lx, &ly, &hx, &hy, facet);
+		contact = allocnodeinst(cell->lib->cluster);
+		nodeprotosizeoffset(thisismycontact, &lx, &ly, &hx, &hy, cell);
 		contact->highx = highx + hx;
 		contact->lowx = lowx - lx;
 		contact->highy = highy + hy;
 		contact->lowy = lowy - ly;
-		contact->parent = facet;
+		contact->parent = cell;
 		contact->proto = thisismycontact;
 
 		/* insert it into nodes */
@@ -408,7 +408,7 @@ void  build_node_arc_list( NODEINST** parselist,
 							 INTBIG *equivlayers,
 							 ARCINST** arcs, 
 							 NODEINST** nodes, 
-							 NODEPROTO* facet )
+							 NODEPROTO* cell )
 {
 	/* data that will be created and added to the list */
 	NODEINST* nodeinst1;
@@ -551,14 +551,14 @@ void  build_node_arc_list( NODEINST** parselist,
 		}
 		if (nodeinst1 == NONODEINST)
 		{
-			nodeinst1 = allocnodeinst(facet->cell->cluster);
-			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy, facet);
+			nodeinst1 = allocnodeinst(cell->lib->cluster);
+			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy, cell);
 			nodeinst1->highx = highx1 + hx;
 			nodeinst1->lowx = lowx1 - lx;
 			nodeinst1->highy = highy1 + hy;
 			nodeinst1->lowy = lowy1 - ly;
 			nodeinst1->proto = nodetech;
-			nodeinst1->parent = facet;
+			nodeinst1->parent = cell;
 			pp1 = nodetech->firstportproto;
 
 			add_node(nodeinst1, nodes);
@@ -577,21 +577,21 @@ void  build_node_arc_list( NODEINST** parselist,
 		}
 		if (nodeinst2 == NONODEINST)
 		{
-			nodeinst2 = allocnodeinst(facet->cell->cluster);
-			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy, facet);
+			nodeinst2 = allocnodeinst(cell->lib->cluster);
+			nodeprotosizeoffset(nodetech, &lx, &ly, &hx, &hy, cell);
 			nodeinst2->highx = highx2 + hx;
 			nodeinst2->lowx = lowx2 - lx;
 			nodeinst2->highy = highy2 + hy;
 			nodeinst2->lowy = lowy2 - ly;
 			nodeinst2->proto = nodetech;
-			nodeinst2->parent = facet;
+			nodeinst2->parent = cell;
 			pp2 = nodetech->firstportproto;
 
 			add_node(nodeinst2, nodes);
 		}
 
 		/* allocate space for new things */
-		arcinst1 = allocarcinst(facet->cell->cluster);
+		arcinst1 = allocarcinst(cell->lib->cluster);
 
 		arcinst1->width = width + arcprotowidthoffset(arctech);
 		arcinst1->end[0].nodeinst = nodeinst1;
@@ -602,7 +602,7 @@ void  build_node_arc_list( NODEINST** parselist,
 		arcinst1->end[1].ypos = py2;
 		arcinst1->proto = arctech;
 		arcinst1->userbits = us_makearcuserbits(arctech);
-		arcinst1->parent = facet;
+		arcinst1->parent = cell;
 
 		add_arc( arcinst1, arcs );
 
@@ -618,12 +618,12 @@ void  build_node_arc_list( NODEINST** parselist,
 
 #if 0		/* not used yet */
 
-NODEINST* arc_to_PL( ARCINST* arc, NODEPROTO* facet )
+NODEINST* arc_to_PL( ARCINST* arc, NODEPROTO* cell )
 {
 	/* create a new node to return */
 	NODEINST* newnode;
 	
-	newnode = allocnodeinst(facet->cell->cluster);
+	newnode = allocnodeinst(cell->lib->cluster);
 	
 	/* get the max x */
 	if( arc->end[0].nodeinst->highx >= arc->end[1].nodeinst->highx )
@@ -668,7 +668,7 @@ NODEINST* arc_to_PL( ARCINST* arc, NODEPROTO* facet )
 	return newnode;
 }
 
-void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
+void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* cell )
 {
 	ARCINST* a1;
 	ARCINST* a2;
@@ -696,8 +696,8 @@ void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 				cross_found = FALSE;
 
 				/* calculate coords of each, store them like pl nodes for comparison */
-				n1 = arc_to_PL( a1, facet );
-				n2 = arc_to_PL( a2, facet );
+				n1 = arc_to_PL( a1, cell );
+				n2 = arc_to_PL( a2, cell );
 
 
 				/* n1 horizontal, n2 vertical */
@@ -709,7 +709,7 @@ void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 
 					ttyputmsg(_("overlap condition met"));
 					/* create the new node */
-					newnode = allocnodeinst(facet->cell->cluster);
+					newnode = allocnodeinst(cell->lib->cluster);
 
 					newnode->highx = n2->highx;
 					newnode->lowx = n2->lowx;
@@ -734,7 +734,7 @@ void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 
 
 					/* create the new node */
-					newnode = allocnodeinst(facet->cell->cluster);
+					newnode = allocnodeinst(cell->lib->cluster);
 
 					newnode->highx = n1->highx;
 					newnode->lowx = n1->lowx;
@@ -750,10 +750,10 @@ void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 				if( cross_found )
 				{
 				/* create 4 new arcs and delete these 2 */
-				newarc1 = allocarcinst(facet->cell->cluster);
-				newarc2 = allocarcinst(facet->cell->cluster);
-				newarc3 = allocarcinst(facet->cell->cluster);
-				newarc4 = allocarcinst(facet->cell->cluster);
+				newarc1 = allocarcinst(cell->lib->cluster);
+				newarc2 = allocarcinst(cell->lib->cluster);
+				newarc3 = allocarcinst(cell->lib->cluster);
+				newarc4 = allocarcinst(cell->lib->cluster);
 
 				
 				/* fill out the new arcs */
@@ -860,14 +860,14 @@ void arc_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 	}
 }
 
-void make_arc_geom( ARCINST** arcs, NODEPROTO* facet )
+void make_arc_geom( ARCINST** arcs, NODEPROTO* cell )
 {
 	GEOM* geom;
 	ARCINST* arcinst;
 
 	for(arcinst = *arcs ; arcinst != NOARCINST; arcinst = arcinst->nextarcinst )
 	{
-		geom = allocgeom(facet->cell->cluster);
+		geom = allocgeom(cell->lib->cluster);
 		
 		/* find the high x */
 		if( arcinst->end[0].nodeinst->highx > arcinst->end[1].nodeinst->highx )
@@ -915,7 +915,7 @@ void make_arc_geom( ARCINST** arcs, NODEPROTO* facet )
 	}
 }
 
-void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
+void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* cell )
 {
 	ARCINST* looper;
 	ARCINST* comparearc;
@@ -927,7 +927,7 @@ void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 	INTBIG ypos;
 
 	/* since geometries are null in the arcs currently, create them for all of them */
-	make_arc_geom( arcs, facet );
+	make_arc_geom( arcs, cell );
 
 	/* for each arc, run through every node and see if any are intersecting part of the arcs body */
 	for( comparearc = *arcs; comparearc != NOARCINST; comparearc = comparearc->nextarcinst )
@@ -948,10 +948,10 @@ void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 					if( ( looper->end[0].nodeinst->highy < comparearc->geom->highy ) &&
 						( looper->end[0].nodeinst->lowy > comparearc->geom->lowy ) )
 					{
-						newnode = allocnodeinst(facet->cell->cluster);
-						newarc1 = allocarcinst(facet->cell->cluster);
-						newarc2 = allocarcinst(facet->cell->cluster);
-						newarc3 = allocarcinst(facet->cell->cluster);
+						newnode = allocnodeinst(cell->lib->cluster);
+						newarc1 = allocarcinst(cell->lib->cluster);
+						newarc2 = allocarcinst(cell->lib->cluster);
+						newarc3 = allocarcinst(cell->lib->cluster);
 
 						newnode->highx = looper->geom->highx;
 						newnode->lowx = looper->geom->lowx;
@@ -986,10 +986,10 @@ void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 					else if( ( looper->end[1].nodeinst->highy < comparearc->geom->highy ) &&
 						     ( looper->end[1].nodeinst->lowy > comparearc->geom->lowy ) )
 					{
-						newnode = allocnodeinst(facet->cell->cluster);
-						newarc1 = allocarcinst(facet->cell->cluster);
-						newarc2 = allocarcinst(facet->cell->cluster);
-						newarc3 = allocarcinst(facet->cell->cluster);
+						newnode = allocnodeinst(cell->lib->cluster);
+						newarc1 = allocarcinst(cell->lib->cluster);
+						newarc2 = allocarcinst(cell->lib->cluster);
+						newarc3 = allocarcinst(cell->lib->cluster);
 
 						newnode->highx = looper->geom->highx;
 						newnode->lowx = looper->geom->lowx;
@@ -1027,10 +1027,10 @@ void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 					if( ( looper->end[0].nodeinst->highx < comparearc->geom->highx ) &&
 						( looper->end[0].nodeinst->lowx > comparearc->geom->lowx ) )
 					{
-						newnode = allocnodeinst(facet->cell->cluster);
-						newarc1 = allocarcinst(facet->cell->cluster);
-						newarc2 = allocarcinst(facet->cell->cluster);
-						newarc3 = allocarcinst(facet->cell->cluster);
+						newnode = allocnodeinst(cell->lib->cluster);
+						newarc1 = allocarcinst(cell->lib->cluster);
+						newarc2 = allocarcinst(cell->lib->cluster);
+						newarc3 = allocarcinst(cell->lib->cluster);
 
 						newnode->highx = comparearc->geom->highx;
 						newnode->lowx = comparearc->geom->lowx;
@@ -1064,10 +1064,10 @@ void t_crossings( ARCINST** arcs, NODEINST** nodes, NODEPROTO* facet )
 					else if( ( looper->end[1].nodeinst->highx < comparearc->geom->highx ) &&
 						     ( looper->end[1].nodeinst->lowx > comparearc->geom->lowx ) )
 					{
-						newnode = allocnodeinst(facet->cell->cluster);
-						newarc1 = allocarcinst(facet->cell->cluster);
-						newarc2 = allocarcinst(facet->cell->cluster);
-						newarc3 = allocarcinst(facet->cell->cluster);
+						newnode = allocnodeinst(cell->lib->cluster);
+						newarc1 = allocarcinst(cell->lib->cluster);
+						newarc2 = allocarcinst(cell->lib->cluster);
+						newarc3 = allocarcinst(cell->lib->cluster);
 
 						newnode->highx = comparearc->geom->highx;
 						newnode->lowx = comparearc->geom->lowx;
