@@ -40,70 +40,73 @@
 /* the PLA tool table */
 static KEYWORD planmosonoffopt[] =
 {
-	{"on",          0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"off",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("on"),          0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("off"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP planmosonoffp = {planmosonoffopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("State of this switch"), 0};
+	INPUTOPT, x_(" \t"), M_("State of this switch"), 0};
 static COMCOMP planmosoptip = {NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Number of inputs to nMOS PLA"), 0};
+	INPUTOPT, x_(" \t"), M_("Number of inputs to nMOS PLA"), 0};
 static COMCOMP planmosoptop = {NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Number of outputs to nMOS PLA"), 0};
+	INPUTOPT, x_(" \t"), M_("Number of outputs to nMOS PLA"), 0};
 static COMCOMP planmosoptpp = {NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Number of p-terms to nMOS PLA"), 0};
+	INPUTOPT, x_(" \t"), M_("Number of p-terms to nMOS PLA"), 0};
 static COMCOMP planmosoptvp = {NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Width of VDD wires in nMOS PLA"), 0};
+	INPUTOPT, x_(" \t"), M_("Width of VDD wires in nMOS PLA"), 0};
 static COMCOMP planmosoptgp = {NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Width of Ground wires in nMOS PLA"), 0};
+	INPUTOPT, x_(" \t"), M_("Width of Ground wires in nMOS PLA"), 0};
 static COMCOMP planmosoptfp = {NOKEYWORD,topoffile,nextfile,NOPARAMS,
-	INPUTOPT, " \t", M_("File name with nMOS PLA personality table"), 0};
+	INPUTOPT, x_(" \t"), M_("File name with nMOS PLA personality table"), 0};
 static COMCOMP planmosoptbp = {NOKEYWORD, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("Name given to nMOS PLA"), 0};
+	INPUTOPT, x_(" \t"), M_("Name given to nMOS PLA"), 0};
 static KEYWORD planmosoopt[] =
 {
-	{"file",             1,{&planmosoptfp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"inputs",           1,{&planmosoptip,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"outputs",          1,{&planmosoptop,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"pterms",           1,{&planmosoptpp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"verbose",          1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"flexible",         1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"fixedangle",       1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"buttingcontact",   1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"samesideoutput",   1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"vddwidth",         1,{&planmosoptvp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"groundwidth",      1,{&planmosoptgp,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"name",             1,{&planmosoptbp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("file"),             1,{&planmosoptfp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("inputs"),           1,{&planmosoptip,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("outputs"),          1,{&planmosoptop,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("pterms"),           1,{&planmosoptpp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("verbose"),          1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("flexible"),         1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("fixedangle"),       1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("buttingcontact"),   1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("samesideoutput"),   1,{&planmosonoffp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("vddwidth"),         1,{&planmosoptvp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("groundwidth"),      1,{&planmosoptgp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("name"),             1,{&planmosoptbp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP planmosop = {planmosoopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("nMOS PLA switch setting option"), 0};
+	INPUTOPT, x_(" \t"), M_("nMOS PLA switch setting option"), 0};
 static KEYWORD placmosopt[] =
 {
-	{"n-plane",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"p-plane",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"decoder",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"generate-pla",   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("n-plane"),        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("p-plane"),        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("decoder"),        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("generate-pla"),   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP placmosp = {placmosopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	INPUTOPT, " \t", M_("CMOS PLA action"), 0};
+	INPUTOPT, x_(" \t"), M_("CMOS PLA action"), 0};
 static KEYWORD plaopt[] =
 {
-	{"nmos",    1,{&planmosop,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"cmos",    1,{&placmosp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("nmos"),    1,{&planmosop,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("cmos"),    1,{&placmosp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP pla_plap = {plaopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	0, " \t", M_("Select a PLA generator to use"), 0};
+	0, x_(" \t"), M_("Select a PLA generator to use"), 0};
 
 TOOL     *pla_tool;				/* the PLA tool object */
 INTBIG    pla_lam;				/* Feature size in internal units */
 INTBIG    pla_filetypeplatab;	/* PLA table disk file descriptor */
 
 /* PLA access routine called from electric user interface */
-void pla_init(INTBIG *argc, char *argv[], TOOL *thistool)
+void pla_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 {
+	Q_UNUSED( argc );
+	Q_UNUSED( argv );
+
 	/* only initialize during pass 1 */
 	if (thistool == NOTOOL || thistool == 0) return;
 	pla_tool = thistool;
@@ -116,22 +119,22 @@ void pla_init(INTBIG *argc, char *argv[], TOOL *thistool)
 	pla_samesideoutput = FALSE;
 	pla_VddWidth = 0;
 	pla_GndWidth = 0;
-	(void)strcpy(pla_infile, INFILE);
-	(void)strcpy(pla_name, DEFNAME);
+	(void)estrcpy(pla_infile, INFILE);
+	(void)estrcpy(pla_name, DEFNAME);
 	pla_alv = pla_atg = pla_arg = pla_otv = NOVDDGND;
 	pla_org = pla_icg = pla_icv = pla_ocg = pla_ocv = NOVDDGND;
 
 	/* setup file descriptor */
-	pla_filetypeplatab = setupfiletype("", "*.*", MACFSTAG('TEXT'), FALSE, "platab", _("PLA table"));
+	pla_filetypeplatab = setupfiletype(x_(""), x_("*.*"), MACFSTAG('TEXT'), FALSE, x_("platab"), _("PLA table"));
 }
 
 /*
  * This routine is called each time the user issues the command,
  */
-void pla_set(INTBIG count, char *par[])
+void pla_set(INTBIG count, CHAR *par[])
 {
 	REGISTER INTBIG len;
-	REGISTER char *pp;
+	REGISTER CHAR *pp;
 
 	if (count == 0)
 	{
@@ -142,9 +145,9 @@ void pla_set(INTBIG count, char *par[])
 			return;
 		}
 	}
-	len = strlen(pp = par[0]);
+	len = estrlen(pp = par[0]);
 
-	if (namesamen(pp, "nmos", len) == 0)
+	if (namesamen(pp, x_("nmos"), len) == 0)
 	{
 		if (count < 3)
 		{
@@ -155,7 +158,7 @@ void pla_set(INTBIG count, char *par[])
 		return;
 	}
 
-	if (namesamen(pp, "cmos", len) == 0)
+	if (namesamen(pp, x_("cmos"), len) == 0)
 	{
 		if (count == 1)
 		{
@@ -167,33 +170,33 @@ void pla_set(INTBIG count, char *par[])
 			}
 		}
 
-		len = strlen(pp = par[1]);
-		if (namesamen(pp, "generate-pla", len) == 0)
+		len = estrlen(pp = par[1]);
+		if (namesamen(pp, x_("generate-pla"), len) == 0)
 		{
 			plac_generate();
 			return;
 		}
-		if (namesamen(pp, "decoder", len) == 0)
+		if (namesamen(pp, x_("decoder"), len) == 0)
 		{
 			plac_dec();
 			return;
 		}
-		if (namesamen(pp, "n-plane", len) == 0)
+		if (namesamen(pp, x_("n-plane"), len) == 0)
 		{
 			plac_n_generate();
 			return;
 		}
-		if (namesamen(pp, "p-plane", len) == 0)
+		if (namesamen(pp, x_("p-plane"), len) == 0)
 		{
 			plac_p_generate();
 			return;
 		}
-		ttyputbadusage("telltool pla cmos");
+		ttyputbadusage(x_("telltool pla cmos"));
 		return;
 	}
 
 	/* Invalid control to the PLA generator.  Print a small summary */
-	ttyputbadusage("telltool pla");
+	ttyputbadusage(x_("telltool pla"));
 }
 
 void pla_slice(void)
