@@ -44,13 +44,13 @@ static BOOLEAN plac_decode_route(NODEPROTO*, NODEINST*, NODEPROTO*, NODEINST*, N
 					NODEINST*, INTBIG);
 
 NODEPROTO *plac_decode_gen(LIBRARY *library, NODEPROTO *pmos_np, NODEPROTO *nmos_np,
-	CHAR *facet_name, INTBIG INPUTS)
+	CHAR *cell_name, INTBIG INPUTS)
 {
 	NODEPROTO *decode_np;
 	NODEINST *p_ni, *n_ni, *first_buf, *last_buf;
 	INTBIG X;
 
-	decode_np = newnodeproto(facet_name, library);
+	decode_np = newnodeproto(cell_name, library);
 	p_ni = plac_make_instance(decode_np, pmos_np, 0, 0, FALSE);
 	if (p_ni == NONODEINST) return(NONODEPROTO);
 	modifynodeinst(p_ni, 0, 0, 0, 0, 2700, 0);  /* rotate by 90 degrees */
@@ -69,7 +69,7 @@ NODEPROTO *plac_decode_gen(LIBRARY *library, NODEPROTO *pmos_np, NODEPROTO *nmos
 		last_buf, INPUTS)) return(NONODEPROTO);
 	plac_dec_exp(nmos_np, n_ni, decode_np);
 
-	/* ensure that the facet is the proper size */
+	/* ensure that the cell is the proper size */
 	(*el_curconstraint->solve)(decode_np);
 
 	return(decode_np);
@@ -261,7 +261,7 @@ BOOLEAN plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np
 	if (pm_ni_1 == NONODEINST) return(TRUE);
 	plac_wire(x_("Metal-1"), 4*pla_lam, p_ni, n_pp, pm_ni_1,
 		pm_ni_1->proto->firstportproto, decode_np);
-	if (INPUTS != TRUE) /* Buffers are at the top of the facet */
+	if (INPUTS != TRUE) /* Buffers are at the top of the cell */
 	{
 		pwr_pp = getportproto(first_buf->proto, x_("PWR.m-2.w"));
 		pm_ni_2 = plac_make_Pin(decode_np, p_X-13*pla_lam,
@@ -306,7 +306,7 @@ BOOLEAN plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np
 		(void)esnprintf(name, 100, x_("DATA%ld.m-1.s"), cnt);
 		p_pp = getportproto(pmos_np, name);
 	}
-	if (INPUTS == TRUE) /* Buffers are at the top of the facet */
+	if (INPUTS == TRUE) /* Buffers are at the top of the cell */
 	{
 		pwr_pp = getportproto(first_buf->proto, x_("PWR.m-2.w"));
 		pm_ni_2 = plac_make_Pin(decode_np, p_X-13*pla_lam,
@@ -327,7 +327,7 @@ BOOLEAN plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np
 	if (pm_ni_1 == NONODEINST) return(TRUE);
 	plac_wire(x_("Metal-1"), 4*pla_lam, n_ni, n_pp, pm_ni_1,
 		pm_ni_1->proto->firstportproto, decode_np);
-	if (INPUTS != TRUE) /* Buffers are at the top of the facet */
+	if (INPUTS != TRUE) /* Buffers are at the top of the cell */
 	{
 		pwr_pp = getportproto(last_buf->proto, x_("GND.m-2.e"));
 		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*pla_lam,
@@ -357,7 +357,7 @@ BOOLEAN plac_decode_route(NODEPROTO *pmos_np, NODEINST *p_ni, NODEPROTO *nmos_np
 		(void)esnprintf(name, 100, x_("GND%ld.m-1.n"), cnt);
 		n_pp = getportproto(nmos_np, name);
 	}
-	if (INPUTS == TRUE) /* Buffers are at the bottom of the facet */
+	if (INPUTS == TRUE) /* Buffers are at the bottom of the cell */
 	{
 		pwr_pp = getportproto(last_buf->proto, x_("GND.m-2.e"));
 		pm_ni_2 = plac_make_Pin(decode_np, p_X+13*pla_lam,
