@@ -46,7 +46,7 @@ void plac_generate(void)
 	LIBRARY  *plac_lib;
 	FILE     *and_array_file, *or_array_file;
 	NODEPROTO *pmos_np, *nmos_np, *or_np, *or_plane_np, *decode_np;
-	CHAR facet_name[100], and_file_name[100], *pt1, *params[MAXPARS], *filename;
+	CHAR cell_name[100], and_file_name[100], *pt1, *params[MAXPARS], *filename;
 	INTBIG INPUTS = FALSE, OUTPUTS = FALSE, count;
 	REGISTER void *infstr;
 
@@ -96,25 +96,25 @@ void plac_generate(void)
 	if (count >= 1 && params[0][0] == 'n') OUTPUTS = FALSE; else
 		OUTPUTS = TRUE;
 
-	/* last prompt of user, for facet name */
-	pt1 = ttygetline(_("Facet name: "));
+	/* last prompt of user, for cell name */
+	pt1 = ttygetline(_("Cell name: "));
 	if (pt1 == 0 || *pt1 == 0)
 	{
-		ttyputerr(_("Aborted: no array facet name given"));
+		ttyputerr(_("Aborted: no array cell name given"));
 		return;
 	}
-	(void)estrcpy(facet_name, pt1);
+	(void)estrcpy(cell_name, pt1);
 
-	/* generate the AND plane (Decode unit of a ROM) using facets from library */
+	/* generate the AND plane (Decode unit of a ROM) using cells from library */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, facet_name);
+	addstringtoinfstr(infstr, cell_name);
 	addstringtoinfstr(infstr, x_("_p_cell"));
 	pmos_np = plac_pmos_grid(plac_lib, and_array_file, returninfstr(infstr));
 	xclose(and_array_file);
 	if (pmos_np == NONODEPROTO) return;
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, facet_name);
+	addstringtoinfstr(infstr, cell_name);
 	addstringtoinfstr(infstr, x_("_n_cell"));
 	and_array_file = xopen(and_file_name, pla_filetypeplatab, x_(""), &filename);
 	if (and_array_file == NULL)
@@ -127,25 +127,25 @@ void plac_generate(void)
 	if (nmos_np == NONODEPROTO) return;
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, facet_name);
+	addstringtoinfstr(infstr, cell_name);
 	addstringtoinfstr(infstr, x_("_decode"));
 	decode_np = plac_decode_gen(plac_lib, pmos_np, nmos_np, returninfstr(infstr), INPUTS);
 	if (decode_np == NONODEPROTO) return;
 
 	/** Generate the OR plane **/
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, facet_name);
+	addstringtoinfstr(infstr, cell_name);
 	addstringtoinfstr(infstr, x_("_or_cell"));
 	or_np = plac_nmos_grid(plac_lib, or_array_file, returninfstr(infstr));
 	xclose(or_array_file);
 	if (or_np == NONODEPROTO) return;
 
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, facet_name);
+	addstringtoinfstr(infstr, cell_name);
 	addstringtoinfstr(infstr, x_("_or_plane"));
 	or_plane_np = plac_or_plane(plac_lib,or_np,returninfstr(infstr),OUTPUTS);
 	if (or_plane_np == NONODEPROTO) return;
-	(void)plac_make_pla(plac_lib, decode_np, or_plane_np, facet_name);
+	(void)plac_make_pla(plac_lib, decode_np, or_plane_np, cell_name);
 }
 
 /*
@@ -156,7 +156,7 @@ void plac_dec(void)
 	LIBRARY *plac_lib;
 	FILE    *and_array_file;
 	NODEPROTO *pmos_np, *nmos_np;
-	CHAR facet_name[40], temp_name[40], and_file_name[100], *params[MAXPARS];
+	CHAR cell_name[40], temp_name[40], and_file_name[100], *params[MAXPARS];
 	INTBIG INPUTS = FALSE, count;
 	CHAR *pt1, *filename;
 	REGISTER void *infstr;
@@ -181,17 +181,17 @@ void plac_dec(void)
 	if (count >= 1 && params[0][0] == 'n') INPUTS = FALSE; else
 		INPUTS = TRUE;
 
-	/* last prompt of user, for facet name */
-	pt1 = ttygetline(_("Facet name: "));
+	/* last prompt of user, for cell name */
+	pt1 = ttygetline(_("Cell name: "));
 	if (pt1 == 0 || *pt1 == 0)
 	{
-		ttyputerr(_("Aborted: no array facet name given"));
+		ttyputerr(_("Aborted: no array cell name given"));
 		return;
 	}
-	(void)estrcpy(facet_name, pt1);
+	(void)estrcpy(cell_name, pt1);
 
-	/* generate the AND plane (Decode unit of a ROM) using facets from library */
-	(void)estrcpy(temp_name, facet_name);
+	/* generate the AND plane (Decode unit of a ROM) using cells from library */
+	(void)estrcpy(temp_name, cell_name);
 	(void)estrcat(temp_name, x_("_p_cell"));
 	and_array_file = xopen(and_file_name, pla_filetypeplatab, x_(""), &filename);
 	if (and_array_file == NULL)
@@ -202,7 +202,7 @@ void plac_dec(void)
 	pmos_np = plac_pmos_grid(plac_lib, and_array_file, temp_name);
 	xclose(and_array_file);
 	if (pmos_np == NONODEPROTO) return;
-	(void)estrcpy(temp_name, facet_name);
+	(void)estrcpy(temp_name, cell_name);
 	(void)estrcat(temp_name, x_("_n_cell"));
 	and_array_file = xopen(and_file_name, pla_filetypeplatab, x_(""), &filename);
 	if (and_array_file == NULL)
@@ -213,7 +213,7 @@ void plac_dec(void)
 	nmos_np = plac_nmos_grid(plac_lib, and_array_file, temp_name);
 	xclose(and_array_file);
 	if (nmos_np == NONODEPROTO) return;
-	(void)estrcpy(temp_name, facet_name);
+	(void)estrcpy(temp_name, cell_name);
 	(void)estrcat(temp_name, x_("_decode"));
 	(void)plac_decode_gen(plac_lib, pmos_np, nmos_np, temp_name, INPUTS);
 }
@@ -226,7 +226,7 @@ void plac_p_generate(void)
 	LIBRARY *plac_lib;
 	FILE *array_file;
 	CHAR *pt1, *filename;
-	CHAR facet_name[40], array_file_name[100], *params[MAXPARS];
+	CHAR cell_name[40], array_file_name[100], *params[MAXPARS];
 	INTBIG count;
 	REGISTER void *infstr;
 
@@ -246,18 +246,18 @@ void plac_p_generate(void)
 	}
 	(void)estrcpy(array_file_name, params[0]);
 
-	/* last prompt of user, for facet name */
-	pt1 = ttygetline(_("Facet name: "));
+	/* last prompt of user, for cell name */
+	pt1 = ttygetline(_("Cell name: "));
 	if (pt1 == 0 || *pt1 == 0)
 	{
-		ttyputerr(_("Aborted: no array facet name given"));
+		ttyputerr(_("Aborted: no array cell name given"));
 		return;
 	}
-	(void)estrcpy(facet_name, pt1);
+	(void)estrcpy(cell_name, pt1);
 
-	/* generate pla_array_facet using facets from library */
+	/* generate pla_array_cell using cells from library */
 	array_file = xopen(array_file_name, pla_filetypeplatab, x_(""), &filename);
-	(void)plac_pmos_grid(plac_lib, array_file, facet_name);
+	(void)plac_pmos_grid(plac_lib, array_file, cell_name);
 	xclose(array_file);
 }
 
@@ -269,7 +269,7 @@ void plac_n_generate(void)
 	LIBRARY *plac_lib;
 	FILE *array_file;
 	CHAR *pt1, *filename;
-	CHAR facet_name[40], array_file_name[100], *params[MAXPARS];
+	CHAR cell_name[40], array_file_name[100], *params[MAXPARS];
 	INTBIG count;
 	REGISTER void *infstr;
 
@@ -289,18 +289,18 @@ void plac_n_generate(void)
 	}
 	(void)estrcpy(array_file_name, params[0]);
 
-	/* last prompt of user, for facet name */
-	pt1 = ttygetline(_("Facet name: "));
+	/* last prompt of user, for cell name */
+	pt1 = ttygetline(_("Cell name: "));
 	if (pt1 == 0 || *pt1 == 0)
 	{
-		ttyputerr(_("Aborted: no array facet name given"));
+		ttyputerr(_("Aborted: no array cell name given"));
 		return;
 	}
-	(void)estrcpy(facet_name, pt1);
+	(void)estrcpy(cell_name, pt1);
 
-	/* generate pla_array_facet using facets from library */
+	/* generate pla_array_cell using cells from library */
 	array_file = xopen(array_file_name, pla_filetypeplatab, x_(""), &filename);
-	(void)plac_nmos_grid(plac_lib, array_file, facet_name);
+	(void)plac_nmos_grid(plac_lib, array_file, cell_name);
 	xclose(array_file);
 }
 
