@@ -44,10 +44,10 @@ static BOOLEAN plac_nmos_init_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*
 static BOOLEAN plac_nmos_init_rows(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
 static BOOLEAN plac_finish_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
 
-NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
+NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR cell_name[])
 {
 	INTBIG height, width, height_in, width_in, read_rows;
-	NODEPROTO *pla_array_facet, *np, *nmos_one;
+	NODEPROTO *pla_array_cell, *np, *nmos_one;
 	INTBIG X1, X2, Y1, Y2, X, Y;
 	INTBIG row_1[PLAC_MAX_COL_SIZE], row_2[PLAC_MAX_COL_SIZE];
 	INTBIG eof, i, X_offset, Y_offset, Y_M_offset, row;
@@ -64,7 +64,7 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 		return(NONODEPROTO);
 	}
 
-	pla_array_facet = newnodeproto(facet_name, library);
+	pla_array_cell = newnodeproto(cell_name, library);
 
 	eof = plac_read_hw(file, &height, &width, &height_in, &width_in);
 	if (eof == EOF)
@@ -73,17 +73,17 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 		return(NONODEPROTO);
 	}
 
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_data_cols"), width_in, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_access_rows"), height_in, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_cols"), width, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_rows"), height, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_data_cols"), width_in, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_access_rows"), height_in, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_cols"), width, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_rows"), height, VINTEGER);
 
 	/* initialize the columns */
-	if (plac_nmos_init_columns(width, X, Y, X_offset, pla_array_facet))
+	if (plac_nmos_init_columns(width, X, Y, X_offset, pla_array_cell))
 		return(NONODEPROTO);
 
 	/* initialize the rows */
-	if (plac_nmos_init_rows(height_in, X, Y, Y_offset, Y_M_offset, pla_array_facet))
+	if (plac_nmos_init_rows(height_in, X, Y, Y_offset, Y_M_offset, pla_array_cell))
 		return(NONODEPROTO);
 
 	row_1[0] = -1;
@@ -112,11 +112,11 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 
 		for (i = 0; i < width; i++)
 		{
-			/* place a nmos_one facet.  Connect to ground and facet up above */
+			/* place a nmos_one cell.  Connect to ground and cell up above */
 			if (((i % 5) == 0) && (i != 0)) /* put in ground strap */
 			{
 				if (plac_gnd_strap(i, (X_offset*i)+(3*pla_lam), Y,
-					row, pla_array_facet, nmos_one)) return(NONODEPROTO);
+					row, pla_array_cell, nmos_one)) return(NONODEPROTO);
 			} else
 			{
 				/* put in bits */
@@ -124,21 +124,21 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 				{
 					/* make an instance of a nmos_one  */
 					if (plac_nmos_make_one(i, i*X_offset, Y, FALSE, row, nmos_one,
-						pla_array_facet)) return(NONODEPROTO);
+						pla_array_cell)) return(NONODEPROTO);
 				}
 				if ((row_2[i] == 1) && (row_2[0] != -1))
 				{
 					/* make an instance of a nmos_one  */
 					/* MIRROR object Horizontally    */
 					if (plac_nmos_make_one(i, i*X_offset, Y-Y_M_offset, TRUE, row,
-						nmos_one, pla_array_facet)) return(NONODEPROTO);
+						nmos_one, pla_array_cell)) return(NONODEPROTO);
 				}
 			}
 		}
 
 		/* Now put the poly metal contact at on the other side of the row */
 		if (plac_complete_row(row, X_offset*width+0*pla_lam, Y,
-			nmos_one, pla_array_facet)) return(NONODEPROTO);
+			nmos_one, pla_array_cell)) return(NONODEPROTO);
 		if ((read_rows % 4) == 0) Y = Y - Y_offset;
 
 		row_1[0] = -1;
@@ -149,26 +149,26 @@ NODEPROTO *plac_nmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 	X = 3*pla_lam;
 	if ((read_rows % 4) == 0) Y = Y + 2*Y_offset+pla_lam; else
 		Y = Y + Y_offset+pla_lam;
-	if (plac_finish_columns(width, X, Y, X_offset, nmos_one, pla_array_facet))
+	if (plac_finish_columns(width, X, Y, X_offset, nmos_one, pla_array_cell))
 		return(NONODEPROTO);
 
 	/* put a well node over the region */
 	np = getnodeproto(x_("mocmos:P-Well-Node"));
 
-	X1 = pla_array_facet->lowx;
-	X2 = pla_array_facet->highx;
-	Y1 = pla_array_facet->lowy - pla_lam;
-	Y2 = pla_array_facet->highy + pla_lam;
-	if (newnodeinst(np, X1, X2, Y1, Y2, 0, 0, pla_array_facet) == NONODEINST)
+	X1 = pla_array_cell->lowx;
+	X2 = pla_array_cell->highx;
+	Y1 = pla_array_cell->lowy - pla_lam;
+	Y2 = pla_array_cell->highy + pla_lam;
+	if (newnodeinst(np, X1, X2, Y1, Y2, 0, 0, pla_array_cell) == NONODEINST)
 		return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
-	(*el_curconstraint->solve)(pla_array_facet);
+	/* ensure that the cell is the proper size */
+	(*el_curconstraint->solve)(pla_array_cell);
 
-	return(pla_array_facet);
+	return(pla_array_cell);
 }
 
-BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_array_facet,
+BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_array_cell,
 	NODEPROTO *nmos_one)
 {
 	UCITEM *new_item;
@@ -177,7 +177,7 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 	new_item = plac_newUCITEM();
 
 	/* put in Substrate contact first */
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
+	new_item->nodeinst = plac_make_Pin(pla_array_cell, X,
 		Y+11*pla_lam, 14*pla_lam, x_("Metal-1-Well-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -187,7 +187,7 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 
 	/* connect to last column object */
 	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 	/* only put this in a column list */
 	plac_col_list[i].lastitem->bottomitem = new_item;
@@ -195,7 +195,7 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 
 	/* put in metal diffusion contact */
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
+	new_item->nodeinst = plac_make_Pin(pla_array_cell, X,
 		Y+pla_lam, 14*pla_lam, x_("Metal-1-D-Active-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -205,14 +205,14 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 
 	/* connect to last column object */
 	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 	/* connect to last row object */
 	if (plac_row_list[row][1].lastitem->nodeinst->proto != nmos_one)
 		last_col_pp = plac_row_list[row][1].lastitem->nodeinst->proto->firstportproto; else
 			last_col_pp = getportproto(plac_row_list[row][1].lastitem->nodeinst->proto, x_("GND.d.s"));
 	plac_wire(x_("D-active"), 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 	/* insert into row and column lists */
 	plac_col_list[i].lastitem->bottomitem = new_item;
@@ -223,7 +223,7 @@ BOOLEAN plac_gnd_strap(INTBIG i, INTBIG X, INTBIG Y, INTBIG row, NODEPROTO *pla_
 }
 
 BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG row,
-	NODEPROTO *nmos_one, NODEPROTO *pla_array_facet)
+	NODEPROTO *nmos_one, NODEPROTO *pla_array_cell)
 {
 	NODEINST *ni;
 	PORTPROTO *ni_col_pp, *last_col_pp;
@@ -237,7 +237,7 @@ BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG r
 	if (Mirror == TRUE)  /* row index value for the one object */
 		row_pos = 2; else row_pos = 0;
 
-	ni = plac_make_instance(pla_array_facet, nmos_one, X, Y, Mirror);
+	ni = plac_make_instance(pla_array_cell, nmos_one, X, Y, Mirror);
 	if (ni == NONODEINST) return(TRUE);
 
 	/* find the ports that need to be connected */
@@ -248,7 +248,7 @@ BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG r
 
 	/* connect to last column object */
 	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst, last_col_pp,
-		ni, ni_col_pp, pla_array_facet);
+		ni, ni_col_pp, pla_array_cell);
 
 	/* connect to last ground object */
 	if (plac_row_list[row][1].lastitem == NOUCITEM)
@@ -272,7 +272,7 @@ BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG r
 	}
 	ni_col_pp = getportproto(ni->proto, x_("GND.d.s"));
 	plac_wire(x_("D-active"), 14*pla_lam, plac_row_list[row][1].lastitem->nodeinst,
-		last_col_pp, ni, ni_col_pp, pla_array_facet);
+		last_col_pp, ni, ni_col_pp, pla_array_cell);
 
 	/* connect to last GATE object */
 	if (plac_row_list[row][row_pos].lastitem->nodeinst->proto != nmos_one)
@@ -281,7 +281,7 @@ BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG r
 				x_("GATE.p.e"));
 	ni_col_pp = getportproto(ni->proto, x_("GATE.p.w"));
 	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][row_pos].lastitem->nodeinst, last_col_pp,
-		ni, ni_col_pp, pla_array_facet);
+		ni, ni_col_pp, pla_array_cell);
 
 	/* put in column list */
 	plac_col_list[i].lastitem->bottomitem = plac_newUCITEM();
@@ -299,14 +299,14 @@ BOOLEAN plac_nmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG Mirror, INTBIG r
 }
 
 BOOLEAN plac_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *nmos_one,
-	NODEPROTO *pla_array_facet)
+	NODEPROTO *pla_array_cell)
 {
 	UCITEM *new_item;
 	PORTPROTO *last_col_pp, *ni_col_pp;
 	CHAR name[40];
 
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y+6*pla_lam,
+	new_item->nodeinst = plac_make_Pin(pla_array_cell, X, Y+6*pla_lam,
 		6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -316,25 +316,25 @@ BOOLEAN plac_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *nmos_one,
 			last_col_pp =  getportproto(plac_row_list[row][0].lastitem->nodeinst->proto, x_("GATE.p.e"));
 	ni_col_pp = new_item->nodeinst->proto->firstportproto;
 	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][0].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 	plac_row_list[row][0].lastitem = new_item;
 
 	/* Now export port at beginning and end of this half of the row grouping */
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.w"), row * 2);
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].firstitem->nodeinst,
 		plac_row_list[row][0].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.e"), row * 2);
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].lastitem->nodeinst,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.w"), row * 2);
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].firstitem->nodeinst,
 		plac_row_list[row][0].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.e"), row * 2);
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].lastitem->nodeinst,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
 
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y-4*pla_lam,
+	new_item->nodeinst = plac_make_Pin(pla_array_cell, X, Y-4*pla_lam,
 		6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -344,26 +344,26 @@ BOOLEAN plac_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *nmos_one,
 			last_col_pp =  getportproto(plac_row_list[row][2].lastitem->nodeinst->proto, x_("GATE.p.e"));
 	ni_col_pp = new_item->nodeinst->proto->firstportproto;
 	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][2].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 	plac_row_list[row][2].lastitem = new_item;
 
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.w"), row * 2 + 1);
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].firstitem->nodeinst,
 		plac_row_list[row][2].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.e"), row * 2 + 1);
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].lastitem->nodeinst,
 		plac_row_list[row][2].lastitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.w"), row * 2 + 1);
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].firstitem->nodeinst,
 		plac_row_list[row][2].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.e"), row * 2 + 1);
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].lastitem->nodeinst,
 		plac_row_list[row][2].lastitem->nodeinst->proto->firstportproto, name);
 	return(FALSE);
 }
 
 BOOLEAN plac_nmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
-	NODEPROTO *pla_array_facet)
+	NODEPROTO *pla_array_cell)
 {
 	CHAR name[40];
 	INTBIG i, gnd_cnt;
@@ -378,7 +378,7 @@ BOOLEAN plac_nmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset
 		if ((i % 5) == 0)
 		{
 			(void)esnprintf(name, 40, x_("GND%ld.m-1.n"), gnd_cnt);
-			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 				X_offset * i + X, Y, 14*pla_lam, x_("Metal-1-Well-Con"));
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(TRUE);
 			gnd_cnt++;
@@ -386,18 +386,18 @@ BOOLEAN plac_nmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset
 		{
 			/* must be a data pin, don't count ground pins */
 			(void)esnprintf(name, 40, x_("DATA%ld.m-1.n"), (i - gnd_cnt));
-			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 				X_offset * i + X, Y, 4*pla_lam, x_("Metal-1-Pin"));
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(TRUE);
 		}
-		(void)newportproto(pla_array_facet, plac_col_list[i].firstitem->nodeinst,
+		(void)newportproto(pla_array_cell, plac_col_list[i].firstitem->nodeinst,
 			plac_col_list[i].firstitem->nodeinst->proto->firstportproto, name);
 	}
 	return(FALSE);
 }
 
 BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset,
-	INTBIG Y_M_offset, NODEPROTO *pla_array_facet)
+	INTBIG Y_M_offset, NODEPROTO *pla_array_cell)
 {
 	INTBIG limit, i;
 	PORTPROTO *ni_col_pp, *last_col_pp;
@@ -413,7 +413,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 		new_item = plac_newUCITEM();
 
 		/* put in Substrate contact first */
-		new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
+		new_item->nodeinst = plac_make_Pin(pla_array_cell, X,
 			Y-Y_M_offset+10*pla_lam, 14*pla_lam, x_("Metal-1-Well-Con"));
 		if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -423,7 +423,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 
 		/* connect to last column object */
 		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
-			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 		/* only put this in a column list */
 		plac_col_list[0].lastitem->bottomitem = new_item;
@@ -436,14 +436,14 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 		plac_row_list[i][2].firstitem = plac_newUCITEM();
 		plac_row_list[i][2].lastitem =  plac_row_list[i][2].firstitem;
 
-		plac_row_list[i][0].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+		plac_row_list[i][0].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 			X-7*pla_lam, Y-5*pla_lam,
 				6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 		if (plac_row_list[i][0].firstitem->nodeinst == NONODEINST) return(TRUE);
-		plac_row_list[i][1].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+		plac_row_list[i][1].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 			X, Y-Y_M_offset, 14*pla_lam, x_("Metal-1-D-Active-Con"));
 		if (plac_row_list[i][1].firstitem->nodeinst == NONODEINST) return(TRUE);
-		plac_row_list[i][2].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+		plac_row_list[i][2].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 			X-7*pla_lam, Y-15*pla_lam,
 				6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 		if (plac_row_list[i][2].firstitem->nodeinst == NONODEINST) return(TRUE);
@@ -454,7 +454,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 
 		/* connect to last column object */
 		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
-			last_col_pp, plac_row_list[i][1].lastitem->nodeinst, ni_col_pp, pla_array_facet);
+			last_col_pp, plac_row_list[i][1].lastitem->nodeinst, ni_col_pp, pla_array_cell);
 		plac_col_list[0].lastitem->bottomitem = plac_row_list[i][1].lastitem;
 		plac_col_list[0].lastitem = plac_col_list[0].lastitem->bottomitem;
 
@@ -464,7 +464,7 @@ BOOLEAN plac_nmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 }
 
 BOOLEAN plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
-	NODEPROTO *nmos_one, NODEPROTO *pla_array_facet)
+	NODEPROTO *nmos_one, NODEPROTO *pla_array_cell)
 {
 	CHAR name[40];
 	INTBIG i, gnd_cnt;
@@ -480,7 +480,7 @@ BOOLEAN plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 		if ((i % 5) == 0)
 		{
 			(void)esnprintf(name, 40, x_("GND%ld.m-1.s"), gnd_cnt);
-			new_item->nodeinst = plac_make_Pin(pla_array_facet,
+			new_item->nodeinst = plac_make_Pin(pla_array_cell,
 				X_offset*i+X, Y, 14*pla_lam, x_("Metal-1-Well-Con"));
 			if (new_item->nodeinst == NONODEINST) return(TRUE);
 			last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
@@ -489,7 +489,7 @@ BOOLEAN plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 		{
 			/* must be a data pin, don't count ground pins */
 			(void)esnprintf(name, 40, x_("DATA%ld.m-1.s"), (i - gnd_cnt));
-			new_item->nodeinst = plac_make_Pin(pla_array_facet,
+			new_item->nodeinst = plac_make_Pin(pla_array_cell,
 				X_offset * i + X, Y, 4*pla_lam, x_("Metal-1-Pin"));
 			if (new_item->nodeinst == NONODEINST) return(TRUE);
 			if (plac_col_list[i].lastitem->nodeinst->proto != nmos_one)
@@ -503,12 +503,12 @@ BOOLEAN plac_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
 
 		/* connect to last column object */
 		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
-			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 		/* only put this in a column list */
 		plac_col_list[i].lastitem->bottomitem = new_item;
 		plac_col_list[i].lastitem = plac_col_list[i].lastitem->bottomitem;
-		(void)newportproto(pla_array_facet, new_item->nodeinst,
+		(void)newportproto(pla_array_cell, new_item->nodeinst,
 			new_item->nodeinst->proto->firstportproto, name);
 	}
 	return(FALSE);
