@@ -44,10 +44,10 @@ static BOOLEAN plac_pmos_make_one(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPR
 static BOOLEAN plac_pmos_complete_row(INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
 static BOOLEAN plac_pmos_finish_columns(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, NODEPROTO*);
 
-NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
+NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, CHAR cell_name[])
 {
 	INTBIG height, width, height_in, width_in, read_rows;
-	NODEPROTO *pla_array_facet, *pmos_one;
+	NODEPROTO *pla_array_cell, *pmos_one;
 	INTBIG X, Y;
 	INTBIG row_1[PLAC_MAX_COL_SIZE], row_2[PLAC_MAX_COL_SIZE];
 	INTBIG eof, i, X_offset, Y_offset, Y_M_offset, row;
@@ -65,7 +65,7 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 		return(NONODEPROTO);
 	}
 
-	pla_array_facet = newnodeproto(facet_name, library);
+	pla_array_cell = newnodeproto(cell_name, library);
 
 	eof = plac_read_hw(file, &height, &width, &height_in, &width_in);
 	if (eof == EOF)
@@ -74,17 +74,17 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 		return(NONODEPROTO);
 	}
 
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_data_cols"), width_in, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_access_rows"), height_in, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_cols"), width, VINTEGER);
-	(void)setval((INTBIG)pla_array_facet, VNODEPROTO, x_("PLA_rows"), height, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_data_cols"), width_in, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_access_rows"), height_in, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_cols"), width, VINTEGER);
+	(void)setval((INTBIG)pla_array_cell, VNODEPROTO, x_("PLA_rows"), height, VINTEGER);
 
 	/* initialize the columns */
-	if (plac_pmos_init_columns(width, X, Y, X_offset, pla_array_facet))
+	if (plac_pmos_init_columns(width, X, Y, X_offset, pla_array_cell))
 		return(NONODEPROTO);
 
 	/* initialize the rows */
-	if (plac_pmos_init_rows(height_in, X, Y, Y_offset, Y_M_offset, pla_array_facet))
+	if (plac_pmos_init_rows(height_in, X, Y, Y_offset, Y_M_offset, pla_array_cell))
 		return(NONODEPROTO);
 
 	row_1[0] = -1;
@@ -111,11 +111,11 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 
 		for(i = 0; i < width; i++)
 		{
-			/* place a pmos_one facet and connect to power, and facet up above */
+			/* place a pmos_one cell and connect to power, and cell up above */
 			if (((i % 5) == 0) && (i != 0)) /* put in power strap */
 			{
 				if (plac_pwr_strap(i, ((X_offset*i)+(3*pla_lam)), Y,
-					pla_array_facet)) return(NONODEPROTO);
+					pla_array_cell)) return(NONODEPROTO);
 			} else
 			{
 				/* put in bits -- make an instance of a pmos_one  */
@@ -123,20 +123,20 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 				{
 					/* make an instance of a pmos_one  */
 					if (plac_pmos_make_one(i, ((i*X_offset)+(6*pla_lam)), Y, 0, row,
-						pmos_one, pla_array_facet)) return(NONODEPROTO);
+						pmos_one, pla_array_cell)) return(NONODEPROTO);
 				}
 				if ((row_2[i] == 1) && (row_2[0] != -1))
 				{
 					/* make an instance of a pmos_one  */
 					if (plac_pmos_make_one(i, ((i*X_offset)+(6*pla_lam)),
-						Y-Y_M_offset, 2, row, pmos_one, pla_array_facet)) return(NONODEPROTO);
+						Y-Y_M_offset, 2, row, pmos_one, pla_array_cell)) return(NONODEPROTO);
 				}
 			}
 		}
 
 		/* Now put the poly metal contact at on the other side of the row */
 		if (plac_pmos_complete_row(row, ((X_offset*width)+(0*pla_lam)),
-			Y, pmos_one, pla_array_facet)) return(NONODEPROTO);
+			Y, pmos_one, pla_array_cell)) return(NONODEPROTO);
 
 		if ((read_rows % 4) == 0) Y = Y - Y_offset;
 
@@ -148,17 +148,17 @@ NODEPROTO *plac_pmos_grid(LIBRARY *library, FILE *file, CHAR facet_name[])
 	X = 3*pla_lam;
 	if ((read_rows % 4) == 0) Y = Y + 2*Y_offset-3*pla_lam; else
 		Y = Y + Y_offset-3*pla_lam;
-	if (plac_pmos_finish_columns(width, X, Y, X_offset, pmos_one, pla_array_facet))
+	if (plac_pmos_finish_columns(width, X, Y, X_offset, pmos_one, pla_array_cell))
 		return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
-	(*el_curconstraint->solve)(pla_array_facet);
+	/* ensure that the cell is the proper size */
+	(*el_curconstraint->solve)(pla_array_cell);
 
-	return(pla_array_facet);
+	return(pla_array_cell);
 }
 
 BOOLEAN plac_pmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
-	NODEPROTO *pla_array_facet)
+	NODEPROTO *pla_array_cell)
 {
 	CHAR name[40];
 	INTBIG i, pwr_cnt;
@@ -173,7 +173,7 @@ BOOLEAN plac_pmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset
 		{
 			/* put in a Power pin every 5th position */
 			(void)esnprintf(name, 40, x_("PWR%ld.m-1.n"), pwr_cnt);
-			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 				X_offset * i + X, Y, 14*pla_lam, x_("Metal-1-Substrate-Con"));
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(TRUE);
 			pwr_cnt++;
@@ -181,18 +181,18 @@ BOOLEAN plac_pmos_init_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset
 		{
 			/* must be a data pin, don't count power pins */
 			(void)esnprintf(name, 40, x_("DATA%ld.m-1.n"), (i - pwr_cnt));
-			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+			plac_col_list[i].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 				X_offset * i + X, Y, 4*pla_lam, x_("Metal-1-Pin"));
 			if (plac_col_list[i].firstitem->nodeinst == NONODEINST) return(TRUE);
 		}
-		(void)newportproto(pla_array_facet, plac_col_list[i].firstitem->nodeinst,
+		(void)newportproto(pla_array_cell, plac_col_list[i].firstitem->nodeinst,
 			plac_col_list[i].firstitem->nodeinst->proto->firstportproto, name);
 	}
 	return(FALSE);
 }
 
 BOOLEAN plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offset,
-	INTBIG Y_M_offset, NODEPROTO *pla_array_facet)
+	INTBIG Y_M_offset, NODEPROTO *pla_array_cell)
 {
 	INTBIG limit, i;
 	PORTPROTO *ni_col_pp, *last_col_pp;
@@ -208,7 +208,7 @@ BOOLEAN plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 		if (((i % 2) == 0) && (i != 0)) Y = Y - Y_offset;
 
 		/* put in Substrate contact first */
-		new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
+		new_item->nodeinst = plac_make_Pin(pla_array_cell, X,
 			Y-Y_M_offset+10*pla_lam, 14*pla_lam, x_("Metal-1-Substrate-Con"));
 		if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -218,7 +218,7 @@ BOOLEAN plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 		ni_col_pp = new_item->nodeinst->proto->firstportproto;
 		last_col_pp = plac_col_list[0].lastitem->nodeinst->proto->firstportproto;
 		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[0].lastitem->nodeinst,
-			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 		plac_col_list[0].lastitem->bottomitem = new_item;
 		plac_col_list[0].lastitem = plac_col_list[0].lastitem->bottomitem;
@@ -228,10 +228,10 @@ BOOLEAN plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 		plac_row_list[i][2].firstitem = plac_newUCITEM();
 		plac_row_list[i][2].lastitem =  plac_row_list[i][2].firstitem;
 
-		plac_row_list[i][0].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+		plac_row_list[i][0].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 			X-7*pla_lam, Y-5*pla_lam, 6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 		if (plac_row_list[i][0].firstitem->nodeinst == NONODEINST) return(TRUE);
-		plac_row_list[i][2].firstitem->nodeinst = plac_make_Pin(pla_array_facet,
+		plac_row_list[i][2].firstitem->nodeinst = plac_make_Pin(pla_array_cell,
 			X-7*pla_lam, Y-15*pla_lam, 6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 		if (plac_row_list[i][2].firstitem->nodeinst == NONODEINST) return(TRUE);
 
@@ -240,7 +240,7 @@ BOOLEAN plac_pmos_init_rows(INTBIG height_in, INTBIG X, INTBIG Y, INTBIG Y_offse
 	return(FALSE);
 }
 
-BOOLEAN plac_pwr_strap(INTBIG i, INTBIG X, INTBIG Y, NODEPROTO *pla_array_facet)
+BOOLEAN plac_pwr_strap(INTBIG i, INTBIG X, INTBIG Y, NODEPROTO *pla_array_cell)
 {
 	UCITEM *new_item;
 	PORTPROTO *ni_col_pp, *last_col_pp;
@@ -248,7 +248,7 @@ BOOLEAN plac_pwr_strap(INTBIG i, INTBIG X, INTBIG Y, NODEPROTO *pla_array_facet)
 	new_item = plac_newUCITEM();
 
 	/* put in Substrate contact first */
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y+7*pla_lam,
+	new_item->nodeinst = plac_make_Pin(pla_array_cell, X, Y+7*pla_lam,
 		14*pla_lam, x_("Metal-1-Substrate-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -257,7 +257,7 @@ BOOLEAN plac_pwr_strap(INTBIG i, INTBIG X, INTBIG Y, NODEPROTO *pla_array_facet)
 	last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
 
 	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 	/* only put this in a column list */
 	plac_col_list[i].lastitem->bottomitem = new_item;
@@ -266,12 +266,12 @@ BOOLEAN plac_pwr_strap(INTBIG i, INTBIG X, INTBIG Y, NODEPROTO *pla_array_facet)
 }
 
 BOOLEAN plac_pmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG row_pos, INTBIG row,
-	NODEPROTO *uc_one, NODEPROTO *pla_array_facet)
+	NODEPROTO *uc_one, NODEPROTO *pla_array_cell)
 {
 	NODEINST *ni;
 	PORTPROTO *ni_col_pp, *last_col_pp;
 
-	ni = plac_make_instance(pla_array_facet, uc_one, X, Y, FALSE);
+	ni = plac_make_instance(pla_array_cell, uc_one, X, Y, FALSE);
 	if (ni == NONODEINST) return(TRUE);
 
 	/* find ports that need to be connected and connect to last column object */
@@ -281,7 +281,7 @@ BOOLEAN plac_pmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG row_pos, INTBIG
 			last_col_pp = getportproto(plac_col_list[i].lastitem->nodeinst->proto, x_("OUT.m-1.s"));
 
 	plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst, last_col_pp,
-		ni, ni_col_pp, pla_array_facet);
+		ni, ni_col_pp, pla_array_cell);
 
 	/* connect to last GATE object */
 	if (plac_row_list[row][row_pos].lastitem->nodeinst->proto != uc_one)
@@ -291,7 +291,7 @@ BOOLEAN plac_pmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG row_pos, INTBIG
 	ni_col_pp = getportproto(ni->proto, x_("GATE.p.w"));
 
 	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][row_pos].lastitem->nodeinst,
-		last_col_pp, ni, ni_col_pp, pla_array_facet);
+		last_col_pp, ni, ni_col_pp, pla_array_cell);
 
 	/* put in column list */
 	plac_col_list[i].lastitem->bottomitem = plac_newUCITEM();
@@ -305,14 +305,14 @@ BOOLEAN plac_pmos_make_one(INTBIG i, INTBIG X, INTBIG Y, INTBIG row_pos, INTBIG
 }
 
 BOOLEAN plac_pmos_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *uc_one,
-	NODEPROTO *pla_array_facet)
+	NODEPROTO *pla_array_cell)
 {
 	UCITEM *new_item;
 	PORTPROTO *last_col_pp, *ni_col_pp;
 	CHAR name[40];
 
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X,
+	new_item->nodeinst = plac_make_Pin(pla_array_cell, X,
 		Y+2*pla_lam, 6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -322,25 +322,25 @@ BOOLEAN plac_pmos_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *uc_one
 			last_col_pp =  getportproto(plac_row_list[row][0].lastitem->nodeinst->proto, x_("GATE.p.e"));
 	ni_col_pp = new_item->nodeinst->proto->firstportproto;
 	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][0].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 	plac_row_list[row][0].lastitem = new_item;
 
 	/* Now export port at the beginning and end of this half of row grouping */
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.w"), (row * 2));
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].firstitem->nodeinst,
 		plac_row_list[row][0].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.e"), (row * 2));
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].lastitem->nodeinst,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.w"), (row * 2));
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].firstitem->nodeinst,
 		plac_row_list[row][0].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.e"), (row * 2));
-	(void)newportproto(pla_array_facet, plac_row_list[row][0].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][0].lastitem->nodeinst,
 		plac_row_list[row][0].lastitem->nodeinst->proto->firstportproto, name);
 
 	new_item = plac_newUCITEM();
-	new_item->nodeinst = plac_make_Pin(pla_array_facet, X, Y-8*pla_lam,
+	new_item->nodeinst = plac_make_Pin(pla_array_cell, X, Y-8*pla_lam,
 		6*pla_lam, x_("Metal-1-Polysilicon-Con"));
 	if (new_item->nodeinst == NONODEINST) return(TRUE);
 
@@ -350,26 +350,26 @@ BOOLEAN plac_pmos_complete_row(INTBIG row, INTBIG X, INTBIG Y, NODEPROTO *uc_one
 			last_col_pp =  getportproto(plac_row_list[row][2].lastitem->nodeinst->proto, x_("GATE.p.e"));
 	ni_col_pp = new_item->nodeinst->proto->firstportproto;
 	plac_wire(x_("Polysilicon"), 0, plac_row_list[row][2].lastitem->nodeinst,
-		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+		last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 	plac_row_list[row][2].lastitem = new_item;
 
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.w"), (row * 2 + 1));
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].firstitem->nodeinst,
 		plac_row_list[row][2].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.m-1.e"), (row * 2 + 1));
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].lastitem->nodeinst,
 		plac_row_list[row][2].lastitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.w"), (row * 2 + 1));
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].firstitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].firstitem->nodeinst,
 		plac_row_list[row][2].firstitem->nodeinst->proto->firstportproto, name);
 	(void)esnprintf(name, 40, x_("ACCESS%ld.p.e"), (row * 2 + 1));
-	(void)newportproto(pla_array_facet, plac_row_list[row][2].lastitem->nodeinst,
+	(void)newportproto(pla_array_cell, plac_row_list[row][2].lastitem->nodeinst,
 		plac_row_list[row][2].lastitem->nodeinst->proto->firstportproto, name);
 	return(FALSE);
 }
 
 BOOLEAN plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offset,
-	NODEPROTO *nmos_one, NODEPROTO *pla_array_facet)
+	NODEPROTO *nmos_one, NODEPROTO *pla_array_cell)
 {
 	CHAR name[40];
 	INTBIG i, pwr_cnt;
@@ -384,7 +384,7 @@ BOOLEAN plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offs
 		if ((i % 5) == 0)	/* put in a power pin every 5th position */
 		{
 			(void)esnprintf(name, 40, x_("PWR%ld.m-1.s"), pwr_cnt);
-			new_item->nodeinst = plac_make_Pin(pla_array_facet, X_offset * i + X, Y,
+			new_item->nodeinst = plac_make_Pin(pla_array_cell, X_offset * i + X, Y,
 				14*pla_lam, x_("Metal-1-Substrate-Con"));
 			if (new_item->nodeinst == NONODEINST) return(TRUE);
 			last_col_pp = plac_col_list[i].lastitem->nodeinst->proto->firstportproto;
@@ -393,7 +393,7 @@ BOOLEAN plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offs
 		{
 			/* must be a data pin, don't count power pins */
 			(void)esnprintf(name, 40, x_("DATA%ld.m-1.s"), (i - pwr_cnt));
-			new_item->nodeinst = plac_make_Pin(pla_array_facet,
+			new_item->nodeinst = plac_make_Pin(pla_array_cell,
 				X_offset * i + X, Y, 4*pla_lam, x_("Metal-1-Pin"));
 			if (new_item->nodeinst == NONODEINST) return(TRUE);
 			if (plac_col_list[i].lastitem->nodeinst->proto != nmos_one)
@@ -407,13 +407,13 @@ BOOLEAN plac_pmos_finish_columns(INTBIG width, INTBIG X, INTBIG Y, INTBIG X_offs
 
 		/* connect to last column object */
 		plac_wire(x_("Metal-1"), 4*pla_lam, plac_col_list[i].lastitem->nodeinst,
-			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_facet);
+			last_col_pp, new_item->nodeinst, ni_col_pp, pla_array_cell);
 
 		/* only put this in a column list */
 		plac_col_list[i].lastitem->bottomitem = new_item;
 		plac_col_list[i].lastitem = plac_col_list[i].lastitem->bottomitem;
 
-		(void)newportproto(pla_array_facet, new_item->nodeinst,
+		(void)newportproto(pla_array_cell, new_item->nodeinst,
 			new_item->nodeinst->proto->firstportproto, name);
 	}
 	return(FALSE);
