@@ -3,7 +3,7 @@
  * Electric(tm) VLSI Design System
  *
  * File: planfacets.c
- * Programmable Logic Array Generator: Defining the facets that make up a PLA
+ * Programmable Logic Array Generator: Defining the cells that make up a PLA
  * Written by: Steven M. Rubin, Static Free Software
  * Written by: Sundaravarathan R. Iyengar, Schlumberger Palo Alto Research
  *
@@ -61,42 +61,42 @@ PORTPROTO *pla_FindPort(NODEINST *node, INTBIG x, INTBIG y)
 
 NODEPROTO *pla_nmos_Connect(void)
 {
-	NODEPROTO *facet;
+	NODEPROTO *cell;
 	NODEINST *mp_contact, *md_contact, *poly_pin;
 	ARCINST *pa;
 
-	facet = newnodeproto(nmosConnect, el_curlib);
-	if (facet == NONODEPROTO) return(NONODEPROTO);
+	cell = newnodeproto(nmosConnect, el_curlib);
+	if (cell == NONODEPROTO) return(NONODEPROTO);
 
 	mp_contact = newnodeinst(pla_mp_proto, 0, 4*pla_lam, 3*pla_lam, 7*pla_lam, NOTRANS, NOROT,
-		facet);
+		cell);
 	poly_pin = newnodeinst(pla_pp_proto, 6*pla_lam+pla_GndWidth, 8*pla_lam+pla_GndWidth,
-		5*pla_lam, 7*pla_lam, NOTRANS, NOROT, facet);
+		5*pla_lam, 7*pla_lam, NOTRANS, NOROT, cell);
 	if (mp_contact == NONODEINST || poly_pin == NONODEINST) return(NONODEPROTO);
 
 	pa = newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, poly_pin, pla_pp_proto->firstportproto,
 		7*pla_lam+pla_GndWidth, 6*pla_lam, mp_contact, pla_mp_proto->firstportproto, 2*pla_lam,
-			6*pla_lam, facet);
+			6*pla_lam, cell);
 	if (pa == NOARCINST) return(NONODEPROTO);
 
 	/* Extend the AndEnd of the metal-poly pin by one lambda */
 	if (newarcinst(pla_ma_proto, 4*pla_lam, FIXANG, mp_contact, pla_mp_proto->firstportproto,
 		pla_lam, 5*pla_lam, mp_contact, pla_mp_proto->firstportproto, 2*pla_lam, 5*pla_lam,
-			facet) == NOARCINST) return(NONODEPROTO);
+			cell) == NOARCINST) return(NONODEPROTO);
 
 	/* Instance a metal-diff contact for ground connection and export it */
 	md_contact = newnodeinst(pla_md_proto, 7*pla_lam, 7*pla_lam+pla_GndWidth,
-		0, 4*pla_lam, NOTRANS, NOROT, facet);
+		0, 4*pla_lam, NOTRANS, NOROT, cell);
 	if (md_contact == NONODEINST) return(NONODEPROTO);
 
-	if ((newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("DiffGnd")) == NOPORTPROTO) ||
-		(newportproto(facet, mp_contact, pla_mp_proto->firstportproto, x_("AndEnd")) == NOPORTPROTO) ||
-		(newportproto(facet, poly_pin, pla_pp_proto->firstportproto, x_("OrEnd")) == NOPORTPROTO))
+	if ((newportproto(cell, md_contact, pla_md_proto->firstportproto, x_("DiffGnd")) == NOPORTPROTO) ||
+		(newportproto(cell, mp_contact, pla_mp_proto->firstportproto, x_("AndEnd")) == NOPORTPROTO) ||
+		(newportproto(cell, poly_pin, pla_pp_proto->firstportproto, x_("OrEnd")) == NOPORTPROTO))
 			return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
-	(*el_curconstraint->solve)(facet);
-	return(facet);
+	/* ensure that the cell is the proper size */
+	(*el_curconstraint->solve)(cell);
+	return(cell);
 }
 
 NODEPROTO *pla_nmos_InPullup(void)
@@ -167,14 +167,14 @@ NODEPROTO *pla_nmos_InPullup(void)
 	if (dtran_pport == NOPORTPROTO) return(NONODEPROTO);
 	if (newportproto(pu, dtran, dtran_pport, x_("Invpt")) == NOPORTPROTO) return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
+	/* ensure that the cell is the proper size */
 	(*el_curconstraint->solve)(pu);
 	return(pu);
 }
 
 NODEPROTO *pla_nmos_Input(void)
 {
-	NODEPROTO *facet, *pu;
+	NODEPROTO *cell, *pu;
 	NODEINST *pu1,  *pu2, *ppin, *etran1, *etran2,
 		*ppin1, *ppin2, *dpin1, *dpin2, *md_contact, *md_contact1;
 	ARCINST *ai;
@@ -187,37 +187,37 @@ NODEPROTO *pla_nmos_Input(void)
 	 * Now create a diffusion to metal contact wide enough to accommodate
 	 * the Vdd line.  Assume that the global variables pla_VddWidth and
 	 * pla_GndWidth contain the widths of  Vdd and Gnd lines.  The
-	 * Y size of the Input facet is these two widths plus the heights
+	 * Y size of the Input cell is these two widths plus the heights
 	 * two inverters.  These inverters are identical.  The difference
 	 * in heights (see code below) comes from the savings resulting
 	 * from the fact that these two are interconnected.
 	 */
-	facet = newnodeproto(x_("nmos_Input"), el_curlib);
-	if (facet == NONODEPROTO) return(NONODEPROTO);
+	cell = newnodeproto(x_("nmos_Input"), el_curlib);
+	if (cell == NONODEPROTO) return(NONODEPROTO);
 
 	md_contact = newnodeinst(pla_md_proto, 2*pla_lam, 8*pla_lam,
-		17*pla_lam, 17*pla_lam+pla_VddWidth, NOTRANS, NOROT, facet);
+		17*pla_lam, 17*pla_lam+pla_VddWidth, NOTRANS, NOROT, cell);
 	if (md_contact == NONODEINST) return(NONODEPROTO);
 
 	/* export this for vdd connection */
-	if (newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("Vdd")) ==
+	if (newportproto(cell, md_contact, pla_md_proto->firstportproto, x_("Vdd")) ==
 		NOPORTPROTO) return(NONODEPROTO);
 
 	/* Instance the pullups on either side (top and bottom) of this contact */
-	pu1 = newnodeinst(pu, 0, 7*pla_lam, 7*pla_lam, 18*pla_lam, NOTRANS, NOROT, facet);
+	pu1 = newnodeinst(pu, 0, 7*pla_lam, 7*pla_lam, 18*pla_lam, NOTRANS, NOROT, cell);
 	pu2 = newnodeinst(pu, 0, 7*pla_lam, 16*pla_lam+pla_VddWidth,
-		27*pla_lam+pla_VddWidth, TRANS, 2700, facet);
+		27*pla_lam+pla_VddWidth, TRANS, 2700, cell);
 	if (pu1 == NONODEINST || pu2 == NONODEINST) return(NONODEPROTO);
 
 	/* connect these pullups to the Vdd line */
 	ai = newarcinst(pla_da_proto, 2*pla_lam, FIXANG, pu1, pla_FindPort(pu1,4*pla_lam,17*pla_lam),
 		4*pla_lam, 17*pla_lam, md_contact, pla_md_proto->firstportproto, 4*pla_lam, 18*pla_lam,
-			facet);
+			cell);
 	if (ai == NOARCINST) return(NONODEPROTO);
 
 	ai = newarcinst(pla_da_proto, 2*pla_lam, FIXANG, pu2,
 		pla_FindPort(pu2,4*pla_lam,17*pla_lam+pla_VddWidth), 4*pla_lam, 17*pla_lam+pla_VddWidth,
-			md_contact, pla_md_proto->firstportproto, 4*pla_lam, (17-1)*pla_lam+pla_VddWidth, facet);
+			md_contact, pla_md_proto->firstportproto, 4*pla_lam, (17-1)*pla_lam+pla_VddWidth, cell);
 	if (ai == NOARCINST) return(NONODEPROTO);
 
 	/*
@@ -227,21 +227,21 @@ NODEPROTO *pla_nmos_Input(void)
 	 * (10,17+11-2+pla_VddWidth/pla_lam)
 	 */
 	etran1 = newnodeinst(pla_etran_proto, 4*pla_lam, 16*pla_lam,
-		3*pla_lam, 9*pla_lam, NOTRANS, 900, facet);
+		3*pla_lam, 9*pla_lam, NOTRANS, 900, cell);
 	etran2 = newnodeinst(pla_etran_proto, 4*pla_lam, 16*pla_lam,
-		(17+11-3-3)*pla_lam+pla_VddWidth, (17+11-3+3)*pla_lam+pla_VddWidth, NOTRANS, 900, facet);
+		(17+11-3-3)*pla_lam+pla_VddWidth, (17+11-3+3)*pla_lam+pla_VddWidth, NOTRANS, 900, cell);
 	if (etran1 == NONODEINST || etran2 == NONODEINST) return(NONODEPROTO);
 
 	/* connect the pullups to the pulldowns */
 	ai = newarcinst(pla_da_proto, 2*pla_lam, FIXANG, pu1, pla_FindPort(pu1,5*pla_lam,9*pla_lam),
 		5*pla_lam, 9*pla_lam, etran1, pla_FindPort(etran1,8*pla_lam,9*pla_lam), 8*pla_lam,
-			9*pla_lam, facet);
+			9*pla_lam, cell);
 	if (ai == NOARCINST) return(NONODEPROTO);
 
 	ai = newarcinst(pla_da_proto, 2*pla_lam, FIXANG, pu2,
 		pla_FindPort(pu2,5*pla_lam,25*pla_lam+pla_VddWidth), 5*pla_lam, 25*pla_lam+pla_VddWidth,
 			etran2, pla_FindPort(etran2,8*pla_lam,25*pla_lam+pla_VddWidth), 8*pla_lam,
-				25*pla_lam+pla_VddWidth, facet);
+				25*pla_lam+pla_VddWidth, cell);
 	if (ai == NOARCINST) return(NONODEPROTO);
 
 	/*
@@ -250,26 +250,26 @@ NODEPROTO *pla_nmos_Input(void)
 	 * respect to pla_VddWidth.
 	 */
 	dpin1 = newnodeinst(pla_dp_proto, 12*pla_lam, 15*pla_lam,
-		6*pla_lam, 9*pla_lam, NOTRANS, NOROT, facet);
+		6*pla_lam, 9*pla_lam, NOTRANS, NOROT, cell);
 	dpin2 = newnodeinst(pla_dp_proto, 12*pla_lam, 15*pla_lam,
-		(17+5)*pla_lam+pla_VddWidth, (17+5+3)*pla_lam+pla_VddWidth, NOTRANS, NOROT, facet);
+		(17+5)*pla_lam+pla_VddWidth, (17+5+3)*pla_lam+pla_VddWidth, NOTRANS, NOROT, cell);
 	if (dpin1 == NONODEINST || dpin2 == NONODEINST) return(NONODEPROTO);
 
 	/* Connect the diff pins to the respective pulldowns */
 	if (newarcinst(pla_da_proto, 3*pla_lam, FIXANG, etran1,
 		pla_FindPort(etran1,12*pla_lam,(INTBIG)(7.5*pla_lam)), 12*pla_lam, (INTBIG)(7.5*pla_lam),
 			dpin1, pla_dp_proto->firstportproto, (INTBIG)(13.5*pla_lam),(INTBIG)(7.5*pla_lam),
-				facet) == NOARCINST) return(NONODEPROTO);
+				cell) == NOARCINST) return(NONODEPROTO);
 	if (newarcinst(pla_da_proto, 3*pla_lam, FIXANG, etran2, pla_FindPort(etran2,12*pla_lam,
 		(INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth), 12*pla_lam,
 			(INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth, dpin2, pla_dp_proto->firstportproto,
-				(INTBIG)(13.5*pla_lam), (INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth, facet) == NOARCINST)
+				(INTBIG)(13.5*pla_lam), (INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth, cell) == NOARCINST)
 					return(NONODEPROTO);
 
 	/* Now connect these d pins together */
 	if (newarcinst(pla_da_proto, 3*pla_lam, FIXANG, dpin1, pla_dp_proto->firstportproto,
 		(INTBIG)(13.5*pla_lam), (INTBIG)(7.5*pla_lam), dpin2, pla_dp_proto->firstportproto,
-			(INTBIG)(13.5*pla_lam), (INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth, facet) == NOARCINST)
+			(INTBIG)(13.5*pla_lam), (INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	/*
@@ -280,30 +280,30 @@ NODEPROTO *pla_nmos_Input(void)
 	 * pullup to the top pulldown.  Then draw arcs to pullup and pulldown
 	 */
 	if ((ppin = newnodeinst(pla_pp_proto, 9*pla_lam, 11*pla_lam,
-		14*pla_lam, 16*pla_lam, NOTRANS, NOROT, facet)) == NONODEINST)
+		14*pla_lam, 16*pla_lam, NOTRANS, NOROT, cell)) == NONODEINST)
 			return(NONODEPROTO);
 
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, pu1, pla_FindPort(pu1, 6*pla_lam, 15*pla_lam),
 		6*pla_lam, 15*pla_lam, ppin, pla_pp_proto->firstportproto, 10*pla_lam, 15*pla_lam,
-			facet) == NOARCINST) return(NONODEPROTO);
+			cell) == NOARCINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin, pla_pp_proto->firstportproto,
 		10*pla_lam, 15*pla_lam, etran2, pla_FindPort(etran2,10*pla_lam, (17+3)*pla_lam+pla_VddWidth),
-			10*pla_lam, (17+3)*pla_lam+pla_VddWidth, facet) == NOARCINST)
+			10*pla_lam, (17+3)*pla_lam+pla_VddWidth, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	/*
 	 * Now pull this connection to the top to form the inverted output
-	 * from the Input facet.
+	 * from the Input cell.
 	 */
 	if ((ppin1 = newnodeinst(pla_pp_proto, 9*pla_lam, 11*pla_lam,
 		(17+11+4-2)*pla_lam+pla_VddWidth+pla_GndWidth,
-			(17+11+4)  *pla_lam+pla_VddWidth+pla_GndWidth, NOTRANS, NOROT, facet)) == NONODEINST)
+			(17+11+4)  *pla_lam+pla_VddWidth+pla_GndWidth, NOTRANS, NOROT, cell)) == NONODEINST)
 				return(NONODEPROTO);
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin1, pla_pp_proto->firstportproto,
 		10*pla_lam, (17+11+4-1)*pla_lam+pla_VddWidth+pla_GndWidth, etran2,
 			pla_FindPort(etran2,10*pla_lam, (17+11+2)*pla_lam+pla_VddWidth),
-				10*pla_lam, (17+11+2)*pla_lam+pla_VddWidth, facet) == NOARCINST)
+				10*pla_lam, (17+11+2)*pla_lam+pla_VddWidth, cell) == NOARCINST)
 					return(NONODEPROTO);
 
 	/*
@@ -312,21 +312,21 @@ NODEPROTO *pla_nmos_Input(void)
 	 */
 	if ((ppin2 = newnodeinst(pla_pp_proto, pla_lam, 3*pla_lam,
 		(17+11+4-2)*pla_lam+pla_VddWidth+pla_GndWidth,
-			(17+11+4)*pla_lam+pla_VddWidth+pla_GndWidth, NOTRANS, NOROT, facet)) == NONODEINST)
+			(17+11+4)*pla_lam+pla_VddWidth+pla_GndWidth, NOTRANS, NOROT, cell)) == NONODEINST)
 				return(NONODEPROTO);
 
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin2, pla_pp_proto->firstportproto,
 		2*pla_lam, (17+11+4-1)*pla_lam+pla_VddWidth+pla_GndWidth, pu2, pla_FindPort(pu2,2*pla_lam,
 			(17+11-3)*pla_lam+pla_VddWidth), 2*pla_lam, (17+11-3)*pla_lam+pla_VddWidth,
-				facet) == NOARCINST) return(NONODEPROTO);
+				cell) == NOARCINST) return(NONODEPROTO);
 
 	/* Pull a diff arc from the pulldowns to a ground pin at the top */
 	if ((md_contact = newnodeinst(pla_md_proto, 12*pla_lam, 16*pla_lam,
 		(17+11+4)*pla_lam+pla_VddWidth, (17+11+4)*pla_lam+pla_VddWidth+pla_GndWidth,
-			NOTRANS, NOROT, facet)) == NONODEINST) return(NONODEPROTO);
+			NOTRANS, NOROT, cell)) == NONODEINST) return(NONODEPROTO);
 	if (newarcinst(pla_da_proto, 3*pla_lam, FIXANG, md_contact, pla_md_proto->firstportproto,
 		(INTBIG)(13.5*pla_lam), (17+11+5)*pla_lam+pla_VddWidth, dpin2, pla_dp_proto->firstportproto,
-			(INTBIG)(13.5*pla_lam), (INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth, facet) == NOARCINST)
+			(INTBIG)(13.5*pla_lam), (INTBIG)((17+11-4.5)*pla_lam)+pla_VddWidth, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	/*
@@ -335,31 +335,31 @@ NODEPROTO *pla_nmos_Input(void)
 	 */
 	if ((md_contact1 = newnodeinst(pla_md_proto, 4*pla_lam, 8*pla_lam,
 		(17+11+4)*pla_lam+pla_VddWidth, (17+11+4)*pla_lam+pla_VddWidth+pla_GndWidth,
-			NOTRANS, NOROT, facet)) == NONODEINST) return(NONODEPROTO);
+			NOTRANS, NOROT, cell)) == NONODEINST) return(NONODEPROTO);
 
 	/* Connect the two md contacts together in metal */
 	if (newarcinst(pla_ma_proto, pla_GndWidth, FIXANG, md_contact, pla_md_proto->firstportproto,
 		14*pla_lam, (17+11+4)*pla_lam+pla_VddWidth+pla_halfGnd, md_contact1,
 			pla_md_proto->firstportproto, 6*pla_lam, (17+11+4)*pla_lam+pla_VddWidth+pla_halfGnd,
-				facet) == NOARCINST) return(NONODEPROTO);
+				cell) == NOARCINST) return(NONODEPROTO);
 
 	/* Export some of the pins and ports for external connections */
-	if (newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("Gnd")) == NOPORTPROTO ||
-		newportproto(facet, ppin1, pla_pp_proto->firstportproto, x_("InvInput")) == NOPORTPROTO ||
-		newportproto(facet, ppin2, pla_pp_proto->firstportproto, x_("NonInvInput")) == NOPORTPROTO ||
-		newportproto(facet, etran1, pla_FindPort(etran1, 10*pla_lam, pla_lam), x_("Input")) == NOPORTPROTO  ||
-		newportproto(facet, md_contact1,pla_md_proto->firstportproto, x_("DiffGnd")) == NOPORTPROTO)
+	if (newportproto(cell, md_contact, pla_md_proto->firstportproto, x_("Gnd")) == NOPORTPROTO ||
+		newportproto(cell, ppin1, pla_pp_proto->firstportproto, x_("InvInput")) == NOPORTPROTO ||
+		newportproto(cell, ppin2, pla_pp_proto->firstportproto, x_("NonInvInput")) == NOPORTPROTO ||
+		newportproto(cell, etran1, pla_FindPort(etran1, 10*pla_lam, pla_lam), x_("Input")) == NOPORTPROTO  ||
+		newportproto(cell, md_contact1,pla_md_proto->firstportproto, x_("DiffGnd")) == NOPORTPROTO)
 			return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
-	(*el_curconstraint->solve)(facet);
-	return(facet);
+	/* ensure that the cell is the proper size */
+	(*el_curconstraint->solve)(cell);
+	return(cell);
 }
 
 NODEPROTO *pla_nmos_OutPullup(void)
 {
 	NODEPROTO *pu;
-	INTBIG sizeX, sizeY;			/* Dimensions of the facet */
+	INTBIG sizeX, sizeY;			/* Dimensions of the cell */
 	NODEINST *dtran, *dpin, *bc;
 	PORTPROTO *dtran_dport, *dtran_pport, *bc_pport, *bc_dport;
 
@@ -428,17 +428,17 @@ NODEPROTO *pla_nmos_OutPullup(void)
 	if (newportproto(pu, bc, bc_pport, x_("Output2")) == NOPORTPROTO ||
 		newportproto(pu, bc, bc_dport, x_("DiffPt")) == NOPORTPROTO) return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
+	/* ensure that the cell is the proper size */
 	(*el_curconstraint->solve)(pu);
 	return(pu);
 }
 
 NODEPROTO *pla_nmos_Output(void)
 {
-	NODEPROTO *facet, *pu;
+	NODEPROTO *cell, *pu;
 	NODEINST  *pu1,  *pu2, *dpin1, *dpin2, *dpin, *etran1, *etran2,
 		*ppin1, *ppin2, *md_cont1, *md_cont2;
-	INTBIG sizeX,		/* Dimensions of the facet */
+	INTBIG sizeX,		/* Dimensions of the cell */
 		WorkPtY;		/* Y value of a point below which work is done */
 
 	/* define the pullup */
@@ -447,37 +447,37 @@ NODEPROTO *pla_nmos_Output(void)
 
 	sizeX = 15 * pla_lam;
 
-	facet = newnodeproto(nmosOutput, el_curlib);
-	if (facet == NONODEPROTO) return(NONODEPROTO);
+	cell = newnodeproto(nmosOutput, el_curlib);
+	if (cell == NONODEPROTO) return(NONODEPROTO);
 
-	/* Instance the OutPullup twice in facet */
+	/* Instance the OutPullup twice in cell */
 	pu1 = newnodeinst(pu, (INTBIG)(1.5*pla_lam), (INTBIG)(1.5*pla_lam+pu->highx-pu->lowx),
 		(INTBIG)((5+2-0.5)*pla_lam)+pla_VddWidth,
-			(INTBIG)((5+2-0.5)*pla_lam+pu->highy-pu->lowy)+pla_VddWidth, TRANS, 1800, facet);
-	pu2 = newnodeinst(pu, 5*pla_lam, sizeX, 0, pu->highy-pu->lowy, NOTRANS, NOROT, facet);
+			(INTBIG)((5+2-0.5)*pla_lam+pu->highy-pu->lowy)+pla_VddWidth, TRANS, 1800, cell);
+	pu2 = newnodeinst(pu, 5*pla_lam, sizeX, 0, pu->highy-pu->lowy, NOTRANS, NOROT, cell);
 	if (pu1 == NONODEINST || pu2 == NONODEINST) return(NONODEPROTO);
 
 	/*
-	 * Create two poly pins near the left most edge of the facet
+	 * Create two poly pins near the left most edge of the cell
 	 * and connect them together to make Output1.
 	 */
 	ppin1 = newnodeinst(pla_pp_proto, 0, 2*pla_lam, (7+3)*pla_lam+pla_VddWidth,
-		(7+5)*pla_lam+pla_VddWidth, NOTRANS, NOROT, facet);
-	ppin2 = newnodeinst(pla_pp_proto, 0, 2*pla_lam, 0, 2*pla_lam, NOTRANS, NOROT, facet);
+		(7+5)*pla_lam+pla_VddWidth, NOTRANS, NOROT, cell);
+	ppin2 = newnodeinst(pla_pp_proto, 0, 2*pla_lam, 0, 2*pla_lam, NOTRANS, NOROT, cell);
 	if (ppin1 == NONODEINST || ppin2 == NONODEINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin1, pla_pp_proto->firstportproto,
 		pla_lam, (7+4)*pla_lam+pla_VddWidth, ppin2, pla_pp_proto->firstportproto,
-			pla_lam, pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			pla_lam, pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	/* Connect ppin1 to pu1 on poly */
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin1, pla_pp_proto->firstportproto,
 		pla_lam, (7+4)*pla_lam+pla_VddWidth, pu1, pla_FindPort(pu1, 4*pla_lam, (7+4)*pla_lam+
-			pla_VddWidth), 4*pla_lam, (7+4)*pla_lam+pla_VddWidth, facet) == NOARCINST)
+			pla_VddWidth), 4*pla_lam, (7+4)*pla_lam+pla_VddWidth, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	/* Export ppin2 as Output1 Point */
-	if (newportproto(facet, ppin2, pla_pp_proto->firstportproto, x_("Output1")) == NOPORTPROTO)
+	if (newportproto(cell, ppin2, pla_pp_proto->firstportproto, x_("Output1")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	/*
@@ -486,69 +486,69 @@ NODEPROTO *pla_nmos_Output(void)
 	 * two pullups.
 	 */
 	md_cont1 = newnodeinst(pla_md_proto, 3*pla_lam, 7*pla_lam, 7*pla_lam, 7*pla_lam+pla_VddWidth,
-		NOTRANS, NOROT, facet);
+		NOTRANS, NOROT, cell);
 	if (md_cont1 == NONODEINST) return(NONODEPROTO);
 
 	/* Export this contact for external Vdd connection */
-	if (newportproto(facet, md_cont1, pla_md_proto->firstportproto, x_("Vdd")) == NOPORTPROTO)
+	if (newportproto(cell, md_cont1, pla_md_proto->firstportproto, x_("Vdd")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	/* Extend the Diff wires from the pullups to md_cont1 */
 	dpin1 = newnodeinst(pla_dp_proto, 3*pla_lam, 5*pla_lam, (7-1)*pla_lam+pla_VddWidth,
-		(7-1+2)*pla_lam+pla_VddWidth, NOTRANS, NOROT, facet);
+		(7-1+2)*pla_lam+pla_VddWidth, NOTRANS, NOROT, cell);
 	dpin2 = newnodeinst(pla_dp_proto, 3*pla_lam, 5*pla_lam,
-		5*pla_lam, 7*pla_lam, NOTRANS, NOROT, facet);
+		5*pla_lam, 7*pla_lam, NOTRANS, NOROT, cell);
 	if (dpin1 == NONODEINST || dpin2 == NONODEINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin1, pla_dp_proto->firstportproto,
 		4*pla_lam, 7*pla_lam+pla_VddWidth, pu1, pla_FindPort(pu1, 8*pla_lam, 7*pla_lam+pla_VddWidth),
-			8*pla_lam, 7*pla_lam+pla_VddWidth, facet) == NOARCINST)
+			8*pla_lam, 7*pla_lam+pla_VddWidth, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin2, pla_dp_proto->firstportproto,
 		4*pla_lam, 6*pla_lam, pu2, pla_FindPort(pu2, 6*pla_lam, 6*pla_lam),
-			6*pla_lam, 6*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			6*pla_lam, 6*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	/* Connect these dpins to the Vdd Contact (md_cont1) */
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin1, pla_dp_proto->firstportproto,
 		4*pla_lam, 7*pla_lam+pla_VddWidth, md_cont1, pla_md_proto->firstportproto,
-			4*pla_lam, 7*pla_lam+pla_halfVdd, facet) == NOARCINST)
+			4*pla_lam, 7*pla_lam+pla_halfVdd, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin2, pla_dp_proto->firstportproto,
 		4*pla_lam, 6*pla_lam, md_cont1, pla_md_proto->firstportproto,
-			4*pla_lam, 7*pla_lam+pla_halfVdd, facet) == NOARCINST)
+			4*pla_lam, 7*pla_lam+pla_halfVdd, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	/* Now instance two enhancement transistors to complete inverter layouts */
 	WorkPtY = 7 * pla_lam + pla_VddWidth + pu->highx - pu->lowx;
 
 	etran1 = newnodeinst(pla_etran_proto, 0, 12*pla_lam, WorkPtY+9*pla_lam,
-		WorkPtY+(9+6)*pla_lam, NOTRANS, 900, facet);
+		WorkPtY+(9+6)*pla_lam, NOTRANS, 900, cell);
 	etran2 = newnodeinst(pla_etran_proto, 5*pla_lam, 17*pla_lam, WorkPtY+(4-1)*pla_lam,
-		WorkPtY+(4+6-1)*pla_lam, NOTRANS, 900, facet);
+		WorkPtY+(4+6-1)*pla_lam, NOTRANS, 900, cell);
 	if (etran1 == NONODEINST || etran2 == NONODEINST) return(NONODEPROTO);
 
 	/* Connect these together on diffusion */
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, etran1,
 		pla_FindPort(etran1, 8*pla_lam,WorkPtY+9*pla_lam), 8*pla_lam, WorkPtY+9*pla_lam,
 			etran2, pla_FindPort(etran2, 9*pla_lam,WorkPtY+9*pla_lam),
-				9*pla_lam, WorkPtY+9*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+				9*pla_lam, WorkPtY+9*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	/*  Instance a diff pin on the left edge of etran1 so that etran1
 	 *  can be connected to the butting/buried contact of pu1.
 	 */
 	dpin1 = newnodeinst(pla_dp_proto, 2*pla_lam, 4*pla_lam,
-		WorkPtY+8*pla_lam, WorkPtY+10*pla_lam, NOTRANS, NOROT, facet);
+		WorkPtY+8*pla_lam, WorkPtY+10*pla_lam, NOTRANS, NOROT, cell);
 	if (dpin1 == NONODEINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin1, pla_dp_proto->firstportproto,
 		3*pla_lam, WorkPtY+9*pla_lam, etran1, pla_FindPort(etran1, 4*pla_lam,WorkPtY+9*pla_lam),
-			4*pla_lam, WorkPtY+9*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			4*pla_lam, WorkPtY+9*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin1, pla_dp_proto->firstportproto,
 		3*pla_lam, WorkPtY+9*pla_lam, pu1, pla_FindPort(pu1, 3*pla_lam, WorkPtY-2*pla_lam),
-			3*pla_lam, WorkPtY-2*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			3*pla_lam, WorkPtY-2*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	/*
 	 * Now we are going to connect etran2 to pu2 on diffusion.
@@ -556,18 +556,18 @@ NODEPROTO *pla_nmos_Output(void)
 	 * together.  Then connect dpin to pu2.
 	 */
 	dpin = newnodeinst(pla_dp_proto, sizeX-2*pla_lam, sizeX,
-		WorkPtY+8*pla_lam, WorkPtY+10*pla_lam, NOTRANS, NOROT, facet);
+		WorkPtY+8*pla_lam, WorkPtY+10*pla_lam, NOTRANS, NOROT, cell);
 	if (dpin == NONODEINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin, pla_dp_proto->firstportproto,
 		sizeX-pla_lam, WorkPtY+9*pla_lam, etran2,
 			pla_FindPort(etran2, sizeX-2*pla_lam, WorkPtY+9*pla_lam),
-				sizeX-2*pla_lam, WorkPtY+9*pla_lam, facet) == NOARCINST)
+				sizeX-2*pla_lam, WorkPtY+9*pla_lam, cell) == NOARCINST)
 					return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, dpin, pla_dp_proto->firstportproto,
 		sizeX-pla_lam, WorkPtY+9*pla_lam, pu2, pla_FindPort(pu2, sizeX-pla_lam, 6*pla_lam),
-			sizeX-pla_lam, 6*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			sizeX-pla_lam, 6*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	/*
 	 * It is time to make a Ground contact.  Instance a ground
@@ -577,17 +577,17 @@ NODEPROTO *pla_nmos_Output(void)
 	WorkPtY = WorkPtY + 12*pla_lam;
 
 	md_cont1 = newnodeinst(pla_md_proto, 8*pla_lam, 12*pla_lam, WorkPtY+2*pla_lam,
-		WorkPtY+2*pla_lam+pla_GndWidth, NOTRANS, NOROT, facet);
+		WorkPtY+2*pla_lam+pla_GndWidth, NOTRANS, NOROT, cell);
 	if (md_cont1 == NONODEINST) return(NONODEPROTO);
 
 	/*  Export this as the external Ground contact */
-	if (newportproto(facet, md_cont1, pla_md_proto->firstportproto, x_("Gnd")) == NOPORTPROTO)
+	if (newportproto(cell, md_cont1, pla_md_proto->firstportproto, x_("Gnd")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
 	/* Now connect etran1 to Ground contact */
 	if (newarcinst(pla_da_proto, 2*pla_lam, FIXANG, etran1,
 		pla_FindPort(etran1, 8*pla_lam, WorkPtY+3*pla_lam), 8*pla_lam, WorkPtY+3*pla_lam,
-			md_cont1, pla_md_proto->firstportproto, 9*pla_lam, WorkPtY+3*pla_lam, facet) == NOARCINST)
+			md_cont1, pla_md_proto->firstportproto, 9*pla_lam, WorkPtY+3*pla_lam, cell) == NOARCINST)
 				return(NONODEPROTO);
 
 	/*
@@ -595,19 +595,19 @@ NODEPROTO *pla_nmos_Output(void)
 	 * be available for the PLA
 	 */
 	ppin1 = newnodeinst(pla_pp_proto, 10*pla_lam, 12*pla_lam, WorkPtY-pla_lam, WorkPtY+pla_lam,
-		NOTRANS, NOROT, facet);
+		NOTRANS, NOROT, cell);
 	ppin2 = newnodeinst(pla_pp_proto, 13*pla_lam, 15*pla_lam, WorkPtY-pla_lam, WorkPtY+pla_lam,
-		NOTRANS, NOROT, facet);
+		NOTRANS, NOROT, cell);
 	if (ppin1 == NONODEINST || ppin2 == NONODEINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin1, pla_pp_proto->firstportproto,
 		11*pla_lam, WorkPtY, ppin2, pla_pp_proto->firstportproto, 14*pla_lam, WorkPtY,
-			facet) == NOARCINST) return(NONODEPROTO);
+			cell) == NOARCINST) return(NONODEPROTO);
 
 	/* Connect ppin1 to etran2 */
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin1, pla_pp_proto->firstportproto,
 		11*pla_lam, WorkPtY, etran2, pla_FindPort(etran2, 11*pla_lam, WorkPtY-pla_lam),
-			11*pla_lam, WorkPtY-pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			11*pla_lam, WorkPtY-pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	/*
 	 * Instance two metal-poly contacts to allow tapping signals
@@ -617,69 +617,69 @@ NODEPROTO *pla_nmos_Output(void)
 	WorkPtY = WorkPtY + 2 * pla_lam + pla_GndWidth;
 
 	md_cont1 = newnodeinst(pla_mp_proto, 3*pla_lam, 7*pla_lam, WorkPtY+4*pla_lam, WorkPtY+8*pla_lam,
-		NOTRANS, NOROT, facet);
+		NOTRANS, NOROT, cell);
 	md_cont2 = newnodeinst(pla_mp_proto, 11*pla_lam, 15*pla_lam, WorkPtY+4*pla_lam,
-		WorkPtY+8*pla_lam, NOTRANS, NOROT, facet);
+		WorkPtY+8*pla_lam, NOTRANS, NOROT, cell);
 	if (md_cont1 == NONODEINST || md_cont2 == NONODEINST) return(NONODEPROTO);
 
 	/* Export these for external connections */
-	if (newportproto(facet, md_cont1, pla_mp_proto->firstportproto, x_("Input1")) == NOPORTPROTO ||
-		newportproto(facet, md_cont2, pla_mp_proto->firstportproto, x_("Input2")) == NOPORTPROTO)
+	if (newportproto(cell, md_cont1, pla_mp_proto->firstportproto, x_("Input1")) == NOPORTPROTO ||
+		newportproto(cell, md_cont2, pla_mp_proto->firstportproto, x_("Input2")) == NOPORTPROTO)
 			return(NONODEPROTO);
 
 	/* Connect these to the etrans */
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, ppin2, pla_pp_proto->firstportproto,
 		14*pla_lam, WorkPtY-(pla_GndWidth+2*pla_lam), md_cont2, pla_mp_proto->firstportproto,
-			14*pla_lam, WorkPtY+5*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			14*pla_lam, WorkPtY+5*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_pa_proto, 2*pla_lam, FIXANG, etran1,
 		pla_FindPort(etran1,6*pla_lam,WorkPtY-pla_GndWidth+3*pla_lam), 6*pla_lam,
 			WorkPtY-pla_GndWidth+3*pla_lam, md_cont1, pla_mp_proto->firstportproto,
-				6*pla_lam, WorkPtY+5*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+				6*pla_lam, WorkPtY+5*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	/* Export the Output point of pu2 as Output2 */
-	if (newportproto(facet, pu2, pla_FindPort(pu2, 11*pla_lam, pla_lam), x_("Output2")) == NOPORTPROTO)
+	if (newportproto(cell, pu2, pla_FindPort(pu2, 11*pla_lam, pla_lam), x_("Output2")) == NOPORTPROTO)
 		return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
-	(*el_curconstraint->solve)(facet);
-	return(facet);
+	/* ensure that the cell is the proper size */
+	(*el_curconstraint->solve)(cell);
+	return(cell);
 }
 
 NODEPROTO *pla_nmos_Program(void)
 {
-	NODEPROTO *facet;
+	NODEPROTO *cell;
 	NODEINST *etran, *md_contact, *dpin;
 
-	facet = newnodeproto(nmosProgram, el_curlib);
-	if (facet == NONODEPROTO) return(NONODEPROTO);
+	cell = newnodeproto(nmosProgram, el_curlib);
+	if (cell == NONODEPROTO) return(NONODEPROTO);
 
 	if ((etran = newnodeinst(pla_etran_proto, 2*pla_lam, 10*pla_lam,
-		pla_lam, 7*pla_lam, NOTRANS, 900, facet)) == NONODEINST) return(NONODEPROTO);
+		pla_lam, 7*pla_lam, NOTRANS, 900, cell)) == NONODEINST) return(NONODEPROTO);
 
 	if ((md_contact = newnodeinst(pla_md_proto, 8*pla_lam, 12*pla_lam,
-		2*pla_lam, 6*pla_lam, NOTRANS, NOROT, facet)) == NONODEINST) return(NONODEPROTO);
+		2*pla_lam, 6*pla_lam, NOTRANS, NOROT, cell)) == NONODEINST) return(NONODEPROTO);
 
 	if ((dpin = newnodeinst(pla_dp_proto, 0, 4*pla_lam, 2*pla_lam, 6*pla_lam,
-		NOTRANS, NOROT, facet)) == NONODEINST) return(NONODEPROTO);
+		NOTRANS, NOROT, cell)) == NONODEINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 4*pla_lam, FIXANG, dpin, pla_dp_proto->firstportproto,
 		2*pla_lam, 4*pla_lam, etran, pla_FindPort(etran, 4*pla_lam, 4*pla_lam),
-			4*pla_lam, 4*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			4*pla_lam, 4*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
 	if (newarcinst(pla_da_proto, 4*pla_lam, FIXANG, etran, pla_FindPort(etran, 8*pla_lam, 4*pla_lam),
 		8*pla_lam, 4*pla_lam, md_contact, pla_md_proto->firstportproto,
-			10*pla_lam, 4*pla_lam, facet) == NOARCINST) return(NONODEPROTO);
+			10*pla_lam, 4*pla_lam, cell) == NOARCINST) return(NONODEPROTO);
 
-	if (newportproto(facet, dpin, pla_dp_proto->firstportproto, x_("DiffPt")) == NOPORTPROTO ||
-		newportproto(facet, etran, pla_FindPort(etran,6*pla_lam,7*pla_lam), x_("Up")) == NOPORTPROTO ||
-		newportproto(facet, etran, pla_FindPort(etran,6*pla_lam,pla_lam), x_("Down")) == NOPORTPROTO ||
-		newportproto(facet, md_contact, pla_md_proto->firstportproto, x_("MdPt")) == NOPORTPROTO)
+	if (newportproto(cell, dpin, pla_dp_proto->firstportproto, x_("DiffPt")) == NOPORTPROTO ||
+		newportproto(cell, etran, pla_FindPort(etran,6*pla_lam,7*pla_lam), x_("Up")) == NOPORTPROTO ||
+		newportproto(cell, etran, pla_FindPort(etran,6*pla_lam,pla_lam), x_("Down")) == NOPORTPROTO ||
+		newportproto(cell, md_contact, pla_md_proto->firstportproto, x_("MdPt")) == NOPORTPROTO)
 			return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
-	(*el_curconstraint->solve)(facet);
-	return(facet);
+	/* ensure that the cell is the proper size */
+	(*el_curconstraint->solve)(cell);
+	return(cell);
 }
 
 NODEPROTO *pla_nmos_Pullup(void)
@@ -765,7 +765,7 @@ NODEPROTO *pla_nmos_Pullup(void)
 	if (vpname == NOPORTPROTO || dpname == NOPORTPROTO)
 		return(NONODEPROTO);
 
-	/* ensure that the facet is the proper size */
+	/* ensure that the cell is the proper size */
 	(*el_curconstraint->solve)(pu);
 	return(pu);
 }
