@@ -100,7 +100,7 @@ NODEPROTO *pla_out_proto;		/* Output Prototype */
 NODEPROTO *pla_prog_proto;		/* Programming Transistor Prototype */
 NODEPROTO *pla_connect_proto;	/* Connect Prototype */
 
-NODEPROTO *pla_facet;			/* The PLA itself */
+NODEPROTO *pla_cell;			/* The PLA itself */
 
 NODEPROTO *pla_md_proto;		/* Metal-Diff contact */
 NODEPROTO *pla_mp_proto;		/* Metal-Poly contact */
@@ -122,7 +122,7 @@ INTBIG  pla_inputs, pla_outputs, pla_pterms;
 INTBIG  pla_VddWidth;			/* VDD width in use */
 INTBIG  pla_GndWidth;			/* Vdd and Gnd Widths in use */
 CHAR    pla_infile[100];		/* Name of the input file */
-CHAR    pla_name[32];			/* Name of the PLA facet */
+CHAR    pla_name[32];			/* Name of the PLA cell */
 
 /*   Miscellaneous global variables  */
 INTBIG    pla_halfVdd, pla_halfGnd;   /* To save repeated division by 2 */
@@ -131,10 +131,10 @@ VDDGND   *pla_atg;				/* And top Gnd points */
 VDDGND   *pla_arg;				/* And right Gnd points */
 VDDGND   *pla_otv;				/* Or top Vdd points */
 VDDGND   *pla_org;				/* Or right Gnd points */
-VDDGND   *pla_icg;				/* Input facet Gnd points */
-VDDGND   *pla_icv;				/* Input facet Vdd points */
-VDDGND   *pla_ocg;				/* Output facet Gnd points */
-VDDGND   *pla_ocv;				/* Output facet Vdd points */
+VDDGND   *pla_icg;				/* Input cell Gnd points */
+VDDGND   *pla_icv;				/* Input cell Vdd points */
+VDDGND   *pla_ocg;				/* Output cell Gnd points */
+VDDGND   *pla_ocv;				/* Output cell Vdd points */
 FILE     *pla_fin;				/* Pointer to the input file */
 
 /* prototypes for local routines */
