@@ -31,7 +31,7 @@
 
 /*
  * Module to generate PLA layouts.  Input in a truth table format
- * is read from a file.  The output is in the form of facet prototypes
+ * is read from a file.  The output is in the form of cell prototypes
  * defined in the current library.
  */
 
@@ -44,10 +44,10 @@
 
 /* prototypes for local routines */
 static PROGTRANS *pla_FindPColTrans(INTBIG, PROGTRANS*);
-static FACETIST  *pla_PlaceInputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-static FACETIST  *pla_PlaceOutputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-static FACETIST  *pla_PlacePullupsonAND(INTBIG, INTBIG, INTBIG, NODEPROTO*);
-static FACETIST  *pla_PlacePullupsonOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static CELLIST   *pla_PlaceInputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static CELLIST   *pla_PlaceOutputs(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static CELLIST   *pla_PlacePullupsonAND(INTBIG, INTBIG, INTBIG, NODEPROTO*);
+static CELLIST   *pla_PlacePullupsonOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*);
 static PROGTRANS *pla_Program(INTBIG, INTBIG, INTBIG, NODEPROTO*);
 static PROGTRANS *pla_ProgramAND(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static PROGTRANS *pla_ProgramOR(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
@@ -59,11 +59,11 @@ static BOOLEAN    pla_ProgramPLA(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG,
  */
 BOOLEAN pla_Make(void)
 {
-	INTBIG inX, inY,               /* Dimensions of Input facet */
-		  puX, puY,               /* Dimensions of Double Pullup facet */
-		  outX, outY,             /* Dimensions of Output facet */
+	INTBIG inX, inY,               /* Dimensions of Input cell */
+		  puX, puY,               /* Dimensions of Double Pullup cell */
+		  outX, outY,             /* Dimensions of Output cell */
 		  progX, progY,           /* Dimensions of Programming Transistor */
-		  connectX, connectY;     /* Dimensions of Connect facet */
+		  connectX, connectY;     /* Dimensions of Connect cell */
 	INTBIG pos;
 	CHAR keyword[32], *filename;
 	TECHNOLOGY *tech;
@@ -120,11 +120,11 @@ BOOLEAN pla_Make(void)
 		return(TRUE);
 	}
 
-	/* Create all the facet prototypes.  Facets are defined in planfacets.c */
+	/* Create all the cell prototypes.  Cells are defined in planfacets.c */
 	pla_pu_proto = pla_nmos_Pullup();
 	if (pla_pu_proto  == NONODEPROTO)
 	{
-		ttyputerr(_("Cannot create pullup facet"));
+		ttyputerr(_("Cannot create pullup cell"));
 		return(TRUE);
 	}
 	puX = pla_pu_proto->highx - pla_pu_proto->lowx;
@@ -133,7 +133,7 @@ BOOLEAN pla_Make(void)
 	pla_in_proto = pla_nmos_Input();
 	if (pla_in_proto == NONODEPROTO)
 	{
-		ttyputerr(_("Cannot create input facet"));
+		ttyputerr(_("Cannot create input cell"));
 		return(TRUE);
 	}
 	inX = pla_in_proto->highx - pla_in_proto->lowx;
@@ -142,7 +142,7 @@ BOOLEAN pla_Make(void)
 	pla_connect_proto = pla_nmos_Connect();
 	if (pla_connect_proto == NONODEPROTO)
 	{
-		ttyputerr(_("Cannot create connect facet"));
+		ttyputerr(_("Cannot create connect cell"));
 		return(TRUE);
 	}
 	connectX = pla_connect_proto->highx - pla_connect_proto->lowx;
@@ -151,7 +151,7 @@ BOOLEAN pla_Make(void)
 	pla_prog_proto = pla_nmos_Program();
 	if (pla_prog_proto== NONODEPROTO)
 	{
-		ttyputerr(_("Cannot create program facet"));
+		ttyputerr(_("Cannot create program cell"));
 		return(TRUE);
 	}
 	progX = pla_prog_proto->highx - pla_prog_proto->lowx;
@@ -160,7 +160,7 @@ BOOLEAN pla_Make(void)
 	pla_out_proto = pla_nmos_Output();
 	if (pla_out_proto == NONODEPROTO)
 	{
-		ttyputerr(_("Cannot create output facet"));
+		ttyputerr(_("Cannot create output cell"));
 		return(TRUE);
 	}
 	outX = pla_out_proto->highx - pla_out_proto->lowx;
@@ -168,7 +168,7 @@ BOOLEAN pla_Make(void)
 
 	if (pla_verbose)
 	{
-		ttyputmsg(M_("Facets have been defined with sizes given below:"));
+		ttyputmsg(M_("Cells have been defined with sizes given below:"));
 		ttyputmsg(M_("Pullup  = %sx%s"), latoa(puX, 0), latoa(puY, 0));
 		ttyputmsg(M_("Input   = %sx%s"), latoa(inX, 0), latoa(inY, 0));
 		ttyputmsg(M_("Output  = %sx%s"), latoa(outX, 0), latoa(outY, 0));
@@ -184,7 +184,7 @@ BOOLEAN pla_Make(void)
 	{
 		if (pla_ProcessFlags()) break;
 
-		pla_facet = NONODEPROTO;
+		pla_cell = NONODEPROTO;
 		pla_alv = pla_atg = pla_arg = pla_otv = NOVDDGND;
 		pla_org = pla_icg = pla_icv = pla_ocg = pla_ocv = NOVDDGND;
 
@@ -206,10 +206,10 @@ BOOLEAN pla_Make(void)
 		if (namesame(pla_name, DEFNAME) == 0)
 			(void)esnprintf(pla_name, 32, x_("PLA-%ld-%ld-%ld"), pla_inputs, pla_pterms, pla_outputs);
 
-		pla_facet = newnodeproto(pla_name, el_curlib);
-		if (pla_facet == NONODEPROTO)
+		pla_cell = newnodeproto(pla_name, el_curlib);
+		if (pla_cell == NONODEPROTO)
 		{
-			ttyputerr(_("Cannot create '%s' facet"), pla_name);
+			ttyputerr(_("Cannot create '%s' cell"), pla_name);
 			return(TRUE);
 		}
 
@@ -217,7 +217,7 @@ BOOLEAN pla_Make(void)
 		if (pla_verbose)
 			ttyputmsg(M_("Beginning to program the AND and OR planes."));
 		if (pla_ProgramPLA(inX, inY, puX, puY, outX, outY, connectX,
-			connectY, pla_facet))
+			connectY, pla_cell))
 				ttyputerr(_("PLA '%s' is incompletely defined"), pla_name);
 
 		while((pos = pla_GetKeyWord(keyword)) != ERRORRET)
@@ -227,7 +227,7 @@ BOOLEAN pla_Make(void)
 }
 
 /*
- * pla_FindPColTrans: Given a pterm, and the address of an input facet,
+ * pla_FindPColTrans: Given a pterm, and the address of an input cell,
  * it tries to find a point below the row indicated by the pterm,
  * which needs to be connected to the programming transistor to be
  * placed on the pterm row.
@@ -256,14 +256,14 @@ PROGTRANS *pla_FindPColTrans(INTBIG pterm, PROGTRANS *trans)
 }
 
 /*
- * Place the Input facets one for each input.  The left most
- * facet is placed at X = X length of pullup facets and
- * Y = 0.  Also we have to remember the addresses of the facets
+ * Place the Input cells one for each input.  The left most
+ * cell is placed at X = X length of pullup cells and
+ * Y = 0.  Also we have to remember the addresses of the cells
  * for later processing.
  */
-FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
+CELLIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 {
-	FACETIST *ptr, *prevptr, *firstptr;
+	CELLIST *ptr, *prevptr, *firstptr;
 	VDDGND *cicv, *picv, *cicg, *picg;
 	INTBIG i;
 	INTBIG llXpos, llYpos, VddYpos, GndYpos;
@@ -274,65 +274,65 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 	VddYpos = llYpos + 17*pla_lam + pla_halfVdd;
 	GndYpos = llYpos + inY - pla_halfGnd;
 
-	prevptr = NOFACETIST;
-	firstptr= NOFACETIST;
+	prevptr = NOCELLIST;
+	firstptr= NOCELLIST;
 	cicv = picv = cicg = picg = NOVDDGND;
 
-	if (pla_verbose) ttyputmsg(M_("Placing the input facets"));
+	if (pla_verbose) ttyputmsg(M_("Placing the input cells"));
 
 	for(i = 1; i <= pla_inputs; i++)
 	{
-		if (pla_verbose) ttyputmsg(M_("Placing input facet %ld"), i);
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST) return(NOFACETIST);
-		ptr->findex = i;    /* remember which input this facet corresponds to */
-		ptr->facetinst = newnodeinst(pla_in_proto, llXpos, llXpos+inX,
+		if (pla_verbose) ttyputmsg(M_("Placing input cell %ld"), i);
+		ptr = (CELLIST *)emalloc(sizeof(CELLIST), pla_tool->cluster);
+		if (ptr == NOCELLIST) return(NOCELLIST);
+		ptr->findex = i;    /* remember which input this cell corresponds to */
+		ptr->cellinst = newnodeinst(pla_in_proto, llXpos, llXpos+inX,
 			llYpos, llYpos+inY, NOTRANS, NOROT, pla);
-		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
+		if (ptr->cellinst == NONODEINST) return(NOCELLIST);
 
 		/* Record the Gnd and Vdd points for later connection */
-		cicg = pla_MkVddGnd(INFACETGND, &picg);
-		cicg->inst = ptr->facetinst;
-		cicg->port = pla_AssignPort(ptr->facetinst, llXpos+6*pla_lam, GndYpos);
-		if (cicg->port->port == NOPORTPROTO) return(NOFACETIST);
+		cicg = pla_MkVddGnd(INCELLGND, &picg);
+		cicg->inst = ptr->cellinst;
+		cicg->port = pla_AssignPort(ptr->cellinst, llXpos+6*pla_lam, GndYpos);
+		if (cicg->port->port == NOPORTPROTO) return(NOCELLIST);
 
-		cicv = pla_MkVddGnd(INFACETVDD, &picv);
-		cicv->inst = ptr->facetinst;
-		cicv->port = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, VddYpos);
-		if (cicv->port->port == NOPORTPROTO) return(NOFACETIST);
+		cicv = pla_MkVddGnd(INCELLVDD, &picv);
+		cicv->inst = ptr->cellinst;
+		cicv->port = pla_AssignPort(ptr->cellinst, llXpos+5*pla_lam, VddYpos);
+		if (cicv->port->port == NOPORTPROTO) return(NOCELLIST);
 
 		/* Find the ports that connect into the PLA */
-		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+2*pla_lam, llYpos+inY-pla_lam);
-		ptr->rport = pla_AssignPort(ptr->facetinst, llXpos+10*pla_lam, llYpos+inY-pla_lam);
-		ptr->gport = pla_AssignPort(ptr->facetinst, llXpos+6*pla_lam, GndYpos);
+		ptr->lport = pla_AssignPort(ptr->cellinst, llXpos+2*pla_lam, llYpos+inY-pla_lam);
+		ptr->rport = pla_AssignPort(ptr->cellinst, llXpos+10*pla_lam, llYpos+inY-pla_lam);
+		ptr->gport = pla_AssignPort(ptr->cellinst, llXpos+6*pla_lam, GndYpos);
 
 		if (ptr->lport->port == NOPORTPROTO ||
 			ptr->rport->port == NOPORTPROTO || ptr->gport->port == NOPORTPROTO)
-				return(NOFACETIST);
+				return(NOCELLIST);
 
 		/* Initialize the progtrans ends */
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
 		/* Export the input point giving it a name */
 		(void)esnprintf(portname, 16, x_("Input%ld"), i);
-		if (newportproto(pla, ptr->facetinst, pla_FindPort(ptr->facetinst,llXpos+10*pla_lam,
-			llYpos+pla_lam), portname) == NOPORTPROTO) return(NOFACETIST);
+		if (newportproto(pla, ptr->cellinst, pla_FindPort(ptr->cellinst,llXpos+10*pla_lam,
+			llYpos+pla_lam), portname) == NOPORTPROTO) return(NOCELLIST);
 
-		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
+		if (prevptr != NOCELLIST) prevptr->nextcell = ptr;
 		prevptr = ptr;
 
-		if (firstptr == NOFACETIST) firstptr = ptr;
+		if (firstptr == NOCELLIST) firstptr = ptr;
 
 		llXpos = llXpos + inX;
 	}
-	if (ptr != NOFACETIST) ptr->nextfacet = NOFACETIST;
+	if (ptr != NOCELLIST) ptr->nextcell = NOCELLIST;
 
 	return(firstptr);
 }
 
-FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *pla)
+CELLIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *pla)
 {
-	FACETIST *ptr, *prevptr, *firstptr;
+	CELLIST *ptr, *prevptr, *firstptr;
 	VDDGND *cocv, *pocv, *cocg, *pocg;
 	INTBIG o;
 	INTBIG llXpos, llYpos, VddYpos, GndYpos;
@@ -343,73 +343,73 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 	VddYpos = llYpos + 7 * pla_lam + pla_halfVdd;
 	GndYpos = llYpos + outY - (8 * pla_lam + pla_halfGnd);
 
-	prevptr = firstptr = NOFACETIST;
+	prevptr = firstptr = NOCELLIST;
 	cocv = pocv = cocg = pocg = NOVDDGND;
 
-	if (pla_verbose) ttyputmsg(M_("Placing the output facets"));
+	if (pla_verbose) ttyputmsg(M_("Placing the output cells"));
 
 	for(o = 1; o <= (pla_outputs+pla_outputs%2)/2; o++)
 	{
-		if (pla_verbose) ttyputmsg(M_("Placing output facet %ld"), o);
+		if (pla_verbose) ttyputmsg(M_("Placing output cell %ld"), o);
 
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST) return(NOFACETIST);
+		ptr = (CELLIST *)emalloc(sizeof(CELLIST), pla_tool->cluster);
+		if (ptr == NOCELLIST) return(NOCELLIST);
 		ptr->findex = o;
-		ptr->facetinst = newnodeinst(pla_out_proto, llXpos, llXpos+outX,
+		ptr->cellinst = newnodeinst(pla_out_proto, llXpos, llXpos+outX,
 			llYpos, llYpos+outY, NOTRANS, NOROT, pla);
-		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
+		if (ptr->cellinst == NONODEINST) return(NOCELLIST);
 
 		/*
-		 * Connect the facets together in metal on the Gnd line if more than
-		 * one facet is placed
+		 * Connect the cells together in metal on the Gnd line if more than
+		 * one cell is placed
 		 */
 		/* Remember the Gnd and Vdd points for later connection */
-		cocg = pla_MkVddGnd(OUTFACETGND, &pocg);
-		cocg->inst = ptr->facetinst;
-		cocg->port = pla_AssignPort(ptr->facetinst, llXpos+outX-5*pla_lam, GndYpos);
-		if (cocg->port->port == NOPORTPROTO) return(NOFACETIST);
+		cocg = pla_MkVddGnd(OUTCELLGND, &pocg);
+		cocg->inst = ptr->cellinst;
+		cocg->port = pla_AssignPort(ptr->cellinst, llXpos+outX-5*pla_lam, GndYpos);
+		if (cocg->port->port == NOPORTPROTO) return(NOCELLIST);
 
-		cocv = pla_MkVddGnd(OUTFACETVDD, &pocv);
-		cocv->inst = ptr->facetinst;
-		cocv->port = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, VddYpos);
-		if (cocv->port->port == NOPORTPROTO) return(NOFACETIST);
+		cocv = pla_MkVddGnd(OUTCELLVDD, &pocv);
+		cocv->inst = ptr->cellinst;
+		cocv->port = pla_AssignPort(ptr->cellinst, llXpos+5*pla_lam, VddYpos);
+		if (cocv->port->port == NOPORTPROTO) return(NOCELLIST);
 
 		/* Find the ports that connect into the PLA */
-		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, llYpos+outY-2*pla_lam);
-		ptr->rport = pla_AssignPort(ptr->facetinst, llXpos+outX-2*pla_lam, llYpos+outY-2*pla_lam);
+		ptr->lport = pla_AssignPort(ptr->cellinst, llXpos+5*pla_lam, llYpos+outY-2*pla_lam);
+		ptr->rport = pla_AssignPort(ptr->cellinst, llXpos+outX-2*pla_lam, llYpos+outY-2*pla_lam);
 		ptr->gport = NOPORT;
 
 		if (ptr->lport->port == NOPORTPROTO || ptr->rport->port == NOPORTPROTO)
-			return(NOFACETIST);
+			return(NOCELLIST);
 
 		/* Initialize the progtrans ends */
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
 		/* Export the output ports */
 		(void)esnprintf(portname, 16, x_("Output%ld"), 2*o-1);
-		if (newportproto(pla, ptr->facetinst,
-			pla_FindPort(ptr->facetinst,llXpos+pla_lam,llYpos+pla_lam), portname) == NOPORTPROTO)
-				return(NOFACETIST);
+		if (newportproto(pla, ptr->cellinst,
+			pla_FindPort(ptr->cellinst,llXpos+pla_lam,llYpos+pla_lam), portname) == NOPORTPROTO)
+				return(NOCELLIST);
 		(void)esnprintf(portname, 16, x_("Output%ld"), 2*o);
-		if (newportproto(pla, ptr->facetinst,
-			pla_FindPort(ptr->facetinst,llXpos+11*pla_lam, llYpos+pla_lam), portname) == NOPORTPROTO)
-				return(NOFACETIST);
+		if (newportproto(pla, ptr->cellinst,
+			pla_FindPort(ptr->cellinst,llXpos+11*pla_lam, llYpos+pla_lam), portname) == NOPORTPROTO)
+				return(NOCELLIST);
 
-		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
+		if (prevptr != NOCELLIST) prevptr->nextcell = ptr;
 		prevptr = ptr;
 
-		if (firstptr == NOFACETIST) firstptr = ptr;
+		if (firstptr == NOCELLIST) firstptr = ptr;
 
 		llXpos = llXpos + outX + pla_lam;
 	}
-	if (ptr != NOFACETIST) ptr->nextfacet = NOFACETIST;
+	if (ptr != NOCELLIST) ptr->nextcell = NOCELLIST;
 
 	return(firstptr);
 }
 
-FACETIST *pla_PlacePullupsonAND(INTBIG puX, INTBIG puY, INTBIG inY, NODEPROTO *pla)
+CELLIST *pla_PlacePullupsonAND(INTBIG puX, INTBIG puY, INTBIG inY, NODEPROTO *pla)
 {
-	FACETIST *ptr, *prevptr, *firstptr;
+	CELLIST *ptr, *prevptr, *firstptr;
 	VDDGND *calv, *palv;
 	INTBIG llXpos, llYpos;
 	INTBIG p;
@@ -417,54 +417,54 @@ FACETIST *pla_PlacePullupsonAND(INTBIG puX, INTBIG puY, INTBIG inY, NODEPROTO *p
 	llXpos = 0;
 	llYpos = inY + 2*pla_lam - (pla_VddWidth - 4*pla_lam);
 
-	prevptr = NOFACETIST;
-	firstptr= NOFACETIST;
+	prevptr = NOCELLIST;
+	firstptr= NOCELLIST;
 	calv = palv = NOVDDGND;
 
 	if (pla_verbose)
-		ttyputmsg(M_("Placing the pullup facets on the left edge of the AND-plane"));
+		ttyputmsg(M_("Placing the pullup cells on the left edge of the AND-plane"));
 
 	for(p = 1; p <= pla_pterms; p++)
 	{
 		if (pla_verbose)
-			ttyputmsg(M_("Placing pullup facet %ld in AND-plane"), p);
+			ttyputmsg(M_("Placing pullup cell %ld in AND-plane"), p);
 
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST) return(NOFACETIST);
+		ptr = (CELLIST *)emalloc(sizeof(CELLIST), pla_tool->cluster);
+		if (ptr == NOCELLIST) return(NOCELLIST);
 		ptr->findex = p;
-		ptr->facetinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
+		ptr->cellinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
 			llYpos, llYpos+puY, NOTRANS, NOROT, pla);
-		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
+		if (ptr->cellinst == NONODEINST) return(NOCELLIST);
 
 		/* Remember the Vdd points for later connection */
 		calv = pla_MkVddGnd(ANDLEFTVDD, &palv);
-		calv->inst = ptr->facetinst;
-		calv->port = pla_AssignPort(ptr->facetinst, pla_halfVdd, llYpos+4*pla_lam);
-		if (calv->port->port == NOPORTPROTO) return(NOFACETIST);
+		calv->inst = ptr->cellinst;
+		calv->port = pla_AssignPort(ptr->cellinst, pla_halfVdd, llYpos+4*pla_lam);
+		if (calv->port->port == NOPORTPROTO) return(NOCELLIST);
 
 		/* Mark the diffusion end of the pu for connections across the plane */
-		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+puX-2*pla_lam,llYpos+3*pla_lam);
-		if (ptr->lport->port == NOPORTPROTO) return(NOFACETIST);
+		ptr->lport = pla_AssignPort(ptr->cellinst, llXpos+puX-2*pla_lam,llYpos+3*pla_lam);
+		if (ptr->lport->port == NOPORTPROTO) return(NOCELLIST);
 
 		ptr->rport = NOPORT;
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
-		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
+		if (prevptr != NOCELLIST) prevptr->nextcell = ptr;
 		prevptr = ptr;
 
-		if (firstptr == NOFACETIST) firstptr = ptr;
+		if (firstptr == NOCELLIST) firstptr = ptr;
 
 		llYpos = llYpos + puY;
 	}
-	if (ptr != NOFACETIST) ptr->nextfacet = NOFACETIST;
+	if (ptr != NOCELLIST) ptr->nextcell = NOCELLIST;
 
 	return(firstptr);
 }
 
-FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG puX,
+CELLIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG puX,
 	INTBIG puY, NODEPROTO *pla)
 {
-	FACETIST *ptr, *prevptr, *firstptr;
+	CELLIST *ptr, *prevptr, *firstptr;
 	VDDGND *cotv, *potv;
 	INTBIG llXpos, llYpos, VddYpos, cX, cY, bc_portY;
 	INTBIG i;
@@ -478,7 +478,7 @@ FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG pu
 	VddYpos = cY + puX/2 - pla_halfVdd;
 	bc_portY = cY - puX/2 + 2*pla_lam;
 
-	prevptr = firstptr = NOFACETIST;
+	prevptr = firstptr = NOCELLIST;
 	cotv = potv = NOVDDGND;
 
 	if (pla_verbose)
@@ -488,36 +488,36 @@ FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG pu
 	for(i = 1; i <= pla_outputs; i++)
 	{
 		if (pla_verbose)
-			ttyputmsg(M_("Placing pullup facet %ld in OR-plane"), i);
+			ttyputmsg(M_("Placing pullup cell %ld in OR-plane"), i);
 
-		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_tool->cluster);
-		if (ptr == NOFACETIST) return(NOFACETIST);
+		ptr = (CELLIST *)emalloc(sizeof(CELLIST), pla_tool->cluster);
+		if (ptr == NOCELLIST) return(NOCELLIST);
 		ptr->findex = i;
-		ptr->facetinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
+		ptr->cellinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
 			llYpos, llYpos+puY, NOTRANS, 2700, pla);
-		if (ptr->facetinst == NONODEINST) return(NOFACETIST);
+		if (ptr->cellinst == NONODEINST) return(NOCELLIST);
 
 		/* Remember the Vdd points for later connection */
 		cotv = pla_MkVddGnd(ORTOPVDD, &potv);
-		cotv->inst = ptr->facetinst;
-		cotv->port = pla_AssignPort(ptr->facetinst, llXpos+puX/2, VddYpos);
-		if (cotv->port->port == NOPORTPROTO) return(NOFACETIST);
+		cotv->inst = ptr->cellinst;
+		cotv->port = pla_AssignPort(ptr->cellinst, llXpos+puX/2, VddYpos);
+		if (cotv->port->port == NOPORTPROTO) return(NOCELLIST);
 
 		/* Mark the diffusion end of the pu for connections across the plane */
-		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+puX/2-pla_lam, bc_portY);
-		if (ptr->lport->port == NOPORTPROTO) return(NOFACETIST);
+		ptr->lport = pla_AssignPort(ptr->cellinst, llXpos+puX/2-pla_lam, bc_portY);
+		if (ptr->lport->port == NOPORTPROTO) return(NOCELLIST);
 
 		ptr->rport = NOPORT;
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
 
-		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
+		if (prevptr != NOCELLIST) prevptr->nextcell = ptr;
 		prevptr = ptr;
 
-		if (firstptr == NOFACETIST) firstptr = ptr;
+		if (firstptr == NOCELLIST) firstptr = ptr;
 
 		llXpos = llXpos + puY;
 	}
-	if (ptr != NOFACETIST) ptr->nextfacet = NOFACETIST;
+	if (ptr != NOCELLIST) ptr->nextcell = NOCELLIST;
 
 	return(firstptr);
 }
@@ -616,7 +616,7 @@ PROGTRANS *pla_ProgramAND(INTBIG in, INTBIG arm, INTBIG pterm, INTBIG puX, INTBI
 {
 	INTBIG llXpos, llYpos;  /* Lower Left X,Y position of the point
 						   where an instance of the programming
-						   facet is to be placed */
+						   cell is to be placed */
 
 	/*
 	 * NOTE:  We are not taking care of situations where if there are
@@ -625,16 +625,16 @@ PROGTRANS *pla_ProgramAND(INTBIG in, INTBIG arm, INTBIG pterm, INTBIG puX, INTBI
 	 */
 	inY = inY - (pla_VddWidth - 4*pla_lam); /* Compensate for Extra Vdd Width */
 	llYpos = inY + (pterm-1) * puY + pla_lam; /* 1 pla_lam from top edge of
-											   Input facet */
+											   Input cell */
 	if (arm == TRUE)
 	{
 		llXpos = puX+(in-1)*inX+4*pla_lam;
-		return(pla_Program(llXpos, llYpos, RIGHT, pla_facet));
+		return(pla_Program(llXpos, llYpos, RIGHT, pla_cell));
 	}
 
 	/* FALSE: */
 	llXpos = puX+(in-1)*inX-4*pla_lam;
-	return(pla_Program(llXpos, llYpos, LEFT, pla_facet));
+	return(pla_Program(llXpos, llYpos, LEFT, pla_cell));
 }
 
 PROGTRANS *pla_ProgramOR(INTBIG out, INTBIG row, INTBIG orLeft, INTBIG puY, INTBIG inY)
@@ -654,24 +654,24 @@ PROGTRANS *pla_ProgramOR(INTBIG out, INTBIG row, INTBIG orLeft, INTBIG puY, INTB
 	if (pla_pterms % 2)		/* Odd number of pterms */
 	{
 		if (row % 2)		/*  Odd pterm */
-			return(pla_Program(llXpos, llYpos, UP, pla_facet));
+			return(pla_Program(llXpos, llYpos, UP, pla_cell));
 		else				/*  Even pterm */
-			return(pla_Program(llXpos, llYpos, DOWN, pla_facet));
+			return(pla_Program(llXpos, llYpos, DOWN, pla_cell));
 	} else
 	{
 		if (row % 2)		/*  Odd pterm */
-			return(pla_Program(llXpos, llYpos, DOWN, pla_facet));
+			return(pla_Program(llXpos, llYpos, DOWN, pla_cell));
 		else				/* Even pterm */
-			return(pla_Program(llXpos, llYpos, UP, pla_facet));
+			return(pla_Program(llXpos, llYpos, UP, pla_cell));
 	}
 }
 
 /*
- * Now it is time to program the PLA by instancing the various facets
+ * Now it is time to program the PLA by instancing the various cells
  * we have created.  The origin of the structure is set to the Lower
- * Left (LL) corner in line with the bottom of the Input facets and the
- * Pullup facets on the AND plane.  This means that the LL corner of
- * Output facets will be on the negative  side of Y axis.
+ * Left (LL) corner in line with the bottom of the Input cells and the
+ * Pullup cells on the AND plane.  This means that the LL corner of
+ * Output cells will be on the negative  side of Y axis.
  */
 BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG outX, INTBIG outY,
 	INTBIG connectX, INTBIG connectY, NODEPROTO *pla)
@@ -684,10 +684,10 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 		CurRow, CurCol;		/* Current Row and Column positions */
 	CHAR keyword[16];		/* Input holder */
 	NODEINST *connect;		/* Metal-Poly Contact */
-	FACETIST *PullupAND,	/* List of Pullups on AND plane */
+	CELLIST *PullupAND,		/* List of Pullups on AND plane */
 		*PullupOR,			/* List of Pullups on OR plane */
-		*Inputs,			/* List of Input facets */
-		*Outputs,			/* List of Output facets */
+		*Inputs,			/* List of Input cells */
+		*Outputs,			/* List of Output cells */
 		*inptr,				/* To keep track of current column in AND */
 		*ptermptr,			/* To keep track of current row */
 		*outptr;			/* To keep track of current column in OR */
@@ -697,8 +697,8 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 
 	/*
 	 * Let us first figure out the dimensions of the planes.
-	 * The Input facets can be placed side by side without any gaps
-	 * between them.  The required gap has been wired in to the facet itself.
+	 * The Input cells can be placed side by side without any gaps
+	 * between them.  The required gap has been wired in to the cell itself.
 	 * Hence, andX = inX * number of inputs.  Similarly,
 	 * andY = orY = puY * number of pterms, orX = outX * number of outputs.
 	 */
@@ -716,15 +716,15 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 		ttyputmsg(M_("orLeft = %s, orRight = %s"), latoa(orLeft, 0), latoa(orRight, 0));
 	}
 
-	/* Place all the input, output and pullup facets */
+	/* Place all the input, output and pullup cells */
 	PullupAND = pla_PlacePullupsonAND(puX, puY, inY, pla);
-	if (PullupAND == NOFACETIST) return(TRUE);
+	if (PullupAND == NOCELLIST) return(TRUE);
 	PullupOR  = pla_PlacePullupsonOR(andY, orLeft, inY, puX, puY, pla);
-	if (PullupOR == NOFACETIST) return(TRUE);
+	if (PullupOR == NOCELLIST) return(TRUE);
 	Inputs    = pla_PlaceInputs(puX, inX, inY, pla);
-	if (Inputs == NOFACETIST) return(TRUE);
+	if (Inputs == NOCELLIST) return(TRUE);
 	Outputs   = pla_PlaceOutputs(orLeft, outX, outY, pla);
-	if (Outputs == NOFACETIST) return(TRUE);
+	if (Outputs == NOCELLIST) return(TRUE);
 
 	/* Initialize all the pointers */
 	ptermptr = PullupAND;
@@ -735,7 +735,7 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 	/* Place the programming transistors */
 	for(p = 1; p <= pla_pterms; p++)
 	{
-		if (ptermptr == NOFACETIST) return(TRUE);
+		if (ptermptr == NOCELLIST) return(TRUE);
 
 		if (pla_verbose) ttyputmsg(M_("Programming row %ld."), p);
 
@@ -745,7 +745,7 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 		/* Program the AND plane */
 		for(i = 1; i <= pla_inputs; i++)
 		{
-			if (inptr == NOFACETIST) return(TRUE);
+			if (inptr == NOCELLIST) return(TRUE);
 
 			CurCol = inptr->findex;
 			if (CurCol != i) return(TRUE);
@@ -787,7 +787,7 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 			{
 				if (pla_verbose)
 					ttyputmsg(M_("row=%ld, ANDcolumn=%ld not programmed."), CurRow, CurCol);
-				inptr = inptr->nextfacet;
+				inptr = inptr->nextcell;
 				continue;
 			}
 
@@ -819,12 +819,12 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 					break;
 			}
 			if (PColTrans != NOPROGTRANS) PColTrans->uprogtrans = CurTrans;
-			inptr = inptr->nextfacet;
+			inptr = inptr->nextcell;
 		}
 
 		/*
 		 * Before we program the OR plane, it is necessary to place the
-		 * facets connecting it to the AND plane and the Ground line.
+		 * cells connecting it to the AND plane and the Ground line.
 		 *
 		 *  PRowTrans points to the last transistor placed on this row.
 		 */
@@ -836,7 +836,7 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 		if (connect == NONODEINST) return(TRUE);
 
 		/*
-		 * Instance a progtrans structure and place the connect facet in it
+		 * Instance a progtrans structure and place the connect cell in it
 		 * so that the connections can be made more uniformly
 		 */
 		CurTrans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_tool->cluster);
@@ -846,7 +846,7 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 			return(TRUE);
 		} else if (CurTrans == NOPROGTRANS) return(TRUE);
 
-		/* Fill in the details for this connect facet */
+		/* Fill in the details for this connect cell */
 		CurTrans->row = CurRow;
 		CurTrans->column = -1;	/* Undefined */
 		CurTrans->trans = connect;
@@ -887,10 +887,10 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 
 		for(o = 1; o <= (pla_outputs+pla_outputs%2)/2; o++)
 		{
-			if (outptr == NOFACETIST) return(TRUE);
+			if (outptr == NOCELLIST) return(TRUE);
 
 			/*
-			 * Each output facet corresponds to two vertical columns of output.
+			 * Each output cell corresponds to two vertical columns of output.
 			 *  So run in a loop twice.
 			 */
 			if (o != outptr->findex) return(TRUE);
@@ -955,19 +955,19 @@ BOOLEAN pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG ou
 						PColTrans->uprogtrans = CurTrans;
 				}
 			}
-			outptr = outptr->nextfacet;
+			outptr = outptr->nextcell;
 		}
 
 		/* Before we switch to a new row, let us reassign the pointers */
 		inptr = Inputs;
 		outptr = Outputs;
-		ptermptr = ptermptr->nextfacet;
+		ptermptr = ptermptr->nextcell;
 		PRowTrans = NOPROGTRANS;
 	}
 
 	/*
 	 * Let us now draw poly, diff and metal arcs to interconnect the
-	 * programming trasistors, pullup, input and output facets.
+	 * programming trasistors, pullup, input and output cells.
 	 */
 	pla_ConnectPlanes(inY, andY, orRight, Inputs, Outputs, PullupAND, PullupOR, pla);
 
