@@ -31,7 +31,7 @@
 
 /*
  * Module to generate PLA layouts.  Input in a truth table format
- * is read from a file.  The output is in the form of facet prototypes
+ * is read from a file.  The output is in the form of cell prototypes
  * defined in the current library.
  */
 
@@ -43,13 +43,13 @@
 #include "planmos.h"
 
 /* prototypes for local routines */
-static void    pla_CHfromPuAND(INTBIG, FACETIST*, NODEPROTO*);
-static void    pla_CVfromInput(INTBIG, INTBIG, FACETIST*, NODEPROTO*);
-static void    pla_CVfromOutput(FACETIST*, FACETIST*, NODEPROTO*);
-static BOOLEAN pla_ConnectFirstFacet(INTBIG, FACETIST*, NODEPROTO*);
+static void    pla_CHfromPuAND(INTBIG, CELLIST*, NODEPROTO*);
+static void    pla_CVfromInput(INTBIG, INTBIG, CELLIST*, NODEPROTO*);
+static void    pla_CVfromOutput(CELLIST*, CELLIST*, NODEPROTO*);
+static BOOLEAN pla_ConnectFirstCell(INTBIG, CELLIST*, NODEPROTO*);
 static void    pla_ConnectOnMetal(INTBIG, VDDGND*, CHAR*, NODEPROTO*);
-static void    pla_ConnectThruFacets(INTBIG, VDDGND*, CHAR*, NODEPROTO*);
-static void    pla_DrawArcs(INTBIG, PROGTRANS*, FACETIST*, INTBIG, NODEPROTO*);
+static void    pla_ConnectThruCells(INTBIG, VDDGND*, CHAR*, NODEPROTO*);
+static void    pla_DrawArcs(INTBIG, PROGTRANS*, CELLIST*, INTBIG, NODEPROTO*);
 static void    pla_InstTurnPin(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, VDDGND*, VDDGND*, CHAR*, NODEPROTO*);
 
 /* pla_AssignPort:  Find the proper port and note down its coordinates. */
@@ -75,43 +75,43 @@ PORT *pla_AssignPort(NODEINST *inst, INTBIG x, INTBIG y)
  * Connect the programming transistors Horizontally from the Pullups
  * on the AND plane.
  */
-void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
+void pla_CHfromPuAND(INTBIG orRight, CELLIST *PullupAND, NODEPROTO *pla)
 {
 	PROGTRANS *connect, *ftrans, *ttrans, cgnd;
-	FACETIST connectfacet, *currow, *prevrow;
+	CELLIST connectcell, *currow, *prevrow;
 	VDDGND *carg, *parg, *corg, *porg;
 	PORT *fport, *tport;
 	INTBIG gndY;
 
-	prevrow = NOFACETIST;
+	prevrow = NOCELLIST;
 	carg = parg = corg = porg = NOVDDGND;
 
-	for(currow = PullupAND; currow != NOFACETIST; currow = currow->nextfacet)
+	for(currow = PullupAND; currow != NOCELLIST; currow = currow->nextcell)
 	{
 		if (pla_verbose)
 			ttyputmsg(M_("connecting right from pullup# %ld"), currow->findex);
 
-		if (pla_ConnectFirstFacet(PULLUPSIDE, currow, pla))
+		if (pla_ConnectFirstCell(PULLUPSIDE, currow, pla))
 			ttyputerr(M_("CHfromPuAND: cannot connect to first trans"));
 
 		/* Find the end instance on the AND plane */
 		connect = currow->lcoltrans;
 		while(connect->trans->proto->primindex != 0 ||
-			namesame(connect->trans->proto->cell->cellname, nmosConnect) != 0)
+			namesame(connect->trans->proto->protoname, nmosConnect) != 0)
 				connect = connect->rprogtrans;
 		if (connect == NOPROGTRANS)
-			ttyputerr(M_("CHfromPuAND: cannot find connect facet"));
+			ttyputerr(M_("CHfromPuAND: cannot find connect cell"));
 				else pla_DrawArcs(PULLUPSIDE, connect, currow, METAL, pla);
 
 		carg = pla_MkVddGnd(ANDRIGHTGND, &parg);
 		carg->inst = connect->trans;
 		carg->port = connect->diffport;
 
-		/* Make the connect transistor look like a FACETIST structure,
+		/* Make the connect transistor look like a CELLIST structure,
 		 * because that is what pla_DrawArcs expects.
 		 */
-		connectfacet.findex = currow->findex;
-		connectfacet.lcoltrans = connect;
+		connectcell.findex = currow->findex;
+		connectcell.lcoltrans = connect;
 
 		/* Connect on ground only if there are odd number of pterms and this
 		 * is an odd row OR there are even number of pterms and this is an
@@ -134,19 +134,19 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 			corg->inst = cgnd.trans;
 			corg->port = cgnd.diffport;
 
-			pla_DrawArcs(PULLUPSIDE, &cgnd, &connectfacet, POLY, pla);
+			pla_DrawArcs(PULLUPSIDE, &cgnd, &connectcell, POLY, pla);
 
 			/* Now connect the transistors on the prev row on diffusion */
 			ftrans = connect;
 			fport  = ftrans->diffport;
-			if (prevrow != NOFACETIST)
+			if (prevrow != NOCELLIST)
 			{
 				connect = prevrow->lcoltrans;
 				while(connect->trans->proto->primindex != 0 ||
-					namesame(connect->trans->proto->cell->cellname, nmosConnect) != 0)
+					namesame(connect->trans->proto->protoname, nmosConnect) != 0)
 						connect = connect->rprogtrans;
 				if (connect == NOPROGTRANS)
-					ttyputerr(M_("Cannot find connect facet on prev row"));
+					ttyputerr(M_("Cannot find connect cell on prev row"));
 				if (connect != NOPROGTRANS)
 					for(ttrans = connect->rprogtrans; ttrans != NOPROGTRANS; ttrans = ttrans->rprogtrans)
 				{
@@ -164,24 +164,24 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 						cgnd.trans, tport->port, tport->x, tport->y, pla) == NOARCINST)
 							ttyputerr(M_("cannot connect to gnd for prev row transistors"));
 			}
-		} else pla_DrawArcs(PULLUPSIDE, &cgnd, &connectfacet, POLY, pla);
+		} else pla_DrawArcs(PULLUPSIDE, &cgnd, &connectcell, POLY, pla);
 		prevrow = currow;
 	}
 }
 
 /*
- * Connect Vertically from the Input facets.
+ * Connect Vertically from the Input cells.
  * Each Programming transistor has four ports.
- * Each Input facet has two  ports for connecting it into the PLA.
- * inputfacet->port1 connects the left arm of the facet to the PLA and
- * inputfacet->port2 connects the right arm.  These two will connect
+ * Each Input cell has two  ports for connecting it into the PLA.
+ * inputcell->port1 connects the left arm of the cell to the PLA and
+ * inputcell->port2 connects the right arm.  These two will connect
  * into the poly ports of the programming transistors on the corresponding
- * columns.  There is also a diff arc to be drawn from the input facet to
+ * columns.  There is also a diff arc to be drawn from the input cell to
  * the diff port of the programming transistor closest to it.  Note that the
  * left arm and the right arm cannot contain a programming transistor
- * at the same distance from the input facet.
+ * at the same distance from the input cell.
  */
-void pla_CVfromInput(INTBIG inY, INTBIG andY, FACETIST *inptr, NODEPROTO *pla)
+void pla_CVfromInput(INTBIG inY, INTBIG andY, CELLIST *inptr, NODEPROTO *pla)
 {
 	PROGTRANS trans;
 	VDDGND *catg, *patg;
@@ -189,12 +189,12 @@ void pla_CVfromInput(INTBIG inY, INTBIG andY, FACETIST *inptr, NODEPROTO *pla)
 	catg = patg = NOVDDGND;
 
 	inY = inY - (pla_VddWidth - 4*pla_lam); /* Compensate for Extra Vdd Width */
-	while(inptr != NOFACETIST)
+	while(inptr != NOCELLIST)
 	{
 		if (inptr->lcoltrans == NOPROGTRANS && inptr->rcoltrans == NOPROGTRANS)
 		{
 			ttyputmsg(_("*** Warning. Input %ld is never used at all."), inptr->findex);
-			inptr = inptr->nextfacet;
+			inptr = inptr->nextcell;
 			continue;
 		}
 		if (inptr->lcoltrans == NOPROGTRANS)
@@ -206,7 +206,7 @@ void pla_CVfromInput(INTBIG inY, INTBIG andY, FACETIST *inptr, NODEPROTO *pla)
 			ttyputmsg(M_("connecting up from input# %ld"), inptr->findex);
 
 		/* Place a contact to ground at the top of the PLA right above the
-		 * current input facet.
+		 * current input cell.
 		 */
 		trans.trans = newnodeinst(pla_md_proto, (inptr->gport->x)-2*pla_lam,
 			(inptr->gport->x)+2*pla_lam, inY+andY+3*pla_lam, inY+andY+3*pla_lam+pla_GndWidth,
@@ -226,31 +226,31 @@ void pla_CVfromInput(INTBIG inY, INTBIG andY, FACETIST *inptr, NODEPROTO *pla)
 		catg->inst = trans.trans;
 		catg->port = trans.diffport;
 
-		/* We also need to connect the input facet to the first transistor */
-		if (pla_ConnectFirstFacet(INPUTSIDE, inptr, pla))
+		/* We also need to connect the input cell to the first transistor */
+		if (pla_ConnectFirstCell(INPUTSIDE, inptr, pla))
 			ttyputerr(M_("CVfromInput: cannot connect to first transistors"));
 
 		pla_DrawArcs(INPUTSIDE, &trans, inptr, POLY, pla);
 
-		inptr = inptr->nextfacet;
+		inptr = inptr->nextcell;
 	}
 }
 
 /*
- * Connect the programming transistors vertically from the output facets
- * Each output facet corresponds to two columns of output.  Connect
+ * Connect the programming transistors vertically from the output cells
+ * Each output cell corresponds to two columns of output.  Connect
  * them one at a time to the OR plane and the corresponding Pullup
- * facet.
+ * cell.
  */
-void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
+void pla_CVfromOutput(CELLIST *outptr, CELLIST *puptr, NODEPROTO *pla)
 {
 	PROGTRANS *endtrans = NOPROGTRANS;
 	PORT *fport, *tport;
 	INTBIG out, i;
 
-	while(outptr != NOFACETIST)
+	while(outptr != NOCELLIST)
 	{
-		if (pla_ConnectFirstFacet(OUTPUTSIDE, outptr, pla))
+		if (pla_ConnectFirstCell(OUTPUTSIDE, outptr, pla))
 			ttyputerr(M_("CVfromOutput: cannot connect to first transistors"));
 
 		for(i = 1; i >= 0; i--)
@@ -269,7 +269,7 @@ void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
 			}
 		}
 		if (pla_verbose)
-			ttyputmsg(M_("connecting up from output facet# %ld"), outptr->findex);
+			ttyputmsg(M_("connecting up from output cell# %ld"), outptr->findex);
 
 		pla_DrawArcs(OUTPUTSIDE, endtrans, outptr, METAL, pla);
 
@@ -283,9 +283,9 @@ void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
 			tport = puptr->lport;
 			if (newarcinst(pla_ma_proto, 3*pla_lam, pla_userbits,
 				endtrans->trans, fport->port, fport->x, fport->y,
-					puptr->facetinst, tport->port, tport->x, tport->y, pla) == NOARCINST)
+					puptr->cellinst, tport->port, tport->x, tport->y, pla) == NOARCINST)
 						ttyputerr(M_("Cannot connect to pullup from L column"));
-			puptr = puptr->nextfacet;
+			puptr = puptr->nextcell;
 		}
 
 		if (outptr->rcoltrans != NOPROGTRANS)
@@ -297,20 +297,20 @@ void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
 			tport = puptr->lport;
 			if (newarcinst(pla_ma_proto, 3*pla_lam, pla_userbits,
 				endtrans->trans, fport->port, fport->x, fport->y,
-					puptr->facetinst, tport->port, tport->x, tport->y, pla) == NOARCINST)
+					puptr->cellinst, tport->port, tport->x, tport->y, pla) == NOARCINST)
 						ttyputerr(M_("Cannot connect to pullup from R column"));
-			puptr = puptr->nextfacet;
+			puptr = puptr->nextcell;
 		}
 
-		outptr = outptr->nextfacet;
+		outptr = outptr->nextcell;
 	}
 }
 
 /*
- * Connect the given facet to the first programming transistor in that
+ * Connect the given cell to the first programming transistor in that
  * column or row.
  */
-BOOLEAN pla_ConnectFirstFacet(INTBIG from, FACETIST *facet, NODEPROTO *pla)
+BOOLEAN pla_ConnectFirstCell(INTBIG from, CELLIST *cell, NODEPROTO *pla)
 {
 	PROGTRANS *trans;
 	PORT *fport, *tport;
@@ -325,7 +325,7 @@ BOOLEAN pla_ConnectFirstFacet(INTBIG from, FACETIST *facet, NODEPROTO *pla)
 			arctype = pla_pa_proto;
 			break;
 		case OUTPUTSIDE:
-			columns = ((facet->findex)*2 <= pla_outputs) ? 2 : 1;
+			columns = ((cell->findex)*2 <= pla_outputs) ? 2 : 1;
 			width = 3*pla_lam;
 			arctype = pla_ma_proto;
 			break;
@@ -337,15 +337,15 @@ BOOLEAN pla_ConnectFirstFacet(INTBIG from, FACETIST *facet, NODEPROTO *pla)
 	}
 	while(columns > 0)
 	{
-		trans = (columns == 1) ? facet->lcoltrans : facet->rcoltrans;
+		trans = (columns == 1) ? cell->lcoltrans : cell->rcoltrans;
 		if (trans == NOPROGTRANS) break;
 		switch(from)
 		{
 			case INPUTSIDE:
-				fport = facet->gport;	/* Connect the ground points first */
+				fport = cell->gport;	/* Connect the ground points first */
 				tport = trans->diffport;
 				if (newarcinst(pla_da_proto, 4*pla_lam, pla_userbits,
-					facet->facetinst, fport->port, fport->x, fport->y,
+					cell->cellinst, fport->port, fport->x, fport->y,
 						trans->trans, tport->port, tport->x, tport->y, pla) == NOARCINST)
 							return(TRUE);
 				tport = trans->polyblport;
@@ -356,9 +356,9 @@ BOOLEAN pla_ConnectFirstFacet(INTBIG from, FACETIST *facet, NODEPROTO *pla)
 				tport = trans->metalport;
 				break;
 		}
-		fport = (columns == 1) ? facet->lport : facet->rport;
+		fport = (columns == 1) ? cell->lport : cell->rport;
 		if (newarcinst(arctype, width, pla_userbits,
-			facet->facetinst, fport->port, fport->x, fport->y,
+			cell->cellinst, fport->port, fport->x, fport->y,
 				trans->trans, tport->port, tport->x, tport->y, pla) == NOARCINST)
 					return(TRUE);
 
@@ -386,16 +386,16 @@ void pla_ConnectOnMetal(INTBIG which, VDDGND *ptr, CHAR *mesg, NODEPROTO *pla)
 }
 
 /* Connect the programming transistors on both the planes */
-void pla_ConnectPlanes(INTBIG inY, INTBIG andY, INTBIG orRight, FACETIST *Inputs,
-	FACETIST *Outputs, FACETIST *PullupAND, FACETIST *PullupOR, NODEPROTO *pla)
+void pla_ConnectPlanes(INTBIG inY, INTBIG andY, INTBIG orRight, CELLIST *Inputs,
+	CELLIST *Outputs, CELLIST *PullupAND, CELLIST *PullupOR, NODEPROTO *pla)
 {
 	pla_CVfromInput(inY, andY, Inputs, pla);
 	pla_CVfromOutput(Outputs, PullupOR, pla);
 	pla_CHfromPuAND(orRight, PullupAND, pla);
 }
 
-/* Connect the Vdd/Gnd points in a string of facets */
-void pla_ConnectThruFacets(INTBIG which, VDDGND *ptr, CHAR *mesg, NODEPROTO *pla)
+/* Connect the Vdd/Gnd points in a string of cells */
+void pla_ConnectThruCells(INTBIG which, VDDGND *ptr, CHAR *mesg, NODEPROTO *pla)
 {
 	while(ptr->nextinst != NOVDDGND)
 	{
@@ -405,10 +405,10 @@ void pla_ConnectThruFacets(INTBIG which, VDDGND *ptr, CHAR *mesg, NODEPROTO *pla
 }
 
 /*
- * Draw appropriate arcs between the start facet and the end transistor
+ * Draw appropriate arcs between the start cell and the end transistor
  * connecting through the intervening programming transistors.
  */
-void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
+void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, CELLIST *startcell,
 	INTBIG layer, NODEPROTO *pla)
 {
 	PROGTRANS *ftrans, *ttrans;
@@ -428,7 +428,7 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 	}
 	while(columns > 0)
 	{
-		ftrans = (columns == 1) ? startfacet->lcoltrans : startfacet->rcoltrans;
+		ftrans = (columns == 1) ? startcell->lcoltrans : startcell->rcoltrans;
 		columns--;
 		while(ftrans != NOPROGTRANS)
 		{
@@ -490,12 +490,12 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 							 * rows the programming transistors on the OR plane
 							 * would be turned clockwise by 90 and their
 							 * diffports would be in line with the diff ports of
-							 * connect facets on the same rows.  For the same
+							 * connect cells on the same rows.  For the same
 							 * reason, if there are even number of pterms then
 							 * connect only for even numbered rows.
 							 */
-							if ((pla_pterms%2 && (startfacet->findex)%2) ||
-								(!pla_pterms%2 && !((startfacet->findex)%2)))
+							if ((pla_pterms%2 && (startcell->findex)%2) ||
+								(!pla_pterms%2 && !((startcell->findex)%2)))
 							{
 								ttrans = ftrans->rprogtrans;
 								fport  = ftrans->diffport;
@@ -527,18 +527,18 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 			}
 
 			/* Break out of the loop if we are connecting from the Pullup side
-			 * and we have reached the connect facet
+			 * and we have reached the connect cell
 			 */
 			if (from == PULLUPSIDE && layer == METAL && ttrans->trans->proto->primindex == 0 &&
-				namesame(ttrans->trans->proto->cell->cellname, nmosConnect) == 0) break;
+				namesame(ttrans->trans->proto->protoname, nmosConnect) == 0) break;
 			ftrans = ttrans;
 		}
 
 		/* Now connect the last transistor to the endinst on diffusion */
 		if (ftrans != NOPROGTRANS &&(from == INPUTSIDE  ||
 			(from == PULLUPSIDE && layer == POLY &&
-				((pla_pterms%2 &&   (startfacet->findex)%2)     ||
-					(!pla_pterms%2 && !((startfacet->findex)%2))))))
+				((pla_pterms%2 &&   (startcell->findex)%2)     ||
+					(!pla_pterms%2 && !((startcell->findex)%2))))))
 		{
 			/* ftrans will not be NIL if went through the while loop above
 			 * at least once, because, we break out of the loop when ttrans
@@ -547,7 +547,7 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 			 * even then only when pterms is odd and current row is odd or
 			 * pterms is even and the current row is even too. If we were
 			 * connecting on Metal from the Pullups, then the endinst would be
-			 * a Connet facet and not a diff-ground pin/pullup.  If we are
+			 * a Connet cell and not a diff-ground pin/pullup.  If we are
 			 * coming up from the output side then the end instances are
 			 * pullups rather than ground pins.
 			 */
@@ -585,19 +585,19 @@ VDDGND *pla_MkVddGnd(INTBIG which, VDDGND **prevptr)
 	ptr->nextinst = NOVDDGND;
 	switch (which)
 	{
-		case INFACETGND:
+		case INCELLGND:
 			if (pla_icg == NOVDDGND)
 			pla_icg = ptr;
 			break;
-		case INFACETVDD:
+		case INCELLVDD:
 			if (pla_icv == NOVDDGND)
 			pla_icv = ptr;
 			break;
-		case OUTFACETGND:
+		case OUTCELLGND:
 			if (pla_ocg == NOVDDGND)
 			pla_ocg = ptr;
 			break;
-		case OUTFACETVDD:
+		case OUTCELLVDD:
 			if (pla_ocv == NOVDDGND)
 			pla_ocv = ptr;
 			break;
@@ -633,8 +633,8 @@ VDDGND *pla_MkVddGnd(INTBIG which, VDDGND **prevptr)
  * Run the Vdd and Gnd busses
  * At this point we have 9 lists, 4 of them with Vdd points and
  * five with Gnd points.
- *  icg and icv start with the first input facet on the left.
- *  ocg and ocv start with the first output facet on the left.
+ *  icg and icv start with the first input cell on the left.
+ *  ocg and ocv start with the first output cell on the left.
  *  alv starts at the bottom and ends at the top.
  *  otv starts at the left and ends at the right.
  *  arg and org start at the bottom and end at the top.
@@ -642,8 +642,8 @@ VDDGND *pla_MkVddGnd(INTBIG which, VDDGND **prevptr)
  *  Let us first connect the Vdd Bus.  Start with otv and connect
  *  to the end on the right.  Start again with otv but connect to
  *  the left after instancing a pin over the Pullups on AND.
- *  Connect through the Pullups on AND, through the Input facets
- *  and finally through the Outptut facets.
+ *  Connect through the Pullups on AND, through the Input cells
+ *  and finally through the Outptut cells.
  */
 void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 {
@@ -652,7 +652,7 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 
 	if (pla_verbose) ttyputmsg(M_("Running the Vdd and Gnd lines"));
 
-	pla_ConnectThruFacets(VDD, pla_otv, M_("RunVddGnd: cannot connect on Vdd at Or Top"), pla);
+	pla_ConnectThruCells(VDD, pla_otv, M_("RunVddGnd: cannot connect on Vdd at Or Top"), pla);
 
 	/* Export this as the external VDD connection point */
 	if (newportproto(pla, pla_otv->inst, pla_otv->port->port, x_("VDD")) == NOPORTPROTO)
@@ -677,27 +677,27 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	pla_ConnectOnMetal(VDD, &turnpin, M_("RunVddGnd: cannot connect turnpin to pu on Left AND/Top"), pla);
 
 	/* Now connect through the pu on AND */
-	pla_ConnectThruFacets(VDD, pla_alv, M_("RunVddGnd: cannot connect on Vdd at And Left"), pla);
+	pla_ConnectThruCells(VDD, pla_alv, M_("RunVddGnd: cannot connect on Vdd at And Left"), pla);
 
-	/* Instance a turnpin near the first input facet and connect it to
-	 * both the pullups and the input facets
+	/* Instance a turnpin near the first input cell and connect it to
+	 * both the pullups and the input cells
 	 */
 	lowy = (pla_icv->port->y) - pla_halfVdd;
 	highy = lowy + pla_VddWidth;
 	porty = pla_icv->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_alv,
-		M_("RunVddGnd: cannot instance Vdd turnpin near Input facet"), pla);
+		M_("RunVddGnd: cannot instance Vdd turnpin near Input cell"), pla);
 
 	pla_ConnectOnMetal(VDD, &turnpin, M_("RunVddGnd: cannot connect turnpin to pu on Left AND/Bot"),pla);
 
 	turnpin.nextinst = pla_icv;
-	pla_ConnectOnMetal(VDD, &turnpin, M_("RunVddGnd: cannot connect turnpin to infacet on left"), pla);
+	pla_ConnectOnMetal(VDD, &turnpin, M_("RunVddGnd: cannot connect turnpin to incell on left"), pla);
 
-	/* Connect through the input facets */
-	pla_ConnectThruFacets(VDD, pla_icv, M_("RunVddGnd: cannot connect on Vdd at Input facets"), pla);
+	/* Connect through the input cells */
+	pla_ConnectThruCells(VDD, pla_icv, M_("RunVddGnd: cannot connect on Vdd at Input cells"), pla);
 
-	/* Instance yet two more turnpins on the right of the input facets */
+	/* Instance yet two more turnpins on the right of the input cells */
 	lowx  = puX + andX;
 	highx = lowx + pla_VddWidth;
 	lowy  = (pla_icv->port->y) - pla_halfVdd;
@@ -706,30 +706,30 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_icv->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_icv,
-		M_("RunVddGnd: cannot instance top Vdd turnpin after Input Facet"), pla);
+		M_("RunVddGnd: cannot instance top Vdd turnpin after Input Cell"), pla);
 
-	pla_ConnectOnMetal(VDD, &turnpin, M_("RunVddGnd: cannot connect turnpin to last input facet"), pla);
+	pla_ConnectOnMetal(VDD, &turnpin, M_("RunVddGnd: cannot connect turnpin to last input cell"), pla);
 
 	lowy = (pla_ocv->port->y) - pla_halfVdd;
 	highy = lowy + pla_VddWidth;
 	porty = pla_ocv->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin1, &turnpin,
-		M_("RunVddGnd: cannot instance bot Vdd turnpin after Input Facet"), pla);
+		M_("RunVddGnd: cannot instance bot Vdd turnpin after Input Cell"), pla);
 
 	pla_ConnectOnMetal(VDD, &turnpin1,
 		M_("RunVddGnd: cannot connect the two turnpins on left of input"), pla);
 
 	turnpin1.nextinst = pla_ocv;
-	pla_ConnectOnMetal(VDD, &turnpin1, M_("RunVddGnd: cannot connect through output facets"), pla);
+	pla_ConnectOnMetal(VDD, &turnpin1, M_("RunVddGnd: cannot connect through output cells"), pla);
 
-	/*  Let us lay out the Ground line now.  Begin with the input facets. */
-	pla_ConnectThruFacets(GND, pla_icg,
+	/*  Let us lay out the Ground line now.  Begin with the input cells. */
+	pla_ConnectThruCells(GND, pla_icg,
 		M_("RunVddGnd: cannot connect on Gnd at Input"), pla);
 
-	/* Instance a fork pin at the end of the input facets.  One arm from
+	/* Instance a fork pin at the end of the input cells.  One arm from
 	 * this fork goes up between the planes and the other through the
-	 * output facets.
+	 * output cells.
 	 */
 	lowx  = (pla_arg->port->x) - pla_halfGnd;
 	highx = lowx + pla_GndWidth;
@@ -740,10 +740,10 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &forkpin, pla_arg,
 		M_("RunVddGnd: cannot instance Gnd fork pin"), pla);
-	pla_ConnectThruFacets(GND, &forkpin, M_("RunVddGnd: cannot connect through And Right Gnds"), pla);
+	pla_ConnectThruCells(GND, &forkpin, M_("RunVddGnd: cannot connect through And Right Gnds"), pla);
 
 	forkpin.nextinst = pla_icg;
-	pla_ConnectOnMetal(GND, &forkpin, M_("RunVddGnd: cannot connect input facets to fork pin"), pla);
+	pla_ConnectOnMetal(GND, &forkpin, M_("RunVddGnd: cannot connect input cells to fork pin"), pla);
 
 	/* Instance a turn pin at the top of the planes */
 	lowy  = (pla_atg->port->y) - pla_halfGnd;
@@ -759,7 +759,7 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	turnpin.nextinst = pla_atg;
 	pla_ConnectOnMetal(GND, &turnpin, M_("RunVddGnd: cannot connect turnpin to And Top Gnds"), pla);
 
-	pla_ConnectThruFacets(GND, pla_atg, M_("RunVddGnd: cannot connect through And Top Gnds"), pla);
+	pla_ConnectThruCells(GND, pla_atg, M_("RunVddGnd: cannot connect through And Top Gnds"), pla);
 
 	/* Connect through the other arm of the Gnd fork.
 	 * Begin by instancing a turnpin below the fork pin
@@ -772,14 +772,14 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_ocg->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, &forkpin,
-		M_("RunVddGnd: cannot instance Gnd turnpin before Output Facet"), pla);
+		M_("RunVddGnd: cannot instance Gnd turnpin before Output Cell"), pla);
 
 	pla_ConnectOnMetal(GND, &turnpin, M_("RunVddGnd: cannot connect forkpin to turnpin"), pla);
 
 	turnpin.nextinst = pla_ocg;
-	pla_ConnectThruFacets(GND, &turnpin, M_("RunVddGnd: cannot connect through output facets"), pla);
+	pla_ConnectThruCells(GND, &turnpin, M_("RunVddGnd: cannot connect through output cells"), pla);
 
-	/* Instance a turn pin after the output facets */
+	/* Instance a turn pin after the output cells */
 	lowx  = (pla_org->port->x) - pla_halfGnd;
 	highx = lowx + pla_GndWidth;
 	lowy  = (pla_ocg->port->y) - pla_halfGnd;
@@ -788,13 +788,13 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_ocg->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_ocg,
-		M_("RunVddGnd: cannot instance Gnd turnpin after Output Facet"), pla);
+		M_("RunVddGnd: cannot instance Gnd turnpin after Output Cell"), pla);
 
 	pla_ConnectOnMetal(GND, &turnpin,
-		M_("RunVddGnd: cannot connect Output facets to turnpin on right"), pla);
+		M_("RunVddGnd: cannot connect Output cells to turnpin on right"), pla);
 
 	turnpin.nextinst = pla_org;
-	pla_ConnectThruFacets(GND, &turnpin, M_("RunVddGnd: cannot connect through Or Right Gnds"), pla);
+	pla_ConnectThruCells(GND, &turnpin, M_("RunVddGnd: cannot connect through Or Right Gnds"), pla);
 
 	/* Export this as the external GND connection point */
 	if (newportproto(pla, pla_org->inst, pla_org->port->port, x_("GND")) == NOPORTPROTO)
