@@ -41,13 +41,13 @@
 #include "efunction.h"
 
 /* the ROUTER tool table */
-static COMCOMP routerfacetp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, x_(" \t"), M_("Facet to stitch"), 0};
+static COMCOMP routercellp = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
+	INPUTOPT, x_(" \t"), M_("Cell to stitch"), 0};
 static COMCOMP routerarcp = {NOKEYWORD, topofarcs, nextarcs, NOPARAMS,
 	INPUTOPT, x_(" \t"), M_("Arc prototype to use in stitching (* to reset)"), 0};
 static KEYWORD routerautoopt[] =
 {
-	{x_("stitch-now"),             1,{&routerfacetp,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("stitch-now"),             1,{&routercellp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("highlighted-stitch-now"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
@@ -56,6 +56,7 @@ static COMCOMP routerautop = {routerautoopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 static KEYWORD routermimicopt[] =
 {
 	{x_("do-now"),                 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("mimic-selected"),         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("enable"),                 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("stitch-and-unstitch"),    0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("stitch-only"),            0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -67,8 +68,8 @@ static KEYWORD routermimicopt[] =
 };
 static COMCOMP routermimicp = {routermimicopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
 	INPUTOPT, x_(" \t"), M_("Mimic-stitching action"), 0};
-static COMCOMP routerriverp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	INPUTOPT, x_(" \t"), M_("Facet to river-route"), 0};
+static COMCOMP routerriverp = {NOKEYWORD, topofcells, nextcells, NOPARAMS,
+	INPUTOPT, x_(" \t"), M_("Cell to river-route"), 0};
 static COMCOMP routermazesetboundaryp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
 	0, x_(" \t"), M_("routing boundary"), 0};
 static COMCOMP routermazesetgridxp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,
@@ -137,7 +138,7 @@ static TOOL        *ro_source;			/* source of batch of changes */
        INTBIG       ro_state;			/* cached value for "ROUT_state" */
 static INTBIG       ro_optionskey;		/* variable key for "ROUT_options" */
        INTBIG       ro_preferedkey;		/* variable key for "ROUT_prefered_arc" */
-	   NODEPROTO   *ro_copiedtopofacet;	/* facet whose topology is being copied */
+	   NODEPROTO   *ro_copiedtopocell;	/* cell whose topology is being copied */
        TOOL        *ro_tool;			/* the Router tool object */
        POLYLIST    *ro_autostitchplist;	/* for auto-stitching */
 
@@ -228,7 +229,7 @@ void ro_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 		/* pass 1: initialize */
 		ro_tool = thistool;
 
-		/* set default mode for router: facet stitching */
+		/* set default mode for router: cell stitching */
 		ro_statekey = makekey(x_("ROUT_state"));
 		ro_optionskey = makekey(x_("ROUT_options"));
 		ro_preferedkey = makekey(x_("ROUT_prefered_arc"));
@@ -244,8 +245,8 @@ void ro_init(INTBIG *argc, CHAR1 *argv[], TOOL *thistool)
 		ro_lastactivity.numcreatedarcs = ro_lastactivity.numcreatednodes = 0;
 		ro_lastactivity.numdeletedarcs = ro_lastactivity.numdeletednodes = 0;
 
-		/* no facet topology was copied */
-		ro_copiedtopofacet = NONODEPROTO;
+		/* no cell topology was copied */
+		ro_copiedtopocell = NONODEPROTO;
 
 		/* setup polylist */
 		ro_autostitchplist = allocpolylist(ro_tool->cluster);
@@ -296,6 +297,7 @@ void ro_set(INTBIG count, CHAR *par[])
 	REGISTER INTBIG l, savestate;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCPROTO *ap;
+	REGISTER ARCINST *ai;
 	REGISTER NODEINST *ni;
 	REGISTER CHAR *pp;
 	REGISTER GEOM **list;
@@ -345,25 +347,25 @@ void ro_set(INTBIG count, CHAR *par[])
 				np = getnodeproto(par[2]);
 				if (np == NONODEPROTO)
 				{
-					ttyputerr(_("No facet named %s"), par[2]);
+					ttyputerr(_("No cell named %s"), par[2]);
 					return;
 				}
 				if (np->primindex != 0)
 				{
-					ttyputerr(M_("Can only stitch facets, not primitives"));
+					ttyputerr(M_("Can only stitch cells, not primitives"));
 					return;
 				}
-				if (np->cell->lib != el_curlib)
+				if (np->lib != el_curlib)
 				{
-					ttyputerr(_("Can only stitch facets in the current library"));
+					ttyputerr(_("Can only stitch cells in the current library"));
 					return;
 				}
 			} else
 			{
-				np = getcurfacet();
+				np = getcurcell();
 				if (np == NONODEPROTO)
 				{
-					ttyputerr(_("No current facet"));
+					ttyputerr(_("No current cell"));
 					return;
 				}
 			}
@@ -371,7 +373,7 @@ void ro_set(INTBIG count, CHAR *par[])
 			for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 			{
 				/* ignore recursive references (showing icon in contents) */
-				if (ni->proto->cell == np->cell) continue;
+				if (isiconof(ni->proto, np)) continue;
 				ro_queuercheck(ni);
 			}
 
@@ -384,7 +386,7 @@ void ro_set(INTBIG count, CHAR *par[])
 
 			/* restore routing state */
 			ro_state = savestate;
-			ttyputverbose(M_("Facet %s stitched"), describenodeproto(np));
+			ttyputverbose(M_("Cell %s stitched"), describenodeproto(np));
 			return;
 		}
 		if (namesamen(pp, x_("highlighted-stitch-now"), l) == 0)
@@ -427,6 +429,17 @@ void ro_set(INTBIG count, CHAR *par[])
 			ro_mimicstitch(TRUE);
 			return;
 		}
+		if (namesamen(pp, x_("mimic-selected"), l) == 0)
+		{
+			ai = (ARCINST *)us_getobject(VARCINST, FALSE);
+			if (ai == NOARCINST) return;
+			ro_lastactivity.numdeletedarcs = 0;
+			ro_lastactivity.numcreatedarcs = 1;
+			ro_lastactivity.createdarcs[0] = ai;
+
+			ro_mimicstitch(TRUE);
+			return;
+		}
 		if (namesamen(pp, x_("enable"), l) == 0)
 		{
 			(void)setvalkey((INTBIG)ro_tool, VTOOL, ro_statekey,
@@ -486,25 +499,25 @@ void ro_set(INTBIG count, CHAR *par[])
 			np = getnodeproto(par[1]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("No facet named %s"), par[1]);
+				ttyputerr(_("No cell named %s"), par[1]);
 				return;
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr(M_("Can only route facets, not primitives"));
+				ttyputerr(M_("Can only route cells, not primitives"));
 				return;
 			}
 		} else
 		{
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("No current facet"));
+				ttyputerr(_("No current cell"));
 				return;
 			}
 		}
 
-		if (ro_river(np)) ttyputverbose(M_("Facet %s river-routed"), describenodeproto(np)); else
+		if (ro_river(np)) ttyputverbose(M_("Cell %s river-routed"), describenodeproto(np)); else
 			ttyputmsg(_("Routing not successful"));			
 		return;
 	}
@@ -568,21 +581,21 @@ void ro_set(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("copy-topology"), l) == 0)
 	{
-		np = getcurfacet();
+		np = getcurcell();
 		if (np == NONODEPROTO)
 		{
-			ttyputerr(_("No current facet"));
+			ttyputerr(_("No current cell"));
 			return;
 		}
-		ro_copiedtopofacet = np;
+		ro_copiedtopocell = np;
 		return;
 	}
 	if (namesamen(pp, x_("paste-topology"), l) == 0 && l >= 3)
 	{
-		np = getcurfacet();
+		np = getcurcell();
 		if (np == NONODEPROTO)
 		{
-			ttyputerr(_("No current facet"));
+			ttyputerr(_("No current cell"));
 			return;
 		}
 		ro_pastetopology(np);
@@ -662,11 +675,11 @@ void ro_slice(void)
 	{
 		case AUTOSTITCH:
 			ro_autostitch();
-			setactivity(_("Facets stitched"));
+			setactivity(_("Cells stitched"));
 			break;
 		case MIMICSTITCH:
 			ro_mimicstitch(FALSE);
-			setactivity(_("Facets stitched"));
+			setactivity(_("Cells stitched"));
 			break;
 	}
 }
@@ -1063,7 +1076,7 @@ INTBIG ro_getoptions(void)
 /****************************** TOPOLOGY COPYING ******************************/
 
 /*
- * Routine to copy the topology of facet "ro_copiedtopofacet" to facet "tonp".
+ * Routine to copy the topology of cell "ro_copiedtopocell" to cell "tonp".
  */
 void ro_pastetopology(NODEPROTO *tonp)
 {
@@ -1078,33 +1091,33 @@ void ro_pastetopology(NODEPROTO *tonp)
 	REGISTER CHAR *matchname;
 	REGISTER VARIABLE *var, *ovar;
 
-	if (ro_copiedtopofacet == NONODEPROTO)
+	if (ro_copiedtopocell == NONODEPROTO)
 	{
 		ttyputerr(_("Must copy topology before pasting it"));
 		return;
 	}
 
-	/* first validate the source facet */
+	/* first validate the source cell */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			if (np == ro_copiedtopofacet) break;
+			if (np == ro_copiedtopocell) break;
 		if (np != NONODEPROTO) break;
 	}
 	if (lib == NOLIBRARY)
 	{
-		ttyputerr(_("Copied facet is no longer valid"));
+		ttyputerr(_("Copied cell is no longer valid"));
 		return;
 	}
 
-	/* make sure copy goes to a different facet */
-	if (ro_copiedtopofacet == tonp)
+	/* make sure copy goes to a different cell */
+	if (ro_copiedtopocell == tonp)
 	{
-		ttyputerr(_("Topology must be copied to a different facet"));
+		ttyputerr(_("Topology must be copied to a different cell"));
 		return;
 	}
 
-	/* reset association pointers in the destination facet */
+	/* reset association pointers in the destination cell */
 	for(ni = tonp->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		ni->temp1 = 0;
 
@@ -1122,13 +1135,13 @@ void ro_pastetopology(NODEPROTO *tonp)
 				fun == NPNODE) continue;
 		}
 
-		/* count the number of this type of node in the two facets */
+		/* count the number of this type of node in the two cells */
 		fromcount = 0;
-		for(oni = ro_copiedtopofacet->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
+		for(oni = ro_copiedtopocell->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
 		{
 			if (ni->proto->primindex == 0)
 			{
-				if (oni->proto->cell == ni->proto->cell) fromcount++;
+				if (insamecellgrp(oni->proto, ni->proto)) fromcount++;
 			} else
 			{
 				ofun = nodefunction(oni);
@@ -1152,8 +1165,8 @@ void ro_pastetopology(NODEPROTO *tonp)
 		if (tocount != fromcount)
 		{
 			if (fromcount == 0) continue;
-			ttyputerr(_("Warning: %s has %ld of %s but facet %s has %ld"),
-				describenodeproto(ro_copiedtopofacet), fromcount, describenodeproto(ni->proto),
+			ttyputerr(_("Warning: %s has %ld of %s but cell %s has %ld"),
+				describenodeproto(ro_copiedtopocell), fromcount, describenodeproto(ni->proto),
 				describenodeproto(tonp), tocount);
 			return;
 		}
@@ -1162,11 +1175,11 @@ void ro_pastetopology(NODEPROTO *tonp)
 		fromlist = (NODEINST **)emalloc(fromcount * (sizeof (NODEINST *)), ro_tool->cluster);
 		if (fromlist == 0) return;
 		fromcount = 0;
-		for(oni = ro_copiedtopofacet->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
+		for(oni = ro_copiedtopocell->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
 		{
 			if (ni->proto->primindex == 0)
 			{
-				if (oni->proto->cell == ni->proto->cell) fromlist[fromcount++] = oni;
+				if (insamecellgrp(oni->proto, ni->proto)) fromlist[fromcount++] = oni;
 			} else
 			{
 				ofun = nodefunction(oni);
@@ -1263,7 +1276,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 			}
 			if (fpi == NOPORTARCINST) continue;
 
-			/* this connection should be repeated in the other facet */
+			/* this connection should be repeated in the other cell */
 			for(tpp = tni->proto->firstportproto; tpp != NOPORTPROTO; tpp = tpp->nextportproto)
 				if (namesame(tpp->protoname, fpi->proto->protoname) == 0) break;
 			if (tpp == NOPORTPROTO) continue;
@@ -1285,11 +1298,11 @@ void ro_pastetopology(NODEPROTO *tonp)
 		fun = nodefunction(tni);
 		if (fun != NPPIN && fun != NPCONTACT) continue;
 
-		/* find that export in the source facet */
+		/* find that export in the source cell */
 		tpp = tni->proto->firstportproto;
 		matchname = tni->firstportexpinst->exportproto->protoname;
 		net = NONETWORK;
-		for(fpp = ro_copiedtopofacet->firstportproto; fpp != NOPORTPROTO; fpp = fpp->nextportproto)
+		for(fpp = ro_copiedtopocell->firstportproto; fpp != NOPORTPROTO; fpp = fpp->nextportproto)
 		{
 			net = fpp->network;
 			if (fpp->network->buswidth > 1)
@@ -1308,7 +1321,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 		}
 		if (fpp == NOPORTPROTO) continue;
 
-		/* check to see if this is connected elsewhere in the "to" facet */
+		/* check to see if this is connected elsewhere in the "to" cell */
 		ofpi = NOPORTARCINST;
 		for(otni = tonp->firstnodeinst; otni != NONODEINST; otni = otni->nextnodeinst)
 		{
@@ -1325,7 +1338,7 @@ void ro_pastetopology(NODEPROTO *tonp)
 		}
 		if (otni != NONODEINST)
 		{
-			/* find the proper port in this facet */
+			/* find the proper port in this cell */
 			for(otpp = otni->proto->firstportproto; otpp != NOPORTPROTO; otpp = otpp->nextportproto)
 				if (namesame(otpp->protoname, ofpi->proto->protoname) == 0) break;
 			if (otpp == NOPORTPROTO) continue;
