@@ -34,6 +34,7 @@
 
 #include "global.h"
 #include "efunction.h"
+#include "tecgen.h"
 #include "rout.h"
 #include "usr.h"
 #include <math.h>
@@ -86,12 +87,12 @@ void ro_autostitch(void)
 	/* if there is nothing queued to stitch, quit now */
 	if (ro_firstrcheck == NORCHECK) return;
 
-	/* set temp1 flag on all facets that will be checked */
+	/* set temp1 flag on all cells that will be checked */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
 
-	/* next pre-compute bounds on all nodes in facets to be changed */
+	/* next pre-compute bounds on all nodes in cells to be changed */
 	count = 0;
 	for(r = ro_firstrcheck; r != NORCHECK; r = r->nextcheck)
 		if (r->entity->parent->temp1 == 0)
@@ -294,7 +295,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 				/* look at all polygons on this nodeinst */
 				useportpoly = 0;
 				tot = nodeEpolys(rni, 0, NOWINDOWPART);
-				if (tot == 0)
+				if (tot == 0 || rni->proto == gen_simprobeprim)
 				{
 					useportpoly = 1;
 					tot = 1;
@@ -378,7 +379,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 			/* look at all polygons on this nodeinst */
 			useportpoly = 0;
 			tot = allnodeEpolys(ni, ro_autostitchplist, NOWINDOWPART, TRUE);
-			if (tot == 0)
+			if (tot == 0 || ni->proto == gen_simprobeprim)
 			{
 				useportpoly = 1;
 				tot = 1;
@@ -522,7 +523,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 	/* now look at every layer in this node */
 	if (oni->proto->primindex == 0)
 	{
-		/* complex facet: look at all exports */
+		/* complex cell: look at all exports */
 		if (oni->temp2 == 0 || oni->temp2 == -1) bbp = -1; else
 		{
 			getbbox(poly, &plx, &phx, &ply, &phy);
@@ -582,8 +583,11 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 					if (opoly->portproto->network != rpp->network) continue;
 
 					/* if the polygon layer is pseudo, substitute real layer */
-					opoly->layer = nonpseudolayer(opoly->layer, opoly->tech);
-					if (!samelayer(ap->tech, ap->temp1, opoly->layer)) continue;
+					if (ni->proto != gen_simprobeprim)
+					{
+						opoly->layer = nonpseudolayer(opoly->layer, opoly->tech);
+						if (!samelayer(ap->tech, ap->temp1, opoly->layer)) continue;
+					}
 
 					/* transform the polygon and pass it on to the next test */
 					xformpoly(opoly, trans);
