@@ -34,6 +34,7 @@
 #if ROUTTOOL
 
 #include "global.h"
+#include "database.h"
 #include "efunction.h"
 #include "egraphics.h"
 #include "usr.h"
@@ -247,7 +248,7 @@ static void        ro_mazedelete_port(SRPORT *port);
 static void        ro_mazecleanout_region(SRREGION *region);
 static UINTBIG     ro_mazedetermine_dir(NODEINST *ni, INTBIG cx, INTBIG cy);
 static void        ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net, SRREGION *region);
-static void        ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
+static void        ro_mazedraw_cell(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
 static void        ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region);
 static void        ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTBIG layer);
 static void        ro_mazedump_layer(CHAR *message, SRREGION *region, UINTBIG layers);
@@ -256,7 +257,7 @@ static INTBIG      ro_mazeexpand_wavefront(SRPORT *port, INTBIG code);
 static BOOLEAN     ro_mazeextract_paths(NODEPROTO *parent, SRNET *net);
 static INTBIG      ro_mazefind_paths(SRWAVEPT *wavept, SRPATH *path);
 static INTBIG      ro_mazefindport(NODEPROTO*, INTBIG, INTBIG, ARCPROTO*, NODEINST *nis[], PORTPROTO *pps[], BOOLEAN);
-static INTBIG      ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, BOOLEAN forcefind);
+static INTBIG      ro_mazefindport_geom(NODEPROTO *cell, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, BOOLEAN forcefind);
 static void        ro_mazefree_net(SRNET *net);
 static void        ro_mazefree_path(SRPATH *path);
 static void        ro_mazefree_port(SRPORT *port);
@@ -382,14 +383,14 @@ void ro_mazerouteselected(void)
 }
 
 /*
- * Routine to reroute every unrouted network in the facet.
+ * Routine to reroute every unrouted network in the cell.
  */
 void ro_mazeroutecell(void)
 {
 	REGISTER NODEPROTO *np;
 	REGISTER ARCINST *ai;
 
-	np = us_needfacet();
+	np = us_needcell();
 	if (np == NONODEPROTO) return;
 
 	/* loop while searching for networks to route */
@@ -441,7 +442,7 @@ BOOLEAN ro_mazeroutenet(NETWORK *net)
 	for(i=0; i<count; i++)
 	{
 		tech = ro_findtech(nilist[i], pplist[i]);
-		lambda = nilist[i]->parent->cell->lib->lambda[tech->techindex];
+		lambda = nilist[i]->parent->lib->lambda[tech->techindex];
 		if (i == 0) ro_mazegridx = lambda; else
 		{
 			if (lambda < ro_mazegridx) ro_mazegridx = lambda;
@@ -555,8 +556,8 @@ BOOLEAN ro_mazeroutenet(NETWORK *net)
 		return(TRUE);
 	}
 
-	/* ensure that the facet is the proper size */
-	(*el_curconstraint->solve)(np);
+	/* ensure that the cell is sized right and the networks are reevaluated */
+	db_endbatch();
 	setactivity(_("Maze routing"));
 	return(FALSE);
 }
@@ -593,8 +594,8 @@ SRREGION *ro_mazedefine_region(NODEPROTO *np, INTBIG lx, INTBIG ly, INTBIG hx, I
 		if (stopping(STOPREASONROUTING)) return(NOSRREGION);
 		if (look->entryisnode)
 		{
-			/* draw this facet */
-			ro_mazedraw_facet(look->entryaddr.ni, trans, NONETWORK, region);
+			/* draw this cell */
+			ro_mazedraw_cell(look->entryaddr.ni, trans, NONETWORK, region);
 		} else
 		{
 			/* draw this arc */
@@ -995,28 +996,28 @@ void ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION
 		}
 	} else
 	{
-		/* draw facet rectangle */
+		/* draw cell rectangle */
 		maketruerectpoly(ni->lowx, ni->highx, ni->lowy, ni->highy, poly);
 		poly->style = CLOSEDRECT;
 		xformpoly(poly, prevtrans);
 		ro_mazedraw_showpoly(poly, region, SCH_ALLLAYER);
 
-		/* transform into the facet for display of its guts */
+		/* transform into the cell for display of its guts */
 		maketrans(ni, localtran);
 		transmult(localtran, prevtrans, subrot);
 
-		/* search through facet */
+		/* search through cell */
 		for (ino = np->firstnodeinst; ino != NONODEINST; ino = ino->nextnodeinst)
-			ro_mazedraw_facet(ino, subrot, net, region);
+			ro_mazedraw_cell(ino, subrot, net, region);
 		for (iar = np->firstarcinst; iar != NOARCINST; iar = iar->nextarcinst)
 			ro_mazedraw_arcinst(iar, subrot, net, region);
 	}
 }
 
-/* module: ro_mazedraw_facet
- * function: will output a specific symbol facet
+/* module: ro_mazedraw_cell
+ * function: will output a specific symbol cell
  */
-void ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region)
+void ro_mazedraw_cell(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region)
 {
 	XARRAY localtran, trans;
 
@@ -1040,7 +1041,7 @@ void ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *r
    function: will locate the nodeinstance and portproto corresponding to
    to a direct intersection with the given point.
    inputs:
-   facet - facet to search
+   cell - cell to search
    x, y  - the point to exam
    ap    - the arc used to connect port (must match pp)
    nis   - pointer to ni pointer buffer.
@@ -1050,7 +1051,7 @@ void ro_mazedraw_facet(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *r
    ni = found ni instance
    pp = found pp proto.
  */
-INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
+INTBIG ro_mazefindport_geom(NODEPROTO *cell, INTBIG x, INTBIG y, ARCPROTO *ap,
 	NODEINST *nis[], PORTPROTO *pps[], ARCINST **ai, BOOLEAN forcefind)
 {
 	REGISTER INTBIG j, cnt, sea, dist, bestdist;
@@ -1065,7 +1066,7 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 	closestni = NONODEINST;
 	bestdist = 0;
 	closestpp = NOPORTPROTO;
-	sea = initsearch(x, x, y, y, facet);
+	sea = initsearch(x, x, y, y, cell);
 	for(;;)
 	{
 		geom = nextobject(sea);
@@ -1127,7 +1128,7 @@ INTBIG ro_mazefindport_geom(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap,
 	return cnt;
 }
 
-INTBIG ro_mazefindport(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[],
+INTBIG ro_mazefindport(NODEPROTO *cell, INTBIG x, INTBIG y, ARCPROTO *ap, NODEINST *nis[],
 	PORTPROTO *pps[], BOOLEAN forcefind)
 {
 	INTBIG cnt;
@@ -1139,7 +1140,7 @@ INTBIG ro_mazefindport(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEI
 	INTBIG wid, bits1, bits2, lx, hx, ly, hy, j, xs, ys;
 	INTBIG fendx, fendy, tendx, tendy;
 
-	cnt = ro_mazefindport_geom(facet, x, y, ap, nis, pps, &ai, forcefind);
+	cnt = ro_mazefindport_geom(cell, x, y, ap, nis, pps, &ai, forcefind);
 
 	if (cnt == 0 && ai != NOARCINST)
 	{
