@@ -36,6 +36,7 @@
 #include "rout.h"
 #include "usr.h"
 #include "edialogs.h"
+#include <math.h>
 
 #define NOPOSSIBLEARC ((POSSIBLEARC *)-1)
 #define LIKELYDIFFPORT      1
@@ -224,7 +225,7 @@ void ro_mimicstitch(BOOLEAN forced)
  */
 void ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports)
 {
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER ARCINST *ai, *nextai;
 	REGISTER INTBIG match, dist, thisdist, deleted, angle, thisangle;
 	INTBIG x0, y0, x1, y1;
@@ -237,8 +238,8 @@ void ro_mimicdelete(ARCPROTO *typ, NODEINST **nodes, PORTPROTO **ports)
 
 	/* look for a similar situation to delete */
 	deleted = 0;
-	facet = nodes[0]->parent;
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = nextai)
+	cell = nodes[0]->parent;
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = nextai)
 	{
 		nextai = ai->nextarcinst;
 
@@ -322,12 +323,15 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 	NODEINST *oni2, PORTPROTO *opp2, INTBIG ox2, INTBIG oy2,
 	INTBIG owidth, ARCPROTO *oproto, INTBIG prefx, INTBIG prefy)
 {
-	REGISTER NODEPROTO *facet, *proto0, *proto1;
+	REGISTER NODEPROTO *cell, *proto0, *proto1;
 	REGISTER NODEINST *ni, *oni, *node0, *node1;
 	NODEINST *endni[2], *nicon1, *nicon2;
 	REGISTER PORTPROTO *port0, *port1, *pp, *opp;
+	REGISTER NETWORK *net1, *net0;
 	PORTPROTO *endpp[2];
 	REGISTER PORTARCINST *pi;
+	REGISTER BOOLEAN usefangle;
+	double fangle;
 	REGISTER ARCINST *newai, *oai;
 	ARCINST *alt1, *alt2;
 	REGISTER INTBIG dist, angle, options, count, i, wantx1, wanty1, end, end0offx, end0offy,
@@ -387,7 +391,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 5, ro_tool->cluster);
 
-	facet = oni1->parent;
+	cell = oni1->parent;
 	endni[0] = oni1;   endni[1] = oni2;
 	endpp[0] = opp1;   endpp[1] = opp2;
 	endx[0] = ox1;     endx[1] = ox2;
@@ -403,9 +407,9 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 	for(pi = oni2->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst) con1++;
 	con1 -= 2;
 
-	/* precompute information about every port in the facet */
+	/* precompute information about every port in the cell */
 	total = 0;
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
@@ -430,7 +434,7 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 		ro_totalmimicports = total;
 	}
 	i = 0;
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		ni->temp1 = i;
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -455,6 +459,11 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 		x1 = endx[1-end];   y1 = endy[1-end];
 		dist = computedistance(x0, y0, x1, y1);
 		angle = (dist != 0 ? figureangle(x0, y0, x1, y1) : 0);
+		if ((angle%900) == 0) usefangle = FALSE; else
+		{
+			fangle = ffigureangle(x0, y1, x1, y1);
+			usefangle = TRUE;
+		}
 		portposition(node0, port0, &x0c, &y0c);
 		end0offx = x0 - x0c;   end0offy = y0 - y0c;
 		nodesizeoffset(node0, &lx, &ly, &hx, &hy);
@@ -464,11 +473,11 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 		node1wid = node1->highx-hx - (node1->lowx+lx);
 		node1hei = node1->highy-hy - (node1->lowy+ly);
 
-		/* now search every node in the facet */
-		for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		/* now search every node in the cell */
+		for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			/* now look for another node that matches the situation */
-			for(oni = facet->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
+			for(oni = cell->firstnodeinst; oni != NONODEINST; oni = oni->nextnodeinst)
 			{
 				/* see if stopping is requested */
 				stopcheck++;
@@ -517,8 +526,15 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 						wantx1 = x0;   wanty1 = y0;
 					} else
 					{
-						wantx1 = x0 + mult(dist, cosine(angle));
-						wanty1 = y0 + mult(dist, sine(angle));
+						if (usefangle)
+						{
+							wantx1 = x0 + rounddouble(dist * cos(fangle));
+							wanty1 = y0 + rounddouble(dist * sin(fangle));
+						} else
+						{
+							wantx1 = x0 + mult(dist, cosine(angle));
+							wanty1 = y0 + mult(dist, sine(angle));
+						}
 					}
 
 					oportpos = oni->temp1;
@@ -541,10 +557,12 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 						/* see if there are already wires going in this direction */
 						if (x0 == wantx1 && y0 == wanty1) desiredangle = -1; else
 							desiredangle = figureangle(x0, y0, wantx1, wanty1);
+						net0 = NONETWORK;
 						for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 						{
 							if (pi->proto != pp) continue;
 							oai = pi->conarcinst;
+							net0 = oai->network;
 							if (desiredangle < 0)
 							{
 								if (oai->end[0].xpos == oai->end[1].xpos &&
@@ -563,10 +581,12 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 
 						if (x0 == wantx1 && y0 == wanty1) desiredangle = -1; else
 							desiredangle = figureangle(wantx1, wanty1, x0, y0);
+						net1 = NONETWORK;
 						for(pi = oni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 						{
 							if (pi->proto != opp) continue;
 							oai = pi->conarcinst;
+							net1 = oai->network;
 							if (desiredangle < 0)
 							{
 								if (oai->end[0].xpos == oai->end[1].xpos &&
@@ -583,6 +603,9 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 						}
 						if (pi != NOPORTARCINST) situation |= LIKELYARCSSAMEDIR;
 
+						/* if there is a network that already connects these, ignore */
+						if (net1 == net0 && net0 != NONETWORK) continue;
+
 						if (pp != port0 || opp != port1)
 							situation |= LIKELYDIFFPORT;
 						con2 = 0;
@@ -689,10 +712,10 @@ INTBIG ro_mimicthis(NODEINST *oni1, PORTPROTO *opp1, INTBIG ox1, INTBIG oy1,
 				{
 					dist = el_curlib->lambda[el_curtech->techindex];
 					(void)asktool(us_tool, x_("show-area"), pa->x1-dist, pa->x1+dist, pa->y1-dist, pa->y1+dist,
-						(INTBIG)facet);
+						(INTBIG)cell);
 				} else
 				{
-					(void)asktool(us_tool, x_("show-line"), pa->x1, pa->y1, pa->x2, pa->y2, (INTBIG)facet);
+					(void)asktool(us_tool, x_("show-line"), pa->x1, pa->y1, pa->x2, pa->y2, (INTBIG)cell);
 				}
 			}
 			esnprintf(question, 200, _("Create %ld %s shown here?"),
