@@ -35,7 +35,7 @@
  *
  *
  *                       p1        p2         p3      p4
- *                        |        |           |       |  /\ facet_off2
+ *                        |        |           |       |  /\ cell_off2
  *                       _|        |           |   ____|  \/
  *                      |          |           |  |
  *                    __|    ______|           |  |
@@ -43,7 +43,7 @@
  *                   |   ___|      ____________|  |
  *                   |  |         | /\ pitch      |
  *                 __|  |      ___| \/____________|
- *  facet_off1/\  |     |     |    <>|
+ *  cell_off1 /\  |     |     |    <>|
  *            \/  |     |     |      |
  *               a1    a2    a3     a4
  *
@@ -158,11 +158,11 @@ typedef struct coord
 
 typedef struct
 {
-	NODEINST  *topfacet;
-	BOOLEAN    facetvalid;
-} MOVEFACET;
+	NODEINST  *topcell;
+	BOOLEAN    cellvalid;
+} MOVECELL;
 
-static MOVEFACET ro_rrmovefacet;
+static MOVECELL ro_rrmovecell;
 
 typedef struct
 {
@@ -217,7 +217,7 @@ static INTBIG ro_rrbx, ro_rrby, ro_rrex, ro_rrey;
 static KEYWORD ro_riveropt[] =
 {
 	{x_("route"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{x_("move-facet"), 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	{x_("move-cell"),  0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{x_("abort"),      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
@@ -260,7 +260,7 @@ static void ro_calculate_bb(INTBIG*, INTBIG*, INTBIG*, INTBIG*, RDESC*, RDESC*);
 static BOOLEAN ro_sorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static RDESC *ro_quicksort(RDESC*);
 static BOOLEAN ro_unsorted_rivrot(ARCPROTO*, RDESC*, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
-static void ro_checkthefacet(NODEINST*);
+static void ro_checkthecell(NODEINST*);
 static void ro_pseudomake(RDESC*, NODEPROTO*);
 static void ro_makepseudogeometry(NODEPROTO*);
 static NODEINST *ro_thenode(RDESC*, NODEPROTO*, RPOINT*, NODEPROTO*);
@@ -419,7 +419,7 @@ void ro_initialize(void)
 	}
 	for(c = ro_rrinfo.xaxis; c; c = c->next) c->total = -1;
 	for(c = ro_rrinfo.yaxis; c; c = c->next) c->total = -1;
-	ro_rrmovefacet.topfacet = NONODEINST;   ro_rrmovefacet.facetvalid = TRUE;
+	ro_rrmovecell.topcell = NONODEINST;   ro_rrmovecell.cellvalid = TRUE;
 }
 
 void ro_freerivermemory(void)
@@ -1076,19 +1076,19 @@ void ro_calculate_bb(INTBIG *llx, INTBIG *lly, INTBIG *urx, INTBIG *ury, RDESC *
  * warning - if the width is not even, there will be round off problems
  */
 BOOLEAN ro_sorted_rivrot(ARCPROTO *layerdesc, RDESC *listr, INTBIG width,
-	INTBIG space, INTBIG facetoff1, INTBIG facetoff2, INTBIG fixedheight)
+	INTBIG space, INTBIG celloff1, INTBIG celloff2, INTBIG fixedheight)
 {
 	INTBIG height;
 
 	/* ports invalid */
 	if (!ro_check_points(listr, width, space)) return(FALSE);
 	ro_structure_points(listr);				/* put in left/right */
-	if (!ro_check_structured_points(ro_rrinfo.rightp, ro_rrinfo.leftp, facetoff1, width, space))
+	if (!ro_check_structured_points(ro_rrinfo.rightp, ro_rrinfo.leftp, celloff1, width, space))
 		return(FALSE);
-	if (ro_process_right(width, layerdesc, ro_rrinfo.rightp, facetoff1, space, -1)) return(FALSE);
-	if (ro_process_left(width, layerdesc, ro_rrinfo.leftp, facetoff1, space, 1)) return(FALSE);
+	if (ro_process_right(width, layerdesc, ro_rrinfo.rightp, celloff1, space, -1)) return(FALSE);
+	if (ro_process_left(width, layerdesc, ro_rrinfo.leftp, celloff1, space, 1)) return(FALSE);
 	if (fixedheight != 0) fixedheight = ro_height_coordinate(fixedheight);
-	if (!ro_calculate_height_and_process(ro_rrinfo.rightp, ro_rrinfo.leftp, width, facetoff2,
+	if (!ro_calculate_height_and_process(ro_rrinfo.rightp, ro_rrinfo.leftp, width, celloff2,
 		fixedheight, &height)) return(FALSE);
 	if (fixedheight > 0 && height > fixedheight)
 	{
@@ -1147,28 +1147,28 @@ RDESC *ro_quicksort(RDESC *rd)
  * warning - if the width is not even, there will be round off problems
  */
 BOOLEAN ro_unsorted_rivrot(ARCPROTO *layerdesc, RDESC *lists, INTBIG width,
-	INTBIG space, INTBIG facetoff1, INTBIG facetoff2, INTBIG fixedheight)
+	INTBIG space, INTBIG celloff1, INTBIG celloff2, INTBIG fixedheight)
 {
 	return(ro_sorted_rivrot(layerdesc, ro_quicksort(lists), width, space,
-		facetoff1, facetoff2, fixedheight));
+		celloff1, celloff2, fixedheight));
 }
 
 /*
- * once the route occurs, make some geometry and move some facets around
+ * once the route occurs, make some geometry and move some cells around
  */
-void ro_checkthefacet(NODEINST *ni)
+void ro_checkthecell(NODEINST *ni)
 {
 	if (ni->proto->primindex == 0)
 	{
 		/* the node is nonprimitive */
-		if (!ro_rrmovefacet.facetvalid) return;
-		if (ro_rrmovefacet.topfacet == NONODEINST)  /* first one */
-			ro_rrmovefacet.topfacet = ni;
-		else if (ro_rrmovefacet.topfacet != ni) ro_rrmovefacet.facetvalid = FALSE;
+		if (!ro_rrmovecell.cellvalid) return;
+		if (ro_rrmovecell.topcell == NONODEINST)  /* first one */
+			ro_rrmovecell.topcell = ni;
+		else if (ro_rrmovecell.topcell != ni) ro_rrmovecell.cellvalid = FALSE;
 	}
 }
 
-void ro_pseudomake(RDESC *rd, NODEPROTO *facet)
+void ro_pseudomake(RDESC *rd, NODEPROTO *cell)
 {
 	RPATH *path;
 	REGISTER RPOINT *rp, *prev;
@@ -1183,30 +1183,30 @@ void ro_pseudomake(RDESC *rd, NODEPROTO *facet)
 			if (prev->x == rp->x && rp->x == rp->next->x) continue;
 			if (prev->y == rp->y && rp->y == rp->next->y) continue;
 		}
-		(void)asktool(us_tool, x_("show-line"), prev->x, prev->y, rp->x, rp->y, facet);
+		(void)asktool(us_tool, x_("show-line"), prev->x, prev->y, rp->x, rp->y, cell);
 		prev = rp;
 	}
-	ro_checkthefacet(rd->unroutedwire2->end[rd->unroutedend2].nodeinst);
+	ro_checkthecell(rd->unroutedwire2->end[rd->unroutedend2].nodeinst);
 }
 
 /*
  * draw lines on the screen denoting what the route would look
  * like if it was done
  */
-void ro_makepseudogeometry(NODEPROTO *facet)
+void ro_makepseudogeometry(NODEPROTO *cell)
 {
 	RDESC *q;
 	INTBIG lambda;
 
-	lambda = lambdaoffacet(facet);
+	lambda = lambdaofcell(cell);
 	ttyputmsg(_("Routing bounds %s <= X <= %s   %s <= Y <= %s"), latoa(ro_rrinfo.llx, lambda),
 		latoa(ro_rrinfo.urx, lambda), latoa(ro_rrinfo.lly, lambda), latoa(ro_rrinfo.ury, lambda));
 
 	/* remove highlighting */
 	(void)asktool(us_tool, x_("clear"));
 
-	for(q = ro_rrinfo.rightp; q != NULLRDESC; q = q->next) ro_pseudomake(q, facet);
-	for(q = ro_rrinfo.leftp; q != NULLRDESC; q = q->next) ro_pseudomake(q, facet);
+	for(q = ro_rrinfo.rightp; q != NULLRDESC; q = q->next) ro_pseudomake(q, cell);
+	for(q = ro_rrinfo.leftp; q != NULLRDESC; q = q->next) ro_pseudomake(q, cell);
 }
 
 NODEINST *ro_thenode(RDESC *rd, NODEPROTO *dn, RPOINT *p, NODEPROTO *np)
@@ -1373,7 +1373,7 @@ BOOLEAN ro_delnodeinst(NODEINST *ni)
 		if (pi->conarcinst != NOARCINST) return(FALSE);
 	}
 
-	/* see if this nodeinst is a portinst of the facet */
+	/* see if this nodeinst is a portinst of the cell */
 	if (ni->firstportexpinst != NOPORTEXPINST) return(FALSE);
 
 	/* now erase the nodeinst */
@@ -1676,7 +1676,7 @@ RDESC *ro_findhighlightedwires(NODEPROTO *np, INTBIG *tot)
 	(void)asktool(us_tool, x_("get-highlighted-area"), (INTBIG)&ro_rrinfo.llx,
 		(INTBIG)&ro_rrinfo.urx, (INTBIG)&ro_rrinfo.lly, (INTBIG)&ro_rrinfo.ury);
 
-	/* reset flags on all arcs in this facet */
+	/* reset flags on all arcs in this cell */
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst) ai->temp1 = 0;
 
 	thelist = NULLRDESC;
@@ -1809,7 +1809,7 @@ BOOLEAN ro_findwires(NODEPROTO *np)
 	ai->length = 10000;
 	(void)arcpolys(ai, NOWINDOWPART);
 	shapearcpoly(ai, 0, poly);
-	amt = drcmindistance(ai->proto->tech, np->cell->lib, poly->layer, ai->width,
+	amt = drcmindistance(ai->proto->tech, np->lib, poly->layer, ai->width,
 		poly->layer, ai->width, FALSE, FALSE, &edge, 0);
 	if (amt < 0) amt = lambdaofarc(ai);
 	return(ro_unsorted_rivrot(wantap, thelist, ai->width, amt, amt, amt, 0));
@@ -1820,10 +1820,10 @@ BOOLEAN ro_move_instance(void)
 	INTBIG lx, ly;
 	NODEINST *ni;
 
-	ni = ro_rrmovefacet.topfacet;
-	if (!ro_rrmovefacet.facetvalid || ni == NONODEINST)
+	ni = ro_rrmovecell.topcell;
+	if (!ro_rrmovecell.cellvalid || ni == NONODEINST)
 	{
-		ttyputmsg(_("River router: Cannot determine facet to move"));
+		ttyputmsg(_("River router: Cannot determine cell to move"));
 		return(FALSE);
 	}
 
@@ -1870,12 +1870,12 @@ BOOLEAN ro_river(NODEPROTO *np)
 		{
 			/* make wires */
 			for(q = ro_rrinfo.rightp; q != NULLRDESC; q = q->next)
-				ro_checkthefacet(q->unroutedwire2->end[q->unroutedend2].nodeinst);
+				ro_checkthecell(q->unroutedwire2->end[q->unroutedend2].nodeinst);
 			for(q = ro_rrinfo.leftp; q != NULLRDESC; q = q->next)
-				ro_checkthefacet(q->unroutedwire2->end[q->unroutedend2].nodeinst);
+				ro_checkthecell(q->unroutedwire2->end[q->unroutedend2].nodeinst);
 
 			/* if there is motion to be done, do it */
-			if (ro_rrmovefacet.facetvalid && ro_rrmovefacet.topfacet != NONODEINST)
+			if (ro_rrmovecell.cellvalid && ro_rrmovecell.topcell != NONODEINST)
 			{
 				if (ro_move_instance()) ro_makethegeometry(np); else
 					valid_route = FALSE;
