@@ -271,8 +271,8 @@ int Sc_parse(int count, CHAR *pars[])
 Module:  Sc_compile
 ------------------------------------------------------------------------
 Description:
-	Read the netlist associated with the current facet (either on disk or
-	in the Netlist view of this facet).
+	Read the netlist associated with the current cell (either on disk or
+	in the Netlist view of this cell).
 ------------------------------------------------------------------------
 */
 
@@ -286,10 +286,10 @@ int Sc_compile(int count, CHAR *pars[])
 	Q_UNUSED( pars );
 
 	/* demand a QUISC netlist */
-	np = getcurfacet();
+	np = getcurcell();
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("No current facet"));
+		ttyputerr(_("No current cell"));
 		return(SC_NOERROR);
 	}
 
@@ -425,7 +425,7 @@ int Sc_show(int count, CHAR *pars[])
 			}
 			if (cells == NULL)
 			{
-				if ((leafcell = Sc_find_leaf_facet(sptr)) == NULL)
+				if ((leafcell = Sc_find_leaf_cell(sptr)) == NULL)
 					return(Sc_seterrmsg(SC_CELLNOFIND, sptr));
 			}
 		}
@@ -520,11 +520,11 @@ int Sc_show(int count, CHAR *pars[])
 
 	if (namesamen(sptr, x_("leaf-cell-numbers"), l) == 0)
 	{
-		if ((leafcell = Sc_find_leaf_facet(pars[1])) == NULL)
+		if ((leafcell = Sc_find_leaf_cell(pars[1])) == NULL)
 		{
 			return(Sc_seterrmsg(SC_CELLNOFIND, pars[1]));
 		}
-		Sc_leaf_facet_get_nums(leafcell, &cnums);
+		Sc_leaf_cell_get_nums(leafcell, &cnums);
 		ttyputmsg(x_("****************************************"));
 		ttyputmsg(M_("**      LEAF CELL MAGIC NUMBERS       **"));
 		ttyputmsg(x_("****************************************"));
@@ -668,7 +668,7 @@ void Sc_nitreelist(SCNITREE *ntp, int all_flag)
 			type = ((SCCELL *)(ntp->np))->name;
 			break;
 		case SCLEAFCELL:
-			type = Sc_leaf_facet_name(ntp->np);
+			type = Sc_leaf_cell_name(ntp->np);
 			break;
 		default:
 			break;
@@ -735,9 +735,9 @@ int Sc_xset(int count, CHAR *pars[])
 	l = maxi(estrlen(pars[0]), 1);
 	if (namesamen(x_("leaf-cell-numbers"), pars[0], l) == 0)
 	{
-		if ((leafcell = Sc_find_leaf_facet(pars[1])) == NULL)
+		if ((leafcell = Sc_find_leaf_cell(pars[1])) == NULL)
 			return(Sc_seterrmsg(SC_NPNOTFIND, pars[1]));
-		Sc_leaf_facet_get_nums(leafcell, &cnums);
+		Sc_leaf_cell_get_nums(leafcell, &cnums);
 		numpar = 2;
 		while (numpar < count)
 		{
@@ -771,7 +771,7 @@ int Sc_xset(int count, CHAR *pars[])
 			}
 			return(Sc_seterrmsg(SC_SET_CNUMS_XOPT, pars[numpar]));
 		}
-		if ((err = Sc_leaf_facet_set_nums(leafcell, &cnums)))
+		if ((err = Sc_leaf_cell_set_nums(leafcell, &cnums)))
 			return(err);
 		return(SC_NOERROR);
 	}
@@ -825,7 +825,7 @@ int Sc_xset(int count, CHAR *pars[])
 		}
 		if (cell == NULL)
 		{
-			if ((leafcell = Sc_find_leaf_facet(pars[1])) == NULL)
+			if ((leafcell = Sc_find_leaf_cell(pars[1])) == NULL)
 				return(Sc_seterrmsg(SC_NPNOTFIND, pars[1]));
 			if ((leafport = Sc_find_leaf_port(leafcell, pars[2])) == NULL)
 				return(Sc_seterrmsg(SC_PPNOTFIND, pars[2], pars[1]));
@@ -924,7 +924,7 @@ int Sc_order(int count, CHAR *pars[])
 		return(Sc_seterrmsg(SC_ORDERNPARS));
 
 	/* search for leaf cell */
-	if ((leafcell = Sc_find_leaf_facet(pars[0])) == NULL)
+	if ((leafcell = Sc_find_leaf_cell(pars[0])) == NULL)
 		return(Sc_seterrmsg(SC_NPNOTFIND, pars[0]));
 
 	/* check if from file or by user */
@@ -1126,7 +1126,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 			pars[1] = newname;
 			if (subinst->type == SCLEAFCELL)
 			{
-				pars[2] = Sc_leaf_facet_name(subinst->np);
+				pars[2] = Sc_leaf_cell_name(subinst->np);
 			} else
 			{
 				pars[2] = ((SCCELL *)(subinst->np))->name;
