@@ -84,8 +84,8 @@ int Sc_create(int count, CHAR *pars[])
 		}
 
 		/* generate warning message if a leaf cell of the same name exists */
-		if (Sc_find_leaf_facet(sptr))
-			ttyputmsg(_("WARNING - facet %s may be overridden by created cell."),
+		if (Sc_find_leaf_cell(sptr))
+			ttyputmsg(_("WARNING - cell %s may be overridden by created cell."),
 				sptr);
 
 		/* create new cell */
@@ -148,11 +148,11 @@ int Sc_create(int count, CHAR *pars[])
 		if (cell == NULL)
 		{
 			/* search for leaf cell in library */
-			if ((bc = Sc_find_leaf_facet(nodep)) == NULL)
+			if ((bc = Sc_find_leaf_cell(nodep)) == NULL)
 				return(Sc_seterrmsg(SC_CRNODEPROTONF, nodep));
 			type = SCLEAFCELL;
 			proto = bc;
-			size = Sc_leaf_facet_xsize(bc);
+			size = Sc_leaf_cell_xsize(bc);
 		} else
 		{
 			type = SCCOMPLEXCELL;
