@@ -74,14 +74,14 @@ err			int			Returned error code, 0 = no error.
 
 int Sc_delete(void)
 {
-	SCCELL	*cell, *nextcell;
+	SCCELL	*cel, *nextcel;
 	int		err;
 
 	/* free all cells */
-	for (cell = sc_cells; cell; cell = nextcell)
+	for (cel = sc_cells; cel; cel = nextcel)
 	{
-		nextcell = cell->next;
-		err = Sc_free_cell(cell);
+		nextcel = cel->next;
+		err = Sc_free_cell(cel);
 		if (err) return(err);
 	}
 
