@@ -317,23 +317,23 @@ void ScSetParameter(INTBIG paramnum, INTBIG addr)
 */
 
 /***********************************************************************
-Module:  Sc_find_leaf_facet
+Module:  Sc_find_leaf_cell
 ------------------------------------------------------------------------
 Description:
-	Return a pointer to the named leaf facet.  If facet is not found,
+	Return a pointer to the named leaf cell.  If cell is not found,
 	return NULL.
 ------------------------------------------------------------------------
-Calling Sequence:  leaffacet = Sc_find_leaf_facet(name);
+Calling Sequence:  leafcell = Sc_find_leaf_cell(name);
 
 Name		Type		Description
 ----		----		-----------
-name		*char		String name of leaf facet.
-leaffacet	*char		Generic pointer to found facet,
+name		*char		String name of leaf cell.
+leafcell	*char		Generic pointer to found cell,
 								NULL if not found.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_find_leaf_facet(CHAR *name)
+CHAR  *Sc_find_leaf_cell(CHAR *name)
 {
 	NODEPROTO *np, *laynp;
 	REGISTER void *infstr;
@@ -359,46 +359,46 @@ CHAR  *Sc_find_leaf_facet(CHAR *name)
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_name
+Module:  Sc_leaf_cell_name
 ------------------------------------------------------------------------
 Description:
-	Return a pointer to the name of a leaf facet.
+	Return a pointer to the name of a leaf cell.
 ------------------------------------------------------------------------
-Calling Sequence:  leaffacetname = Sc_leaf_facet_name(leaffacet);
+Calling Sequence:  leafcellname = Sc_leaf_cell_name(leafcell);
 
 Name			Type		Description
 ----			----		-----------
-leaffacet		*char		Pointer to the leaf facet.
-leaffacetname	*char		String of leaf facet name.
+leafcell		*char		Pointer to the leaf cell.
+leafcellname	*char		String of leaf cell name.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_leaf_facet_name(CHAR *leaffacet)
+CHAR  *Sc_leaf_cell_name(CHAR *leafcell)
 {
 	NODEPROTO *np;
 
-	np = (NODEPROTO *)leaffacet;
-	if (np->primindex != 0) return(np->primname);
-	return(np->cell->cellname);
+	np = (NODEPROTO *)leafcell;
+	if (np->primindex != 0) return(np->protoname);
+	return(np->protoname);
 }
 
 /***********************************************************************
-Module:  Sc_first_leaf_facet
+Module:  Sc_first_leaf_cell
 ------------------------------------------------------------------------
 Description:
-	Return a pointer to the first leaf facet in the current library.
-	Return NULL if error, eg. no library, no leaf facets, etc.
+	Return a pointer to the first leaf cell in the current library.
+	Return NULL if error, eg. no library, no leaf cells, etc.
 ------------------------------------------------------------------------
-Calling Sequence:  leaffacet = Sc_first_leaf_facet();
+Calling Sequence:  leafcell = Sc_first_leaf_cell();
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the first leaf facet, NULL if
-								no leaf facet found.
+leafcell	*char		Pointer to the first leaf cell, NULL if
+								no leaf cell found.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_first_leaf_facet(void)
+CHAR  *Sc_first_leaf_cell(void)
 {
 	if (el_curlib == NOLIBRARY) return((CHAR *)NULL);
 	if (el_curlib->firstnodeproto == NONODEPROTO) return((CHAR *)NULL);
@@ -406,53 +406,53 @@ CHAR  *Sc_first_leaf_facet(void)
 }
 
 /***********************************************************************
-Module:  Sc_next_leaf_facet
+Module:  Sc_next_leaf_cell
 ------------------------------------------------------------------------
 Description:
-	Return a pointer to the next leaf facet in the current library.
+	Return a pointer to the next leaf cell in the current library.
 	Return NULL when end of list is reached.
 ------------------------------------------------------------------------
-Calling Sequence:  nextleaffacet = Sc_next_leaf_facet(leaffacet);
+Calling Sequence:  nextleafcell = Sc_next_leaf_cell(leafcell);
 
 Name			Type		Description
 ----			----		-----------
-leaffacet		*char		Pointer to the current leaf facet.
-nextleaffacet	*char		Returned pointer to next leaf facet.
+leafcell		*char		Pointer to the current leaf cell.
+nextleafcell	*char		Returned pointer to next leaf cell.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_next_leaf_facet(CHAR *leaffacet)
+CHAR  *Sc_next_leaf_cell(CHAR *leafcell)
 {
-	if (((NODEPROTO *)leaffacet)->nextnodeproto == NONODEPROTO)
+	if (((NODEPROTO *)leafcell)->nextnodeproto == NONODEPROTO)
 		return((CHAR *)NULL);
-	return((CHAR *)(((NODEPROTO *)leaffacet)->nextnodeproto));
+	return((CHAR *)(((NODEPROTO *)leafcell)->nextnodeproto));
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_bits
+Module:  Sc_leaf_cell_bits
 ------------------------------------------------------------------------
 Description:
-	Return the value of the bits field of the leaf facet for the
+	Return the value of the bits field of the leaf cell for the
 	Silicon Compiler.
 ------------------------------------------------------------------------
-Calling Sequence:  bits = Sc_leaf_facet_bits(leaffacet);
+Calling Sequence:  bits = Sc_leaf_cell_bits(leafcell);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the leaf facet.
+leafcell	*char		Pointer to the leaf cell.
 bits		int			Value of the SC bit field.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_bits(CHAR *leaffacet)
+int Sc_leaf_cell_bits(CHAR *leafcell)
 {
 	VARIABLE	*var;
 
 	/* check if variable exits */
-	if ((var = getvalkey((INTBIG)leaffacet, VNODEPROTO, VINTEGER, sc_bitskey))
+	if ((var = getvalkey((INTBIG)leafcell, VNODEPROTO, VINTEGER, sc_bitskey))
 		== NOVARIABLE)
 	{
-		if (setvalkey((INTBIG)leaffacet, VNODEPROTO, sc_bitskey, 0, VINTEGER) ==
+		if (setvalkey((INTBIG)leafcell, VNODEPROTO, sc_bitskey, 0, VINTEGER) ==
 			NOVARIABLE) ttyputmsg(_("ERROR creating SCBITS variable."));
 		return(0);
 	}
@@ -460,33 +460,33 @@ int Sc_leaf_facet_bits(CHAR *leaffacet)
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_bits_address
+Module:  Sc_leaf_cell_bits_address
 ------------------------------------------------------------------------
 Description:
-	Return the address of the bits field of the leaf facet for the
+	Return the address of the bits field of the leaf cell for the
 	Silicon Compiler.
 ------------------------------------------------------------------------
-Calling Sequence:  bits_addr = Sc_leaf_facet_bits_address(leaffacet);
+Calling Sequence:  bits_addr = Sc_leaf_cell_bits_address(leafcell);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the leaf facet.
+leafcell	*char		Pointer to the leaf cell.
 bits_addr	*int		Address of the SC bits field.
 ------------------------------------------------------------------------
 */
 
-int  *Sc_leaf_facet_bits_address(CHAR *leaffacet)
+int  *Sc_leaf_cell_bits_address(CHAR *leafcell)
 {
 	VARIABLE	*var;
 	static int retval;
 
 	/* check if variable exits */
-	if ((var = getvalkey((INTBIG)leaffacet, VNODEPROTO, VINTEGER, sc_bitskey))
+	if ((var = getvalkey((INTBIG)leafcell, VNODEPROTO, VINTEGER, sc_bitskey))
 		== NOVARIABLE)
 	{
-		if (setvalkey((INTBIG)leaffacet, VNODEPROTO, sc_bitskey, 0, VINTEGER) ==
+		if (setvalkey((INTBIG)leafcell, VNODEPROTO, sc_bitskey, 0, VINTEGER) ==
 			NOVARIABLE) ttyputmsg(_("ERROR creating SCBITS variable."));
-		if ((var = getvalkey((INTBIG)leaffacet, VNODEPROTO, VINTEGER,
+		if ((var = getvalkey((INTBIG)leafcell, VNODEPROTO, VINTEGER,
 			sc_bitskey)) == NOVARIABLE)
 		{
 			ttyputmsg(_("ERROR creating SCBITS variable."));
@@ -498,64 +498,64 @@ int  *Sc_leaf_facet_bits_address(CHAR *leaffacet)
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_xsize
+Module:  Sc_leaf_cell_xsize
 ------------------------------------------------------------------------
 Description:
-	Return the size in the x direction for the indicated leaf facet.
+	Return the size in the x direction for the indicated leaf cell.
 ------------------------------------------------------------------------
-Calling Sequence:  xsize = Sc_leaf_facet_xsize(leaffacet);
+Calling Sequence:  xsize = Sc_leaf_cell_xsize(leafcell);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the leaf facet.
+leafcell	*char		Pointer to the leaf cell.
 xsize		int			Returned size in x direction.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_xsize(CHAR *leaffacet)
+int Sc_leaf_cell_xsize(CHAR *leafcell)
 {
-	return(((NODEPROTO *)leaffacet)->highx - ((NODEPROTO *)leaffacet)->lowx);
+	return(((NODEPROTO *)leafcell)->highx - ((NODEPROTO *)leafcell)->lowx);
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_ysize
+Module:  Sc_leaf_cell_ysize
 ------------------------------------------------------------------------
 Description:
-	Return the size in the y direction for the indicated leaf facet.
+	Return the size in the y direction for the indicated leaf cell.
 ------------------------------------------------------------------------
-Calling Sequence:  xsize = Sc_leaf_facet_ysize(leaffacet);
+Calling Sequence:  xsize = Sc_leaf_cell_ysize(leafcell);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the leaf facet.
+leafcell	*char		Pointer to the leaf cell.
 xsize		int			Returned size in y direction.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_ysize(CHAR *leaffacet)
+int Sc_leaf_cell_ysize(CHAR *leafcell)
 {
-	return(((NODEPROTO *)leaffacet)->highy - ((NODEPROTO *)leaffacet)->lowy);
+	return(((NODEPROTO *)leafcell)->highy - ((NODEPROTO *)leafcell)->lowy);
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_sim_info
+Module:  Sc_leaf_cell_sim_info
 ------------------------------------------------------------------------
 Description:
-	Return an array of pointers to strings for the leaf facet's
+	Return an array of pointers to strings for the leaf cell's
 	simulation information.  Return NULL on error.  Note that the
 	array should be terminated by a NULL.
 ------------------------------------------------------------------------
-Calling Sequence:  simlist = Sc_leaf_facet_sim_info(leaffacet);
+Calling Sequence:  simlist = Sc_leaf_cell_sim_info(leafcell);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the leaf facet.
+leafcell	*char		Pointer to the leaf cell.
 simlist		**char		Array of pointers to simulation info,
 								NULL on error.
 ------------------------------------------------------------------------
 */
 
-CHAR  **Sc_leaf_facet_sim_info(CHAR *leaffacet)
+CHAR  **Sc_leaf_cell_sim_info(CHAR *leafcell)
 {
 	VARIABLE	*simvar;
 	CHAR	**simlist, **simlist2;
@@ -565,7 +565,7 @@ CHAR  **Sc_leaf_facet_sim_info(CHAR *leaffacet)
 		use_key = sc_simkey;
 	else if (sc_sim_format == SC_SILOS_FORMAT)
 		use_key = sc_silkey;
-	if ((simvar = getvalkey((INTBIG)leaffacet, VNODEPROTO, VSTRING | VISARRAY,
+	if ((simvar = getvalkey((INTBIG)leafcell, VNODEPROTO, VSTRING | VISARRAY,
 		use_key)) == NOVARIABLE) return((CHAR **)NULL);
 	simlist2 = (CHAR **)simvar->addr;
 
@@ -582,22 +582,22 @@ CHAR  **Sc_leaf_facet_sim_info(CHAR *leaffacet)
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_set_sim
+Module:  Sc_leaf_cell_set_sim
 ------------------------------------------------------------------------
 Description:
-	Set the passed simulation information to the indicated leaf facet.
+	Set the passed simulation information to the indicated leaf cell.
 ------------------------------------------------------------------------
-Calling Sequence:  err = Sc_leaf_facet_set_sim(simline, leaffacet);
+Calling Sequence:  err = Sc_leaf_cell_set_sim(simline, leafcell);
 
 Name		Type		Description
 ----		----		-----------
 simline		*SCSIM		Lines of simulation information.
-leaffacet	*char		Pointer to the leaf facet.
+leafcell	*char		Pointer to the leaf cell.
 err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_set_sim(SCSIM *simline, CHAR *leaffacet)
+int Sc_leaf_cell_set_sim(SCSIM *simline, CHAR *leafcell)
 {
 	CHAR	**simlist;
 	SCSIM	*nextsim;
@@ -622,27 +622,27 @@ int Sc_leaf_facet_set_sim(SCSIM *simline, CHAR *leaffacet)
 	simlist[numsim] = NOSTRING;
 
 	/* set variable */
-	if (setvalkey((INTBIG)leaffacet, VNODEPROTO, use_key, (INTBIG)simlist,
+	if (setvalkey((INTBIG)leafcell, VNODEPROTO, use_key, (INTBIG)simlist,
 		VSTRING | VISARRAY) == NOVARIABLE) return(Sc_seterrmsg(SC_SIMXSETVAL));
 	return(0);
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_get_nums
+Module:  Sc_leaf_cell_get_nums
 ------------------------------------------------------------------------
 Description:
-	Fill in the facet_nums structure for the indicated leaf facet.
+	Fill in the cell_nums structure for the indicated leaf cell.
 ------------------------------------------------------------------------
-Calling Sequence:  Sc_leaf_facet_get_nums(leaffacet, nums);
+Calling Sequence:  Sc_leaf_cell_get_nums(leafcell, nums);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the leaf facet.
+leafcell	*char		Pointer to the leaf cell.
 nums		*SCCELLNUMS	Address of structure to fill.
 ------------------------------------------------------------------------
 */
 
-void Sc_leaf_facet_get_nums(CHAR *leaffacet, SCCELLNUMS *nums)
+void Sc_leaf_cell_get_nums(CHAR *leafcell, SCCELLNUMS *nums)
 {
 	VARIABLE	*var;
 	int		i, j, *iarray, *jarray;
@@ -650,7 +650,7 @@ void Sc_leaf_facet_get_nums(CHAR *leaffacet, SCCELLNUMS *nums)
 	i = sizeof(SCCELLNUMS) / sizeof(int);
 
 	/* check if variable exits */
-	var = getvalkey((INTBIG)leaffacet, VNODEPROTO, VINTEGER|VISARRAY, sc_numskey);
+	var = getvalkey((INTBIG)leafcell, VNODEPROTO, VINTEGER|VISARRAY, sc_numskey);
 	if (var == NOVARIABLE)
 	{
 		iarray = (int *)nums;
@@ -664,22 +664,22 @@ void Sc_leaf_facet_get_nums(CHAR *leaffacet, SCCELLNUMS *nums)
 }
 
 /***********************************************************************
-Module:  Sc_leaf_facet_set_nums
+Module:  Sc_leaf_cell_set_nums
 ------------------------------------------------------------------------
 Description:
-	Set the facet_nums variable for the indicated leaf facet.
+	Set the cell_nums variable for the indicated leaf cell.
 ------------------------------------------------------------------------
-Calling Sequence:  err = Sc_leaf_facet_set_nums(leaffacet, nums);
+Calling Sequence:  err = Sc_leaf_cell_set_nums(leafcell, nums);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to the leaf facet.
-nums		*SCCELLNUMS	Pointer to facet nums structure.
+leafcell	*char		Pointer to the leaf cell.
+nums		*SCCELLNUMS	Pointer to cell nums structure.
 err			int			Returned error code, 0 = no error.
 ------------------------------------------------------------------------
 */
 
-int Sc_leaf_facet_set_nums(CHAR *leaffacet, SCCELLNUMS *nums)
+int Sc_leaf_cell_set_nums(CHAR *leafcell, SCCELLNUMS *nums)
 {
 	VARIABLE	*var;
 	int		i, j, *iarray;
@@ -688,7 +688,7 @@ int Sc_leaf_facet_set_nums(CHAR *leaffacet, SCCELLNUMS *nums)
 	i = sizeof(SCCELLNUMS) / sizeof(int);
 
 	/* check if variable exits */
-	var = getvalkey((INTBIG)leaffacet, VNODEPROTO, VINTEGER|VISARRAY, sc_numskey);
+	var = getvalkey((INTBIG)leafcell, VNODEPROTO, VINTEGER|VISARRAY, sc_numskey);
 	if (var == NOVARIABLE)
 	{
 		if ((jarray = emalloc((i + 1) * sizeof(INTBIG), sc_tool->cluster)) == 0)
@@ -696,7 +696,7 @@ int Sc_leaf_facet_set_nums(CHAR *leaffacet, SCCELLNUMS *nums)
 		iarray = (int *)nums;
 		for (j = 0; j < i; j++) jarray[j] = iarray[j];
 		jarray[j] = -1;
-		if (setvalkey((INTBIG)leaffacet, VNODEPROTO, sc_numskey, (INTBIG)jarray,
+		if (setvalkey((INTBIG)leafcell, VNODEPROTO, sc_numskey, (INTBIG)jarray,
 			VINTEGER | VISARRAY) == NOVARIABLE)
 				return(Sc_seterrmsg(SC_NOSET_CELL_NUMS));
 		return(SC_NOERROR);
@@ -711,25 +711,25 @@ int Sc_leaf_facet_set_nums(CHAR *leaffacet, SCCELLNUMS *nums)
 Module:  Sc_find_leaf_port
 ------------------------------------------------------------------------
 Description:
-	Return a pointer to the named port on the facet.  If no port found,
+	Return a pointer to the named port on the cell.  If no port found,
 	return NULL.
 ------------------------------------------------------------------------
-Calling Sequence:  leafport = Sc_find_leaf_port(leaffacet, portname);
+Calling Sequence:  leafport = Sc_find_leaf_port(leafcell, portname);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to leaf facet.
+leafcell	*char		Pointer to leaf cell.
 portname	*char		String name of port.
 leafport	*char		Generic pointer to first port,
 								NULL if not found.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_find_leaf_port(CHAR *leaffacet, CHAR *portname)
+CHAR  *Sc_find_leaf_port(CHAR *leafcell, CHAR *portname)
 {
 	PORTPROTO	*pp;
 
-	for (pp = ((NODEPROTO *)leaffacet)->firstportproto; pp != NOPORTPROTO;
+	for (pp = ((NODEPROTO *)leafcell)->firstportproto; pp != NOPORTPROTO;
 		pp = pp->nextportproto)
 	{
 		if (namesame(pp->protoname, portname) == 0)
@@ -762,24 +762,24 @@ CHAR  *Sc_leaf_port_name(CHAR *leafport)
 Module:  Sc_first_leaf_port
 ------------------------------------------------------------------------
 Description:
-	Return a pointer to the first port of the facet.  If no ports,
+	Return a pointer to the first port of the cell.  If no ports,
 	return NULL.
 ------------------------------------------------------------------------
-Calling Sequence:  leafport = Sc_first_leaf_port(leaffacet);
+Calling Sequence:  leafport = Sc_first_leaf_port(leafcell);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to leaf facet.
+leafcell	*char		Pointer to leaf cell.
 leafport	*char		Generic pointer to first port,
 								NULL if not found.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_first_leaf_port(CHAR *leaffacet)
+CHAR  *Sc_first_leaf_port(CHAR *leafcell)
 {
 	PORTPROTO	*pp;
 
-	pp = ((NODEPROTO *)leaffacet)->firstportproto;
+	pp = ((NODEPROTO *)leafcell)->firstportproto;
 	if (pp == NOPORTPROTO) return((CHAR *)NULL);
 	return((CHAR *)pp);
 }
@@ -788,7 +788,7 @@ CHAR  *Sc_first_leaf_port(CHAR *leaffacet)
 Module:  Sc_next_leaf_port
 ------------------------------------------------------------------------
 Description:
-	Return a pointer to the next port of the facet.  If no ports left,
+	Return a pointer to the next port of the cell.  If no ports left,
 	return NULL.
 ------------------------------------------------------------------------
 Calling Sequence:  nextport = Sc_next_leaf_port(curport);
@@ -986,14 +986,14 @@ Module:  Sc_leaf_port_xpos
 ------------------------------------------------------------------------
 Description:
 	Return the xpos of the indicated leaf port from the left side of
-	it's parent leaf facet.
+	it's parent leaf cell.
 ------------------------------------------------------------------------
 Calling Sequence:  xpos = Sc_leaf_port_xpos(port);
 
 Name		Type		Description
 ----		----		-----------
 port		*char		Pointer to leaf port.
-xpos		int			Returned position from left side of facet.
+xpos		int			Returned position from left side of cell.
 ------------------------------------------------------------------------
 */
 
@@ -1015,14 +1015,14 @@ Module:  Sc_leaf_port_ypos
 ------------------------------------------------------------------------
 Description:
 	Return the ypos of the indicated leaf port from the bottom of
-	it's parent leaf facet.
+	it's parent leaf cell.
 ------------------------------------------------------------------------
 Calling Sequence:  ypos = Sc_leaf_port_ypos(port);
 
 Name		Type		Description
 ----		----		-----------
 port		*char		Pointer to leaf port.
-ypos		int			Returned position from bottom of facet.
+ypos		int			Returned position from bottom of cell.
 ------------------------------------------------------------------------
 */
 
@@ -1043,21 +1043,21 @@ int Sc_leaf_port_ypos(CHAR *port)
 Module:  Sc_leaf_port_set_first
 ------------------------------------------------------------------------
 Description:
-	Set the first port of the indicated leaf facet to the indicated
+	Set the first port of the indicated leaf cell to the indicated
 	leaf port.
 ------------------------------------------------------------------------
-Calling Sequence:  Sc_leaf_port_set_first(leaffacet, leafport);
+Calling Sequence:  Sc_leaf_port_set_first(leafcell, leafport);
 
 Name		Type		Description
 ----		----		-----------
-leaffacet	*char		Pointer to leaf facet.
+leafcell	*char		Pointer to leaf cell.
 leafport	*char		Pointer to leaf port.
 ------------------------------------------------------------------------
 */
 
-void Sc_leaf_port_set_first(CHAR *leaffacet, CHAR *leafport)
+void Sc_leaf_port_set_first(CHAR *leafcell, CHAR *leafport)
 {
-	((NODEPROTO *)leaffacet)->firstportproto = (PORTPROTO *)leafport;
+	((NODEPROTO *)leafcell)->firstportproto = (PORTPROTO *)leafport;
 }
 
 /***********************************************************************
@@ -1258,24 +1258,24 @@ int Sc_setup_for_maker(ARCPROTO *layer1, ARCPROTO *layer2)
 }
 
 /***********************************************************************
-Module:  Sc_create_leaf_facet
+Module:  Sc_create_leaf_cell
 ------------------------------------------------------------------------
 Description:
-	Create a new leaf facet of the indicated name in the VLSI Layout Tool
+	Create a new leaf cell of the indicated name in the VLSI Layout Tool
 	Environment.  Return NULL on error.
 ------------------------------------------------------------------------
-Calling Sequence:  bfacet = Sc_create_leaf_facet(name);
+Calling Sequence:  bcell = Sc_create_leaf_cell(name);
 
 Name		Type		Description
 ----		----		-----------
-name		*char		Name of new leaf facet.
-bfacet		*char		Pointer to created leaf facet.
+name		*char		Name of new leaf cell.
+bcell		*char		Pointer to created leaf cell.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_create_leaf_facet(CHAR *name)
+CHAR  *Sc_create_leaf_cell(CHAR *name)
 {
-	NODEPROTO	*bfacet;
+	NODEPROTO	*bcell;
 	CHAR	*view, layoutname[256];
 
 	/*
@@ -1292,9 +1292,9 @@ CHAR  *Sc_create_leaf_facet(CHAR *name)
 		(void) estrcat (layoutname, x_("{lay}"));
 	}
 
-	bfacet = us_newnodeproto(layoutname, el_curlib);
-	if (bfacet == NONODEPROTO) return((CHAR *)NULL);
-	return((CHAR *)bfacet);
+	bcell = us_newnodeproto(layoutname, el_curlib);
+	if (bcell == NONODEPROTO) return((CHAR *)NULL);
+	return((CHAR *)bcell);
 }
 
 /***********************************************************************
@@ -1310,12 +1310,12 @@ Calling Sequence:  binst = Sc_create_leaf_instance(name, type, minx, maxx,
 Name		Type		Description
 ----		----		-----------
 name		*char		Name of new leaf instance.
-type		*char		Pointer to leaf facet type.
+type		*char		Pointer to leaf cell type.
 minx, maxx	int			Bounds in X.
 miny, maxy	int			Bounds in Y.
 transpose	int			Transposition flag (TRUE == transpose).
 rotation	int			Degrees of rotation.
-parent		*char		Facet in which to create instance.
+parent		*char		Cell in which to create instance.
 binst		*char		Pointer to created leaf instance.
 ------------------------------------------------------------------------
 */
@@ -1345,10 +1345,10 @@ CHAR  *Sc_create_leaf_instance(CHAR *name, CHAR *type, int minx, int maxx, int m
 Module:  Sc_create_layer1_node
 ------------------------------------------------------------------------
 Description:
-	Create a node in layer1 in the indicated facet at the given position.
+	Create a node in layer1 in the indicated cell at the given position.
 ------------------------------------------------------------------------
 Calling Sequence:  binst = Sc_create_layer1_node(xpos, ypos, xsize,
-								ysize, bfacet);
+								ysize, bcell);
 
 Name		Type		Description
 ----		----		-----------
@@ -1356,12 +1356,12 @@ xpos		int			Center X position.
 ypos		int			Center Y position.
 xsize		int			Size in X.
 ysize		int			Size in Y.
-bfacet		*char		Facet in which to create feed.
+bcell		*char		Cell in which to create feed.
 binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_create_layer1_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
+CHAR  *Sc_create_layer1_node(int xpos, int ypos, int xsize, int ysize, CHAR *bcell)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1371,7 +1371,7 @@ CHAR  *Sc_create_layer1_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfa
 	lowy = ypos - (ysize >> 1);
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_layer1proto, lowx, highx, lowy, highy, 0, 0,
-		(NODEPROTO *)bfacet);
+		(NODEPROTO *)bcell);
 	if (binst == NONODEINST) return((CHAR *)NULL);
 	return((CHAR *)binst);
 }
@@ -1380,10 +1380,10 @@ CHAR  *Sc_create_layer1_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfa
 Module:  Sc_create_layer2_node
 ------------------------------------------------------------------------
 Description:
-	Create a layer2 node in the indicated facet at the given position.
+	Create a layer2 node in the indicated cell at the given position.
 ------------------------------------------------------------------------
 Calling Sequence:  binst = Sc_create_layer2_node(xpos, ypos, xsize,
-								ysize, bfacet);
+								ysize, bcell);
 
 Name		Type		Description
 ----		----		-----------
@@ -1391,12 +1391,12 @@ xpos		int			Center X position.
 ypos		int			Center Y position.
 xsize		int			Width in X direction.
 ysize		int			Size in Y direction.
-bfacet		*char		Facet in which to create feed.
+bcell		*char		Cell in which to create feed.
 binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_create_layer2_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
+CHAR  *Sc_create_layer2_node(int xpos, int ypos, int xsize, int ysize, CHAR *bcell)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1406,7 +1406,7 @@ CHAR  *Sc_create_layer2_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfa
 	lowy = ypos - (ysize >> 1);
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_layer2proto, lowx, highx, lowy, highy, 0, 0,
-		(NODEPROTO *)bfacet);
+		(NODEPROTO *)bcell);
 	if (binst == NONODEINST) return((CHAR *)NULL);
 	return((CHAR *)binst);
 }
@@ -1415,20 +1415,20 @@ CHAR  *Sc_create_layer2_node(int xpos, int ypos, int xsize, int ysize, CHAR *bfa
 Module:  Sc_create_via
 ------------------------------------------------------------------------
 Description:
-	Create a via in the indicated facet at the given position.
+	Create a via in the indicated cell at the given position.
 ------------------------------------------------------------------------
-Calling Sequence:  binst = Sc_create_via(xpos, ypos, bfacet);
+Calling Sequence:  binst = Sc_create_via(xpos, ypos, bcell);
 
 Name		Type		Description
 ----		----		-----------
 xpos		int			Center X position.
 ypos		int			Center Y position.
-bfacet		*char		Facet in which to create feed.
+bcell		*char		Cell in which to create feed.
 binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_create_via(int xpos, int ypos, CHAR *bfacet)
+CHAR  *Sc_create_via(int xpos, int ypos, CHAR *bcell)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1440,7 +1440,7 @@ CHAR  *Sc_create_via(int xpos, int ypos, CHAR *bfacet)
 	lowy = ypos - pys / 2;
 	highy = lowy + pys;
 	binst = newnodeinst(sc_viaproto, lowx, highx, lowy, highy, 0, 0,
-		(NODEPROTO *)bfacet);
+		(NODEPROTO *)bcell);
 	if (binst == NONODEINST) return((CHAR *)NULL);
 	return((CHAR *)binst);
 }
@@ -1449,9 +1449,9 @@ CHAR  *Sc_create_via(int xpos, int ypos, CHAR *bfacet)
 Module:  Sc_create_pwell
 ------------------------------------------------------------------------
 Description:
-	Create a pwell in the indicated facet at the given position.
+	Create a pwell in the indicated cell at the given position.
 ------------------------------------------------------------------------
-Calling Sequence:  binst = Sc_create_pwell(xpos, ypos, xsize, ysize, bfacet);
+Calling Sequence:  binst = Sc_create_pwell(xpos, ypos, xsize, ysize, bcell);
 
 Name		Type		Description
 ----		----		-----------
@@ -1459,12 +1459,12 @@ xpos		int			Center X position.
 ypos		int			Center Y position.
 xsize		int			Size in X.
 ysize		int			Size in Y.
-bfacet		*char		Facet in which to create feed.
+bcell		*char		Cell in which to create feed.
 binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_create_pwell(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
+CHAR  *Sc_create_pwell(int xpos, int ypos, int xsize, int ysize, CHAR *bcell)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1476,7 +1476,7 @@ CHAR  *Sc_create_pwell(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
 	lowy = ypos - (ysize >> 1);
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_pwellproto, lowx, highx, lowy, highy, 0, 0,
-		(NODEPROTO *)bfacet);
+		(NODEPROTO *)bcell);
 	if (binst == NONODEINST) return((CHAR *)NULL);
 	return((CHAR *)binst);
 }
@@ -1485,10 +1485,10 @@ CHAR  *Sc_create_pwell(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
 Module:  Sc_create_nwell
 ------------------------------------------------------------------------
 Description:
-	Create a nwell in the indicated facet at the given position.
+	Create a nwell in the indicated cell at the given position.
 	Added 2/11/01 David_Harris@hmc.edu
 ------------------------------------------------------------------------
-Calling Sequence:  binst = Sc_create_nwell(xpos, ypos, xsize, ysize, bfacet);
+Calling Sequence:  binst = Sc_create_nwell(xpos, ypos, xsize, ysize, bcell);
 
 Name		Type		Description
 ----		----		-----------
@@ -1496,12 +1496,12 @@ xpos		int			Center X position.
 ypos		int			Center Y position.
 xsize		int			Size in X.
 ysize		int			Size in Y.
-bfacet		*char		Facet in which to create feed.
+bcell		*char		Cell in which to create feed.
 binst		*char		Returned pointer to created instance.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_create_nwell(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
+CHAR  *Sc_create_nwell(int xpos, int ypos, int xsize, int ysize, CHAR *bcell)
 {
 	NODEINST	*binst;
 	int		lowx, highx, lowy, highy;
@@ -1513,7 +1513,7 @@ CHAR  *Sc_create_nwell(int xpos, int ypos, int xsize, int ysize, CHAR *bfacet)
 	lowy = ypos - (ysize >> 1);
 	highy = lowy + ysize;
 	binst = newnodeinst(sc_nwellproto, lowx, highx, lowy, highy, 0, 0,
-		(NODEPROTO *)bfacet);
+		(NODEPROTO *)bcell);
 	if (binst == NONODEINST) return((CHAR *)NULL);
 	return((CHAR *)binst);
 }
@@ -1527,7 +1527,7 @@ Description:
 	and must be determined.
 ------------------------------------------------------------------------
 Calling Sequence:  inst = Sc_create_track_layer1(instA, portA,
-								instB, portB, width, bfacet);
+								instB, portB, width, bcell);
 
 Name		Type		Description
 ----		----		-----------
@@ -1536,13 +1536,13 @@ portA		*char		Pointer to first port.
 instB		*char		Pointer to second instance.
 portB		*char		Pointer to second port.
 width		int			Width of track.
-bfacet		*char		Pointer to facet in which to create.
+bcell		*char		Pointer to cell in which to create.
 inst		*char		Returned pointer to created track.
 ------------------------------------------------------------------------
 */
 
 CHAR  *Sc_create_track_layer1(CHAR *instA, CHAR *portA, CHAR *instB, CHAR *portB,
-	int width, CHAR *bfacet)
+	int width, CHAR *bcell)
 {
 	PORTPROTO *pa, *pb;
 	NODEINST *na, *nb;
@@ -1578,7 +1578,7 @@ CHAR  *Sc_create_track_layer1(CHAR *instA, CHAR *portA, CHAR *instB, CHAR *portB
 	}
 
 	inst = newarcinst(sc_layer1arc, width, FIXANG, na, pa, xA, yA,
-		nb, pb, xB, yB, (NODEPROTO *)bfacet);
+		nb, pb, xB, yB, (NODEPROTO *)bcell);
 	if (inst == NOARCINST) return((CHAR *)NULL);
 	return((CHAR *)inst);
 }
@@ -1592,7 +1592,7 @@ Description:
 	and must be determined.
 ------------------------------------------------------------------------
 Calling Sequence:  inst = Sc_create_track_layer2(instA, portA,
-								instB, portB, width, bfacet);
+								instB, portB, width, bcell);
 
 Name		Type		Description
 ----		----		-----------
@@ -1601,13 +1601,13 @@ portA		*char		Pointer to first port.
 instB		*char		Pointer to second instance.
 portB		*char		Pointer to second port.
 width		int			Width of track.
-bfacet		*char		Pointer to facet in which to create.
+bcell		*char		Pointer to cell in which to create.
 inst		*char		Returned pointer to created track.
 ------------------------------------------------------------------------
 */
 
 CHAR  *Sc_create_track_layer2(CHAR *instA, CHAR *portA, CHAR *instB, CHAR *portB,
-	int width, CHAR *bfacet)
+	int width, CHAR *bcell)
 {
 	PORTPROTO *pa, *pb;
 	NODEINST *na, *nb;
@@ -1643,7 +1643,7 @@ CHAR  *Sc_create_track_layer2(CHAR *instA, CHAR *portA, CHAR *instB, CHAR *portB
 	}
 
 	inst = newarcinst(sc_layer2arc, width, FIXANG, na, pa, xA, yA,
-		nb, pb, xB, yB, (NODEPROTO *)bfacet);
+		nb, pb, xB, yB, (NODEPROTO *)bcell);
 	if (inst == NOARCINST) return((CHAR *)NULL);
 	return((CHAR *)inst);
 }
@@ -1705,7 +1705,7 @@ Description:
 	be determined.
 ------------------------------------------------------------------------
 Calling Sequence:  xport = Sc_create_export_port(inst, port, name,
-								type, bfacet);
+								type, bcell);
 
 Name		Type		Description
 ----		----		-----------
@@ -1713,12 +1713,12 @@ instA		*char		Pointer to instance.
 port		*char		Pointer to port.
 name		*char		Pointer to name.
 type		int			Type of port (eg. input, output, etc.)
-bfacet		*char		Pointer to facet in which to create.
+bcell		*char		Pointer to cell in which to create.
 xport		*char		Returned pointer to created port.
 ------------------------------------------------------------------------
 */
 
-CHAR  *Sc_create_export_port(CHAR *inst, CHAR *port, CHAR *name, int type, CHAR *bfacet)
+CHAR  *Sc_create_export_port(CHAR *inst, CHAR *port, CHAR *name, int type, CHAR *bcell)
 {
 	PORTPROTO	*xport;
 
@@ -1726,7 +1726,7 @@ CHAR  *Sc_create_export_port(CHAR *inst, CHAR *port, CHAR *name, int type, CHAR
 	if ((PORTPROTO *)port == NULL)
 		port = (CHAR *)(((NODEINST *)inst)->proto->firstportproto);
 
-	xport = newportproto((NODEPROTO *)bfacet, (NODEINST *)inst,
+	xport = newportproto((NODEPROTO *)bcell, (NODEINST *)inst,
 		(PORTPROTO *)port, name);
 	if (xport == NOPORTPROTO) return((CHAR *)NULL);
 	Sc_set_leaf_port_type(xport, type);
@@ -1734,7 +1734,7 @@ CHAR  *Sc_create_export_port(CHAR *inst, CHAR *port, CHAR *name, int type, CHAR
 }
 
 /*
- * routine to examine a schematic from the current facet
+ * routine to examine a schematic from the current cell
  */
 void Sc_schematic(void)
 {
