@@ -33,11 +33,11 @@
 #include "global.h"
 #if SCTOOL
 
-char *sc_errmsg;
+CHAR *sc_errmsg;
 
-char *sc_standard_errmsg[] =
+CHAR *sc_standard_errmsg[] =
 {
-	"",																		/* SC_NOERROR */
+	x_(""),																		/* SC_NOERROR */
 	N_("Unknown command '%s'"),												/* SC_UNKNOWN */
 	N_("No keyword for CREATE command"),									/* SC_NCREATE */
 	N_("No name for CREATE CELL command"),									/* SC_NCREATECELL */
