@@ -154,7 +154,7 @@ int Sc_maker(int count, CHAR *pars[])
 		return(err);
 
 	/* create actual layout */
-	ttyputmsg(_("Creating facet %s"), make_data->cell->name);
+	ttyputmsg(_("Creating cell %s"), make_data->cell->name);
 	if ((err = Sc_maker_create_layout(make_data)))
 		return(err);
 
@@ -423,7 +423,7 @@ int Sc_maker_create_info(SCCELL *cell)
 			{
 				num_leaf_cells++;
 				max_height = maxi(max_height,
-					Sc_leaf_facet_ysize(place->cell->np));
+					Sc_leaf_cell_ysize(place->cell->np));
 			} else if (place->cell->type == SCFEEDCELL)
 			{
 				num_feeds++;
@@ -689,8 +689,8 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 		for (place = row->start; place; place = place->next)
 		{
 			if (place->cell->type != SCLEAFCELL) continue;
-			Sc_leaf_facet_get_nums(place->cell->np, &cnums);
-			toffset = maxi(toffset, Sc_leaf_facet_ysize(place->cell->np)
+			Sc_leaf_cell_get_nums(place->cell->np, &cnums);
+			toffset = maxi(toffset, Sc_leaf_cell_ysize(place->cell->np)
 				- cnums.top_active);
 			boffset = mini(boffset, cnums.bottom_active);
 		}
@@ -713,7 +713,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 			minst->xsize = place->cell->size;
 			if (place->cell->type == SCLEAFCELL)
 			{
-				minst->ysize = Sc_leaf_facet_ysize(place->cell->np);
+				minst->ysize = Sc_leaf_cell_ysize(place->cell->np);
 
 				/* add power ports */
 				for (iport = place->cell->power; iport; iport = iport->next)
@@ -1018,7 +1018,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 		ScGetParameter(SC_PARAM_MAKE_MIN_SPACING);
 
 	/* create new cell */
-	if ((bcell = Sc_create_leaf_facet(data->cell->name)) == NULL)
+	if ((bcell = Sc_create_leaf_cell(data->cell->name)) == NULL)
 		return(Sc_seterrmsg(SC_MAKER_NOCREATE_LEAF_CELL, data->cell->name));
 
 	if ((err = Sc_setup_for_maker((ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC),
