@@ -539,7 +539,7 @@ void Sc_place_total_cell_size(SCNITREE *ilist, int *num, int *width, int *height
 		{
 			(*num)++;
 			*width += ilist->size;
-			*height += Sc_leaf_facet_ysize(ilist->np);
+			*height += Sc_leaf_cell_ysize(ilist->np);
 		}
 	}
 	return;
