@@ -135,7 +135,7 @@ int Sc_simset(int count, CHAR *pars[])
 	if (cell == NULL)
 	{
 		/* try to find leaf cell in current library */
-		if ((leafcell = Sc_find_leaf_facet(pars[0])) == NULL)
+		if ((leafcell = Sc_find_leaf_cell(pars[0])) == NULL)
 			return(Sc_seterrmsg(SC_CELLNOFIND, pars[0]));
 		type = SCLEAFCELL;
 	} else
@@ -157,7 +157,7 @@ int Sc_simset(int count, CHAR *pars[])
 	} else
 	{
 		/* write out simulation information for leafcell if it exists */
-		if ((simlist = Sc_leaf_facet_sim_info(leafcell)))
+		if ((simlist = Sc_leaf_cell_sim_info(leafcell)))
 		{
 			if ((fp = xcreate(SCSIMFILE, sc_filetypescsim, _("Simulation File"), 0)) == NULL)
 				return(Sc_seterrmsg(SC_SIMSETFERROR));
@@ -220,7 +220,7 @@ int Sc_simset(int count, CHAR *pars[])
 		cell->siminfo = startline;
 	} else
 	{
-		(void)Sc_leaf_facet_set_sim(startline, leafcell);
+		(void)Sc_leaf_cell_set_sim(startline, leafcell);
 	}
 	return(0);
 }
@@ -257,10 +257,10 @@ int Sc_simshow(int count, CHAR *pars[])
 	}
 	if (cell == NULL)
 	{
-		if ((leafcell = Sc_find_leaf_facet(pars[0])) == NULL)
+		if ((leafcell = Sc_find_leaf_cell(pars[0])) == NULL)
 			return(Sc_seterrmsg(SC_CELLNOFIND, pars[0]));
 		ttyputmsg(_("%s SIMULATION Model for leaf cell %s:"), simhdr, pars[0]);
-		if ((simlist = Sc_leaf_facet_sim_info(leafcell)))
+		if ((simlist = Sc_leaf_cell_sim_info(leafcell)))
 		{
 			for (i = 0; simlist[i]; i++)
 			{
@@ -403,10 +403,10 @@ void Sc_simwrite_clear_flags(void)
 		cell->bits &= ~SCSIMWRITEBITS;
 
 	/* clear flags on all leafcells */
-	for (leafcell = Sc_first_leaf_facet(); leafcell != NULL;
-		leafcell = Sc_next_leaf_facet(leafcell))
+	for (leafcell = Sc_first_leaf_cell(); leafcell != NULL;
+		leafcell = Sc_next_leaf_cell(leafcell))
 	{
-		bits = Sc_leaf_facet_bits_address(leafcell);
+		bits = Sc_leaf_cell_bits_address(leafcell);
 		*bits &= ~SCSIMWRITEBITS;
 	}
 }
@@ -529,7 +529,7 @@ int Sc_simwrite_subelements(SCNITREE *nptr, FILE *fp)
 				}
 				break;
 			case SCLEAFCELL:
-				if (!(Sc_leaf_facet_bits(nptr->np) & SCSIMWRITESEEN))
+				if (!(Sc_leaf_cell_bits(nptr->np) & SCSIMWRITESEEN))
 				{
 					if ((err = Sc_simwrite_gate(nptr->np, fp)))
 						return(err);
@@ -618,11 +618,11 @@ int Sc_simwrite_cell_instances(SCCELL *cell, FILE *fp)
 				if (sc_sim_format == SC_ALS_FORMAT)
 				{
 					Sc_fprintf_80(fp, x_("%s: "), nptr->name);
-					Sc_fprintf_80(fp, x_("%s("), Sc_leaf_facet_name(nptr->np));
+					Sc_fprintf_80(fp, x_("%s("), Sc_leaf_cell_name(nptr->np));
 				} else if (sc_sim_format == SC_SILOS_FORMAT)
 				{
 					Sc_fprintf_80(fp, x_("(%s %s "), nptr->name,
-						Sc_leaf_facet_name(nptr->np));
+						Sc_leaf_cell_name(nptr->np));
 				}
 				first = TRUE;
 				for (port = nptr->ports; port; port = port->next)
@@ -742,9 +742,9 @@ int Sc_simwrite_gate(CHAR *leafcell, FILE *fp)
 	CHAR	**simlist;
 	int		i, *bits;
 
-	bits = Sc_leaf_facet_bits_address(leafcell);
+	bits = Sc_leaf_cell_bits_address(leafcell);
 	*bits |= SCSIMWRITESEEN;
-	if ((simlist = Sc_leaf_facet_sim_info(leafcell)))
+	if ((simlist = Sc_leaf_cell_sim_info(leafcell)))
 	{
 		for (i = 0; simlist[i]; i++)
 		{
@@ -755,7 +755,7 @@ int Sc_simwrite_gate(CHAR *leafcell, FILE *fp)
 		return(0);
 	} else
 	{
-		return(Sc_seterrmsg(SC_SCVARNOFIND,Sc_leaf_facet_name(leafcell)));
+		return(Sc_seterrmsg(SC_SCVARNOFIND,Sc_leaf_cell_name(leafcell)));
 	}
 }
 
