@@ -144,7 +144,7 @@ void simals_term(void)
 }
 
 /*
- * routine to create a new window with simulation of facet "simals_mainproto"
+ * routine to create a new window with simulation of cell "simals_mainproto"
  */
 void simals_init_display(void)
 {
@@ -154,14 +154,14 @@ void simals_init_display(void)
 
 	if (simals_mainproto == NONODEPROTO)
 	{
-		ttyputerr(_("No facet to simulate"));
+		ttyputerr(_("No cell to simulate"));
 		return;
 	}
 
 	/* set top level */
 	simals_levelptr = simals_cellroot;
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, simals_mainproto->cell->cellname);
+	addstringtoinfstr(infstr, simals_mainproto->protoname);
 	pt = returninfstr(infstr);
 	simals_convert_to_upper(pt);
 	cellptr = simals_find_level(pt);
@@ -171,17 +171,10 @@ void simals_init_display(void)
 		ttyputerr(_("No simulation to resume"));
 		return;
 	}
-#if 1
 	if (simals_set_current_level()) return;
 
 	/* run simulation */
 	(void)simals_initialize_simulator(TRUE);
-#else
-	/* it crashed here and I think it should be reversed, but I'm too chicken to try */
-	(void)simals_initialize_simulator(TRUE);
-
-	if (simals_set_current_level()) return;
-#endif
 }
 
 void simals_com_comp(INTBIG count, CHAR *par[10])
