@@ -80,7 +80,7 @@ typedef struct Iactelparam
  *
  * Description:
  *	This procedure reads an Actel table file and creates a library with
- * ALS-netlist facets.
+ * ALS-netlist cells.
  */
 void simals_build_actel_command(INTBIG count, CHAR *par[])
 {
@@ -142,7 +142,7 @@ void simals_build_actel_command(INTBIG count, CHAR *par[])
 void simals_makeactelmodel(CHAR *name, FILE *io, LIBRARY *lib)
 {
 	CHAR line[MAXCHRS];
-	REGISTER CHAR *pt, *start, save, *facetname;
+	REGISTER CHAR *pt, *start, save, *cellname;
 	REGISTER NODEPROTO *np;
 	INTBIG statetablestate;
 	BOOLEAN doinginput, edgesense, fourstate;
@@ -442,18 +442,18 @@ void simals_makeactelmodel(CHAR *name, FILE *io, LIBRARY *lib)
 	}
 	addtostringarray(sa, returninfstr(infstr));
 
-	/* now put strings onto a facet */
+	/* now put strings onto a cell */
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, name);
 	addstringtoinfstr(infstr, x_("{net-als}"));
-	facetname = returninfstr(infstr);
-	np = newnodeproto(facetname, lib);
+	cellname = returninfstr(infstr);
+	np = newnodeproto(cellname, lib);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(M_("Cannot create facet %s"), facetname);
+		ttyputerr(M_("Cannot create cell %s"), cellname);
 		return;
 	}
-	stringarraytotextfacet(sa, np, TRUE);
+	stringarraytotextcell(sa, np, TRUE);
 	killstringarray(sa);
 	ttyputmsg(M_("Created %s"), describenodeproto(np));
 }
@@ -1923,7 +1923,7 @@ NODEINST *simals_getcellinstance(CHAR *celltype, CHAR *instance)
 	INTBIG i, j, count = 1;
 	Q_UNUSED( celltype );
 
-	np = getcurfacet();
+	np = getcurcell();
 	ni = NONODEINST;
 
 	/* count number of hierarchy levels */
@@ -2122,7 +2122,7 @@ void simals_order_save(void)
 	INTBIG tr;
 	BOOLEAN first = FALSE;
 	CHAR str[256], *ts;
-	NODEPROTO *curfacet;
+	NODEPROTO *curcell;
 	REGISTER void *infstr = 0;
 
 	sim_window_inittraceloop();
@@ -2139,9 +2139,9 @@ void simals_order_save(void)
 		ts = returninfstr(infstr);
 		ts[(estrlen(ts)-1)] = 0;  /* chop off trailing ":" */
 
-		/* save on current facet */
-		curfacet = getcurfacet();
-		if (curfacet != NULL) (void)setval((INTBIG)curfacet, VNODEPROTO,
+		/* save on current cell */
+		curcell = getcurcell();
+		if (curcell != NULL) (void)setval((INTBIG)curcell, VNODEPROTO,
 			x_("SIM_als_trace_order"), (INTBIG)ts, VSTRING);
 	}
 }
@@ -2152,15 +2152,15 @@ void simals_order_restore(CHAR *list)
 	INTBIG tr, trl;
 	NODEPTR node;
 	VARIABLE *var;
-	NODEPROTO *curfacet;
+	NODEPROTO *curcell;
 	CHAR *pt, *str, **tl, tmp[256];
 
 	if (namesame(list, x_("fromlib")) == 0)
 	{
-		curfacet = getcurfacet();
-		if (curfacet != NONODEPROTO)
+		curcell = getcurcell();
+		if (curcell != NONODEPROTO)
 		{
-			var = getval((INTBIG)curfacet, VNODEPROTO, VSTRING, x_("SIM_als_trace_order"));
+			var = getval((INTBIG)curcell, VNODEPROTO, VSTRING, x_("SIM_als_trace_order"));
 			if (var != NOVARIABLE)
 			{
 				(void)esnprintf(tmp, 256, x_("%s"), (CHAR *)var->addr);
