@@ -101,7 +101,7 @@ BOOLEAN simals_flatten_network(void)
 
 	/* get upper-case version of main proto */
 	if (simals_mainname != 0) efree(simals_mainname);
-	(void)allocstring(&simals_mainname, simals_mainproto->cell->cellname, sim_tool->cluster);
+	(void)allocstring(&simals_mainname, simals_mainproto->protoname, sim_tool->cluster);
 	simals_convert_to_upper(simals_mainname);
 
 	simals_cellroot = (CONPTR) simals_alloc_mem((INTBIG)sizeof(CONNECT));
