@@ -76,7 +76,7 @@ static COMCOMP sim_window_pickalstrace = {NOKEYWORD, simals_topofsignals,
 	simals_nextsignals, NOPARAMS, 0, x_(" \t"), N_("pick a signal to display"), x_("")};
 
 /*
- * Routine to start ALS simulation of facet "np".
+ * Routine to start ALS simulation of cell "np".
  */
 BOOLEAN simals_startsimulation(NODEPROTO *np)
 {
@@ -295,7 +295,6 @@ BOOLEAN simals_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special)
 	if (chr == 'r' || chr == DELETEKEY)		/* remove trace */
 	{
 		sim_window_cleartracehighlight();
-		sim_window_clearframehighlight();
 
 		/* delete them */
 		nexttr = prevtr = 0;
@@ -714,7 +713,7 @@ BOOLEAN simals_set_current_level(void)
 	{
 		if (i != 0 && np != simals_mainproto)
 		{
-			/* stop simulation of facet "np" */
+			/* stop simulation of cell "np" */
 			sim_window_stopsimulation();
 		}
 
@@ -972,4 +971,13 @@ void simals_fill_display_arrays(void)
 	efree((CHAR *)statearrays);
 }
 
+/*
+ * Routine that feeds the current signals into the explorer window.
+ */
+void simals_reportsignals(WINDOWPART *simwin, void *(*addbranch)(CHAR*, void*),
+	void *(*findbranch)(CHAR*, void*), void *(*addleaf)(CHAR*, void*), CHAR *(*nodename)(void*))
+{
+	(*addleaf)("NO SIGNALS YET", 0);
+}
+
 #endif  /* SIMTOOL - at top */
