@@ -38,10 +38,10 @@
 #include "simals.h"
 
 extern BOOLEAN simals_tracing;
-extern char *simals_statedesc[], *simals_strengthdesc[];
+extern CHAR *simals_statedesc[], *simals_strengthdesc[];
 
 /* prototypes for local routines */
-static BOOLEAN simals_schedule_node_update(MODPTR, EXPTR, unsigned char, INTBIG, INTSML, double);
+static BOOLEAN simals_schedule_node_update(MODPTR, EXPTR, UCHAR, INTBIG, INTSML, double);
 static void   simals_calculate_bidir_outputs(MODPTR, EXPTR*, INTSML);
 static BOOLEAN simals_bidir_path_search(MODPTR);
 static void   simals_PMOSTRAN(MODPTR);
@@ -87,38 +87,38 @@ static void   simals_BUS12_TO_STATE(MODPTR);
  */
 static struct
 {
-	char  *name;
+	CHAR  *name;
 	void  (*address)(MODPTR);
 } func_table[] =
 {
-	{"PMOStran",       simals_PMOSTRAN},			/* pMOS transistor */
-	{"nMOStran",       simals_NMOSTRAN},			/* nMOS transistor */
-	{"nMOStranWeak",   simals_NMOSTRANWeak},		/* Weak nMOS transistor */
-	{"pMOStranWeak",   simals_PMOSTRANWeak},		/* Weak pMOS transistor */
-	{"JKFFLOP",        simals_JK_FF},				/* JK flip-flop */
-	{"DFFLOP",         simals_DFFLOP},				/* D flip-flop */
-	{"BUS_TO_STATE",   simals_BUS_TO_STATE},
-	{"STATE_TO_BUS",   simals_STATE_TO_BUS},
+	{x_("PMOStran"),       simals_PMOSTRAN},			/* pMOS transistor */
+	{x_("nMOStran"),       simals_NMOSTRAN},			/* nMOS transistor */
+	{x_("nMOStranWeak"),   simals_NMOSTRANWeak},		/* Weak nMOS transistor */
+	{x_("pMOStranWeak"),   simals_PMOSTRANWeak},		/* Weak pMOS transistor */
+	{x_("JKFFLOP"),        simals_JK_FF},				/* JK flip-flop */
+	{x_("DFFLOP"),         simals_DFFLOP},				/* D flip-flop */
+	{x_("BUS_TO_STATE"),   simals_BUS_TO_STATE},
+	{x_("STATE_TO_BUS"),   simals_STATE_TO_BUS},
 #if 0			/* unused user functions */
-	{"Q_CALC",         simals_Q_CALC},
-	{"STATS",          simals_STATS},
-	{"COUNTER",        simals_COUNTER},
-	{"DELAY_CALC",     simals_DELAY_CALC},
-	{"FIFO",           simals_FIFO},
-	{"RX_DATA",        simals_RX_DATA},
-	{"A_F_REGISTERS",  simals_A_F_REGISTERS},
-	{"CONTROL_LOGIC",  simals_CONTROL_LOGIC},
-	{"MOD2_ADDER",     simals_MOD2_ADDER},
-	{"ABOVE_ADDER",    simals_ABOVE_ADDER},
-	{"WRITE_OUT",      simals_WRITE_OUT},
-	{"BUS12_TO_STATE", simals_BUS12_TO_STATE},
+	{x_("Q_CALC"),         simals_Q_CALC},
+	{x_("STATS"),          simals_STATS},
+	{x_("COUNTER"),        simals_COUNTER},
+	{x_("DELAY_CALC"),     simals_DELAY_CALC},
+	{x_("FIFO"),           simals_FIFO},
+	{x_("RX_DATA"),        simals_RX_DATA},
+	{x_("A_F_REGISTERS"),  simals_A_F_REGISTERS},
+	{x_("CONTROL_LOGIC"),  simals_CONTROL_LOGIC},
+	{x_("MOD2_ADDER"),     simals_MOD2_ADDER},
+	{x_("ABOVE_ADDER"),    simals_ABOVE_ADDER},
+	{x_("WRITE_OUT"),      simals_WRITE_OUT},
+	{x_("BUS12_TO_STATE"), simals_BUS12_TO_STATE},
 #endif
 	{NULL, NULL}  /* 0 */
 };
 
 /************************** SUPPORT ROUTINES **************************/
 
-INTBIG *simals_get_function_address(char *s1)
+INTBIG *simals_get_function_address(CHAR *s1)
 {
 	INTBIG i;
 
@@ -146,17 +146,17 @@ INTBIG *simals_get_function_address(char *s1)
  *
  * Calling Arguments:
  *	nodehead = pointer to the node data structure to be updated
- *	operatr  = unsigned char indicating operation to be performed on node
+ *	operatr  = char indicating operation to be performed on node
  *	state    = integer value representing the state of the node
  *	strength = integer value representing the logic stregth of the signal
  *	time     = double value representing the time the change is to take place
  */
-BOOLEAN simals_schedule_node_update(MODPTR primhead, EXPTR exhead, unsigned char operatr,
+BOOLEAN simals_schedule_node_update(MODPTR primhead, EXPTR exhead, UCHAR operatr,
 	INTBIG state, INTSML strength, double time)
 {
 	STATPTR stathead;
 	LINKPTR linkptr2;
-	char s1[30], s2[300];
+	CHAR s2[300];
 
 	stathead = (STATPTR)exhead->node_name;
 	if (stathead->sched_op == operatr && stathead->sched_state == state &&
@@ -167,14 +167,14 @@ BOOLEAN simals_schedule_node_update(MODPTR primhead, EXPTR exhead, unsigned char
 	if (simals_tracing)
 	{
 		simals_compute_node_name(stathead->nodeptr, s2);
-		sim_windowconvertengineeringnotation(time, s1);
 		ttyputmsg(_("      Schedule(F) gate %s%s, net %s  at %s"),
-			stathead->primptr->name, stathead->primptr->level, s2, s1);
+			stathead->primptr->name, stathead->primptr->level, s2,
+				sim_windowconvertengineeringnotation(time));
 	}
 	linkptr2 = simals_alloc_link_mem();
 	if (linkptr2 == 0) return(TRUE);
 	linkptr2->type = 'G';
-	linkptr2->ptr = (char *)stathead;
+	linkptr2->ptr = (CHAR *)stathead;
 	linkptr2->operatr = stathead->sched_op = operatr;
 	linkptr2->state = stathead->sched_state = state;
 	linkptr2->strength = stathead->sched_strength = strength;
@@ -338,7 +338,7 @@ BOOLEAN simals_bidir_path_search(MODPTR primhead)
 
 	for (pinhead = end_node->pinptr; pinhead; pinhead = pinhead->next)
 	{
-		if (pinhead->ptr == (char *)primhead) continue;
+		if (pinhead->ptr == (CHAR *)primhead) continue;
 
 		i = simals_bidir_path_search((MODPTR)pinhead->ptr);
 		if (i) break;
@@ -830,7 +830,7 @@ void simals_FIFO(MODPTR primhead)
 		if (fifohead == 0) return;
 		fifohead->r_ptr = 0;
 		fifohead->w_ptr = 0;
-		funchead->userptr = (char *)fifohead;
+		funchead->userptr = (CHAR *)fifohead;
 	}
 
 	if (input_ptr->nodeptr->sum_state > 0)
@@ -1178,11 +1178,11 @@ void simals_ABOVE_ADDER(MODPTR primhead)
 void simals_WRITE_OUT(MODPTR primhead)
 {
 	INTBIG state;
-	char *truename
+	CHAR *truename
 	FILE *fp;
 	EXPTR ptr;
 
-	fp = xcreate("als.out", el_filetypetext, M_("Simulation Trace File"), &truename);
+	fp = xcreate(x_("als.out"), el_filetypetext, M_("Simulation Trace File"), &truename);
 	if (fp == 0)
 	{
 		if (truename != 0) ttyputmsg(M_("ERROR: cannot open %s"), truename);
@@ -1191,7 +1191,7 @@ void simals_WRITE_OUT(MODPTR primhead)
 
 	ptr = primhead->exptr;
 	state = ptr->nodeptr->sum_state;
-	xprintf(fp, "time: %e ; node: %s ; state: %ld", simals_time_abs, ptr->node_name, state);
+	xprintf(fp, x_("time: %e ; node: %s ; state: %ld"), simals_time_abs, ptr->node_name, state);
 	xclose(fp);
 }
 
