@@ -54,7 +54,7 @@ INTBIG sim_fasthenryztailkey = 0;			/* variable key for "SIM_fasthenry_z_tail" *
 INTBIG sim_fasthenrygroupnamekey = 0;		/* variable key for "SIM_fasthenry_group_name" */
 
 /* prototypes for local routines */
-static BOOLEAN sim_writefhfacet(NODEPROTO *np, FILE *io);
+static BOOLEAN sim_writefhcell(NODEPROTO *np, FILE *io);
 static void    sim_fasthenryarcdlog(void);
 static void    sim_fasthenrydlog(void);
 static void    sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
@@ -77,7 +77,7 @@ void sim_fasthenryinit(void)
 }
 
 /*
- * routine to write a ".sil" file from the facet "np"
+ * routine to write a ".sil" file from the cell "np"
  */
 void sim_writefasthenrynetlist(NODEPROTO *np)
 {
@@ -101,7 +101,7 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 		&seglenlimit, &thickness, &widsubdiv, &heisubdiv);
 
 	/* first write the "inp" file */
-	(void)estrcpy(name, np->cell->cellname);
+	(void)estrcpy(name, np->protoname);
 	(void)estrcat(name, x_(".inp"));
 	io = xcreate(name, sim_filetypefasthenry, _("FastHenry File"), &truename);
 	if (io == NULL)
@@ -109,15 +109,15 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
-	xprintf(io, x_("* FastHenry for facet %s\n"), describenodeproto(np));
+	xprintf(io, x_("* FastHenry for cell %s\n"), describenodeproto(np));
 	us_emitcopyright(io, x_("* "), x_(""));
 
 	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
 		if (np->creationdate != 0)
-			xprintf(io, x_("* Facet created on %s\n"), timetostring((time_t)np->creationdate));
+			xprintf(io, x_("* Cell created on %s\n"), timetostring((time_t)np->creationdate));
 		if (np->revisiondate != 0)
-			xprintf(io, x_("* Facet last modified on %s\n"), timetostring((time_t)np->revisiondate));
+			xprintf(io, x_("* Cell last modified on %s\n"), timetostring((time_t)np->revisiondate));
 		xprintf(io, x_("* Netlist written on %s\n"), timetostring(getcurrenttime()));
 		xprintf(io, x_("* Written by Electric VLSI Design System, version %s\n"), el_version);
 	} else
@@ -129,12 +129,12 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	xprintf(io, x_(".units um\n"));
 
 	/* write default width and height subdivisions */
-	lambda = lambdaoffacet(np);
+	lambda = lambdaofcell(np);
 	xprintf(io, x_("\n* Default number of subdivisions\n"));
 	xprintf(io, x_(".Default nwinc=%ld nhinc=%ld h=%s\n"), widsubdiv, heisubdiv, latoa(thickness, lambda));
 
-	/* reset flags for facets that have been written */
-	if (sim_writefhfacet(np, io))
+	/* reset flags for cells that have been written */
+	if (sim_writefhcell(np, io))
 		ttyputmsg(x_("Back-annotation information has been added (library must be saved)"));
 
 	/* write frequency range */
@@ -170,11 +170,11 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 }
 
 /*
- * recursively called routine to print the SILOS description of facet "np".
- * The description is treated as the top-level facet if "top" is nonzero
+ * recursively called routine to print the SILOS description of cell "np".
+ * The description is treated as the top-level cell if "top" is nonzero
  * np is the current nodeproto
  */
-BOOLEAN sim_writefhfacet(NODEPROTO *np, FILE *io)
+BOOLEAN sim_writefhcell(NODEPROTO *np, FILE *io)
 {
 	REGISTER BOOLEAN backannotate, found;
 	REGISTER NODEINST *ni;
@@ -209,7 +209,7 @@ BOOLEAN sim_writefhfacet(NODEPROTO *np, FILE *io)
 	backannotate = FALSE;
 	if (asktool(net_tool, x_("name-all-nodes"), (INTBIG)np) != 0) backannotate = TRUE;
 
-	/* look at every node in the facet */
+	/* look at every node in the cell */
 	xprintf(io, x_("\n* Traces\n"));
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
@@ -254,7 +254,7 @@ BOOLEAN sim_writefhfacet(NODEPROTO *np, FILE *io)
 		xprintf(io, x_("N_%s x=%g y=%g z=%g\n"), nname, xf, yf, zf);
 	}
 
-	/* look at every arc in the facet */
+	/* look at every arc in the cell */
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		/* get info about this arc, stop if not part of the FastHenry output */
@@ -303,7 +303,7 @@ BOOLEAN sim_writefhfacet(NODEPROTO *np, FILE *io)
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
 
-	/* look at every export in the facet */
+	/* look at every export in the cell */
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if (pp->temp1 != 0) continue;
