@@ -44,7 +44,7 @@
 
        IRSIMTRANSISTOR *sim_firstirsimtransistor = NOIRSIMTRANSISTOR;
 static IRSIMTRANSISTOR *sim_irsimtransistorfree = NOIRSIMTRANSISTOR;
-static IRSIMTRANSISTOR *sim_irsimfacetlisthead;
+static IRSIMTRANSISTOR *sim_irsimcelllisthead;
 	   IRSIMNETWORK    *sim_irsimnets;
        INTBIG           sim_irsimnetnumber = 0;
 static INTBIG           sim_irsimnettotal = 0;
@@ -84,7 +84,7 @@ static INTBIG           sim_irsimnewnetnumber(CHAR *name);
 #if SIMFSDBWRITE != 0
 static void             sim_irsimnewalias(INTBIG netnum, CHAR *alias);
 #endif
-static INTBIG           sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m);
+static INTBIG           sim_irsimrecurse(NODEPROTO *cell, XARRAY trans, float m);
 
 /*
  * Routine to free all memory associated with this module.
@@ -115,10 +115,10 @@ void sim_freeirsimmemory(void)
 }
 
 /*
- * Routine to write a simulation deck for facet "facet".  This is called when the user
+ * Routine to write a simulation deck for cell "cell".  This is called when the user
  * just requests a deck, so the file is not temporary.
  */
-void sim_writeirsim(NODEPROTO *facet)
+void sim_writeirsim(NODEPROTO *cell)
 {
 	REGISTER FILE *f;
 	CHAR *truename;
@@ -134,9 +134,9 @@ void sim_writeirsim(NODEPROTO *facet)
 		return;
 	}
 
-	/* construct the simulation description file name from the facet */
+	/* construct the simulation description file name from the cell */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, facet->cell->cellname);
+	addstringtoinfstr(infstr, cell->protoname);
 	addstringtoinfstr(infstr, x_(".sim"));
 	netfile = returninfstr(infstr);
 
@@ -150,7 +150,7 @@ void sim_writeirsim(NODEPROTO *facet)
 
 	ttyputmsg(_("Writing IRSIM deck..."));
 	sim_irsiminternal = 1;
-	sim_irsimgeneratedeck(facet, f);
+	sim_irsimgeneratedeck(cell, f);
 
 	xclose(f);
 	ttyputmsg(_("%s written"), truename);
@@ -177,9 +177,9 @@ int sim_irsimsortsignalnames(const void *e1, const void *e2)
 }
 
 /*
- * Routine to generate an IRSIM deck for facet "facet" and write it to stream "f".
+ * Routine to generate an IRSIM deck for cell "cell" and write it to stream "f".
  */
-void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
+void sim_irsimgeneratedeck(NODEPROTO *cell, FILE *f)
 {
 	REGISTER INTBIG backannotate;
 	REGISTER TECHNOLOGY *tech;
@@ -197,8 +197,8 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 	INTBIG index, nextindex;
 
 	/* get value of lambda */
-	tech = facet->tech;
-	sim_irsimlambda = facet->cell->lib->lambda[tech->techindex];
+	tech = cell->tech;
+	sim_irsimlambda = cell->lib->lambda[tech->techindex];
 
 	/* get IRSIM state */
 	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_irsim_statekey);
@@ -217,7 +217,7 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
 	sim_irsimglobalnetcount = 0;
-	sim_irsimgatherglobals(facet);
+	sim_irsimgatherglobals(cell);
 	for(i=0; i<sim_irsimglobalnetcount; i++)
 		sim_irsimglobalnetsnumbers[i] = sim_irsimnewnetnumber(sim_irsimglobalnets[i]);
 
@@ -228,16 +228,16 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 				ni->temp1 = 0;
 
 	/*
-	 * extract the IRSIM information from facet "facet".  Creates a linked
+	 * extract the IRSIM information from cell "cell".  Creates a linked
 	 * list of transistors in "sim_firstirsimtransistor" and creates
 	 * "sim_irsimnetnumber" networks in "sim_irsimnetnames".
 	 */
 	sim_firstirsimtransistor = NOIRSIMTRANSISTOR;
 	backannotate = 0;
-	if (asktool(net_tool, x_("name-nets"), (INTBIG)facet) != 0) backannotate++;
-	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+	if (asktool(net_tool, x_("name-nets"), (INTBIG)cell) != 0) backannotate++;
+	for(net = cell->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 		net->temp1 = -1;
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if (pp->network->temp1 != -1) continue;
 		if (pp->network->buswidth > 1)
@@ -270,36 +270,36 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 	begintraversehierarchy();
 	if ((sim_irsim_state&IRSIMPARASITICS) == IRSIMPARAFULL)
 		sim_irsimmerge = mergenew(sim_tool->cluster);
-	if (sim_irsimrecurse(facet, el_matid, 1.0) != 0) backannotate++;
+	if (sim_irsimrecurse(cell, el_matid, 1.0) != 0) backannotate++;
 	if ((sim_irsim_state&IRSIMPARASITICS) == IRSIMPARAFULL)
 	{
-		sim_irsimfacetlisthead = NOIRSIMTRANSISTOR;
+		sim_irsimcelllisthead = NOIRSIMTRANSISTOR;
 		mergeextract(sim_irsimmerge, sim_irsimgetallgeometry);
 		mergedelete(sim_irsimmerge);
 	}
 	endtraversehierarchy();
 
 	/* write deck to "f" */	
-	var = getval((INTBIG)facet, VNODEPROTO, VSTRING, x_("SIM_irsim_behave_file"));
+	var = getval((INTBIG)cell, VNODEPROTO, VSTRING, x_("SIM_irsim_behave_file"));
 	if (var != NOVARIABLE)
 	{
-		/* this facet has a disk file of IRSIM associated with it */
+		/* this cell has a disk file of IRSIM associated with it */
 		xprintf(f, x_("|\n")); /* First comment line is treated by IRSIM in a special way */
-		xprintf(f, x_("| Facet %s is described in this file:\n"), describenodeproto(facet));
+		xprintf(f, x_("| Cell %s is described in this file:\n"), describenodeproto(cell));
 		xprintf(f, x_("@ %s\n"), (CHAR *)var->addr);
 	} else
 	{
 		xprintf(f,x_("| units: %g tech: %s format: SU\n"),
 			scaletodispunit(sim_irsimlambda, DISPUNITCMIC), tech->techname);
-		xprintf(f, x_("| IRSIM file for facet %s from Library %s\n"),
-			describenodeproto(facet), facet->cell->lib->libname);
+		xprintf(f, x_("| IRSIM file for cell %s from Library %s\n"),
+			describenodeproto(cell), cell->lib->libname);
 		us_emitcopyright(f, x_("| "), x_(""));
 		if ((us_useroptions&NODATEORVERSION) == 0)
 		{
-			if (facet->creationdate)
-				xprintf(f, x_("| Created on %s\n"), timetostring((time_t)facet->creationdate));
-			if (facet->revisiondate)
-				xprintf(f, x_("| Last revised on %s\n"), timetostring((time_t)facet->revisiondate));
+			if (cell->creationdate)
+				xprintf(f, x_("| Created on %s\n"), timetostring((time_t)cell->creationdate));
+			if (cell->revisiondate)
+				xprintf(f, x_("| Last revised on %s\n"), timetostring((time_t)cell->revisiondate));
 			(void)esnprintf(numberstring, 80, x_("%s"), timetostring(getcurrenttime()));
 			xprintf(f, x_("| Written on %s by Electric VLSI Design System, version %s\n"),
 				numberstring, el_version);
@@ -368,10 +368,10 @@ void sim_irsimgeneratedeck(NODEPROTO *facet, FILE *f)
 }
 
 /*
- * Routine to recursively examine facet "facet" with transformation matrix "trans"
+ * Routine to recursively examine cell "cell" with transformation matrix "trans"
  * and gather transistor information.
  */
-INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
+INTBIG sim_irsimrecurse(NODEPROTO *cell, XARRAY trans, float m)
 {
 	REGISTER NETWORK *net, *gate, *source, *drain;
 	REGISTER PORTPROTO *pp, *s, *g1, *g2, *d, *cpp;
@@ -390,10 +390,10 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 	REGISTER void *infstr;
 
 	backannotate = 0;
-	if (asktool(net_tool, x_("name-nodes"), (INTBIG)facet) != 0) backannotate++;
+	if (asktool(net_tool, x_("name-nodes"), (INTBIG)cell) != 0) backannotate++;
 
 	/* create unique numbers for internal nets */
-	for(net = facet->firstnetwork; net != NONETWORK; net = net->nextnetwork)
+	for(net = cell->firstnetwork; net != NONETWORK; net = net->nextnetwork)
 	{
 		if (net->buswidth > 1)  continue;
 		if (net->temp1 != -1)
@@ -417,10 +417,10 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 		}
 	}
 
-	/* now examine all geometry in the facet */
-	sim_irsimfacetlisthead = NOIRSIMTRANSISTOR;
+	/* now examine all geometry in the cell */
+	sim_irsimcelllisthead = NOIRSIMTRANSISTOR;
 	firsttransistor = 0;
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		np = ni->proto;
 		makerot(ni, singletrans);
@@ -437,9 +437,9 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 		if (np->primindex == 0)
 		{
 			/* ignore recursive references (showing icon in contents) */
-			if (np->cell == facet->cell) continue;
+			if (isiconof(np, cell)) continue;
 
-			/* facet instance: recurse */
+			/* cell instance: recurse */
 			cnp = contentsview(np);
 			if (cnp == NONODEPROTO) cnp = np;
 
@@ -503,7 +503,7 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 						{
 							if (cpp->network->buswidth != net->buswidth)
 							{
-								ttyputerr(_("***ERROR: port %s on node %s in facet %s is %d wide, but is connected/exported with width %d"),
+								ttyputerr(_("***ERROR: port %s on node %s in cell %s is %d wide, but is connected/exported with width %d"),
 									pp->protoname, describenodeinst(ni), describenodeproto(np),
 										cpp->network->buswidth, net->buswidth);
 								sigcount = mini(sigcount, cpp->network->buswidth);
@@ -594,8 +594,8 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 				}
 				if (gate == NONETWORK || source == NONETWORK || drain == NONETWORK)
 				{
-					ttyputerr(_("Warning: ignoring transistor %s in facet %s (not fully connected)"),
-						describenodeinst(ni), describenodeproto(facet));
+					ttyputerr(_("Warning: ignoring transistor %s in cell %s (not fully connected)"),
+						describenodeinst(ni), describenodeproto(cell));
 				} else
 				{
 					it = sim_irsimalloctransistor();
@@ -636,9 +636,9 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 					it->nextirsimtransistor = sim_firstirsimtransistor;
 					sim_firstirsimtransistor = it;
 
-					/* insert in list of transistors in this facet */
-					it->nextfacetirsimtransistor = sim_irsimfacetlisthead;
-					sim_irsimfacetlisthead = it;
+					/* insert in list of transistors in this cell */
+					it->nextcellirsimtransistor = sim_irsimcelllisthead;
+					sim_irsimcelllisthead = it;
 				}
 			}
 
@@ -648,21 +648,21 @@ INTBIG sim_irsimrecurse(NODEPROTO *facet, XARRAY trans, float m)
 	}
 	if ((sim_irsim_state&IRSIMPARASITICS) == IRSIMPARAFULL)
 	{
-		for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+		for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 			sim_irsimaddarctomerge(ai, trans);
 	}
 
-	/* do quick (facet-level) parasitics if requested */
+	/* do quick (cell-level) parasitics if requested */
 	if ((sim_irsim_state&IRSIMPARASITICS) == IRSIMPARALOCAL && firsttransistor != 0)
 	{
 		sim_irsimmerge = mergenew(sim_tool->cluster);
-		for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+		for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			makerot(ni, singletrans);
 			transmult(singletrans, trans, localtrans);
 			sim_irsimaddnodetomerge(ni, localtrans);
 		}
-		for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+		for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 			sim_irsimaddarctomerge(ai, trans);
 		mergeextract(sim_irsimmerge, sim_irsimgetallgeometry);
 		mergedelete(sim_irsimmerge);
@@ -739,7 +739,7 @@ void sim_irsimaddnodetomerge(NODEINST *ni, XARRAY trans)
 }
 
 /*
- * Routine to clip polygon "poly" on arc "ai" given a transformation for this facet
+ * Routine to clip polygon "poly" on arc "ai" given a transformation for this cell
  * in "trans".
  * Returns true if the polygon is clipped to oblivion.
  */
@@ -817,7 +817,7 @@ BOOLEAN sim_irsimcropbox(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy, INTBIG
 
 /*
  * Coroutine for polygon merging that is called for every complex polygon of Diffusion found
- * in the circuit (either in the facet or the entire flattened circuit, depending on the user
+ * in the circuit (either in the cell or the entire flattened circuit, depending on the user
  * preferences).  "layer" is always the Diffusion layer and "tech" is the current technology.
  * The polygon has "count" points in "(x, y)".
  */
@@ -845,16 +845,16 @@ void sim_irsimgetallgeometry(INTBIG layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *
 	firstsource = firstdrain = NOIRSIMTRANSISTOR;
 
 	/* determine the first transistor in the list */
-	firstit = sim_irsimfacetlisthead;
+	firstit = sim_irsimcelllisthead;
 	if (firstit == NOIRSIMTRANSISTOR) firstit = sim_firstirsimtransistor;
 
 	/* loop through the list */
 	for(it = firstit; it != NOIRSIMTRANSISTOR; it = nextit)
 	{
 		/* determine the next transistor in the list */
-		if (sim_irsimfacetlisthead == NOIRSIMTRANSISTOR)
+		if (sim_irsimcelllisthead == NOIRSIMTRANSISTOR)
 			nextit = it->nextirsimtransistor; else
-				nextit = it->nextfacetirsimtransistor;
+				nextit = it->nextcellirsimtransistor;
 
 		/* see if the source or drain of this transistor is in the polygon */
 		if (it->sarea == 0.0)
@@ -976,7 +976,7 @@ CHAR *sim_irsimbuildnetname(CHAR *name)
 				addstringtoinfstr(infstr, (CHAR *)var->addr);
 		} else
 		{
-			addstringtoinfstr(infstr, ni->proto->cell->cellname);
+			addstringtoinfstr(infstr, ni->proto->protoname);
 		}
 		addtoinfstr(infstr, '/');
 	}
@@ -1013,7 +1013,7 @@ void sim_irsimfreetransistor(IRSIMTRANSISTOR *it)
 }
 
 /*
- * Routine to clear out the IRSIM network in memory (from the last facet that was
+ * Routine to clear out the IRSIM network in memory (from the last cell that was
  * simulated).
  */
 void sim_irsimfreenetworkinfo(void)
@@ -1107,7 +1107,7 @@ INTBIG sim_irsimgetglobal(NETWORK *net)
 }
 
 /*
- * Routine to recursively examine facets and gather global network names.
+ * Routine to recursively examine cells and gather global network names.
  */
 void sim_irsimgatherglobals(NODEPROTO *np)
 {
@@ -1172,7 +1172,7 @@ void sim_irsimgatherglobals(NODEPROTO *np)
 		if (onp->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (onp->cell == np->cell) continue;
+		if (isiconof(onp, np)) continue;
 
 		if (onp->cellview == el_iconview)
 		{
