@@ -34,9 +34,9 @@
  * The variable "SIM_mossim_strength" may be placed on any node or arc.
  * On transistor nodes, it specifies the strength field to use for that
  * transistor declaration.  On arcs, it specifies the strength field to
- * use for that network node (only works for internal nodes of a facet).
+ * use for that network node (only works for internal nodes of a cell).
  *
- * The use of "icon" views of facets as instances works correctly and will
+ * The use of "icon" views of cells as instances works correctly and will
  * replace them with the contents view.
  */
 
@@ -53,12 +53,12 @@ static INTBIG sim_mossiminternal;
 static INTBIG sim_mossim_strength_key = 0;
 
 /* prototypes for local routines */
-static BOOLEAN sim_writemossimfacet(NODEPROTO*, BOOLEAN);
+static BOOLEAN sim_writemossimcell(NODEPROTO*, BOOLEAN);
 static void    sim_addmossimnode(void*, NODEINST*, PORTPROTO*);
 static CHAR   *sim_mossim_netname(ARCINST*);
 
 /*
- * routine to write a ".ntk" file from the facet "np"
+ * routine to write a ".ntk" file from the cell "np"
  */
 void sim_writemossim(NODEPROTO *np)
 {
@@ -75,7 +75,7 @@ void sim_writemossim(NODEPROTO *np)
 		return;
 	}
 
-	(void)estrcpy(name, np->cell->cellname);
+	(void)estrcpy(name, np->protoname);
 	(void)estrcat(name, x_(".ntk"));
 	sim_mossimfile = xcreate(name, sim_filetypemossim, _("MOSSIM File"), &truename);
 	if (sim_mossimfile == NULL)
@@ -88,11 +88,11 @@ void sim_writemossim(NODEPROTO *np)
 	if (sim_mossim_strength_key == 0)
 		sim_mossim_strength_key = makekey(x_("SIM_mossim_strength"));
 
-	/* reset flags for facets that have been written */
+	/* reset flags for cells that have been written */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(lnp = lib->firstnodeproto; lnp != NONODEPROTO; lnp = lnp->nextnodeproto)
 			lnp->temp1 = 0;
-	if (sim_writemossimfacet(np, TRUE))
+	if (sim_writemossimcell(np, TRUE))
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	xclose(sim_mossimfile);
@@ -100,10 +100,10 @@ void sim_writemossim(NODEPROTO *np)
 }
 
 /*
- * recursively called routine to print MOSSIM description of facet "np"
- * The description is treated as the top-level facet if "top" is true.
+ * recursively called routine to print MOSSIM description of cell "np"
+ * The description is treated as the top-level cell if "top" is true.
  */
-BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
+BOOLEAN sim_writemossimcell(NODEPROTO *np, BOOLEAN top)
 {
 	REGISTER INTBIG type, inst, i, strength;
 	REGISTER BOOLEAN backannotate;
@@ -118,10 +118,10 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 	/* stop if requested */
 	if (stopping(STOPREASONDECK)) return(FALSE);
 
-	/* mark this facet as written */
+	/* mark this cell as written */
 	np->temp1 = 1;
 
-	/* make sure all sub-facets have been written */
+	/* make sure all sub-cells have been written */
 	backannotate = FALSE;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
@@ -129,11 +129,11 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 		if (subnp->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (subnp->cell == np->cell) continue;
+		if (isiconof(subnp, np)) continue;
 		snp = contentsview(subnp);
 		if (snp == NONODEPROTO) snp = subnp;
 		if (snp->temp1 != 0) continue;
-		if (sim_writemossimfacet(snp, FALSE)) backannotate = TRUE;
+		if (sim_writemossimcell(snp, FALSE)) backannotate = TRUE;
 	}
 
 	/* make sure that all nodes have names on them */
@@ -144,13 +144,13 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 
 	if (top)
 	{
-		/* declare power and ground nodes if this is top facet */
-		xprintf(sim_mossimfile, x_("| Top-level facet %s ;\n"), describenodeproto(np));
+		/* declare power and ground nodes if this is top cell */
+		xprintf(sim_mossimfile, x_("| Top-level cell %s ;\n"), describenodeproto(np));
 		xprintf(sim_mossimfile, x_("i VDD ;\ni GND ;\n"));
 	} else
 	{
-		/* write ports if this facet is sub-facet */
-		xprintf(sim_mossimfile, x_("| Facet %s ;\nc %s"), describenodeproto(np), np->cell->cellname);
+		/* write ports if this cell is sub-cell */
+		xprintf(sim_mossimfile, x_("| Cell %s ;\nc %s"), describenodeproto(np), np->protoname);
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			xprintf(sim_mossimfile, x_(" %s"), pp->protoname);
 		xprintf(sim_mossimfile, x_(" ;\n"));
@@ -331,17 +331,17 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 		} else
 		{
 			/* ignore recursive references (showing icon in contents) */
-			if (subnp->cell == np->cell) continue;
+			if (isiconof(subnp, np)) continue;
 
 			/* complex node: make instance call */
 			infstr = initinfstr();
 			addstringtoinfstr(infstr, x_("h "));
 
-			/* see if this facet is an icon for the real thing */
+			/* see if this cell is an icon for the real thing */
 			snp = contentsview(subnp);
 			if (snp != NONODEPROTO)
-				addstringtoinfstr(infstr, snp->cell->cellname); else
-					addstringtoinfstr(infstr, subnp->cell->cellname);
+				addstringtoinfstr(infstr, snp->protoname); else
+					addstringtoinfstr(infstr, subnp->protoname);
 			addtoinfstr(infstr, ' ');
 
 			/* get appropriate name of node */
@@ -356,7 +356,7 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 
 			if (snp != NONODEPROTO)
 			{
-				/* icon facet: report ports according to order on contents */
+				/* icon cell: report ports according to order on contents */
 				for(pp = snp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 				{
 					spp = equivalentport(snp, pp, subnp);
@@ -365,7 +365,7 @@ BOOLEAN sim_writemossimfacet(NODEPROTO *np, BOOLEAN top)
 				}
 			} else
 			{
-				/* normal facet: simply report ports in order */
+				/* normal cell: simply report ports in order */
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					sim_addmossimnode(infstr, ni, pp);
 			}
@@ -425,7 +425,7 @@ void sim_addmossimnode(void *infstr, NODEINST *ni, PORTPROTO *pp)
 
 	/*
 	 * a strange situation may occur here: there may be a node with two
-	 * unconnected ports that do connect inside the facet.  Rather than write
+	 * unconnected ports that do connect inside the cell.  Rather than write
 	 * two internal node names, there should only be one.  Therefore, when
 	 * internal node names are assigned, they are stored on the port prototype
 	 * so that subsequent unconnected equivalent ports can use the same name.
