@@ -44,7 +44,7 @@
 
 /* Types returned by sim_silostype() */
 
-#define SILOSFACET		-1		/* Complex node */
+#define SILOSCELL		-1		/* Complex node */
 #define SILOSUNKNOWN	 0		/* All connected together */
 #define SILOSNMOS		 1		/* Transistor */
 #define SILOSPMOS		 2		/* P-transistor */
@@ -74,7 +74,7 @@ static INTBIG sim_silos_model_key = 0;		/* for model on cell */
 /* ************************************************************* */
 
 /* prototypes for local routines */
-static INTBIG  sim_writesilfacet(NODEPROTO*, BOOLEAN);
+static INTBIG  sim_writesilcell(NODEPROTO*, BOOLEAN);
 static void    sim_writesilinstances(NODEPROTO*, BOOLEAN);
 static CHAR   *sim_silportname(BOOLEAN, NODEINST*, PORTPROTO*, NODEPROTO*);
 static CHAR   *sim_silname(NODEINST*);
@@ -93,7 +93,7 @@ static CHAR   *sim_sil_isaport(NODEPROTO*, CHAR*);
 static CHAR   *sim_convertsub(CHAR*);
 
 /*
- * routine to write a ".sil" file from the facet "np"
+ * routine to write a ".sil" file from the cell "np"
  */
 void sim_writesilnetlist(NODEPROTO *np)
 {
@@ -111,7 +111,7 @@ void sim_writesilnetlist(NODEPROTO *np)
 	}
 
 	/* first write the "sil" file */
-	(void)estrcpy(name, np->cell->cellname);
+	(void)estrcpy(name, np->protoname);
 	(void)estrcat(name, x_(".sil"));
 	sim_silfile = xcreate(name, sim_filetypesilos, _("SILOS File"), &truename);
 	if (sim_silfile == NULL)
@@ -120,16 +120,16 @@ void sim_writesilnetlist(NODEPROTO *np)
 		return;
 	}
 	sim_sendtosil(x_("\n"));
-	sim_sendtosil(x_("$ FACET "));
+	sim_sendtosil(x_("$ CELL "));
 	sim_sendtosil(describenodeproto(np));
 	sim_sendtosil(x_(" FROM LIBRARY:"));
-	sim_sendtosil(np->cell->lib->libname);
+	sim_sendtosil(np->lib->libname);
 	sim_sendtosil(x_("\n"));
 	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
 		if (np->creationdate)
 		{
-			(void)esnprintf(numberstring, 100, x_("$ FACET CREATED ON %s"),
+			(void)esnprintf(numberstring, 100, x_("$ CELL CREATED ON %s"),
 				timetostring((time_t)np->creationdate));
 			sim_sendtosil(numberstring);
 			sim_sendtosil(x_("\n"));
@@ -166,11 +166,11 @@ void sim_writesilnetlist(NODEPROTO *np)
 	if (sim_silos_model_key == 0)
 		sim_silos_model_key = makekey(x_("SC_silos"));
 
-	/* reset flags for facets that have been written */
+	/* reset flags for cells that have been written */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(lnp = lib->firstnodeproto; lnp != NONODEPROTO; lnp = lnp->nextnodeproto)
 			lnp->temp1 = 0;
-	if (sim_writesilfacet(np, TRUE) != 0)
+	if (sim_writesilcell(np, TRUE) != 0)
 		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 	sim_sendtosil(x_("\n"));
 
@@ -181,11 +181,11 @@ void sim_writesilnetlist(NODEPROTO *np)
 }
 
 /*
- * recursively called routine to print the SILOS description of facet "np".
- * The description is treated as the top-level facet if "top" is true
+ * recursively called routine to print the SILOS description of cell "np".
+ * The description is treated as the top-level cell if "top" is true
  * np is the current nodeproto
  */
-INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
+INTBIG sim_writesilcell(NODEPROTO *np, BOOLEAN top)
 {
 	UCHAR1 buf[256];
 	REGISTER INTBIG i, j, nodetype, clktype, count, backannotate;
@@ -259,14 +259,14 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 	}
 
 	/* Read a behavior file if it is available */
-	for (onp = np->cell->firstincell; onp != NONODEPROTO; onp = onp->nextincell)
+	FOR_CELLGROUP(onp, np)
 	{
 		var = getval((INTBIG)onp, VNODEPROTO, VSTRING, x_("SIM_silos_behavior_file"));
 		if (var != NOVARIABLE)
 		{
 			f = xopen(truepath((CHAR *)var->addr), sim_filetypesilos, x_(""), &filename);
 			if (f == NULL)
-				ttyputerr(_("Cannot find SILOS behavior file %s on facet %s"),
+				ttyputerr(_("Cannot find SILOS behavior file %s on cell %s"),
 					(CHAR *)var->addr, describenodeproto(onp)); else
 			{
 				/* copy the file */
@@ -280,7 +280,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 				xclose(f);
 				sim_sendtosil(x_("\n"));
 
-				/* mark this facet as written */
+				/* mark this cell as written */
 				np->temp1++;
 				return(backannotate);
 			}
@@ -291,7 +291,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 	 * There was no behavior file...
 	 * Get the SILOS model from the library if it exists
 	 */
-	for (onp = np->cell->firstincell; onp != NONODEPROTO; onp = onp->nextincell)
+	FOR_CELLGROUP(onp, np)
 	{
 		var = getvalkey((INTBIG)onp, VNODEPROTO, VSTRING|VISARRAY, sim_silos_model_key);
 		if (var != NOVARIABLE)
@@ -302,7 +302,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 				xprintf(sim_silfile, x_("%s\n"), model[i]);
 			sim_sendtosil(x_("\n"));
 
-			/* mark this facet as written */
+			/* mark this cell as written */
 			np->temp1++;
 			return(backannotate);
 		}
@@ -310,32 +310,32 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 
 	/*
 	 * No database model either...
-	 * must write netlist for this facet
-	 * ...recurse on sub-facets first
+	 * must write netlist for this cell
+	 * ...recurse on sub-cells first
 	 */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (ni->proto->cell == np->cell) continue;
+		if (isiconof(ni->proto, np)) continue;
 
-		/* get actual subfacet (including contents/body distinction) */
+		/* get actual subcell (including contents/body distinction) */
 		/* NOTE: this gets the schematic before the layout */
 		onp = contentsview(ni->proto);
 		if (onp == NONODEPROTO) onp = ni->proto;
 
-		/* write the subfacet */
+		/* write the subcell */
 		if (onp->temp1 == 0)
 		{
-			if (sim_writesilfacet(onp, FALSE) != 0) backannotate = 1;
+			if (sim_writesilcell(onp, FALSE) != 0) backannotate = 1;
 		}
 	}
 
 	/* make sure that all nodes have names on them */
 	if (asktool(net_tool, x_("name-nodes"), (INTBIG)np) != 0) backannotate++;
 
-	/* mark this facet as written */
+	/* mark this cell as written */
 	np->temp1++;
 
 	/* write the header if this not the top level */
@@ -343,7 +343,7 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 	{
 		sim_sendtosil(x_("\n"));
 		sim_sendtosil(x_(".MACRO"));
-		(void)estrcpy(line, (np->cell->cellname));
+		(void)estrcpy(line, np->protoname);
 		for (i=0; line[i] && line[i] != '{'; i++)
 			;
 		line[i] = 0;			/* explicit termination of line */
@@ -381,11 +381,11 @@ INTBIG sim_writesilfacet(NODEPROTO *np, BOOLEAN top)
 	if (top == 0) sim_sendtosil(x_(".EOM\n"));
 	sim_sendtosil(x_("\n"));
 	return(backannotate);
-}						/* end sim_writesilfacet() */
+}						/* end sim_writesilcell() */
 
 
 /* Function to write the instances contained in 'np'
- * This was part of sim_writesilfacet before...
+ * This was part of sim_writesilcell before...
  */
 void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 {
@@ -400,7 +400,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 	sim_pseudonet = 1;
 	schem_ref = 1;
 
-	/* look at every node in this facet */
+	/* look at every node in this cell */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		ni->temp1 = 0;
@@ -422,7 +422,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 		nodetype = sim_silostype(ni);
 		switch (nodetype)
 		{
-			case SILOSFACET:		/* Complex cell uses instance name */
+			case SILOSCELL:		/* Complex cell uses instance name */
 				sim_sendtosil(x_("("));
 				sim_sendtosil(sim_silname(ni));
 				sim_sendtosil(x_(" "));
@@ -464,7 +464,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 
 			case SILOSCLOCK:
 			case SILOSSOURCE:
-				if (!top) ttyputerr(_("WARNING: Global Clock in a sub-facet"));
+				if (!top) ttyputerr(_("WARNING: Global Clock in a sub-cell"));
 				break;
 
 			case SILOSAND:	/* only need positive logic here */
@@ -498,7 +498,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
 						break;
 				}
 				if (pp == NOPORTPROTO)
-					ttyputerr(_("Could not find an output connection on %s"), ni->proto->primname);
+					ttyputerr(_("Could not find an output connection on %s"), ni->proto->protoname);
 
 				/* get the fall and rise times */
 				sim_sendtosil(sim_silrisetime(ni));
@@ -566,7 +566,7 @@ void sim_writesilinstances(NODEPROTO *np, BOOLEAN top)
  * on the port, concatenate the names (with spaces between them).
  * If there is no arc, but the port is an export, use the exported name.
  * If the port is a power or ground port, ignore it
- * If this is not the top level facet (ie. a .macro) remove [] notation.
+ * If this is not the top level cell (ie. a .macro) remove [] notation.
  */
 CHAR *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 {
@@ -621,7 +621,7 @@ CHAR *sim_silportname(BOOLEAN top, NODEINST *ni, PORTPROTO *pp, NODEPROTO *np)
 		}
 	}
 
-	/* if this is the top facet and we didn't find an arc */
+	/* if this is the top cell and we didn't find an arc */
 	if (top && noarcs)
 	{
 		/* search for an export */
@@ -689,10 +689,10 @@ CHAR *sim_silproto(NODEINST *ni, BOOLEAN neg)
 	REGISTER INTBIG f;
 	static CHAR name[100];
 
-	/* facets use their real name */
+	/* cells use their real name */
 	if (ni->proto->primindex == 0)
 	{
-		esnprintf(name, 100, x_("%s"), sim_siltext(ni->proto->cell->cellname));
+		esnprintf(name, 100, x_("%s"), sim_siltext(ni->proto->protoname));
 		if (estrlen(name) > MAXNAME) name[MAXNAME] = 0;
 		return(name);
 	}
@@ -734,7 +734,7 @@ CHAR *sim_silproto(NODEINST *ni, BOOLEAN neg)
 			if ((ni->userbits&FFCLOCK) == FFCLOCKN) return(x_(".TNEFF"));
 			return(x_(".TPEFF"));
 	}
-	return(sim_siltext(ni->proto->primname));
+	return(sim_siltext(ni->proto->protoname));
 }
 
 /*
@@ -841,7 +841,7 @@ INTBIG sim_silostype(NODEINST *ni)
 {
 	INTBIG func;
 
-	if (ni->proto->primindex == 0) return(SILOSFACET);
+	if (ni->proto->primindex == 0) return(SILOSCELL);
 
 	func = nodefunction(ni);
 	switch(func)
@@ -974,7 +974,7 @@ INTBIG sim_silgetcapacitance(NODEINST *ni)
 /*
  * Function to write the ports of a flip-flop;
  * get them in the Electric order, then rewrite them
- * 'ni' is the current NODEINST, found in 'np' facet
+ * 'ni' is the current NODEINST, found in 'np' cell
  */
 #define JORD 0
 #define K	 1
