@@ -60,7 +60,7 @@ void sim_writesim(NODEPROTO *simnt, INTBIG format)
 	REGISTER VARIABLE *var;
 	REGISTER FILE *f;
 	REGISTER PORTPROTO *pp, *spt, *shpt;
-	CHAR *truename, *presimloc;
+	CHAR *truename, *presimloc, *newname;
 	REGISTER CHAR *simprog, *presimtmp, *presimprog, *netfile;
 	REGISTER void *infstr;
 
@@ -87,11 +87,13 @@ void sim_writesim(NODEPROTO *simnt, INTBIG format)
 	var = getvalkey((INTBIG)sim_tool, VTOOL, VINTEGER, sim_formatkey);
 	if (var == NOVARIABLE) format = -1; else format = var->addr;
 
-	/* construct the simulation description file name from the facet */
+	/* construct the simulation description file name from the cell */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, simnt->cell->cellname);
+	addstringtoinfstr(infstr, simnt->protoname);
 	addstringtoinfstr(infstr, x_(".sim"));
-	var = setvalkey((INTBIG)sim_tool, VTOOL, sim_netfilekey, (INTBIG)returninfstr(infstr), VSTRING|VDONTSAVE);
+	allocstring(&newname, returninfstr(infstr), el_tempcluster);
+	var = setvalkey((INTBIG)sim_tool, VTOOL, sim_netfilekey, (INTBIG)newname, VSTRING|VDONTSAVE);
+	efree(newname);
 	if (var != NOVARIABLE) netfile = (CHAR *)var->addr; else netfile = x_("");
 
 	/* also record the actual input file to the simulator */
@@ -112,7 +114,7 @@ void sim_writesim(NODEPROTO *simnt, INTBIG format)
 	if ((us_useroptions&NODATEORVERSION) == 0)
 	{
 		if (simnt->creationdate != 0)
-			xprintf(f, x_("| Facet created %s\n"), timetostring((time_t)simnt->creationdate));
+			xprintf(f, x_("| Cell created %s\n"), timetostring((time_t)simnt->creationdate));
 		xprintf(f, x_("| Version %ld"), simnt->version);
 		if (simnt->revisiondate != 0)
 			xprintf(f, x_(" last revised %s\n"), timetostring((time_t)simnt->revisiondate));
@@ -129,7 +131,7 @@ void sim_writesim(NODEPROTO *simnt, INTBIG format)
 		xprintf(f,x_("| N node xpos ypos M-area P-area D-area D-perim\n"));
 	}
 
-	/* assign net-list values to each port of the top facet */
+	/* assign net-list values to each port of the top cell */
 	sim_index = 1;
 	sim_vdd = sim_gnd = 0;
 	sim_phi1h = sim_phi1l = sim_phi2h = sim_phi2l = 0;
@@ -185,8 +187,8 @@ void sim_writesim(NODEPROTO *simnt, INTBIG format)
 	}
 	sim_namethresh = sim_index;
 
-	if (sim_vdd == 0) ttyputmsg(_("Warning: no power export in this facet"));
-	if (sim_gnd == 0) ttyputmsg(_("Warning: no ground export in this facet"));
+	if (sim_vdd == 0) ttyputmsg(_("Warning: no power export in this cell"));
+	if (sim_gnd == 0) ttyputmsg(_("Warning: no ground export in this cell"));
 
 	/* select the shortest name for electrically equivalent ports */
 	for(pp = simnt->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -325,10 +327,10 @@ void sim_simpointout(CHAR *nonum, INTBIG format)
 		return;
 	}
 
-	/* make sure user is still in the same facet */
-	if (sim_simnt != getcurfacet())
+	/* make sure user is still in the same cell */
+	if (sim_simnt != getcurcell())
 	{
-		ttyputerr(_("Simulation was done on facet %s; please edit that facet"),
+		ttyputerr(_("Simulation was done on cell %s; please edit that cell"),
 			describenodeproto(sim_simnt));
 		return;
 	}
@@ -345,7 +347,7 @@ void sim_simpointout(CHAR *nonum, INTBIG format)
 		want = pp->temp1;
 	}
 
-	/* re-assign net-list values, starting at each portinst of the top facet */
+	/* re-assign net-list values, starting at each portinst of the top cell */
 	sim_index = 1;
 	sim_vdd = sim_gnd = 0;
 	sim_phi1h = sim_phi1l = sim_phi2h = sim_phi2l = 0;
@@ -408,7 +410,7 @@ void sim_simpointout(CHAR *nonum, INTBIG format)
 	}
 }
 
-BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *facet, INTBIG format)
+BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *cell, INTBIG format)
 {
 	CHAR *newpar[2];
 	INTBIG darea, dperim, parea, pperim, marea, mperim;
@@ -422,16 +424,16 @@ BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *facet, INTBIG format)
 	REGISTER INTBIG type;
 
 	/* reset the arcinst node values */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		ai->temp1 = 0;
 
 	/* set every arcinst to a global node number (from inside or outside) */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->temp1 != 0) continue;
 
 		/* see if this arcinst is connected to a port */
-		for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+		for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			if (pp->network != ai->network) continue;
 			if (pp->temp1 == want)
@@ -465,7 +467,7 @@ BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *facet, INTBIG format)
 	}
 
 	/* see if the port has the right node but is unconnected */
-	for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		if (pp->temp1 == want)
 	{
 		(void)asktool(us_tool, x_("clear"));
@@ -473,8 +475,8 @@ BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *facet, INTBIG format)
 		return(FALSE);
 	}
 
-	/* look at every nodeinst in the facet */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* look at every nodeinst in the cell */
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		np = ni->proto;
 		if (format == COSMOS)
@@ -486,7 +488,7 @@ BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *facet, INTBIG format)
 				type = NPUNKNOWN;
 
 				/* ignore recursive references (showing icon in contents) */
-				if (np->cell == facet->cell) continue;
+				if (isiconof(np, cell)) continue;
 				np = contentsview(snp);
 				if (np == NONODEPROTO) np = snp;
 			}
@@ -541,7 +543,7 @@ BOOLEAN sim_simsearch(INTBIG want, NODEPROTO *facet, INTBIG format)
 			} else pp->temp1 = sim_index++;
 		}
 
-		/* if it is a facet, recurse */
+		/* if it is a cell, recurse */
 		if (np->primindex == 0)
 		{
 			i = sim_simsearch(want, ni->proto, format);
@@ -676,7 +678,7 @@ void sim_simtell(void)
 	longjmp(sim_userdone, 1);
 }
 
-void sim_simprint(NODEPROTO *facet, FILE *f, INTBIG format)
+void sim_simprint(NODEPROTO *cell, FILE *f, INTBIG format)
 {
 	REGISTER INTBIG gate, source, drain, type;
 	INTBIG darea, dperim, parea, pperim, marea, mperim, length, width;
@@ -691,16 +693,16 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTBIG format)
 	if (stopping(STOPREASONDECK)) return;
 
 	/* reset the arcinst node values */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		ai->temp1 = 0;
 
 	/* set every arcinst to a global node number (from inside or outside) */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->temp1 != 0) continue;
 
 		/* see if this arcinst is connected to a port */
-		for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+		for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			if (pp->network != ai->network) continue;
 			darea = dperim = parea = pperim = marea = mperim = 0;
@@ -726,8 +728,8 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTBIG format)
 		}
 	}
 
-	/* look at every nodeinst in the facet */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* look at every nodeinst in the cell */
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* initialize network numbers on every portinst on this nodeinst */
 		np = ni->proto;
@@ -738,7 +740,7 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTBIG format)
 			type = NPUNKNOWN;
 
 			/* ignore recursive references (showing icon in contents) */
-			if (np->cell == facet->cell) continue;
+			if (isiconof(np, cell)) continue;
 			np = contentsview(snp);
 			if (np == NONODEPROTO) np = snp;
 		}
@@ -804,8 +806,8 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTBIG format)
 		if ((type == NPSUBSTRATE && np->firstportproto->temp1 != sim_vdd) ||
 			(type == NPWELL && np->firstportproto->temp1 != sim_gnd))
 		{
-			ttyputmsg(_("WARNING: node %s in facet %s not connected to proper supply"),
-				describenodeinst(ni), describenodeproto(facet));
+			ttyputmsg(_("WARNING: node %s in cell %s not connected to proper supply"),
+				describenodeinst(ni), describenodeproto(cell));
 		}
 
 		/* if it is a transistor, write the information */
@@ -871,7 +873,7 @@ void sim_simprint(NODEPROTO *facet, FILE *f, INTBIG format)
 	}
 }
 
-void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTBIG format)
+void sim_simprintcosmos(NODEPROTO *cell, FILE *f, INTBIG format)
 {
 	REGISTER PORTPROTO *gate, *source, *drain;
 	REGISTER INTBIG type;
@@ -888,22 +890,22 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTBIG format)
 	/* stop if requested */
 	if (stopping(STOPREASONDECK)) return;
 
-	xprintf(f, x_("| cell %s\n"), facet->cell->cellname);
+	xprintf(f, x_("| cell %s\n"), cell->protoname);
 
-	lambda = lambdaoffacet(facet); /* setup lambda for scaling */
+	lambda = lambdaofcell(cell); /* setup lambda for scaling */
 	lambda_2 = lambda*lambda;
 
 	/* reset the arcinst node values */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		ai->temp1 = 0;
 
 	/* set every arcinst to a global node number (from inside or outside) */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (ai->temp1 != 0) continue;
 
 		/* see if this arcinst is connected to a port */
-		for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+		for(pp = cell->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		{
 			if (pp->network != ai->network) continue;
 			darea = dperim = parea = pperim = marea = mperim = 0;
@@ -930,7 +932,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTBIG format)
 	}
 
 	/* Test each arc for attributes */
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		var = getvalkey((INTBIG)ai, VARCINST, -1, sim_cosmos_attribute_key);
 		if (var != NOVARIABLE)
@@ -941,8 +943,8 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTBIG format)
 		}
 	}
 
-	/* look at every nodeinst in the facet */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* look at every nodeinst in the cell */
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* initialize network numbers on every portinst on this nodeinst */
 		np = ni->proto;
@@ -953,7 +955,7 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTBIG format)
 			type = NPUNKNOWN;
 
 			/* ignore recursive references (showing icon in contents) */
-			if (np->cell == facet->cell) continue;
+			if (isiconof(np, cell)) continue;
 			np = contentsview(snp);
 			if (np == NONODEPROTO) np = snp;
 		}
@@ -1020,8 +1022,8 @@ void sim_simprintcosmos(NODEPROTO *facet, FILE *f, INTBIG format)
 		if ((type == NPSUBSTRATE && np->firstportproto->temp1 != sim_vdd) ||
 			(type == NPWELL && np->firstportproto->temp1 != sim_gnd))
 		{
-			ttyputmsg(_("WARNING: node %s in facet %s not connected to proper supply"),
-				describenodeinst(ni), describenodeproto(facet));
+			ttyputmsg(_("WARNING: node %s in cell %s not connected to proper supply"),
+				describenodeinst(ni), describenodeproto(cell));
 		}
 
 		/* if it is a transistor, write the information */
