@@ -36,6 +36,7 @@
 #include "sim.h"
 #include "efunction.h"
 #include "usr.h"
+#include "network.h"
 #include "edialogs.h"
 #include <math.h>
 #ifdef WIN32
@@ -73,7 +74,7 @@ static PA0LINE *sim_pa0linefree = NOPA0LINE;
 static PA0LINE *sim_pa0linefirst = NOPA0LINE;
 
 
-static CHAR	    sim_spice_facetname[100] = {x_("")};		/* Name extracted from .SPO file */
+static CHAR	    sim_spice_cellname[100] = {x_("")};		/* Name extracted from .SPO file */
 static FILE    *sim_spice_streamfromsim;
 static EProcess *sim_spice_process;
 static NUMBERS *sim_spice_numbers = NONUMBERS;		/* current list */
@@ -99,13 +100,12 @@ static INTSML   sim_spice_getfromsimulator(void);
 static BOOLEAN  sim_spice_getlinefromsimulator(CHAR *line);
 static BOOLEAN  sim_spice_topofsignals(CHAR**);
 static CHAR    *sim_spice_nextsignals(void);
-static BOOLEAN  sim_spice_plotvalues();
+static BOOLEAN  sim_spice_plotvalues(NODEPROTO *np);
 static BOOLEAN  sim_spice_ensurespace(INTBIG);
 static INTBIG   sim_spice_parseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode, void *dia);
 static INTBIG   sim_spice_findsignalname(CHAR *name);
 static BOOLEAN  sim_spice_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special);
 static BOOLEAN  sim_spice_charhandlerwave(WINDOWPART *w, INTSML chr, INTBIG special);
-static void     sim_spice_addhighlightednet(BOOLEAN);
 static BOOLEAN  sim_spice_readbtr0block(BOOLEAN firstbyteread);
 static void     sim_spice_resetbtr0(void);
 static INTBIG   sim_spice_gethspicefloat(double *val);
@@ -115,7 +115,7 @@ static void     sim_spice_removesignal(void);
 #ifdef WIN32
 static double   sim_spice_swapendian(double v);
 #endif
-static void     sim_spice_addarguments(EProcess &process, CHAR *deckname, CHAR *facetname);
+static void     sim_spice_addarguments(EProcess &process, CHAR *deckname, CHAR *cellname);
 
 /*
  * Routine to free all memory allocated by this module.
@@ -204,9 +204,9 @@ void sim_freepa0line(PA0LINE *pl)
  * routine to execute SPICE with "infile" as the input deck file, "outfile"
  * as the output listing file.  If "infile" is null, do not run the simulator,
  * but just read "outfile" as the output listing.  If "infile" is not null,
- * run SPICE on that file, presuming that it came from facet "facet".
+ * run SPICE on that file, presuming that it came from cell "cell".
  */
-void sim_spice_execute(CHAR *infile, CHAR *outfile, NODEPROTO *facet)
+void sim_spice_execute(CHAR *infile, CHAR *outfile, NODEPROTO *cell)
 {
 	CHAR line[MAXLINE+5];
 	REGISTER INTBIG i, important, parsemode, filetype, simstate;
@@ -344,7 +344,7 @@ void sim_spice_execute(CHAR *infile, CHAR *outfile, NODEPROTO *facet)
 			/* spice on the local machine */
 			process.addArgument( path );
 		}
-		sim_spice_addarguments(process, infile, facet->cell->cellname);
+		sim_spice_addarguments(process, infile, cell->protoname);
 
 		BOOLEAN quiet = (parsemode == SIMRUNYESQPARSE || parsemode == SIMRUNYESQ) &&
 			(sim_spice_state & SPICETYPE) == SPICEHSPICE;
@@ -422,14 +422,14 @@ void sim_spice_execute(CHAR *infile, CHAR *outfile, NODEPROTO *facet)
 
 	/* plot the list of numbers */
 	if (important < 0) return;
-	if (sim_spice_plotvalues()) ttyputerr(_("Problem making the plot"));
+	if (sim_spice_plotvalues(cell)) ttyputerr(_("Problem making the plot"));
 }
 
 /*
  * Routine to add execution parameters to the array "sim_spice_execpars" starting at index "index".
- * The name of the facet is in "facetname".
+ * The name of the cell is in "cellname".
  */
-void sim_spice_addarguments(EProcess &process, CHAR *deckname, CHAR *facetname)
+void sim_spice_addarguments(EProcess &process, CHAR *deckname, CHAR *cellname)
 {
 	REGISTER VARIABLE *var;
 	REGISTER CHAR *runargs;
@@ -448,7 +448,7 @@ void sim_spice_addarguments(EProcess &process, CHAR *deckname, CHAR *facetname)
 			infstr = initinfstr();
 			for( ; *runargs != 0 && *runargs != ' '; runargs++)
 			{
-				if (*runargs == '%') addstringtoinfstr(infstr, facetname); else
+				if (*runargs == '%') addstringtoinfstr(infstr, cellname); else
 					addtoinfstr(infstr, *runargs);
 			}
 			process.addArgument( returninfstr(infstr) );
@@ -519,8 +519,8 @@ INTBIG sim_spice_parseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode,
 
 			if (namesame(line, x_("Plotname")) == 0)
 			{
-				if (sim_spice_facetname[0] == '\0')
-					estrcpy(sim_spice_facetname, ptr);
+				if (sim_spice_cellname[0] == '\0')
+					estrcpy(sim_spice_cellname, ptr);
 				continue;
 			}
 
@@ -723,8 +723,8 @@ INTBIG sim_spice_parseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode,
 
 			if (namesame(line, x_("Plotname")) == 0)
 			{
-				if (sim_spice_facetname[0] == '\0')
-					estrcpy(sim_spice_facetname, ptr);
+				if (sim_spice_cellname[0] == '\0')
+					estrcpy(sim_spice_cellname, ptr);
 				continue;
 			}
 
@@ -946,10 +946,10 @@ INTBIG sim_spice_parseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode,
 				} else sim_spice_xprintf(outputfile, FALSE, x_("%s\n"), line);
 			}
 
-			/* look for a facet name */
-			if ((sim_spice_facetname[0] == '\0') && (namesamen(line, x_("*** SPICE deck for facet "),25) == 0))
-				if ((i = esscanf(line+25,x_("%s"),sim_spice_facetname)) != 1)
-					sim_spice_facetname[0] = '\0';
+			/* look for a cell name */
+			if ((sim_spice_cellname[0] == '\0') && (namesamen(line, x_("*** SPICE deck for cell "),25) == 0))
+				if ((i = esscanf(line+25,x_("%s"),sim_spice_cellname)) != 1)
+					sim_spice_cellname[0] = '\0';
 			if (namesamen(line, x_(".END"), 4) == 0 && namesamen(line, x_(".ENDS"), 5) != 0)
 			{
 				past_end = TRUE;
@@ -1641,7 +1641,7 @@ extern "C" { extern COMCOMP us_yesnop, us_showdp; }
  * linked list is another time sample, with "sim_spice_signals" trace points.  The
  * names of these signals is in "sim_spice_signames". Returns true on error.
  */
-BOOLEAN sim_spice_plotvalues()
+BOOLEAN sim_spice_plotvalues(NODEPROTO *np)
 {
 	REGISTER INTBIG i, numtotal, j, k, tr, position, numtraces;
 	INTBIG oldsigcount;
@@ -1658,17 +1658,17 @@ BOOLEAN sim_spice_plotvalues()
 		numtotal++;
 	if (numtotal == 0) return(FALSE);
 
-	/* we have to establish a link for the plot facet */
-	plotnp = NONODEPROTO;
+	/* we have to establish a link for the plot cell */
+	plotnp = np;
 
-	/* if we're already simulating a facet, use that one */
+	/* if we're already simulating a cell, use that one */
 	if (sim_simnt != NONODEPROTO) plotnp = sim_simnt; else
-		if (sim_spice_facetname[0] != '\0') plotnp = getnodeproto(sim_spice_facetname);
+		if (sim_spice_cellname[0] != '\0') plotnp = getnodeproto(sim_spice_cellname);
 	if (plotnp != NONODEPROTO && plotnp->primindex != 0) plotnp = NONODEPROTO;
-	if (plotnp != NONODEPROTO)
+	if (plotnp != NONODEPROTO && np == NONODEPROTO)
 	{
 		infstr = initinfstr();
-		formatinfstr(infstr, _("Is this a simulation of facet %s?"),
+		formatinfstr(infstr, _("Is this a simulation of cell %s?"),
 			describenodeproto(plotnp));
 		i = ttygetparam(returninfstr(infstr), &us_yesnop, 3, pars);
 		if (i == 1)
@@ -1677,10 +1677,10 @@ BOOLEAN sim_spice_plotvalues()
 		}
 	}
 
-	/* one final chance to pick a facet */
+	/* one final chance to pick a cell */
 	if (plotnp == NONODEPROTO)
 	{
-		i = ttygetparam(_("Please select a facet to associate with this plot: "),
+		i = ttygetparam(_("Please select a cell to associate with this plot: "),
 			&us_showdp, 3, pars);
 		if (i > 0) plotnp = getnodeproto(pars[0]);
 	}
@@ -1830,16 +1830,16 @@ BOOLEAN sim_spice_charhandlerschem(WINDOWPART *w, INTSML chr, INTBIG special)
 			ttyputinstruction(x_(" r"), 6, _("remove selected network from waveform window"));
 			return(FALSE);
 		case 'a':		/* add trace */
-			sim_spice_addhighlightednet(FALSE);
+			sim_spice_addhighlightednet(0, FALSE);
 			return(FALSE);
 		case 'o':		/* overlap trace */
-			sim_spice_addhighlightednet(TRUE);
+			sim_spice_addhighlightednet(0, TRUE);
 			return(FALSE);
 		case 'r':		/* remove trace */
 			sim_spice_removesignal();
 			return(FALSE);
 		case 'd':		/* move down the hierarchy */
-			us_editfacet(0, par);
+			us_editcell(0, par);
 			return(FALSE);
 		case 'u':		/* move up the hierarchy */
 			us_outhier(0, par);
@@ -2007,7 +2007,7 @@ void sim_spice_removesignal(void)
 /*
  * Routine to add the highlighted signal to the waveform window.
  */
-void sim_spice_addhighlightednet(BOOLEAN overlay)
+void sim_spice_addhighlightednet(CHAR *name, BOOLEAN overlay)
 {
 	REGISTER ARCINST *ai;
 	NODEPROTO *np;
@@ -2021,22 +2021,25 @@ void sim_spice_addhighlightednet(BOOLEAN overlay)
 		return;
 	}
 
-	ai = (ARCINST *)asktool(us_tool, x_("get-arc"));
-	if (ai == NOARCINST)
+	if (name != 0) pt = name; else
 	{
-		ttyputerr(_("Select an arc first"));
-		return;
-	}
-	if (ai->network == NONETWORK)
-	{
-		ttyputerr(_("This arc has no network information"));
-		return;
-	}
-	pt = sim_spice_signalname(ai->network);
-	if (pt == 0)
-	{
-		ttyputerr(_("Cannot get SPICE signal for network %s"), pt);
-		return;
+		ai = (ARCINST *)asktool(us_tool, x_("get-arc"));
+		if (ai == NOARCINST)
+		{
+			ttyputerr(_("Select an arc first"));
+			return;
+		}
+		if (ai->network == NONETWORK)
+		{
+			ttyputerr(_("This arc has no network information"));
+			return;
+		}
+		pt = sim_spice_signalname(ai->network);
+		if (pt == 0)
+		{
+			ttyputerr(_("Cannot get SPICE signal for network %s"), pt);
+			return;
+		}
 	}
 	i = sim_spice_findsignalname(pt);
 	if (i < 0)
@@ -2083,7 +2086,7 @@ NETWORK *sim_spice_networkfromname(CHAR *name)
 	REGISTER NODEINST *ni;
 	REGISTER NETWORK *net;
 
-	/* get simulation facet, quit if not simulating */
+	/* get simulation cell, quit if not simulating */
 	if (sim_window_isactive(&np) == 0) return(NONETWORK);
 
 	/* parse the names, separated by dots */
@@ -2110,7 +2113,7 @@ NETWORK *sim_spice_networkfromname(CHAR *name)
 		if (cnp != NONODEPROTO) np = cnp;
 	}
 
-	/* find network "start" in facet "np" */
+	/* find network "start" in cell "np" */
 	net = getnetwork(start, np);
 	return(net);
 }
@@ -2121,17 +2124,20 @@ NETWORK *sim_spice_networkfromname(CHAR *name)
 CHAR *sim_spice_signalname(NETWORK *net)
 {
 	NODEPROTO *np;
-	REGISTER CHAR *prevstr;
+	REGISTER CHAR *prevstr, *signame;
+	CHAR **nodenames;
 	REGISTER NODEPROTO *netpar;
 	REGISTER VARIABLE *varname;
 	REGISTER PORTPROTO *pp;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER NODEINST *ni;
+	REGISTER NETWORK *busnet;
+	REGISTER INTBIG sigcount, i, busidx;
 	REGISTER void *infstr;
 	INTBIG index;
 
-	/* get simulation facet, quit if not simulating */
+	/* get simulation cell, quit if not simulating */
 	if (sim_window_isactive(&np) == 0) return(0);
 
 	/* shift this network up the hierarchy as far as it is exported */
@@ -2140,7 +2146,7 @@ CHAR *sim_spice_signalname(NETWORK *net)
 		/* if this network is at the current level of hierarchy, stop going up the hierarchy */
 		if (net->parent == np) break;
 
-		/* find the instance that is the proper parent of this facet */
+		/* find the instance that is the proper parent of this cell */
 		ni = descentparent(net->parent, &index, NOWINDOWPART, 0);
 		if (ni == NONODEINST) break;
 
@@ -2149,13 +2155,45 @@ CHAR *sim_spice_signalname(NETWORK *net)
 			if (pp->network == net) break;
 		if (pp != NOPORTPROTO)
 			pp = equivalentport(net->parent, pp, ni->proto);
+
+		/* see if network is exported from this level as part of a bus */
+		if (pp == NOPORTPROTO && net->buswidth <= 1 && net->buslinkcount > 0) {
+			/* find bus that this singel wire net is part of */
+			busidx = -1;
+			for (busnet = net->parent->firstnetwork; busnet != NONETWORK; busnet = busnet->nextnetwork) {
+				if (busnet->buswidth > 1) { // must be bus
+					for (i=0; i<busnet->buswidth; i++) {
+						if (net == busnet->networklist[i]) { 
+							busidx = i; // net part of bus
+							break;
+						}
+					}
+				}
+				if (busidx != -1) break;
+			}
+			/* make sure won't access array out of bounds */
+			if (busidx == -1) busidx = 0;
+			/* see if bus exported */
+			for(pp = busnet->parent->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				if (pp->network == busnet) {
+					break;
+				}
+			if (pp != NOPORTPROTO) {
+				pp = equivalentport(busnet->parent, pp, ni->proto);
+			}
+		}
 		if (pp == NOPORTPROTO) break;
 
 		/* exported: find the network in the higher level */
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 			if (pi->proto == pp)
 		{
-			net = pi->conarcinst->network;
+			/* if bussed, grab correct net in bus, otherwise just grab net */
+			if (pi->conarcinst->network->buswidth > 1 && pi->conarcinst->network->buswidth > busidx) {
+				net = pi->conarcinst->network->networklist[busidx];
+			} else {
+				net = pi->conarcinst->network;
+			}
 			break;
 		}
 		if (pi == NOPORTARCINST)
@@ -2163,7 +2201,12 @@ CHAR *sim_spice_signalname(NETWORK *net)
 			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 				if (pe->proto == pp)
 			{
-				net = pe->exportproto->network;
+				/* if bussed, grab correct net in bus, otherwise just grab net */
+				if (pe->exportproto->network->buswidth > 1 && pe->exportproto->network->buswidth > busidx) {
+					net = pe->exportproto->network->networklist[busidx];
+				} else {
+					net = pe->exportproto->network;
+				}
 				break;
 			}
 			if (pe == NOPORTEXPINST) break;
@@ -2175,9 +2218,9 @@ CHAR *sim_spice_signalname(NETWORK *net)
 	prevstr = x_("");
 	for(;;)
 	{
-		if (netpar->cell == np->cell) break;
+		if (insamecellgrp(netpar, np)) break;
 
-		/* find the instance that is the proper parent of this facet */
+		/* find the instance that is the proper parent of this cell */
 		ni = descentparent(netpar, &index, NOWINDOWPART, 0);
 		if (ni == NONODEINST) break;
 
@@ -2189,7 +2232,15 @@ CHAR *sim_spice_signalname(NETWORK *net)
 		}
 		infstr = initinfstr();
 		addtoinfstr(infstr, 'x');
-		addstringtoinfstr(infstr, (CHAR *)varname->addr);
+		signame = (CHAR *)varname->addr;
+		if (ni->arraysize > 1)
+		{
+			sigcount = net_evalbusname(APBUS, signame, &nodenames,
+				NOARCINST, NONODEPROTO, 0);
+			if (index >= 0 && index < sigcount)
+				signame = nodenames[index];
+		}
+		addstringtoinfstr(infstr, signame);
 		if (*prevstr != 0)
 		{
 			addtoinfstr(infstr, '.');
@@ -2231,4 +2282,51 @@ INTBIG sim_spice_findsignalname(CHAR *name)
 	return(-1);
 }
 
+/*
+ * Routine that feeds the current signals into the explorer window.
+ */
+void sim_spicereportsignals(WINDOWPART *simwin, void *(*addbranch)(CHAR*, void*),
+	void *(*findbranch)(CHAR*, void*), void *(*addleaf)(CHAR*, void*), CHAR *(*nodename)(void*))
+{
+	REGISTER INTBIG i, j, k, len;
+	REGISTER CHAR *pt, *signame, save;
+	REGISTER void *curlevel, *nextlevel;
+
+	for(i=0; i<sim_spice_signals; i++)
+	{
+		signame = sim_spice_signames[i];
+		len = strlen(signame);
+		for(j=len-2; j>0; j--)
+			if (signame[j] == '.') break;
+		if (j <= 0)
+		{
+			/* no "." qualifiers */
+			(*addleaf)(signame, 0);
+		} else
+		{
+			/* is down the hierarchy */
+			signame[j] = 0;
+
+			/* now find the location for this branch */
+			curlevel = 0;
+			pt = signame;
+			for(;;)
+			{
+				for(k=0; pt[k] != 0; k++) if (pt[k] == '.') break;
+				save = pt[k];
+				pt[k] = 0;
+				nextlevel = (*findbranch)(pt, curlevel);
+				if (nextlevel == 0)
+					nextlevel = (*addbranch)(pt, curlevel);
+				curlevel = nextlevel;
+				if (save == 0) break;
+				pt[k] = save;
+				pt = &pt[k+1];
+			}
+			(*addleaf)(&signame[j+1], curlevel);
+			signame[j] = '.';
+		}
+	}
+}
+
 #endif  /* SIMTOOL - at top */
