@@ -79,7 +79,7 @@ void sim_writetexnetlist(NODEPROTO *np)
 	CHAR str1[30], filename[200], *libname, *resfilename, *truename;
 
 	/* write the "TDL" file */
-	(void)estrcpy(filename, np->cell->cellname);
+	(void)estrcpy(filename, np->protoname);
 	(void)estrcat(filename, x_(".tdl"));
 	sim_texfile = xcreate(filename, sim_filetypetegas, _("TEGAS File"), &truename);
 	if (sim_texfile == NULL)
@@ -155,7 +155,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 		if (ni->proto->temp1 != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (ni->proto->cell == np->cell) continue;
+		if (isiconof(ni->proto, np)) continue;
 
 		sim_writetexcell(ni->proto, 0);
 	}
@@ -302,7 +302,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 			/*  directory or for a module from the MASTER directory */
 			case NPUNKNOWN:
 				/* ignore recursive references (showing icon in contents) */
-				if (ni->proto->cell == np->cell) continue;
+				if (isiconof(ni->proto, np)) continue;
 				addstringtoinfstr(infstr, x_("  "));
 				addstringtoinfstr(infstr, sim_texproto(ni, f, &module_err));
 				addstringtoinfstr(infstr, x_(" = "));
@@ -383,7 +383,7 @@ void sim_writetexcell(NODEPROTO *np, INTBIG top)
 
 			case NPUNKNOWN:
 				/* ignore recursive references (showing icon in contents) */
-				if (ni->proto->cell == np->cell) continue;
+				if (isiconof(ni->proto, np)) continue;
 				/* FALLTHROUGH */ 
 			case NPTRANS:
 			case NPGATEXOR:
@@ -1029,9 +1029,9 @@ CHAR *sim_texlibname(NODEPROTO *np)
 
 	if (np->primindex != 0) return(x_("MASTER"));
 
-	separator = sim_strcspn(np->cell->lib->libname, x_(":]")) + 1;
-	if (separator == (INTBIG)(estrlen(np->cell->lib->libname)+1)) separator = 0;
-	return(sim_texname((np->cell->lib->libname + separator)));
+	separator = sim_strcspn(np->lib->libname, x_(":]")) + 1;
+	if (separator == (INTBIG)(estrlen(np->lib->libname)+1)) separator = 0;
+	return(sim_texname((np->lib->libname + separator)));
 }
 
 /*
