@@ -186,10 +186,10 @@ static void       fpga_describepip(NODEINST *ni, FPGANODE *fn, INTBIG pipindex,
 static void       fpga_findvariableobjects(NODEINST *ni, INTBIG varkey, void (*setit)(CHAR*));
 static void       fpga_killptree(LISPTREE *lt);
 static BOOLEAN    fpga_makeblockinstance(NODEPROTO *np, LISPTREE *lt);
-static BOOLEAN    fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt);
+static BOOLEAN    fpga_makeblocknet(NODEPROTO *cell, LISPTREE *lt);
 static BOOLEAN    fpga_makeblockport(NODEPROTO *np, LISPTREE *lt);
 static BOOLEAN    fpga_makeblockrepeater(NODEPROTO *np, LISPTREE *lt);
-static NODEPROTO *fpga_makefacet(LISPTREE *lt);
+static NODEPROTO *fpga_makecell(LISPTREE *lt);
 static BOOLEAN    fpga_makeprimitive(LISPTREE *lt);
 static INTBIG     fpga_makeprimitives(LISPTREE *lt);
 static BOOLEAN    fpga_makeprimnet(NODEPROTO *np, LISPTREE *lt, FPGANODE *fn, FPGANET *fnet);
@@ -364,11 +364,10 @@ void fpga_termprocess(void)
 {
 #ifdef DEBUGMEMORY
 	LISPTREE *lt;
-	REGISTER INTBIG i, j, k;
+	REGISTER INTBIG i, j;
 	REGISTER FPGANET *fnet;
 	REGISTER FPGAPIP *fpip;
 	REGISTER FPGANODE *fn;
-	REGISTER FPGAPORT *fp, *ofp;
 
 	if (fpga_arcbufsize > 0) efree((CHAR *)fpga_arcbuf);
 	if (fpga_pipbufsize > 0) efree((CHAR *)fpga_pipbuf);
@@ -440,7 +439,7 @@ void fpga_termprocess(void)
 void fpga_setmode(INTBIG count, CHAR *par[])
 {
 	REGISTER CHAR *pp;
-	REGISTER NODEPROTO *topfacet;
+	REGISTER NODEPROTO *topcell;
 	REGISTER NODEINST *ni;
 	CHAR *filename, *subpar[1];
 	FILE *f;
@@ -590,8 +589,8 @@ void fpga_setmode(INTBIG count, CHAR *par[])
 		/* place and wire the primitives */
 		if (namesamen(pp, x_("read-architecture-file"), l) == 0)
 		{
-			topfacet = fpga_placeprimitives(lt);
-			if (topfacet != NONODEPROTO)
+			topcell = fpga_placeprimitives(lt);
+			if (topcell != NONODEPROTO)
 			{
 				/* recompute bounds */
 				(*el_curconstraint->solve)(NONODEPROTO);
@@ -599,9 +598,9 @@ void fpga_setmode(INTBIG count, CHAR *par[])
 				/* recompute networks */
 				(void)asktool(net_tool, x_("total-re-number"));
 
-				/* display top facet */
-				subpar[0] = describenodeproto(topfacet);
-				us_editfacet(1, subpar);
+				/* display top cell */
+				subpar[0] = describenodeproto(topcell);
+				us_editcell(1, subpar);
 			}
 		}
 
@@ -781,7 +780,7 @@ void fpga_intshapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly, POLYLOOP *pl
 				poly->yv[3] = poly->yv[0];   poly->yv[2] = poly->yv[1];
 				poly->count = 4;
 				poly->style = TEXTBOX;
-				poly->string = ni->proto->primname;
+				poly->string = ni->proto->protoname;
 				TDCLEAR(poly->textdescript);
 				TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(12));
 				poly->tech = fpga_tech;
@@ -1040,7 +1039,7 @@ BOOLEAN fpga_arcendactive(ARCINST *ai, INTBIG j)
 	pindex = ni->proto->primindex;
 	if (pindex == 0)
 	{
-		/* follow down into facet */
+		/* follow down into cell */
 		downhierarchy(ni, ni->proto, 0);
 		subni = pp->subnodeinst;
 		for(pi = subni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
@@ -1314,7 +1313,7 @@ void fpga_setrepeater(CHAR *name)
 }
 
 /*
- * Routine to clear the cache of arc activity in the current facet.  If "ni" is NONODEINST,
+ * Routine to clear the cache of arc activity in the current cell.  If "ni" is NONODEINST,
  * clear all node caches as well, otherwise only clear the node cache on "ni".
  */
 void fpga_clearcache(NODEINST *ni)
@@ -1323,10 +1322,10 @@ void fpga_clearcache(NODEINST *ni)
 	REGISTER ARCINST *ai;
 	REGISTER NODEPROTO *np;
 
-	np = getcurfacet();
+	np = getcurcell();
 	if (np == NONODEPROTO)
 	{
-		ttyputerr(_("Must edit a facet to clear its cache"));
+		ttyputerr(_("Must edit a cell to clear its cache"));
 		return;
 	}
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -1847,7 +1846,7 @@ BOOLEAN fpga_makeprimitive(LISPTREE *lt)
 	/* make the primitive */
 	primnp = allocnodeproto(fpga_tech->cluster);
 	if (primnp == NONODEPROTO) return(TRUE);
-	if (allocstring(&primnp->primname, primname, fpga_tech->cluster)) return(TRUE);
+	if (allocstring(&primnp->protoname, primname, fpga_tech->cluster)) return(TRUE);
 	lambda = el_curlib->lambda[fpga_tech->techindex];
 	sizex = myatoi(primsizex) * lambda;
 	sizey = myatoi(primsizey) * lambda;
@@ -2408,7 +2407,7 @@ NODEPROTO *fpga_placeprimitives(LISPTREE *lt)
 			namesame(sublt->keyword, x_("architecture")) != 0) continue;
 
 		/* create the primitive */
-		np = fpga_makefacet(sublt);
+		np = fpga_makecell(sublt);
 		if (np == NONODEPROTO) return(NONODEPROTO);
 		if (namesame(sublt->keyword, x_("architecture")) == 0) toplevel = np;
 	}
@@ -2416,16 +2415,16 @@ NODEPROTO *fpga_placeprimitives(LISPTREE *lt)
 }
 
 /*
- * Routine to create a facet from a subtree "lt".
+ * Routine to create a cell from a subtree "lt".
  * Tree has "(blockdef...)" or "(architecture...)" structure.
  * Returns nonzero on error.
  */
-NODEPROTO *fpga_makefacet(LISPTREE *lt)
+NODEPROTO *fpga_makecell(LISPTREE *lt)
 {
 	REGISTER INTBIG i, j;
 	REGISTER BOOLEAN gotsize;
 	REGISTER INTBIG sizex, sizey, lambda;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER LISPTREE *scanlt, *ltattribute, *ltnets, *ltports, *ltcomponents;
 	REGISTER CHAR *blockname;
 
@@ -2520,18 +2519,18 @@ NODEPROTO *fpga_makefacet(LISPTREE *lt)
 		return(NONODEPROTO);
 	}
 
-	/* make the facet */
-	facet = us_newnodeproto(blockname, el_curlib);
-	if (facet == NONODEPROTO) return(NONODEPROTO);
-	ttyputmsg(_("Creating facet '%s'"), blockname);
+	/* make the cell */
+	cell = us_newnodeproto(blockname, el_curlib);
+	if (cell == NONODEPROTO) return(NONODEPROTO);
+	ttyputmsg(_("Creating cell '%s'"), blockname);
 
 	/* force size by placing pins in the corners */
 	if (gotsize)
 	{
-		newnodeinst(fpga_wirepinprim, 0, lambda, 0, lambda, 0, 0, facet);
-		newnodeinst(fpga_wirepinprim, sizex-lambda, sizex, 0, lambda, 0, 0, facet);
-		newnodeinst(fpga_wirepinprim, 0, lambda, sizey-lambda, sizey, 0, 0, facet);
-		newnodeinst(fpga_wirepinprim, sizex-lambda, sizex, sizey-lambda, sizey, 0, 0, facet);
+		newnodeinst(fpga_wirepinprim, 0, lambda, 0, lambda, 0, 0, cell);
+		newnodeinst(fpga_wirepinprim, sizex-lambda, sizex, 0, lambda, 0, 0, cell);
+		newnodeinst(fpga_wirepinprim, 0, lambda, sizey-lambda, sizey, 0, 0, cell);
+		newnodeinst(fpga_wirepinprim, sizex-lambda, sizex, sizey-lambda, sizey, 0, 0, cell);
 	}
 
 	/* add any unrecognized attributes */
@@ -2548,7 +2547,7 @@ NODEPROTO *fpga_makefacet(LISPTREE *lt)
 				scanlt->keyword, scanlt->lineno);
 			return(NONODEPROTO);
 		}
-		(void)setval((INTBIG)facet, VNODEPROTO, scanlt->keyword, (INTBIG)scanlt->paramvalue[0],
+		(void)setval((INTBIG)cell, VNODEPROTO, scanlt->keyword, (INTBIG)scanlt->paramvalue[0],
 			VSTRING);
 	}
 
@@ -2561,12 +2560,12 @@ NODEPROTO *fpga_makefacet(LISPTREE *lt)
 			scanlt = (LISPTREE *)ltcomponents->paramvalue[j];
 			if (namesame(scanlt->keyword, x_("repeater")) == 0)
 			{
-				if (fpga_makeblockrepeater(facet, scanlt)) return(NONODEPROTO);
+				if (fpga_makeblockrepeater(cell, scanlt)) return(NONODEPROTO);
 				continue;
 			}
 			if (namesame(scanlt->keyword, x_("instance")) == 0)
 			{
-				if (fpga_makeblockinstance(facet, scanlt)) return(NONODEPROTO);
+				if (fpga_makeblockinstance(cell, scanlt)) return(NONODEPROTO);
 				continue;
 			}
 		}
@@ -2581,7 +2580,7 @@ NODEPROTO *fpga_makefacet(LISPTREE *lt)
 			scanlt = (LISPTREE *)ltports->paramvalue[j];
 			if (namesame(scanlt->keyword, x_("port")) == 0)
 			{
-				if (fpga_makeblockport(facet, scanlt)) return(NONODEPROTO);
+				if (fpga_makeblockport(cell, scanlt)) return(NONODEPROTO);
 			}
 		}
 	}
@@ -2596,19 +2595,19 @@ NODEPROTO *fpga_makefacet(LISPTREE *lt)
 			scanlt = (LISPTREE *)ltnets->paramvalue[j];
 			if (namesame(scanlt->keyword, x_("net")) == 0)
 			{
-				if (fpga_makeblocknet(facet, scanlt)) return(NONODEPROTO);
+				if (fpga_makeblocknet(cell, scanlt)) return(NONODEPROTO);
 				i++;
 			}
 		}
 	}
-	return(facet);
+	return(cell);
 }
 
 /*
- * Routine to place an instance in facet "facet" from the LISPTREE in "lt".
+ * Routine to place an instance in cell "cell" from the LISPTREE in "lt".
  * Tree has "(instance...)" structure.  Returns true on error.
  */
-BOOLEAN fpga_makeblockinstance(NODEPROTO *facet, LISPTREE *lt)
+BOOLEAN fpga_makeblockinstance(NODEPROTO *cell, LISPTREE *lt)
 {
 	REGISTER INTBIG i, rotation;
 	REGISTER INTBIG posx, posy, yoff, lambda;
@@ -2687,7 +2686,7 @@ BOOLEAN fpga_makeblockinstance(NODEPROTO *facet, LISPTREE *lt)
 		return(TRUE);
 	}
 	for(np = fpga_tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-		if (namesame(np->primname, (CHAR *)lttype->paramvalue[0]) == 0) break;
+		if (namesame(np->protoname, (CHAR *)lttype->paramvalue[0]) == 0) break;
 	if (np == NONODEPROTO)
 		np = getnodeproto((CHAR *)lttype->paramvalue[0]);
 	if (np == NONODEPROTO)
@@ -2721,7 +2720,7 @@ BOOLEAN fpga_makeblockinstance(NODEPROTO *facet, LISPTREE *lt)
 	lambda = el_curlib->lambda[fpga_tech->techindex];
 	posx = myatoi((CHAR *)ltposition->paramvalue[0]) * lambda;
 	posy = myatoi((CHAR *)ltposition->paramvalue[1]) * lambda;
-	ni = newnodeinst(np, posx, posx+np->highx-np->lowx, posy, posy+np->highy-np->lowy, 0, rotation, facet);
+	ni = newnodeinst(np, posx, posx+np->highx-np->lowx, posy, posy+np->highy-np->lowy, 0, rotation, cell);
 	if (ni == NONODEINST) return(TRUE);
 
 	/* add any attributes */
@@ -2763,10 +2762,10 @@ BOOLEAN fpga_makeblockinstance(NODEPROTO *facet, LISPTREE *lt)
 }
 
 /*
- * Routine to add a port to block "facet" from the tree in "lt".
+ * Routine to add a port to block "cell" from the tree in "lt".
  * Tree has "(port...)" structure.  Returns true on error.
  */
-BOOLEAN fpga_makeblockport(NODEPROTO *facet, LISPTREE *lt)
+BOOLEAN fpga_makeblockport(NODEPROTO *cell, LISPTREE *lt)
 {
 	REGISTER INTBIG j;
 	REGISTER INTBIG posx, posy, lambda;
@@ -2821,7 +2820,7 @@ BOOLEAN fpga_makeblockport(NODEPROTO *facet, LISPTREE *lt)
 	lambda = el_curlib->lambda[fpga_tech->techindex];
 	posx = myatoi((CHAR *)ltposition->paramvalue[0]) * lambda;
 	posy = myatoi((CHAR *)ltposition->paramvalue[1]) * lambda;
-	ni = newnodeinst(fpga_wirepinprim, posx, posx, posy, posy, 0, 0, facet);
+	ni = newnodeinst(fpga_wirepinprim, posx, posx, posy, posy, 0, 0, cell);
 	if (ni == NONODEINST)
 	{
 		ttyputerr(_("Error creating pin for port '%s' (line %ld)"),
@@ -2829,7 +2828,7 @@ BOOLEAN fpga_makeblockport(NODEPROTO *facet, LISPTREE *lt)
 		return(TRUE);
 	}
 	pp = fpga_wirepinprim->firstportproto;
-	expp = newportproto(facet, ni, pp, (CHAR *)ltname->paramvalue[0]);
+	expp = newportproto(cell, ni, pp, (CHAR *)ltname->paramvalue[0]);
 	if (expp == NOPORTPROTO)
 	{
 		ttyputerr(_("Error creating port '%s' (line %ld)"),
@@ -2840,10 +2839,10 @@ BOOLEAN fpga_makeblockport(NODEPROTO *facet, LISPTREE *lt)
 }
 
 /*
- * Routine to place a repeater in facet "facet" from the LISPTREE in "lt".
+ * Routine to place a repeater in cell "cell" from the LISPTREE in "lt".
  * Tree has "(repeater...)" structure.  Returns true on error.
  */
-BOOLEAN fpga_makeblockrepeater(NODEPROTO *facet, LISPTREE *lt)
+BOOLEAN fpga_makeblockrepeater(NODEPROTO *cell, LISPTREE *lt)
 {
 	REGISTER INTBIG j, angle;
 	REGISTER INTBIG portax, portay, portbx, portby, ctrx, ctry, length, lambda;
@@ -2911,7 +2910,7 @@ BOOLEAN fpga_makeblockrepeater(NODEPROTO *facet, LISPTREE *lt)
 	ctrx = (portax + portbx) / 2;
 	ctry = (portay + portby) / 2;
 	ni = newnodeinst(fpga_repeaterprim, ctrx-length/2, ctrx+length/2,
-		ctry-lambda, ctry+lambda, 0, angle, facet);
+		ctry-lambda, ctry+lambda, 0, angle, cell);
 	if (ni == NONODEINST)
 	{
 		ttyputerr(_("Error creating repeater (line %ld)"), lt->lineno);
@@ -2937,7 +2936,7 @@ BOOLEAN fpga_makeblockrepeater(NODEPROTO *facet, LISPTREE *lt)
  * Routine to extract block net information from the LISPTREE in "lt".
  * Tree has "(net...)" structure.  Returns true on error.
  */
-BOOLEAN fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt)
+BOOLEAN fpga_makeblocknet(NODEPROTO *cell, LISPTREE *lt)
 {
 	REGISTER INTBIG i, j, pos;
 	REGISTER NODEINST *ni;
@@ -3003,7 +3002,7 @@ BOOLEAN fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt)
 					}
 
 					/* find component and port */
-					for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+					for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 					{
 						var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
 						if (var == NOVARIABLE) continue;
@@ -3042,7 +3041,7 @@ BOOLEAN fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt)
 					y = myatoi((CHAR *)scanlt->paramvalue[pos+2]) * lambda;
 
 					/* find pin at this point */
-					sea = initsearch(x, x, y, y, facet);
+					sea = initsearch(x, x, y, y, cell);
 					ni = NONODEINST;
 					for(;;)
 					{
@@ -3059,7 +3058,7 @@ BOOLEAN fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt)
 					}
 					if (geom == NOGEOM)
 					{
-						ni = newnodeinst(fpga_wirepinprim, x, x, y, y, 0, 0, facet);
+						ni = newnodeinst(fpga_wirepinprim, x, x, y, y, 0, 0, cell);
 						if (ni == NONODEINST)
 						{
 							ttyputerr(_("Cannot create pin for block net segment (line %ld)"), scanlt->lineno);
@@ -3083,7 +3082,7 @@ BOOLEAN fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt)
 					}
 
 					/* find port */
-					pp = getportproto(facet, (CHAR *)scanlt->paramvalue[pos+1]);
+					pp = getportproto(cell, (CHAR *)scanlt->paramvalue[pos+1]);
 					if (pp == NOPORTPROTO)
 					{
 						ttyputerr(_("Cannot find port '%s' in block net segment (line %ld)"),
@@ -3105,7 +3104,7 @@ BOOLEAN fpga_makeblocknet(NODEPROTO *facet, LISPTREE *lt)
 			portposition(nis[0], pps[0], &px0, &py0);
 			portposition(nis[1], pps[1], &px1, &py1);
 			ai = newarcinst(fpga_tech->firstarcproto, 0, FIXANG, nis[0], pps[0], px0, py0,
-				nis[1], pps[1], px1, py1, facet);
+				nis[1], pps[1], px1, py1, cell);
 			if (ai == NOARCINST)
 			{
 				ttyputerr(_("Cannot run segment (line %ld)"), scanlt->lineno);
