@@ -59,29 +59,29 @@ static TECHNOLOGY *gem_tech;
 #define LFORKARC   6		/* fork arcs */
 
 static GRAPHICS gem_e_lay = {LAYERO, RED, SOLIDC, SOLIDC,
-/* node */		{0, 0, 0, 0, 0, 0, 0, 0}, NOVARIABLE, 0};
+/* node */		{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gem_ga_lay = {LAYERO, BLUE, SOLIDC, SOLIDC,
-/* general arc */	{0, 0, 0, 0, 0, 0, 0, 0}, NOVARIABLE, 0};
+/* general arc */	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gem_ta_lay = {LAYERO, GREEN, SOLIDC, SOLIDC,
-/* temporal arc */	{0, 0, 0, 0, 0, 0, 0, 0}, NOVARIABLE, 0};
+/* temporal arc */	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gem_ca_lay = {LAYERO, BLACK, SOLIDC, SOLIDC,
-/* causal arc */	{0, 0, 0, 0, 0, 0, 0, 0}, NOVARIABLE, 0};
+/* causal arc */	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gem_pa_lay = {LAYERO, ORANGE, SOLIDC, SOLIDC,
-/* prereq. arc */	{0, 0, 0, 0, 0, 0, 0, 0}, NOVARIABLE, 0};
+/* prereq. arc */	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gem_na_lay = {LAYERO, YELLOW, SOLIDC, SOLIDC,
-/* nondet arc */	{0, 0, 0, 0, 0, 0, 0, 0}, NOVARIABLE, 0};
+/* nondet arc */	{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gem_fa_lay = {LAYERO, PURPLE, SOLIDC, SOLIDC,
-/* fork arc */		{0, 0, 0, 0, 0, 0, 0, 0}, NOVARIABLE, 0};
+/* fork arc */		{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 
 /* these tables must be updated togehter */
 GRAPHICS *gem_layers[MAXLAYERS+1] = {&gem_e_lay, &gem_ga_lay,
 	&gem_ta_lay, &gem_ca_lay, &gem_pa_lay, &gem_na_lay, &gem_fa_lay, NOGRAPHICS};
-static char *gem_layer_names[MAXLAYERS] = {"Element", "General-arc",
-	"Temporal-arc", "Causal-arc", "Prereq-arc", "Nondet-arc", "Fork-arc"};
+static CHAR *gem_layer_names[MAXLAYERS] = {x_("Element"), x_("General-arc"),
+	x_("Temporal-arc"), x_("Causal-arc"), x_("Prereq-arc"), x_("Nondet-arc"), x_("Fork-arc")};
 static INTBIG gem_layer_function[MAXLAYERS] = {LFART|LFNONELEC,
 	LFCONTROL|LFNONELEC, LFCONTROL|LFNONELEC, LFCONTROL|LFNONELEC,
 	LFCONTROL|LFNONELEC, LFCONTROL|LFNONELEC, LFCONTROL|LFNONELEC};
-static char *gem_layer_letters[MAXLAYERS] = {"e", "g", "t", "c", "p", "n", "f"};
+static CHAR *gem_layer_letters[MAXLAYERS] = {x_("e"), x_("g"), x_("t"), x_("c"), x_("p"), x_("n"), x_("f")};
 
 /********************************* ARCS *************************************/
 
@@ -96,42 +96,42 @@ static char *gem_layer_letters[MAXLAYERS] = {"e", "g", "t", "c", "p", "n", "f"};
 /* General arc */
 static TECH_ARCLAY gem_gw[] = {{LGENARC,0,VECTORS}};
 static TECH_ARCS gem_a_g = {
-	"General",0,AGENERAL,NOARCPROTO,					/* name */
+	x_("General"),0,AGENERAL,NOARCPROTO,				/* name */
 	1,gem_gw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Temporal arc */
 static TECH_ARCLAY gem_tw[] = {{LTEMPARC,0,VECTORS}};
 static TECH_ARCS gem_a_t = {
-	"Temporal",0,ATEMP,NOARCPROTO,						/* name */
+	x_("Temporal"),0,ATEMP,NOARCPROTO,					/* name */
 	1,gem_tw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Causal arc */
 static TECH_ARCLAY gem_cw[] = {{LCAUSEARC,0,VECTORS}};
 static TECH_ARCS gem_a_c = {
-	"Causal",0,ACAUSE,NOARCPROTO,						/* name */
+	x_("Causal"),0,ACAUSE,NOARCPROTO,					/* name */
 	1,gem_cw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Prereq arc */
 static TECH_ARCLAY gem_pw[] = {{LPREARC,0,VECTORS}};
 static TECH_ARCS gem_a_p = {
-	"Prerequisite",0,APREREQ,NOARCPROTO,				/* name */
+	x_("Prerequisite"),0,APREREQ,NOARCPROTO,			/* name */
 	1,gem_pw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Nondeterministic arc */
 static TECH_ARCLAY gem_nw[] = {{LNONARC,0,VECTORS}};
 static TECH_ARCS gem_a_n = {
-	"Nondeterministic",0,ANONDET,NOARCPROTO,			/* name */
+	x_("Nondeterministic"),0,ANONDET,NOARCPROTO,		/* name */
 	1,gem_nw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
 /* Nondeterministic-fork arc */
 static TECH_ARCLAY gem_fw[] = {{LFORKARC,0,VECTORS}};
 static TECH_ARCS gem_a_f = {
-	"Nondeterministic-fork",0,AFORK,NOARCPROTO,			/* name */
+	x_("Nondeterministic-fork"),0,AFORK,NOARCPROTO,		/* name */
 	1,gem_fw,											/* layers */
 	(APNONELEC<<AFUNCTIONSH)|CANWIPE|(0<<AANGLEINCSH)};	/* userbits */
 
@@ -151,21 +151,21 @@ static INTBIG gem_pcn[] = {-1, ANONDET, ALLGEN, -1};
 static INTBIG gem_pcf[] = {-1, AFORK, ALLGEN, -1};
 
 /* polygon descriptions */
-static char gem_Element[] = "Element";
-static char gem_sc1[] = "1";
-static char gem_sc2[] = "2";
-static char gem_sc3[] = "3";
-static char gem_sc4[] = "4";
+static CHAR gem_Element[] = {x_("Element")};
+static CHAR gem_sc1[] = {x_("1")};
+static CHAR gem_sc2[] = {x_("2")};
+static CHAR gem_sc3[] = {x_("3")};
+static CHAR gem_sc4[] = {x_("4")};
 
 static INTBIG gem_circle[]      = {CENTER,   CENTER,   CENTER,    TOPEDGE};
 static INTBIG gem_fullbox[]     = {LEFTEDGE, BOTEDGE,  RIGHTEDGE, TOPEDGE};
-static char *gem_elementname[] = {(char *)-H0,  (char *)0, (char *)0, (char *)K1,
-								  (char *)H0,  (char *)0, (char *)H0,  (char *)0,
+static CHAR *gem_elementname[] = {(CHAR *)-H0,  (CHAR *)0, (CHAR *)0, (CHAR *)K1,
+								  (CHAR *)H0,  (CHAR *)0, (CHAR *)H0,  (CHAR *)0,
 								  gem_Element};
-static char *gem_event1name[]  = {(char *)-H0, (char *)K2,  (char *)0, (char *)0,  gem_sc1};
-static char *gem_event2name[]  = {(char *)-H0, (char *)K2,  (char *)0,(char *)-K1, gem_sc2};
-static char *gem_event3name[]  = {(char *)-H0, (char *)K2,  (char *)0,(char *)-K2, gem_sc3};
-static char *gem_event4name[]  = {(char *)-H0, (char *)K2,  (char *)0,(char *)-K3, gem_sc4};
+static CHAR *gem_event1name[]  = {(CHAR *)-H0, (CHAR *)K2,  (CHAR *)0, (CHAR *)0,  gem_sc1};
+static CHAR *gem_event2name[]  = {(CHAR *)-H0, (CHAR *)K2,  (CHAR *)0,(CHAR *)-K1, gem_sc2};
+static CHAR *gem_event3name[]  = {(CHAR *)-H0, (CHAR *)K2,  (CHAR *)0,(CHAR *)-K2, gem_sc3};
+static CHAR *gem_event4name[]  = {(CHAR *)-H0, (CHAR *)K2,  (CHAR *)0,(CHAR *)-K3, gem_sc4};
 
 /********************************** NODES **********************************/
 
@@ -181,13 +181,13 @@ static char *gem_event4name[]  = {(char *)-H0, (char *)K2,  (char *)0,(char *)-K
 
 /* element */
 static TECH_PORTS gem_e_p[] = {				/* ports */
-	{gem_pc, "port1", NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pc, x_("port1"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2, CENTERU0H, LEFTIN2, CENTERU0H},
-	{gem_pc, "port2", NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pc, x_("port2"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2, CENTERD0H, LEFTIN2, CENTERD0H},
-	{gem_pc, "port3", NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pc, x_("port3"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2, CENTERD1H, LEFTIN2, CENTERD1H},
-	{gem_pc, "port4", NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pc, x_("port4"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTIN2, CENTERD2H, LEFTIN2, CENTERD2H}};
 static TECH_POLYGON gem_e_l[] = {			/* layers */
 	{LELEGROUP, -1, 2, CIRCLE,      POINTS, gem_circle},
@@ -197,7 +197,7 @@ static TECH_POLYGON gem_e_l[] = {			/* layers */
 	{LELEGROUP, -1, 1, TEXTBOTLEFT, POINTS, (INTBIG *)gem_event3name},
 	{LELEGROUP, -1, 1, TEXTBOTLEFT, POINTS, (INTBIG *)gem_event4name}};
 static TECH_NODES gem_e = {
-	"Element",NELEMENT,NONODEPROTO,			/* name */
+	x_("Element"),NELEMENT,NONODEPROTO,		/* name */
 	K8,K8,									/* size */
 	4,gem_e_p,								/* ports */
 	6,gem_e_l,								/* layers */
@@ -206,12 +206,12 @@ static TECH_NODES gem_e = {
 
 /* group */
 static TECH_PORTS gem_g_p[] = {				/* ports */
-	{gem_pc, "group",    NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pc, x_("group"),    NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTEDGE, BOTEDGE, RIGHTEDGE, TOPEDGE}};
 static TECH_POLYGON gem_g_l[] = {			/* layers */
 	{LELEGROUP, -1, 4, CLOSEDRECT, BOX, gem_fullbox}};
 static TECH_NODES gem_g = {
-	"Group",NGROUP,NONODEPROTO,				/* name */
+	x_("Group"),NGROUP,NONODEPROTO,			/* name */
 	K10,K10,								/* size */
 	1,gem_g_p,								/* ports */
 	1,gem_g_l,								/* layers */
@@ -220,25 +220,26 @@ static TECH_NODES gem_g = {
 
 /* general-pin */
 static TECH_PORTS gem_gp_p[] = {			/* ports */
-	{gem_pcg, "general",    NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pcg, x_("general"),    NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gem_gp_l[] = {			/* layers */
 	{LGENARC, -1, 2, DISC, POINTS, gem_circle}};
 static TECH_NODES gem_gp = {
-	"General-Pin",NGENERALP,NONODEPROTO,	/* name */
+	x_("General-Pin"),NGENERALP,NONODEPROTO,/* name */
 	K1,K1,									/* size */
 	1,gem_gp_p,								/* ports */
 	1,gem_gp_l,								/* layers */
-	(NPPIN<<NFUNCTIONSH)|ARCSWIPE};			/* userbits */
+	(NPPIN<<NFUNCTIONSH)|ARCSWIPE,			/* userbits */
+	0,0,0,0,0,0,0,0,0};						/* characteristics */
 
 /* temporal-pin */
 static TECH_PORTS gem_tp_p[] = {			/* ports */
-	{gem_pct, "temporal",    NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pct, x_("temporal"),    NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gem_tp_l[] = {			/* layers */
 	{LTEMPARC, -1, 2, DISC, POINTS, gem_circle}};
 static TECH_NODES gem_tp = {
-	"Temporal-Pin",NTEMPP,NONODEPROTO,		/* name */
+	x_("Temporal-Pin"),NTEMPP,NONODEPROTO,	/* name */
 	K1,K1,									/* size */
 	1,gem_tp_p,								/* ports */
 	1,gem_tp_l,								/* layers */
@@ -247,12 +248,12 @@ static TECH_NODES gem_tp = {
 
 /* causal-pin */
 static TECH_PORTS gem_cp_p[] = {			/* ports */
-	{gem_pcc, "cause",    NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pcc, x_("cause"),    NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gem_cp_l[] = {			/* layers */
 	{LCAUSEARC, -1, 2, DISC, POINTS, gem_circle}};
 static TECH_NODES gem_cp = {
-	"Cause-Pin",NCAUSEP,NONODEPROTO,		/* name */
+	x_("Cause-Pin"),NCAUSEP,NONODEPROTO,	/* name */
 	K1,K1,									/* size */
 	1,gem_cp_p,								/* ports */
 	1,gem_cp_l,								/* layers */
@@ -261,12 +262,12 @@ static TECH_NODES gem_cp = {
 
 /* prereq-pin */
 static TECH_PORTS gem_pp_p[] = {			/* ports */
-	{gem_pcp, "prereq",    NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pcp, x_("prereq"),    NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gem_pp_l[] = {			/* layers */
 	{LPREARC, -1, 2, DISC, POINTS, gem_circle}};
 static TECH_NODES gem_pp = {
-	"Prereq-Pin",NPREREQP,NONODEPROTO,		/* name */
+	x_("Prereq-Pin"),NPREREQP,NONODEPROTO,	/* name */
 	K1,K1,									/* size */
 	1,gem_pp_p,								/* ports */
 	1,gem_pp_l,								/* layers */
@@ -275,12 +276,12 @@ static TECH_NODES gem_pp = {
 
 /* nondeterministic-pin */
 static TECH_PORTS gem_np_p[] = {			/* ports */
-	{gem_pcn, "nondet",    NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pcn, x_("nondet"),    NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gem_np_l[] = {			/* layers */
 	{LNONARC, -1, 2, DISC, POINTS, gem_circle}};
 static TECH_NODES gem_np = {
-	"Nondet-Pin",NNONDETP,NONODEPROTO,		/* name */
+	x_("Nondet-Pin"),NNONDETP,NONODEPROTO,	/* name */
 	K1,K1,									/* size */
 	1,gem_np_p,								/* ports */
 	1,gem_np_l,								/* layers */
@@ -289,12 +290,12 @@ static TECH_NODES gem_np = {
 
 /* fork-pin */
 static TECH_PORTS gem_fp_p[] = {			/* ports */
-	{gem_pcf, "fork",    NOPORTPROTO, (180<<PORTARANGESH),
+	{gem_pcf, x_("fork"),    NOPORTPROTO, (180<<PORTARANGESH),
 		CENTER, CENTER, CENTER, CENTER}};
 static TECH_POLYGON gem_fp_l[] = {			/* layers */
 	{LFORKARC, -1, 2, DISC, POINTS, gem_circle}};
 static TECH_NODES gem_fp = {
-	"Fork-Pin",NFORKP,NONODEPROTO,			/* name */
+	x_("Fork-Pin"),NFORKP,NONODEPROTO,		/* name */
 	K1,K1,									/* size */
 	1,gem_fp_p,								/* ports */
 	1,gem_fp_l,								/* layers */
@@ -309,13 +310,13 @@ TECH_NODES *gem_nodeprotos[NODEPROTOCOUNT+1] = { &gem_e, &gem_g,
 TECH_VARIABLES gem_variables[] =
 {
 	/* set general information about the technology */
-	{"TECH_layer_names", (char *)gem_layer_names, 0.0,
+	{x_("TECH_layer_names"), (CHAR *)gem_layer_names, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
-	{"TECH_layer_function", (char *)gem_layer_function, 0.0,
+	{x_("TECH_layer_function"), (CHAR *)gem_layer_function, 0.0,
 		VINTEGER|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 
 	/* set information for the USER tool */
-	{"USER_layer_letters", (char *)gem_layer_letters, 0.0,
+	{x_("USER_layer_letters"), (CHAR *)gem_layer_letters, 0.0,
 		VSTRING|VDONTSAVE|VISARRAY|(MAXLAYERS<<VLENGTHSH)},
 	{NULL, NULL, 0.0, 0}
 };
@@ -362,29 +363,31 @@ void gem_intshapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly, POLYLOOP *pl)
 	switch (box)
 	{
 		case 1:
-			if (elementkey == 0) elementkey = makekey("GEM_element");
+			if (elementkey == 0) elementkey = makekey(x_("GEM_element"));
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, elementkey);
 			TDCLEAR(poly->textdescript);
 			TDSETSIZE(poly->textdescript, TXTSETQLAMBDA(12));
 			break;
 		case 2:
-			if (event1key == 0) event1key = makekey("GEM_event1");
+			if (event1key == 0) event1key = makekey(x_("GEM_event1"));
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event1key);
 			break;
 		case 3:
-			if (event2key == 0) event2key = makekey("GEM_event2");
+			if (event2key == 0) event2key = makekey(x_("GEM_event2"));
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event2key);
 			break;
 		case 4:
-			if (event3key == 0) event3key = makekey("GEM_event3");
+			if (event3key == 0) event3key = makekey(x_("GEM_event3"));
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event3key);
 			break;
 		case 5:
-			if (event4key == 0) event4key = makekey("GEM_event4");
+			if (event4key == 0) event4key = makekey(x_("GEM_event4"));
 			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, event4key);
 			break;
+		default:
+			var = NOVARIABLE;
 	}
-	if (var != NOVARIABLE) poly->string = (char *)var->addr;
+	if (var != NOVARIABLE) poly->string = (CHAR *)var->addr;
 }
 
 INTBIG gem_allnodepolys(NODEINST *ni, POLYLIST *plist, WINDOWPART *win, BOOLEAN onlyreasonable)
