@@ -46,8 +46,8 @@ typedef struct
 static GENPOLYLOOP gen_oneprocpolyloop;
 
 TECHNOLOGY *gen_tech;
-NODEPROTO  *gen_univpinprim, *gen_invispinprim, *gen_unroutedpinprim, *gen_facetcenterprim,
-	*gen_portprim, *gen_drcprim, *gen_essentialprim;
+NODEPROTO  *gen_univpinprim, *gen_invispinprim, *gen_unroutedpinprim, *gen_cellcenterprim,
+	*gen_portprim, *gen_drcprim, *gen_essentialprim, *gen_simprobeprim;
 ARCPROTO   *gen_universalarc, *gen_invisiblearc, *gen_unroutedarc;
 ARCPROTO  **gen_upconn = 0;
 
@@ -59,12 +59,13 @@ static void gen_intshapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly, POLYLO
 
 /******************** LAYERS ********************/
 
-#define MAXLAYERS       5		/* total layers below */
+#define MAXLAYERS       6		/* total layers below */
 #define LUNIV           0		/* universal layer (connects all) */
 #define LINVIS          1		/* invisible layer (nonelectrical) */
 #define LUNROUTED       2		/* unrouted layer (for routers) */
 #define LGLYPH          3		/* glyph layer (for menu icons) */
 #define LDRC            4		/* drc ignore layer */
+#define LSIMPROBE       5		/* simulation probe layer */
 
 static GRAPHICS gen_un_lay = {LAYERO, MENTXT, SOLIDC, SOLIDC,
 /* univ */					{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
@@ -78,16 +79,18 @@ static GRAPHICS gen_gl_lay = {LAYERO, MENGLY, SOLIDC, SOLIDC,
 /* glyph */					{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 static GRAPHICS gen_dr_lay = {LAYERO, ORANGE, SOLIDC, SOLIDC,
 /* drc */					{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
+static GRAPHICS gen_sp_lay = {LAYERO, GREEN, SOLIDC, SOLIDC,
+/* sim probe */				{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, NOVARIABLE, 0};
 
 /* these tables must be updated togehter */
 GRAPHICS *gen_layers[MAXLAYERS+1] = {&gen_un_lay, &gen_in_lay,
-	&gen_ur_lay, &gen_gl_lay, &gen_dr_lay, NOGRAPHICS};
+	&gen_ur_lay, &gen_gl_lay, &gen_dr_lay, &gen_sp_lay, NOGRAPHICS};
 static CHAR *gen_layer_names[MAXLAYERS] = {x_("Universal"), x_("Invisible"),
-	x_("Unrouted"), x_("Glyph"), x_("DRC")};
-static CHAR *gen_cif_layers[MAXLAYERS] = {x_(""), x_(""), x_(""), x_(""), x_("DRC")};
+	x_("Unrouted"), x_("Glyph"), x_("DRC"), x_("Sim-Probe")};
+static CHAR *gen_cif_layers[MAXLAYERS] = {x_(""), x_(""), x_(""), x_(""), x_("DRC"), x_("")};
 static INTBIG gen_layer_function[MAXLAYERS] = {LFUNKNOWN, LFUNKNOWN|LFNONELEC,
-	LFUNKNOWN, LFART|LFNONELEC, LFART|LFNONELEC};
-static CHAR *gen_layer_letters[MAXLAYERS] = {x_("u"), x_("i"), x_("r"), x_("g"), x_("d")};
+	LFUNKNOWN, LFART|LFNONELEC, LFART|LFNONELEC, LFART|LFNONELEC};
+static CHAR *gen_layer_letters[MAXLAYERS] = {x_("u"), x_("i"), x_("r"), x_("g"), x_("d"), x_("s")};
 
 /******************** ARCS ********************/
 
@@ -128,14 +131,15 @@ static INTBIG gen_pc_riu[] = {-1, GENAUNROUTED, GENAINVIS, GENAUNIV, -1};
 
 /******************** NODES ********************/
 
-#define NODEPROTOCOUNT     7
+#define NODEPROTOCOUNT     8
 #define NUNIV              1		/* universal pin */
 #define NINVIS             2		/* invisible pin */
 #define NUNROUTED          3		/* unrouted pin */
-#define NCENTER            4		/* facet center */
+#define NCENTER            4		/* cell center */
 #define NPORT              5		/* port declaration (for tech edit) */
 #define NDRC               6		/* drc ignore mask (for ECAD's DRC) */
 #define NESSENTIAL         7		/* essential bounds marker */
+#define NSIMPROBE          8		/* simulation probe */
 
 static INTBIG gen_fullbox[]    = {LEFTEDGE, BOTEDGE, RIGHTEDGE, TOPEDGE};
 static INTBIG gen_disccenter[] = {CENTER,   CENTER,  RIGHTEDGE, CENTER};
@@ -187,7 +191,7 @@ static TECH_NODES gen_r = {
 	(NPPIN<<NFUNCTIONSH)|WIPEON1OR2,				/* userbits */
 	0,0,0,0,0,0,0,0,0};								/* characteristics */
 
-/* Facet Center */
+/* Cell Center */
 static TECH_PORTS gen_c_p[] = {{					/* ports */
 	gen_pc_iu, x_("center"), NOPORTPROTO, (180<<PORTARANGESH),
 		LEFTEDGE, BOTEDGE, LEFTEDGE, BOTEDGE}};
@@ -245,11 +249,25 @@ static TECH_NODES gen_e = {
 	(NPART<<NFUNCTIONSH),							/* userbits */
 	0,0,0,0,0,0,0,0,0};								/* characteristics */
 
+/* Simulation Probe node */
+static TECH_PORTS gen_s_p[] = {{					/* ports */
+	gen_pc_riu, x_("center"), NOPORTPROTO, (180<<PORTARANGESH),
+		LEFTEDGE, BOTEDGE, RIGHTEDGE, TOPEDGE}};
+static TECH_POLYGON gen_s_l[] = {					/* layers */
+	{LSIMPROBE, 0, 4, FILLEDRECT, BOX, gen_fullbox}};
+static TECH_NODES gen_s = {
+	x_("Simulation-Probe"),NSIMPROBE,NONODEPROTO,	/* name */
+	K10,K10,										/* size */
+	1,gen_s_p,										/* ports */
+	1,gen_s_l,										/* layers */
+	(NPART<<NFUNCTIONSH)|HOLDSTRACE,				/* userbits */
+	0,0,0,0,0,0,0,0,0};								/* characteristics */
+
 TECH_NODES *gen_nodeprotos[NODEPROTOCOUNT+1] = {&gen_u, &gen_i,
-	&gen_r, &gen_c, &gen_p, &gen_d, &gen_e, ((TECH_NODES *)-1)};
+	&gen_r, &gen_c, &gen_p, &gen_d, &gen_e, &gen_s, ((TECH_NODES *)-1)};
 
 static INTBIG gen_node_widoff[NODEPROTOCOUNT*4] = {0,0,0,0, 0,0,0,0, 0,0,0,0,
-	0,0,0,0, K2,K2,K2,K2, 0,0,0,0, 0,0,0,0};
+	0,0,0,0, K2,K2,K2,K2, 0,0,0,0, 0,0,0,0, 0,0,0,0};
 
 /******************** VARIABLE AGGREGATION ********************/
 
@@ -291,10 +309,11 @@ BOOLEAN gen_initprocess(TECHNOLOGY *tech, INTBIG pass)
 			gen_univpinprim = getnodeproto(x_("Generic:Universal-Pin"));
 			gen_invispinprim = getnodeproto(x_("Generic:Invisible-Pin"));
 			gen_unroutedpinprim = getnodeproto(x_("Generic:Unrouted-Pin"));
-			gen_facetcenterprim = getnodeproto(x_("Generic:Facet-Center"));
+			gen_cellcenterprim = getnodeproto(x_("Generic:Facet-Center"));
 			gen_portprim = getnodeproto(x_("Generic:Port"));
 			gen_drcprim = getnodeproto(x_("Generic:DRC-Node"));
 			gen_essentialprim = getnodeproto(x_("Generic:Essential-Bounds"));
+			gen_simprobeprim = getnodeproto(x_("Generic:Simulation-Probe"));
 
 			gen_universalarc = getarcproto(x_("Generic:Universal"));
 			gen_invisiblearc = getarcproto(x_("Generic:Invisible"));
@@ -502,7 +521,7 @@ void gen_intshapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly, POLYLOOP *pl,
 
 		case NUNIV:
 			/* universal pins may have trace information */
-			var = getvalkey((INTBIG)ni, VNODEINST, VINTEGER|VISARRAY, el_trace_key);
+			var = gettrace(ni);
 			if (var != NOVARIABLE)
 			{
 				/* make sure polygon can hold this description */
@@ -578,9 +597,11 @@ INTBIG gen_allnodepolys(NODEINST *ni, POLYLIST *plist, WINDOWPART *win, BOOLEAN
 void gen_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	BOOLEAN purpose)
 {
-	REGISTER INTBIG pindex;
+	REGISTER INTBIG pindex, style;
 	Q_UNUSED( purpose );
 
 	pindex = ni->proto->primindex;
-	tech_fillportpoly(ni, pp, poly, trans, gen_nodeprotos[pindex-1], OPENED, lambdaofnode(ni));
+	if (pindex == NSIMPROBE) style = FILLED; else
+		style = OPENED;
+	tech_fillportpoly(ni, pp, poly, trans, gen_nodeprotos[pindex-1], style, lambdaofnode(ni));
 }
