@@ -300,7 +300,7 @@ static GRAPHICS sch_b_lay = {LAYERT3,COLORT3, SOLIDC, PATTERNED,
 static GRAPHICS sch_n_lay = {LAYERO, RED, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
 	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
-static GRAPHICS sch_t_lay = {LAYERO, FACETTXT, SOLIDC, SOLIDC,
+static GRAPHICS sch_t_lay = {LAYERO, CELLTXT, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,
 	0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
