@@ -95,7 +95,7 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 		return(NOARCINST);
 	}
 
-	/* handle special case of an arcinst connecting to a facet */
+	/* handle special case of an arcinst connecting to a cell */
 	if (!fromgeom->entryisnode || !togeom->entryisnode)
 	{
 		if (!fromgeom->entryisnode) ai = fromgeom->entryaddr.ai; else
@@ -106,7 +106,7 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 
 		if (ni != NONODEINST && ni->proto->primindex == 0)
 		{
-			/* found facet connected to arcinst: search for closest portinst */
+			/* found cell connected to arcinst: search for closest portinst */
 			if (pp == NOPORTPROTO)
 			{
 				bestdist = MAXINTBIG;
@@ -378,7 +378,7 @@ ARCINST *us_makeconnection(NODEINST *fromnodeinst, PORTPROTO *fromportproto, ARC
 	REGISTER ARCINST *newai;
 	INTBIG x, y, hx, hy, lx, ly;
 
-	/* see if the cursor is near a port on a facet */
+	/* see if the cursor is near a port on a cell */
 	bestdist = MAXINTBIG;
 	if (fromportproto == NOPORTPROTO && fromnodeinst->proto->primindex == 0)
 		for(fpt = fromnodeinst->proto->firstportproto; fpt != NOPORTPROTO; fpt = fpt->nextportproto)
@@ -454,7 +454,7 @@ ARCINST *us_makeconnection(NODEINST *fromnodeinst, PORTPROTO *fromportproto, ARC
 		}
 
 		/* if cursor location is in 2, 4, 5, 6, or 8, try two-bend connection */
-		if ((prefx >= lx && prefx <= hx) || (prefy >= ly && prefy <= hy))
+		if ((prefx > lx && prefx < hx) || (prefy > ly && prefy < hy))
 		{
 			newai = us_twobend(fromnodeinst, fromportproto, fromarcproto, tonodeinst,
 				toportproto, toarcproto, con, prefx, prefy, fwid, twid,
@@ -631,10 +631,10 @@ ARCINST *us_directarcinst(NODEINST *fromnodeinst, PORTPROTO *fromppt, ARCPROTO *
 
 			/* ignore range calculations for serpentine transistors */
 			if ((tonodeinst->proto->userbits&HOLDSTRACE) != 0 &&
-				getvalkey((INTBIG)tonodeinst, VNODEINST, VINTEGER|VISARRAY, el_trace_key) != NOVARIABLE)
+				gettrace(tonodeinst) != NOVARIABLE)
 					trange = 1800;
 			if ((fromnodeinst->proto->userbits&HOLDSTRACE) != 0 &&
-				getvalkey((INTBIG)fromnodeinst, VNODEINST, VINTEGER|VISARRAY, el_trace_key) != NOVARIABLE)
+				gettrace(fromnodeinst) != NOVARIABLE)
 					frange = 1800;
 
 			/* make sure ranges are acceptable */
@@ -1499,7 +1499,6 @@ NODEINST *us_getnodeonarcinst(GEOM **ipos, PORTPROTO **ipp, GEOM *othergeom,
 	static NODEINST node;
 	REGISTER INTBIG w, wid, owid, lx, hx, ly, hy, delta, fun;
 	INTBIG pxs, pys;
-	static POLYGON *poly = NOPOLYGON;
 
 	/* get the actual geometry modules */
 	geom = *ipos;
@@ -1507,24 +1506,19 @@ NODEINST *us_getnodeonarcinst(GEOM **ipos, PORTPROTO **ipp, GEOM *othergeom,
 	/* if the module is a nodeinst, return it */
 	if (geom->entryisnode) return(geom->entryaddr.ni);
 
-	/* if the other module is a primitive node, use center as break point */
+	/* if the other module is a node use it to determine the break point */
 	if (othergeom->entryisnode)
 	{
 		ni = othergeom->entryaddr.ni;
-		if (ni->proto->primindex != 0)
+
+		/* if the other module has a port specified, use port center as break point */
+		if (othergeom->entryisnode && otherport != NOPORTPROTO)
 		{
-			if (otherport != NOPORTPROTO)
-			{
-				/* make sure there is a polygon */
-				(void)needstaticpolygon(&poly, 1, us_tool->cluster);
-
-				/* get the polygon describing the port */
-				poly->xv[0] = prefx;   poly->yv[0] = prefy;   poly->count = 1;
-				shapeportpoly(ni, otherport, poly, TRUE);
-
-				/* determine the center of the polygon */
-				getcenter(poly, &prefx, &prefy);
-			} else if (ni->proto->primindex != 0)
+			portposition(ni, otherport, &prefx, &prefy);
+		} else
+		{
+			/* if the other module is a primitive node, use center as break point */
+			if (ni->proto->primindex != 0)
 			{
 				prefx = (ni->lowx + ni->highx) / 2;
 				prefy = (ni->lowy + ni->highy) / 2;
@@ -2105,25 +2099,6 @@ BOOLEAN us_figuredrawpath(GEOM *fromgeom, PORTPROTO *fromport, GEOM *togeom, POR
 			}
 		}
 
-#if 0		/* exaggerate corner by pushing it away from the center */
-		cornerx[0] = lx-1;   cornery[0] = ly-1;
-		cornerx[1] = lx-1;   cornery[1] = hy+1;
-		cornerx[2] = hx+1;   cornery[2] = hy+1;
-		cornerx[3] = hx+1;   cornery[3] = ly-1;
-		for(i=0; i<4; i++)
-		{
-			dist = abs(cornerx[i]-pxs) + abs(cornery[i]-pys);
-
-			/* LINTED "bestdist" used in proper order */
-			if (i == 0 || dist < bestdist)
-			{
-				bestdist = dist;
-				j = i;
-			}
-		}
-		pxs = cornerx[j]*2 - (lx+hx)/2;
-		pys = cornery[j]*2 - (ly+hy)/2;
-#endif
 		/* set coordinate in the center if the ports overlap in either axis */
 		if (fromport != NOPORTPROTO)
 		{
