@@ -435,7 +435,7 @@ void us_array(INTBIG count, CHAR *par[])
 		return;
 	}
 	np = geomparent(list[0]);
-	lambda = lambdaoffacet(np);
+	lambda = lambdaofcell(np);
 
 	/* disallow arraying if lock is on */
 	for(i=0; list[i] != NOGEOM; i++)
@@ -510,7 +510,7 @@ void us_array(INTBIG count, CHAR *par[])
 		return;
 	}
 
-	/* mark the list of nodes and arcs in the facet that will be arrayed */
+	/* mark the list of nodes and arcs in the cell that will be arrayed */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		ni->temp1 = 0;
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -745,7 +745,7 @@ void us_array(INTBIG count, CHAR *par[])
 				{
 					defaulttextsize(3, var->textdescript);
 
-					/* shift text down if on a facet instance */
+					/* shift text down if on a cell instance */
 					if (ni->proto->primindex == 0)
 					{
 						us_setdescriptoffset(var->textdescript,
@@ -862,7 +862,7 @@ void us_array(INTBIG count, CHAR *par[])
 			{
 				defaulttextsize(3, var->textdescript);
 
-				/* shift text down if on a facet instance */
+				/* shift text down if on a cell instance */
 				if (ni->proto->primindex == 0)
 				{
 					us_setdescriptoffset(var->textdescript,
@@ -1235,7 +1235,7 @@ void us_bind(INTBIG count, CHAR *par[])
 					nodeglyph = getnodeproto(par[3]);
 					if (nodeglyph == NONODEPROTO)
 					{
-						us_abortcommand(_("Cannot find %s"), par[3]);
+						us_abortcommand(_("Cannot find glyph '%s' for component menu"), par[3]);
 						return;
 					}
 					count -= 2;
@@ -1415,7 +1415,7 @@ void us_bind(INTBIG count, CHAR *par[])
 			{
 				addstringtoinfstr(infstr, nodeglyph->tech->techname);
 				addtoinfstr(infstr, ':');
-				addstringtoinfstr(infstr, nodeglyph->primname);
+				addstringtoinfstr(infstr, nodeglyph->protoname);
 			} else addstringtoinfstr(infstr, describenodeproto(nodeglyph));
 			addtoinfstr(infstr, ' ');
 		}
