@@ -34,10 +34,12 @@
 #include "usrtrack.h"
 #include "usrdiacom.h"
 #include "efunction.h"
+#include "edialogs.h"
 #include "tecart.h"
 #include "tecgen.h"
 #include "tecschem.h"
 #include "sim.h"
+#include "network.h"
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
@@ -79,22 +81,40 @@ void us_echo(INTBIG count, CHAR *par[])
 	(void)ttyquiet(lastquiet);
 }
 
-void us_editfacet(INTBIG count, CHAR *par[])
+/* Simulation: Select Node Index */
+static DIALOGITEM us_selinddialogitems[] =
 {
-	REGISTER INTBIG implicit, i, len, newwindow, nonredundant, intoicon, lambda, inplace;
+ /*  1 */ {0, {76,120,100,200}, BUTTON, N_("OK")},
+ /*  2 */ {0, {76,16,100,96}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {4,4,20,216}, MESSAGE, N_("This node is arrayed")},
+ /*  4 */ {0, {24,4,40,216}, MESSAGE, N_("Which entry should be entered?")},
+ /*  5 */ {0, {48,4,64,216}, POPUP, x_("")}
+};
+static DIALOG us_selinddialog = {{75,75,184,301}, N_("Select Node Index"), 0, 5, us_selinddialogitems, 0, 0};
+
+/* special items for the "Select Node Index" dialog: */
+#define DSNI_CHOICES       5		/* List of indices (popup) */
+
+void us_editcell(INTBIG count, CHAR *par[])
+{
+	REGISTER INTBIG implicit, i, len, newwindow, nonredundant, intoicon, lambda, inplace, index,
+		sigcount, itemHit;
 	BOOLEAN newframe, push, exact;
 	INTBIG lx, hx, ly, hy;
 	INTBIG viewinfo[22];
-	REGISTER NODEPROTO *np, *onp, *np1, *curfacet;
+	REGISTER NODEPROTO *np, *onp, *np1, *curcell;
 	REGISTER NODEINST *ni, *stacknodeinst;
 	REGISTER LIBRARY *lib, *olib;
+	REGISTER VARIABLE *var;
+	REGISTER void *dia;
 	REGISTER WINDOWPART *win;
 	REGISTER CHAR *pt;
+	CHAR **nodenames;
 	NODEINST *hini;
 	XARRAY rotarray, transarray, xfarray, newarray;
 	PORTPROTO *hipp;
 
-	/* get proper highlighting in subfacet if port is selected */
+	/* get proper highlighting in subcell if port is selected */
 	us_findlowerport(&hini, &hipp);
 
 	/* find the nodeinst in this window to go "down into" (if any) */
@@ -102,6 +122,7 @@ void us_editfacet(INTBIG count, CHAR *par[])
 	nonredundant = 0;
 	intoicon = 0;
 	inplace = 0;
+	index = 0;
 	if (count == 1)
 	{
 		len = estrlen(par[0]);
@@ -127,11 +148,11 @@ void us_editfacet(INTBIG count, CHAR *par[])
 		stacknodeinst = ni;
 		np = ni->proto;
 
-		/* translate this reference if this is an icon facet */
+		/* translate this reference if this is an icon cell */
 		if (np->cellview == el_iconview)
 		{
 			implicit = 0;
-			if (np->cell != ni->parent->cell)
+			if (!isiconof(np, ni->parent))
 			{
 				onp = contentsview(np);
 				if (onp != NONODEPROTO) np = onp;
@@ -149,16 +170,16 @@ void us_editfacet(INTBIG count, CHAR *par[])
 			if (namesamen(par[i], x_("new-window"), len) == 0 && len > 1) newwindow++; else
 			if (namesamen(par[i], x_("non-redundant"), len) == 0 && len > 1) nonredundant++; else
 			{
-				ttyputbadusage(x_("editfacet"));
+				ttyputbadusage(x_("editcell"));
 				return;
 			}
 		}
 
-		/* see if specified facet exists */
+		/* see if specified cell exists */
 		implicit = 0;
 		np = getnodeproto(par[0]);
 
-		/* if it is a new facet, create it */
+		/* if it is a new cell, create it */
 		if (np == NONODEPROTO)
 		{
 			lib = el_curlib;
@@ -171,7 +192,7 @@ void us_editfacet(INTBIG count, CHAR *par[])
 				*pt = (CHAR)i;
 				if (lib == NOLIBRARY)
 				{
-					us_abortcommand(_("Cannot find library for new facet %s"), par[0]);
+					us_abortcommand(_("Cannot find library for new cell %s"), par[0]);
 					return;
 				}
 				pt++;
@@ -179,18 +200,18 @@ void us_editfacet(INTBIG count, CHAR *par[])
 			np = us_newnodeproto(pt, lib);
 			if (np == NONODEPROTO)
 			{
-				us_abortcommand(_("Cannot create facet %s"), par[0]);
+				us_abortcommand(_("Cannot create cell %s"), par[0]);
 				return;
 			}
-			ttyputverbose(M_("Editing new facet: %s"), par[0]);
+			ttyputverbose(M_("Editing new cell: %s"), par[0]);
 		}
 
-		/* look through window for instances of this facet */
+		/* look through window for instances of this cell */
 		stacknodeinst = NONODEINST;
-		curfacet = getcurfacet();
-		if (curfacet != NONODEPROTO)
+		curcell = getcurcell();
+		if (curcell != NONODEPROTO)
 		{
-			for(ni = curfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+			for(ni = curcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 				if (ni->proto == np)
 			{
 				stacknodeinst = ni;
@@ -224,42 +245,65 @@ void us_editfacet(INTBIG count, CHAR *par[])
 				VWINDOWPART|VDONTSAVE);
 		}
 
+		/* if simulating, and node is arrayed, find out the index */
+		if (stacknodeinst->arraysize > 1 && el_curwindowpart != NOWINDOWPART &&
+			(el_curwindowpart->state&WINDOWMODE) == WINDOWSIMMODE)
+		{
+			var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
+			if (var != NOVARIABLE)
+			{
+				/* must find out which index is being traversed */
+				sigcount = net_evalbusname(APBUS, (CHAR *)var->addr, &nodenames,
+					NOARCINST, NONODEPROTO, 0);
+				dia = DiaInitDialog(&us_selinddialog);
+				DiaSetPopup(dia, DSNI_CHOICES, sigcount, nodenames);
+				for(;;)
+				{
+					itemHit = DiaNextHit(dia);
+					if (itemHit == CANCEL || itemHit == OK) break;
+				}
+				if (itemHit != CANCEL)
+					index = DiaGetPopupEntry(dia, DSNI_CHOICES);
+				DiaDoneDialog(dia);
+			}
+		}
+
 		viewinfo[0] = el_curwindowpart->screenlx;
 		viewinfo[1] = el_curwindowpart->screenhx;
 		viewinfo[2] = el_curwindowpart->screenly;
 		viewinfo[3] = el_curwindowpart->screenhy;
-		viewinfo[4] = el_curwindowpart->intofacet[0][0];
-		viewinfo[5] = el_curwindowpart->intofacet[0][1];
-		viewinfo[6] = el_curwindowpart->intofacet[0][2];
-		viewinfo[7] = el_curwindowpart->intofacet[1][0];
-		viewinfo[8] = el_curwindowpart->intofacet[1][1];
-		viewinfo[9] = el_curwindowpart->intofacet[1][2];
-		viewinfo[10] = el_curwindowpart->intofacet[2][0];
-		viewinfo[11] = el_curwindowpart->intofacet[2][1];
-		viewinfo[12] = el_curwindowpart->intofacet[2][2];
-		viewinfo[13] = el_curwindowpart->outoffacet[0][0];
-		viewinfo[14] = el_curwindowpart->outoffacet[0][1];
-		viewinfo[15] = el_curwindowpart->outoffacet[0][2];
-		viewinfo[16] = el_curwindowpart->outoffacet[1][0];
-		viewinfo[17] = el_curwindowpart->outoffacet[1][1];
-		viewinfo[18] = el_curwindowpart->outoffacet[1][2];
-		viewinfo[19] = el_curwindowpart->outoffacet[2][0];
-		viewinfo[20] = el_curwindowpart->outoffacet[2][1];
-		viewinfo[21] = el_curwindowpart->outoffacet[2][2];
+		viewinfo[4] = el_curwindowpart->intocell[0][0];
+		viewinfo[5] = el_curwindowpart->intocell[0][1];
+		viewinfo[6] = el_curwindowpart->intocell[0][2];
+		viewinfo[7] = el_curwindowpart->intocell[1][0];
+		viewinfo[8] = el_curwindowpart->intocell[1][1];
+		viewinfo[9] = el_curwindowpart->intocell[1][2];
+		viewinfo[10] = el_curwindowpart->intocell[2][0];
+		viewinfo[11] = el_curwindowpart->intocell[2][1];
+		viewinfo[12] = el_curwindowpart->intocell[2][2];
+		viewinfo[13] = el_curwindowpart->outofcell[0][0];
+		viewinfo[14] = el_curwindowpart->outofcell[0][1];
+		viewinfo[15] = el_curwindowpart->outofcell[0][2];
+		viewinfo[16] = el_curwindowpart->outofcell[1][0];
+		viewinfo[17] = el_curwindowpart->outofcell[1][1];
+		viewinfo[18] = el_curwindowpart->outofcell[1][2];
+		viewinfo[19] = el_curwindowpart->outofcell[2][0];
+		viewinfo[20] = el_curwindowpart->outofcell[2][1];
+		viewinfo[21] = el_curwindowpart->outofcell[2][2];
 		push = TRUE;
 		exact = TRUE;
 		onp = contentsview(np);
 		if (onp == NONODEPROTO || intoicon != 0) onp = np;
-		sethierarchicalparent(onp, stacknodeinst, el_curwindowpart, viewinfo);
+		sethierarchicalparent(onp, stacknodeinst, el_curwindowpart, index, viewinfo);
 	}
 
-	/* check dates of subfacets */
+	/* check dates of subcells */
 	if ((us_useroptions&CHECKDATE) != 0)
 	{
 		for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 			for(np1 = olib->firstnodeproto; np1 != NONODEPROTO; np1 = np1->nextnodeproto)
 				np1->temp1 = 0;
-		us_check_facet_date(np, np->revisiondate);
+		us_check_cell_date(np, np->revisiondate);
 	}
 
 	/* if a nonredundant display is needed, see if it already exists */
@@ -296,12 +340,12 @@ void us_editfacet(INTBIG count, CHAR *par[])
 	}
 	if (implicit == 0)
 	{
-		/* make the new facet fill the window */
+		/* make the new cell fill the window */
 		us_fullview(np, &lx, &hx, &ly, &hy);
 		exact = FALSE;
 	} else
 	{
-		/* make the current facet be in the same place in the window */
+		/* make the current cell be in the same place in the window */
 		if (inplace != 0)
 		{
 			lx = el_curwindowpart->screenlx;   hx = el_curwindowpart->screenhx;
@@ -325,7 +369,7 @@ void us_editfacet(INTBIG count, CHAR *par[])
 		}
 	}
 
-	/* edit the facet (creating a new frame/partition if requested) */
+	/* edit the cell (creating a new frame/partition if requested) */
 	if (newwindow != 0 || el_curwindowpart == NOWINDOWPART)
 	{
 		newframe = TRUE;
@@ -339,14 +383,14 @@ void us_editfacet(INTBIG count, CHAR *par[])
 		makerotI(stacknodeinst, rotarray);
 		maketransI(stacknodeinst, transarray);
 		transmult(rotarray, transarray, xfarray);
-		transmult(el_curwindowpart->intofacet, xfarray, newarray);
-		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("intofacet"), newarray);
+		transmult(el_curwindowpart->intocell, xfarray, newarray);
+		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("intocell"), newarray);
 
 		makerot(stacknodeinst, rotarray);
 		maketrans(stacknodeinst, transarray);
 		transmult(transarray, rotarray, xfarray);
-		transmult(xfarray, el_curwindowpart->outoffacet, newarray);
-		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("outoffacet"), newarray);
+		transmult(xfarray, el_curwindowpart->outofcell, newarray);
+		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("outofcell"), newarray);
 		if ((el_curwindowpart->state&INPLACEEDIT) == 0)
 		{
 			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("inplacedepth"), 0, VINTEGER);
@@ -363,13 +407,13 @@ void us_editfacet(INTBIG count, CHAR *par[])
 	{
 		if (el_curwindowpart != NOWINDOWPART)
 		{
-			us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("intofacet"), el_matid);
-			us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("outoffacet"), el_matid);
+			us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("intocell"), el_matid);
+			us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("outofcell"), el_matid);
 			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("state"),
 				el_curwindowpart->state & ~INPLACEEDIT, VINTEGER);
 		}
 	}
-	us_switchtofacet(np, lx, hx, ly, hy, hini, hipp, newframe, push, exact);
+	us_switchtocell(np, lx, hx, ly, hy, hini, hipp, newframe, push, exact);
 }
 
 void us_erase(INTBIG count, CHAR *par[])
@@ -397,21 +441,21 @@ void us_erase(INTBIG count, CHAR *par[])
 			us_clearhighlightcount();
 			cleaned = FALSE;
 			for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-				if (us_cleanupfacet(np, FALSE)) cleaned = TRUE;
+				if (us_cleanupcell(np, FALSE)) cleaned = TRUE;
 			if (!cleaned) ttyputmsg(_("Nothing to clean"));
 			return;
 		}
 		if (namesamen(pt, x_("clean-up"), l) == 0)
 		{
-			np = us_needfacet();
+			np = us_needcell();
 			if (np == NONODEPROTO) return;
 			us_clearhighlightcount();
-			(void)us_cleanupfacet(np, TRUE);
+			(void)us_cleanupcell(np, TRUE);
 			return;
 		}
 		if (namesamen(pt, x_("geometry"), l) == 0)
 		{
-			np = us_needfacet();
+			np = us_needcell();
 			if (np == NONODEPROTO) return;
 			us_erasegeometry(np);
 			return;
@@ -419,10 +463,10 @@ void us_erase(INTBIG count, CHAR *par[])
 	}
 
 	/* get list of highlighted objects to be erased */
-	np = us_needfacet();
+	np = us_needcell();
 	if (np == NONODEPROTO)
 	{
-		us_abortcommand(_("No current facet"));
+		us_abortcommand(_("No current cell"));
 		return;
 	}
 	list = us_gethighlighted(WANTARCINST|WANTNODEINST, &textcount, &textinfo);
@@ -457,7 +501,7 @@ void us_erase(INTBIG count, CHAR *par[])
 	for(i=0; i<textcount; i++)
 	{
 		(void)us_makehighlight(textinfo[i], &high);
-		np = high.facet;
+		np = high.cell;
 		if (np->temp1 == 0) allvisible = FALSE;
 	}
 	if (!allvisible)
@@ -524,7 +568,7 @@ void us_erase(INTBIG count, CHAR *par[])
 			/* worked: highlight the arc */
 			newhigh.status = HIGHFROM;
 			newhigh.fromgeom = ai->geom;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			us_setfind(&newhigh, 0, 1, 0, 0);
 			return;
 		}
@@ -536,7 +580,7 @@ void us_erase(INTBIG count, CHAR *par[])
 		(void)us_makehighlight(textinfo[i], &high);
 
 		/* disallow erasing if lock is on */
-		np = high.facet;
+		np = high.cell;
 		if (np != NONODEPROTO)
 		{
 			if (us_cantedit(np, NONODEINST, TRUE)) continue;
@@ -555,7 +599,7 @@ void us_erase(INTBIG count, CHAR *par[])
 		{
 			if (high.fromgeom == NOGEOM)
 			{
-				us_undrawfacetvariable(high.fromvar, np);
+				us_undrawcellvariable(high.fromvar, np);
 				(void)delval((INTBIG)np, VNODEPROTO, makename(high.fromvar->key));
 			} else if (high.fromgeom->entryisnode)
 			{
@@ -587,7 +631,7 @@ void us_erase(INTBIG count, CHAR *par[])
 			us_undoportproto((NODEINST *)ni, high.fromport);
 			endobjectchange((INTBIG)ni, VNODEINST);
 		} else if (high.fromgeom->entryisnode)
-			us_abortcommand(_("Cannot delete facet name"));
+			us_abortcommand(_("Cannot delete cell name"));
 	}
 
 	/* look for option to re-connect arcs into an erased node */
@@ -668,8 +712,8 @@ void us_find(INTBIG count, CHAR *par[])
 		}
 	}
 
-	/* make sure there is a facet being edited */
-	np = us_needfacet();
+	/* make sure there is a cell being edited */
+	np = us_needcell();
 	if (np == NONODEPROTO) return;
 	if ((np->cellview->viewstate&TEXTVIEW) != 0)
 	{
@@ -681,7 +725,7 @@ void us_find(INTBIG count, CHAR *par[])
 			us_highlightline(el_curwindowpart, 0, i-1);
 			return;
 		}
-		us_abortcommand(M_("There are no components to select in a text-only facet"));
+		us_abortcommand(M_("There are no components to select in a text-only cell"));
 		return;
 	}
 	if ((el_curwindowpart->state&WINDOWTYPE) == DISP3DWINDOW)
@@ -806,13 +850,13 @@ void us_find(INTBIG count, CHAR *par[])
 
 			newhigh.status = HIGHFROM | extrainfo;
 			if (findnobox != 0) newhigh.status |= HIGHNOBOX;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			newhigh.frompoint = 0;
 			newhigh.fromvar = NOVARIABLE;
 			newhigh.fromvarnoeval = NOVARIABLE;
 
 			newhightext.status = HIGHTEXT;
-			newhightext.facet = np;
+			newhightext.cell = np;
 			newhightext.fromport = NOPORTPROTO;
 			newhightext.frompoint = 0;
 			newhightext.fromvarnoeval = NOVARIABLE;
@@ -822,7 +866,7 @@ void us_find(INTBIG count, CHAR *par[])
 			{
 				if (ni->proto->primindex == 0 && (us_useroptions&NOINSTANCESELECT) != 0)
 				{
-					/* facet instance that is hard to select */
+					/* cell instance that is hard to select */
 					if (findhard == 0) continue;
 				} else
 				{
@@ -925,13 +969,13 @@ void us_find(INTBIG count, CHAR *par[])
 			}
 			if (ai == NOARCINST)
 			{
-				us_abortcommand(_("Sorry, no %s arc named '%s' in this facet"),
+				us_abortcommand(_("Sorry, no %s arc named '%s' in this cell"),
 					(findexclusively==0 ? x_("") : describearcproto(us_curarcproto)), par[1]);
 				return;
 			}
 			newhigh.status = HIGHFROM;
 			newhigh.fromgeom = ai->geom;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			us_setfind(&newhigh, 0, extrainfo, findmore, findnobox);
 			return;
 		}
@@ -962,6 +1006,8 @@ void us_find(INTBIG count, CHAR *par[])
 			trackcursor(waitforpush, us_ignoreup, us_finddbegin, us_stretchdown, us_stoponchar,
 				us_invertdragup, TRACKDRAGGING);
 			if (el_pleasestop != 0) return;
+			np = getcurcell();
+			if (np == NONODEPROTO) return;
 			us_finddterm(&newhigh.stalx, &newhigh.staly);
 			if (us_demandxy(&xcur, &ycur)) return;
 			if (xcur >= newhigh.stalx) newhigh.stahx = xcur; else
@@ -973,7 +1019,7 @@ void us_find(INTBIG count, CHAR *par[])
 				newhigh.stahy = newhigh.staly;   newhigh.staly = ycur;
 			}
 			newhigh.status = HIGHBBOX;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			us_addhighlight(&newhigh);
 			return;
 		}
@@ -1014,7 +1060,7 @@ void us_find(INTBIG count, CHAR *par[])
 				gridalign(&xcur, &ycur, 1, np);
 			}
 			newhigh.status = HIGHBBOX;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			newhigh.stalx = xcur;   newhigh.stahx = xcur + areasizex;
 			newhigh.staly = ycur;   newhigh.stahy = ycur + areasizey;
 			us_addhighlight(&newhigh);
@@ -1038,9 +1084,9 @@ void us_find(INTBIG count, CHAR *par[])
 				us_abortcommand(M_("Use 'find area-move' first, then this"));
 				return;
 			}
-			if (np != newhigh.facet)
+			if (np != newhigh.cell)
 			{
-				us_abortcommand(M_("Not in same facet as highlight area"));
+				us_abortcommand(M_("Not in same cell as highlight area"));
 				return;
 			}
 
@@ -1188,13 +1234,13 @@ void us_find(INTBIG count, CHAR *par[])
 				if (namesame(par[1], pp->protoname) == 0) break;
 			if (pp == NOPORTPROTO)
 			{
-				us_abortcommand(_("Sorry, no export named '%s' in this facet"), par[1]);
+				us_abortcommand(_("Sorry, no export named '%s' in this cell"), par[1]);
 				return;
 			}
 			newhigh.status = HIGHFROM;
 			newhigh.fromgeom = pp->subnodeinst->geom;
 			newhigh.fromport = pp->subportproto;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			us_setfind(&newhigh, 0, extrainfo, findmore, findnobox);
 			return;
 		}
@@ -1281,7 +1327,7 @@ void us_find(INTBIG count, CHAR *par[])
 			if ((newhigh.status&HIGHTYPE) != HIGHBBOX) return;
 
 			/* remove it and select everything in that area */
-			np = newhigh.facet;
+			np = newhigh.cell;
 			us_clearhighlightcount();
 			total = us_selectarea(np, newhigh.stalx, newhigh.stahx, newhigh.staly,
 				newhigh.stahy, 0, 0, 0, &list);
@@ -1345,14 +1391,14 @@ void us_find(INTBIG count, CHAR *par[])
 			}
 			if (ni == NONODEINST)
 			{
-				us_abortcommand(_("Sorry, no %s node named '%s' in this facet"),
+				us_abortcommand(_("Sorry, no %s node named '%s' in this cell"),
 					(findexclusively==0 ? x_("") : describenodeproto(us_curnodeproto)), par[1]);
 				return;
 			}
 			newhigh.status = HIGHFROM;
 			newhigh.fromgeom = ni->geom;
 			newhigh.fromport = NOPORTPROTO;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			us_setfind(&newhigh, findpoint, extrainfo, findmore, findnobox);
 			return;
 		}
@@ -1391,7 +1437,7 @@ void us_find(INTBIG count, CHAR *par[])
 					ai->end[0].ypos == ai->end[1].ypos)) continue;
 				if (i == 0) us_clearhighlightcount();
 				newhigh.status = HIGHFROM;
-				newhigh.facet = np;
+				newhigh.cell = np;
 				newhigh.fromgeom = ai->geom;
 				newhigh.fromport = NOPORTPROTO;
 				newhigh.frompoint = 0;
@@ -1403,15 +1449,15 @@ void us_find(INTBIG count, CHAR *par[])
 				if ((ni->rotation % 900) == 0) continue;
 				if (i == 0) us_clearhighlightcount();
 				newhigh.status = HIGHFROM;
-				newhigh.facet = np;
+				newhigh.cell = np;
 				newhigh.fromgeom = ni->geom;
 				newhigh.fromport = NOPORTPROTO;
 				newhigh.frompoint = 0;
 				us_addhighlight(&newhigh);
 				i++;
 			}
-			if (i == 0) ttyputmsg(_("No nonmanhattan objects in this facet")); else
-				ttyputmsg(_("%ld objects are not manhattan in this facet"), i);
+			if (i == 0) ttyputmsg(_("No nonmanhattan objects in this cell")); else
+				ttyputmsg(_("%ld objects are not manhattan in this cell"), i);
 			for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			{
 				if ((lib->userbits&HIDDENLIBRARY) != 0) continue;
@@ -1432,10 +1478,10 @@ void us_find(INTBIG count, CHAR *par[])
 					}
 					if (l == 1)
 					{
-						ttyputmsg(_("Found nonmanhattan geometry in facet %s"), returninfstr(infstr));
+						ttyputmsg(_("Found nonmanhattan geometry in cell %s"), returninfstr(infstr));
 					} else
 					{
-						ttyputmsg(_("Found nonmanhattan geometry in these facets: %s"),
+						ttyputmsg(_("Found nonmanhattan geometry in these cells: %s"),
 							returninfstr(infstr));
 					}
 				} else
@@ -1501,13 +1547,13 @@ void us_find(INTBIG count, CHAR *par[])
 					if (ni == 0 || ni == NONODEINST) return;
 					if (ni->parent != np)
 					{
-						us_abortcommand(_("Cannot find node %ld in this facet"), addr);
+						us_abortcommand(_("Cannot find node %ld in this cell"), addr);
 						return;
 					}
 					newhigh.status = HIGHFROM;
 					newhigh.fromgeom = ni->geom;
 					newhigh.fromport = NOPORTPROTO;
-					newhigh.facet = np;
+					newhigh.cell = np;
 					us_setfind(&newhigh, findpoint, extrainfo, findmore, findnobox);
 					break;
 				case VARCINST:
@@ -1515,13 +1561,13 @@ void us_find(INTBIG count, CHAR *par[])
 					if (ai == 0 || ai == NOARCINST) return;
 					if (ai->parent != np)
 					{
-						us_abortcommand(_("Cannot find arc %ld in this facet"), addr);
+						us_abortcommand(_("Cannot find arc %ld in this cell"), addr);
 						return;
 					}
 					newhigh.status = HIGHFROM;
 					newhigh.fromgeom = ai->geom;
 					newhigh.fromport = NOPORTPROTO;
-					newhigh.facet = np;
+					newhigh.cell = np;
 					us_setfind(&newhigh, findpoint, extrainfo, findmore, findnobox);
 					break;
 				case VNETWORK:
@@ -1529,7 +1575,7 @@ void us_find(INTBIG count, CHAR *par[])
 					if (net == 0 || net == NONETWORK) return;
 					if (net->parent != np)
 					{
-						us_abortcommand(_("Cannot find network %ld in this facet"), addr);
+						us_abortcommand(_("Cannot find network %ld in this cell"), addr);
 						return;
 					}
 					for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -1538,7 +1584,7 @@ void us_find(INTBIG count, CHAR *par[])
 						newhigh.status = HIGHFROM;
 						newhigh.fromgeom = ai->geom;
 						newhigh.fromport = NOPORTPROTO;
-						newhigh.facet = np;
+						newhigh.cell = np;
 						us_setfind(&newhigh, findpoint, extrainfo, findmore, findnobox);
 					}
 					for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -1547,7 +1593,7 @@ void us_find(INTBIG count, CHAR *par[])
 						newhigh.status = HIGHFROM;
 						newhigh.fromgeom = pp->subnodeinst->geom;
 						newhigh.fromport = pp->subportproto;
-						newhigh.facet = np;
+						newhigh.cell = np;
 						us_setfind(&newhigh, 0, extrainfo, findmore, findnobox);
 					}
 					break;
@@ -1556,13 +1602,13 @@ void us_find(INTBIG count, CHAR *par[])
 					if (pp == 0 || pp == NOPORTPROTO) return;
 					if (pp->parent != np)
 					{
-						us_abortcommand(_("Cannot find port %ld in this facet"), addr);
+						us_abortcommand(_("Cannot find port %ld in this cell"), addr);
 						return;
 					}
 					newhigh.status = HIGHFROM;
 					newhigh.fromgeom = pp->subnodeinst->geom;
 					newhigh.fromport = pp->subportproto;
-					newhigh.facet = np;
+					newhigh.cell = np;
 					us_setfind(&newhigh, 0, extrainfo, findmore, findnobox);
 					break;
 				default:
@@ -1686,7 +1732,7 @@ void us_find(INTBIG count, CHAR *par[])
 				if (ni->temp1 == 0) continue;
 				if (first != 0) addtoinfstr(infstr, '\n');
 				first++;
-				formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
+				formatinfstr(infstr, x_("CELL=%s FROM=0%lo;-1;0"),
 					describenodeproto(np), (INTBIG)ni->geom);
 			}
 			for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -1694,7 +1740,7 @@ void us_find(INTBIG count, CHAR *par[])
 				if (ai->temp1 == 0) continue;
 				if (first != 0) addtoinfstr(infstr, '\n');
 				first++;
-				formatinfstr(infstr, x_("FACET=%s FROM=0%lo;-1;0"),
+				formatinfstr(infstr, x_("CELL=%s FROM=0%lo;-1;0"),
 					describenodeproto(np), (INTBIG)ai->geom);
 			}
 			us_setmultiplehighlight(returninfstr(infstr), FALSE);
@@ -1821,7 +1867,7 @@ void us_find(INTBIG count, CHAR *par[])
 			newhigh.fromgeom = ni->geom;
 			newhigh.fromport = NOPORTPROTO;
 			newhigh.fromvar = var;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			us_setfind(&newhigh, 0, extrainfo, findmore, findnobox);
 			return;
 		}
@@ -1837,18 +1883,17 @@ void us_find(INTBIG count, CHAR *par[])
 		us_findobject(xcur, ycur, el_curwindowpart, &newhigh, findexclusively, 0, findport, 0, findspecial);
 	if (newhigh.status == 0) return;
 	if (findport == 0) newhigh.fromport = NOPORTPROTO;
-	newhigh.facet = np;
+	newhigh.cell = np;
 	us_setfind(&newhigh, findpoint, extrainfo, findmore, findnobox);
 }
 
 void us_getproto(INTBIG count, CHAR *par[])
 {
-	REGISTER NODEPROTO *np;
+	REGISTER NODEPROTO *np, *onp;
 	REGISTER ARCPROTO *ap, *lat;
-	REGISTER INTBIG cellcount, facetcount, doarc, i, l, firstinpass;
+	REGISTER INTBIG cellgroupcount, cellcount, doarc, i, l, firstinpass;
 	BOOLEAN butstate;
 	REGISTER CHAR *pp;
-	REGISTER CELL *cell;
 	HIGHLIGHT high;
 	extern COMCOMP us_getproto1p;
 	REGISTER VARIABLE *highvar;
@@ -1874,102 +1919,115 @@ void us_getproto(INTBIG count, CHAR *par[])
 	if (namesamen(pp, x_("instance"), l) == 0)
 	{
 		/* show a popup menu with instances */
-		cellcount = 0;
-		for(cell = el_curlib->firstcell; cell != NOCELL; cell = cell->nextcell)
-			cellcount++;
+
+		/* number each cellgroup */
+		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			np->temp1 = 0;
+		cellgroupcount = 0;
+		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		{
+			if (np->temp1 != 0) continue;
+			cellgroupcount++;
+			FOR_CELLGROUP(onp, np)
+				onp->temp1 = cellgroupcount;
+		}
 		pm = (POPUPMENU *)emalloc(sizeof(POPUPMENU), us_tool->cluster);
 		if (pm == 0) return;
-		mi = (POPUPMENUITEM *)emalloc(cellcount * sizeof(POPUPMENUITEM), us_tool->cluster);
+		mi = (POPUPMENUITEM *)emalloc(cellgroupcount * sizeof(POPUPMENUITEM), us_tool->cluster);
 		if (mi == 0) return;
 		pm->name = x_("x");
 		infstr = initinfstr();
-		if (cellcount != 0) formatinfstr(infstr, _("Facets in %s"), el_curlib->libname); else
-			formatinfstr(infstr, _("No facets in %s"), el_curlib->libname);
+		if (cellgroupcount != 0) formatinfstr(infstr, _("Cells in %s"), el_curlib->libname); else
+			formatinfstr(infstr, _("No cells in %s"), el_curlib->libname);
 		(void)allocstring(&pm->header, returninfstr(infstr), us_tool->cluster);
 		pm->list = mi;
-		pm->total = cellcount;
+		pm->total = cellgroupcount;
 
 		/* fill the menu */
-		cellcount = 0;
-		for(cell = el_curlib->firstcell; cell != NOCELL; cell = cell->nextcell)
+		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+			np->temp1 = 0;
+		cellgroupcount = 0;
+		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
-			uc = us_allocusercom();
-			mi[cellcount].response = uc;
-			mi[cellcount].response->active = -1;
-			mi[cellcount].value = 0;
-
-			facetcount = 0;
-			for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-				if (np->cell == cell) facetcount++;
-			if (facetcount == 1)
+			if (np->temp1 != 0) continue;
+			cellcount = 0;
+			FOR_CELLGROUP(onp, np)
 			{
-				/* only one facet of this cell: create it directly */
+				onp->temp1 = 1;
+				cellcount++;
+			}
+
+			uc = us_allocusercom();
+			mi[cellgroupcount].response = uc;
+			mi[cellgroupcount].response->active = -1;
+			mi[cellgroupcount].value = 0;
+
+			if (cellcount == 1)
+			{
+				/* only one cell of this cell: create it directly */
 				uc->active = parse(x_("getproto"), &us_userp, TRUE);
 				(void)allocstring(&uc->comname, x_("getproto"), us_tool->cluster);
 				uc->count = 2;
 				(void)allocstring(&uc->word[0], x_("node"), us_tool->cluster);
-				(void)allocstring(&uc->word[1], describenodeproto(cell->firstincell),
-					us_tool->cluster);
-				mi[cellcount].attribute = uc->word[1];
+				(void)allocstring(&uc->word[1], describenodeproto(np), us_tool->cluster);
+				mi[cellgroupcount].attribute = uc->word[1];
 			} else
 			{
-				/* multiple facets of this cell: make a submenu */
-				mi[cellcount].attribute = cell->cellname;
-				mi[cellcount].value = x_(">>");
-				mi[cellcount].maxlen = -1;
+				/* multiple cells of this cell: make a submenu */
+				mi[cellgroupcount].attribute = np->protoname;
+				mi[cellgroupcount].value = x_(">>");
+				mi[cellgroupcount].maxlen = -1;
 				pmsub = (POPUPMENU *)emalloc(sizeof(POPUPMENU), us_tool->cluster);
 				if (pmsub == 0) return;
-				misub = (POPUPMENUITEM *)emalloc(facetcount * sizeof(POPUPMENUITEM), us_tool->cluster);
+				misub = (POPUPMENUITEM *)emalloc(cellcount * sizeof(POPUPMENUITEM), us_tool->cluster);
 				if (misub == 0) return;
 				pmsub->name = x_("x");
 				pmsub->header = 0;
 				pmsub->list = misub;
-				pmsub->total = facetcount;
-				facetcount = 0;
+				pmsub->total = cellcount;
+				cellcount = 0;
 				for(i=0; i<2; i++)
 				{
-					firstinpass = facetcount;
-					for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+					firstinpass = cellcount;
+					FOR_CELLGROUP(onp, np)
 					{
-						if (np->cell != cell) continue;
-
-						/* see if this facet should be included on this pass */
+						/* see if this cell should be included on this pass */
 						if (i == 0)
 						{
-							/* first pass: only include facets that match the current view */
-							if (!us_facetfromtech(np, el_curtech)) continue;
+							/* first pass: only include cells that match the current view */
+							if (!us_cellfromtech(onp, el_curtech)) continue;
 						} else
 						{
-							/* first pass: only include facets that don't match the current view */
-							if (us_facetfromtech(np, el_curtech)) continue;
+							/* first pass: only include cells that don't match the current view */
+							if (us_cellfromtech(onp, el_curtech)) continue;
 						}
 
 						ucsub = us_allocusercom();
-						misub[facetcount].response = ucsub;
-						misub[facetcount].response->active = -1;
-						(void)allocstring(&misub[facetcount].attribute, describenodeproto(np),
+						misub[cellcount].response = ucsub;
+						misub[cellcount].response->active = -1;
+						(void)allocstring(&misub[cellcount].attribute, describenodeproto(onp),
 							us_tool->cluster);
-						misub[facetcount].value = 0;
+						misub[cellcount].value = 0;
 
-						/* only one facet of this cell: create it directly */
+						/* only one cell of this cell: create it directly */
 						ucsub->active = parse(x_("getproto"), &us_userp, TRUE);
 						(void)allocstring(&ucsub->comname, x_("getproto"), us_tool->cluster);
 						ucsub->count = 2;
 						(void)allocstring(&ucsub->word[0], x_("node"), us_tool->cluster);
-						(void)allocstring(&ucsub->word[1], describenodeproto(np),
+						(void)allocstring(&ucsub->word[1], describenodeproto(onp),
 							us_tool->cluster);
-						facetcount++;
+						cellcount++;
 					}
-					esort(&misub[firstinpass], facetcount-firstinpass,
+					esort(&misub[firstinpass], cellcount-firstinpass,
 						sizeof (POPUPMENUITEM), us_sortpopupmenuascending);
 				}
 				uc->menu = pmsub;
 			}
-			cellcount++;
+			cellgroupcount++;
 		}
 
 		/* invoke the popup menu */
-		esort(mi, cellcount, sizeof (POPUPMENUITEM), us_sortpopupmenuascending);
+		esort(mi, cellgroupcount, sizeof (POPUPMENUITEM), us_sortpopupmenuascending);
 		butstate = TRUE;
 		cpm = pm;
 		miret = us_popupmenu(&cpm, &butstate, TRUE, -1, -1, 4);
@@ -1981,7 +2039,7 @@ void us_getproto(INTBIG count, CHAR *par[])
 			if (miret != NOPOPUPMENUITEM)
 				us_execute(miret->response, FALSE, FALSE, FALSE);
 		}
-		for(i=0; i<cellcount; i++)
+		for(i=0; i<cellgroupcount; i++)
 		{
 			uc = mi[i].response;
 			if (uc->menu != NOPOPUPMENU)
@@ -2023,7 +2081,7 @@ void us_getproto(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("this-proto"), l) == 0 && l >= 1)
 	{
-		np = us_needfacet();
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
 		us_setnodeproto(np);
 		return;
@@ -2710,7 +2768,7 @@ void us_iterate(INTBIG count, CHAR *par[])
 	}
 }
 
-void us_killfacet(INTBIG count, CHAR *par[])
+void us_killcell(INTBIG count, CHAR *par[])
 {
 	REGISTER NODEPROTO *np, *onp;
 	REGISTER NODEINST *ni;
@@ -2719,7 +2777,7 @@ void us_killfacet(INTBIG count, CHAR *par[])
 
 	if (count == 0)
 	{
-		count = ttygetparam(M_("Facet name: "), &us_showdp, MAXPARS, par);
+		count = ttygetparam(M_("Cell name: "), &us_showdp, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -2730,19 +2788,19 @@ void us_killfacet(INTBIG count, CHAR *par[])
 	np = getnodeproto(par[0]);
 	if (np == NONODEPROTO)
 	{
-		us_abortcommand(_("No facet called %s"), par[0]);
+		us_abortcommand(_("No cell called %s"), par[0]);
 		return;
 	}
 	if (np->primindex != 0)
 	{
-		us_abortcommand(_("Can only kill facets"));
+		us_abortcommand(_("Can only kill cells"));
 		return;
 	}
 
 	/* disallow killing if lock is on */
 	if (us_cantedit(np, NONODEINST, TRUE)) return;
 
-	/* if there are still instances of the facet, mention them */
+	/* if there are still instances of the cell, mention them */
 	if (np->firstinst != NONODEINST)
 	{
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -2750,15 +2808,15 @@ void us_killfacet(INTBIG count, CHAR *par[])
 				onp->temp1 = 0;
 		for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
 			ni->parent->temp1++;
-		ttyputerr(_("Erase all of the following instances of this facet first:"));
+		ttyputerr(_("Erase all of the following instances of this cell first:"));
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 			for(onp = lib->firstnodeproto; onp != NONODEPROTO; onp = onp->nextnodeproto)
 				if (onp->temp1 != 0)
-					ttyputmsg(_("  %ld instance(s) in facet %s"), onp->temp1, describenodeproto(onp));
+					ttyputmsg(_("  %ld instance(s) in cell %s"), onp->temp1, describenodeproto(onp));
 		return;
 	}
 
-	/* kill the facet */
-	us_dokillfacet(np);
-	ttyputmsg(_("Facet %s:%s deleted"), np->cell->lib->libname, nldescribenodeproto(np));
+	/* kill the cell */
+	us_dokillcell(np);
+	ttyputmsg(_("Cell %s:%s deleted"), np->lib->libname, nldescribenodeproto(np));
 }
