@@ -181,7 +181,7 @@ void us_lambda(INTBIG count, CHAR *par[])
 		{
 			if (w->curnodeproto == NONODEPROTO) continue;
 			if (w->curnodeproto->tech != el_curtech) continue;
-			if (how == 2 || (how == 1 && w->curnodeproto->cell->lib == el_curlib))
+			if (how == 2 || (how == 1 && w->curnodeproto->lib == el_curlib))
 			{
 				w->screenlx = muldiv(w->screenlx, lam, oldlam);
 				w->screenhx = muldiv(w->screenhx, lam, oldlam);
@@ -264,7 +264,7 @@ void us_library(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("purge"), l) == 0 && l >= 1)
 	{
-		/* delete all facets that are not the most recent and are unused */
+		/* delete all cells that are not the most recent and are unused */
 		found = 1;
 		total = 0;
 		while (found != 0)
@@ -274,15 +274,15 @@ void us_library(INTBIG count, CHAR *par[])
 			{
 				if (np->newestversion == np) continue;
 				if (np->firstinst != NONODEINST) continue;
-				ttyputmsg(_("Deleting facet %s"), describenodeproto(np));
-				us_dokillfacet(np);
+				ttyputmsg(_("Deleting cell %s"), describenodeproto(np));
+				us_dokillcell(np);
 				found++;
 				total++;
 				break;
 			}
 		}
-		if (total == 0) ttyputmsg(_("No unused old facet versions to delete")); else
-			ttyputmsg(_("Deleted %ld facets"), total);
+		if (total == 0) ttyputmsg(_("No unused old cell versions to delete")); else
+			ttyputmsg(_("Deleted %ld cells"), total);
 		return;
 	}
 
@@ -319,7 +319,7 @@ void us_library(INTBIG count, CHAR *par[])
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
 			for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
-				ni->parent->cell->lib->temp1 = 1;
+				ni->parent->lib->temp1 = 1;
 		}
 		for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary)
 		{
@@ -331,14 +331,14 @@ void us_library(INTBIG count, CHAR *par[])
 				ttyputerr(_("Cannot delete library %s because:"), lib->libname);
 			}
 			infstr = initinfstr();
-			formatinfstr(infstr, _("   These facets (in library %s) use it:"),
+			formatinfstr(infstr, _("   These cells (in library %s) use it:"),
 				olib->libname);
 			for(np = olib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			{
 				for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 				{
 					if (ni->proto->primindex != 0) continue;
-					if (ni->proto->cell->lib == lib) break;
+					if (ni->proto->lib == lib) break;
 				}
 				if (ni == NONODEINST) continue;
 				formatinfstr(infstr, x_(" %s"), nldescribenodeproto(np));
@@ -360,11 +360,11 @@ void us_library(INTBIG count, CHAR *par[])
 			ttyputverbose(M_("Current library is now %s"), el_curlib->libname);
 		} else ttyputverbose(M_("Library %s killed"), lib->libname);
 
-		/* remove display of all facets in this library */
+		/* remove display of all cells in this library */
 		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 		{
 			if (w->curnodeproto == NONODEPROTO) continue;
-			if (w->curnodeproto->cell->lib == lib) us_clearwindow(w);
+			if (w->curnodeproto->lib == lib) us_clearwindow(w);
 		}
 
 		ttyputmsg(x_("Library %s closed"), lib->libname);
@@ -373,7 +373,7 @@ void us_library(INTBIG count, CHAR *par[])
 		killlibrary(lib);
 
 		/*
-		 * the facet structure has changed
+		 * the cell structure has changed
 		 *
 		 * this wouldn't be necessary if the "killlibrary()" routine did a
 		 * broadcast.  Then it would be detected properly in "us_killobject"
@@ -493,7 +493,7 @@ void us_library(INTBIG count, CHAR *par[])
 					for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 					{
 						if (w->curnodeproto != NONODEPROTO &&
-							w->curnodeproto->cell->lib == oldlib)
+							w->curnodeproto->lib == oldlib)
 						{
 							w->curnodeproto = NONODEPROTO;
 							us_redisplaynow(w, TRUE);
@@ -599,11 +599,11 @@ void us_library(INTBIG count, CHAR *par[])
 						}
 
 						/* get the text that belongs here */
-						var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
+						var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_cell_message_key);
 						if (var == NOVARIABLE)
 						{
 							newpar[0] = x_("");
-							var = setvalkey((INTBIG)np, VNODEPROTO, el_facet_message_key,
+							var = setvalkey((INTBIG)np, VNODEPROTO, el_cell_message_key,
 								(INTBIG)newpar, VSTRING|VISARRAY|(1<<VLENGTHSH));
 							if (var == NOVARIABLE)
 							{
@@ -630,8 +630,8 @@ void us_library(INTBIG count, CHAR *par[])
 							us_addline(curw, i, pp);
 						}
 						us_resumegraphics(curw);
-						curw->changehandler = us_textfacetchanges;
-						us_setfacetname(curw);
+						curw->changehandler = us_textcellchanges;
+						us_setcellname(curw);
 					} else
 					{
 						/* adjust the new window to account for borders in the old one */
@@ -654,7 +654,7 @@ void us_library(INTBIG count, CHAR *par[])
 						}
 						curw->curnodeproto = np;
 						newstate = (curw->state & ~(WINDOWTYPE|WINDOWMODE)) | DISPWINDOW;
-						if ((np->userbits&TECEDITFACET) != 0) newstate |= WINDOWTECEDMODE;
+						if ((np->userbits&TECEDITCELL) != 0) newstate |= WINDOWTECEDMODE;
 						us_setwindowmode(curw, curw->state, newstate);
 						curw->editor = NOEDITOR;
 						curw->buttonhandler = DEFAULTBUTTONHANDLER;
@@ -669,12 +669,12 @@ void us_library(INTBIG count, CHAR *par[])
 						curw->screenly = ly;
 						curw->screenhy = hy;
 						computewindowscale(curw);
-						us_setfacetname(curw);
-						us_setfacetsize(curw);
+						us_setcellname(curw);
+						us_setcellsize(curw);
 						us_setgridsize(curw);
 						if (curw->redisphandler != 0)
 							(*curw->redisphandler)(curw);
-						us_state |= CURFACETCHANGED;
+						us_state |= CURCELLCHANGED;
 					}
 				}
 
@@ -716,7 +716,7 @@ void us_library(INTBIG count, CHAR *par[])
 				if (el_curlib->curnodeproto != NONODEPROTO)
 				{
 					newpar[0] = describenodeproto(el_curlib->curnodeproto);
-					us_editfacet(1, newpar);
+					us_editcell(1, newpar);
 				}
 			}
 		}
@@ -1784,7 +1784,7 @@ void us_mirror(INTBIG count, CHAR *par[])
 		thepp = theni->proto->firstportproto;
 		if (thepp == NOPORTPROTO)
 		{
-			/* no port on the facet: create one */
+			/* no port on the cell: create one */
 			subni = newnodeinst(gen_univpinprim, theni->proto->lowx, theni->proto->highx,
 				theni->proto->lowy, theni->proto->highy, 0, 0, theni->proto);
 			if (subni == NONODEINST) break;
@@ -1898,8 +1898,8 @@ void us_move(INTBIG count, CHAR *par[])
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, us_tool->cluster);
 
-	/* make sure there is a current facet */
-	np = us_needfacet();
+	/* make sure there is a current cell */
+	np = us_needcell();
 	if (np == NONODEPROTO) return;
 
 	/* get the objects to be moved (mark nodes with nonzero "temp1") */
@@ -1911,10 +1911,10 @@ void us_move(INTBIG count, CHAR *par[])
 		return;
 	}
 
-	/* make sure they are all in the same facet */
+	/* make sure they are all in the same cell */
 	for(i=0; list[i] != NOGEOM; i++) if (np != geomparent(list[i]))
 	{
-		us_abortcommand(_("All moved objects must be in the same facet"));
+		us_abortcommand(_("All moved objects must be in the same cell"));
 		return;
 	}
 
@@ -2006,7 +2006,7 @@ void us_move(INTBIG count, CHAR *par[])
 		if (ly < bestly) bestly = ly;
 	}
 
-	/* special case when moving one node: account for facet center */
+	/* special case when moving one node: account for cell center */
 	if (total == 1 && list[1] == NOGEOM && numtexts == 0)
 	{
 		/* get standard corner offset */
@@ -2324,9 +2324,9 @@ void us_move(INTBIG count, CHAR *par[])
 	/* transform to space of this window */
 	if ((el_curwindowpart->state&INPLACEEDIT) != 0)
 	{
-		xform(0, 0, &snapx, &snapy, el_curwindowpart->outoffacet);
+		xform(0, 0, &snapx, &snapy, el_curwindowpart->outofcell);
 		snapx += dx;   snapy += dy;
-		xform(snapx, snapy, &dx, &dy, el_curwindowpart->intofacet);
+		xform(snapx, snapy, &dx, &dy, el_curwindowpart->intocell);
 	}
 
 	/* now move the object */
@@ -2360,7 +2360,7 @@ void us_node(INTBIG count, CHAR *par[])
 	REGISTER VARIABLE *var;
 
 	/* disallow node modification if lock is on */
-	np = us_needfacet();
+	np = us_needcell();
 	if (np == NONODEPROTO) return;
 
 	if (count == 0)
@@ -2451,7 +2451,7 @@ void us_node(INTBIG count, CHAR *par[])
 				if (var == NOVARIABLE) continue;
 				if (namesame(ch, (CHAR *)var->addr) == 0)
 				{
-					ttyputmsg(_("Warning: already a node in this facet called %s"), ch);
+					ttyputmsg(_("Warning: already a node in this cell called %s"), ch);
 					break;
 				}
 			}
@@ -2470,7 +2470,7 @@ void us_node(INTBIG count, CHAR *par[])
 			{
 				defaulttextsize(3, var->textdescript);
 
-				/* shift text down if on a facet instance */
+				/* shift text down if on a cell instance */
 				if (ni->proto->primindex == 0)
 				{
 					us_setdescriptoffset(var->textdescript,
@@ -2530,7 +2530,7 @@ void us_node(INTBIG count, CHAR *par[])
 				x = (store->lowx + store->highx) / 2;
 				y = (store->lowy + store->highy) / 2;
 				tech = store->parent->tech;
-				curlamb = store->parent->cell->lib->lambda[tech->techindex];
+				curlamb = store->parent->lib->lambda[tech->techindex];
 				initlist[0] = x - curlamb * 3;
 				initlist[1] = y - curlamb * 3;
 				initlist[2] = x - curlamb;
@@ -2548,7 +2548,7 @@ void us_node(INTBIG count, CHAR *par[])
 				x = (store->lowx + store->highx) / 2;
 				y = (store->lowy + store->highy) / 2;
 				tech = store->parent->tech;
-				curlamb = store->parent->cell->lib->lambda[tech->techindex];
+				curlamb = store->parent->lib->lambda[tech->techindex];
 				initlist[0] = x;
 				initlist[1] = y - curlamb * 3;
 				initlist[2] = x - curlamb * 3;
@@ -2620,12 +2620,15 @@ void us_node(INTBIG count, CHAR *par[])
 			}
 
 			l = 0;
-			for(i=0; i<=segs; i++)
+			if (inside > 0)
 			{
-				p = degs*i/segs;
-				x = mult(inside, cosine(p)) + (store->lowx+store->highx)/2;
-				y = mult(inside, sine(p)) + (store->lowy+store->highy)/2;
-				newlist[l++] = x;   newlist[l++] = y;
+				for(i=0; i<=segs; i++)
+				{
+					p = degs*i/segs;
+					x = mult(inside, cosine(p)) + (store->lowx+store->highx)/2;
+					y = mult(inside, sine(p)) + (store->lowy+store->highy)/2;
+					newlist[l++] = x;   newlist[l++] = y;
+				}
 			}
 			for(i=segs; i>=0; i--)
 			{
@@ -2638,7 +2641,7 @@ void us_node(INTBIG count, CHAR *par[])
 			/* save highlighting, set trace, restore highlighting */
 			us_pushhighlight();
 			us_clearhighlightcount();
-			us_settrace(store, newlist, (segs+1)*2);
+			us_settrace(store, newlist, l/2);
 			us_pophighlight(FALSE);
 			efree((CHAR *)newlist);
 			return;
@@ -2750,7 +2753,7 @@ void us_node(INTBIG count, CHAR *par[])
 			newhigh.fromgeom = store->geom;
 			newhigh.fromport = NOPORTPROTO;
 			newhigh.frompoint = whichpoint;
-			newhigh.facet = store->parent;
+			newhigh.cell = store->parent;
 			us_addhighlight(&newhigh);
 			return;
 		}
@@ -2771,7 +2774,7 @@ void us_node(INTBIG count, CHAR *par[])
 			newhigh.fromgeom = store->geom;
 			newhigh.fromport = NOPORTPROTO;
 			newhigh.frompoint = whichpoint;
-			newhigh.facet = store->parent;
+			newhigh.cell = store->parent;
 			us_addhighlight(&newhigh);
 			return;
 		}
@@ -2843,7 +2846,7 @@ void us_node(INTBIG count, CHAR *par[])
 				newhigh.fromgeom = store->geom;
 				newhigh.fromport = NOPORTPROTO;
 				newhigh.frompoint = size+1;
-				newhigh.facet = store->parent;
+				newhigh.cell = store->parent;
 				us_addhighlight(&newhigh);
 			}
 			efree((CHAR *)newlist);
@@ -2924,7 +2927,7 @@ void us_node(INTBIG count, CHAR *par[])
 			newhigh.fromgeom = store->geom;
 			newhigh.fromport = NOPORTPROTO;
 			newhigh.frompoint = whichpoint;
-			newhigh.facet = store->parent;
+			newhigh.cell = store->parent;
 			us_addhighlight(&newhigh);
 			return;
 		}
@@ -2981,7 +2984,7 @@ void us_node(INTBIG count, CHAR *par[])
 			newhigh.fromgeom = store->geom;
 			newhigh.fromport = NOPORTPROTO;
 			newhigh.frompoint = whichpoint;
-			newhigh.facet = store->parent;
+			newhigh.cell = store->parent;
 			us_addhighlight(&newhigh);
 			return;
 		}
