@@ -76,8 +76,8 @@ void us_outhier(INTBIG count, CHAR *par[])
 		}
 	}
 
-	/* must be editing a facet */
-	curnp = us_needfacet();
+	/* must be editing a cell */
+	curnp = us_needcell();
 	if (curnp == NONODEPROTO) return;
 
 	/* if in waveform window, switch to associated circuit window */
@@ -179,25 +179,25 @@ void us_outhier(INTBIG count, CHAR *par[])
 			}
 		}
 
-		/* if stack didn't tell where to go, see if upper facet is obvious */
+		/* if stack didn't tell where to go, see if upper cell is obvious */
 		if (hinp == NONODEPROTO)
 		{
-			/* see if facet "curnp" has an icon facet */
+			/* see if cell "curnp" has an icon cell */
 			np = iconview(curnp);
 			if (np == NONODEPROTO) np = curnp;
 
-			/* see if there is any instance of that facet */
+			/* see if there is any instance of that cell */
 			found = FALSE;
 			hinp = NONODEPROTO;
 			iconinst = NONODEINST;
 			for(ni = np->firstinst; ni != NONODEINST; ni = ni->nextinst)
 			{
-				if (ni->parent->cell == np->cell)
+				if (isiconof(np, ni->parent))
 				{
 					iconinst = ni;
 					continue;
 				}
-				if ((ni->parent->cell->lib->userbits&HIDDENLIBRARY) != 0) continue;
+				if ((ni->parent->lib->userbits&HIDDENLIBRARY) != 0) continue;
 				found = TRUE;
 				if (hinp != NONODEPROTO)
 				{
@@ -218,7 +218,7 @@ void us_outhier(INTBIG count, CHAR *par[])
 			{
 				if (i == 0)
 				{
-					us_abortcommand(_("Not in any facets"));
+					us_abortcommand(_("Not in any cells"));
 					return;
 				}
 				ttyputerr(_("Only in %ld deep"), i);
@@ -239,7 +239,7 @@ void us_outhier(INTBIG count, CHAR *par[])
 		if (hini != NONODEINST && curpp != NOPORTPROTO)
 			hipp = equivalentport(curnp, curpp, hini->proto);
 
-		/* adjust view of the facet */
+		/* adjust view of the cell */
 		if (haveview != 0)
 		{
 			lx = vlx;   hx = vhx;
@@ -254,7 +254,7 @@ void us_outhier(INTBIG count, CHAR *par[])
 				hy += hini->geom->lowy - curnp->lowy;
 			} else
 			{
-				/* make a full view of the facet */
+				/* make a full view of the cell */
 				us_fullview(hinp, &lx, &hx, &ly, &hy);
 			}
 		}
@@ -267,8 +267,8 @@ void us_outhier(INTBIG count, CHAR *par[])
 	/* display the final location */
 	if (haveview != 0)
 	{
-		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("intofacet"), into);
-		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("outoffacet"), outof);
+		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("intocell"), into);
+		us_setxarray((INTBIG)el_curwindowpart, VWINDOWPART, x_("outofcell"), outof);
 		if (outof[2][0] == 0 && outof[2][1] == 0 && outof[2][2] == 0)
 		{
 			(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, x_("state"),
@@ -281,7 +281,7 @@ void us_outhier(INTBIG count, CHAR *par[])
 				el_curwindowpart->inplacedepth-1, VINTEGER);
 		}
 	}
-	us_switchtofacet(hinp, lx, hx, ly, hy, hini, hipp, newwindow, TRUE, TRUE);
+	us_switchtocell(hinp, lx, hx, ly, hy, hini, hipp, newwindow, TRUE, TRUE);
 
 	/* if simulating, coordinate this hierarchy traversal with the waveform */
 	if (el_curwindowpart != NOWINDOWPART &&
@@ -294,7 +294,8 @@ void us_outhier(INTBIG count, CHAR *par[])
 void us_package(INTBIG count, CHAR *par[])
 {
 	INTBIG lx, hx, ly, hy;
-	REGISTER INTBIG search;
+	REGISTER INTBIG search, len;
+	REGISTER void *infstr;
 	REGISTER GEOM *look;
 	REGISTER NODEPROTO *np, *parnt;
 	REGISTER PORTPROTO *ppt, *npt;
@@ -313,7 +314,7 @@ void us_package(INTBIG count, CHAR *par[])
 
 	if (count == 0)
 	{
-		count = ttygetparam(M_("New facet name: "), &us_packagep, MAXPARS, par);
+		count = ttygetparam(M_("New cell name: "), &us_packagep, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -336,16 +337,25 @@ void us_package(INTBIG count, CHAR *par[])
 		par[0] = pt;
 	}
 
-	/* create the new facet */
+	/* make sure there is a proper view type on this new cell */
+	parnt = getcurcell();
+	len = strlen(par[0]);
+	if (par[0][len-1] != '}')
+	{
+		infstr = initinfstr();
+		formatinfstr(infstr, "%s{%s}", par[0], parnt->cellview->sviewname);
+		par[0] = returninfstr(infstr);
+	}
+
+	/* create the new cell */
 	np = us_newnodeproto(par[0], lib);
 	if (np == NONODEPROTO)
 	{
-		us_abortcommand(_("Cannot create facet %s"), par[0]);
+		us_abortcommand(_("Cannot create cell %s"), par[0]);
 		return;
 	}
 
 	/* first zap all nodes touching all arcs in the region */
-	parnt = getcurfacet();
 	search = initsearch(lx, hx, ly, hy, parnt);
 	for(;;)
 	{
@@ -358,7 +368,7 @@ void us_package(INTBIG count, CHAR *par[])
 		ai->end[1].nodeinst->temp1 = (UINTBIG)ni;
 	}
 
-	/* copy the nodes into the new facet */
+	/* copy the nodes into the new cell */
 	search = initsearch(lx, hx, ly, hy, parnt);
 	for(;;)
 	{
@@ -370,7 +380,7 @@ void us_package(INTBIG count, CHAR *par[])
 			ni->highy, ni->transpose, ni->rotation, np);
 		if (newni == NONODEINST)
 		{
-			us_abortcommand(_("Cannot create node in new facet"));
+			us_abortcommand(_("Cannot create node in new cell"));
 			return;
 		}
 		ni->temp1 = (INTBIG)newni;
@@ -401,7 +411,7 @@ void us_package(INTBIG count, CHAR *par[])
 		}
 	}
 
-	/* copy the arcs into the new facet */
+	/* copy the arcs into the new cell */
 	search = initsearch(lx, hx, ly, hy, parnt);
 	for(;;)
 	{
@@ -417,7 +427,7 @@ void us_package(INTBIG count, CHAR *par[])
 					ai->end[1].xpos,ai->end[1].ypos, np);
 		if (newar == NOARCINST)
 		{
-			us_abortcommand(_("Cannot create arc in new facet"));
+			us_abortcommand(_("Cannot create arc in new cell"));
 			return;
 		}
 		if (copyvars((INTBIG)ai, VARCINST, (INTBIG)newar, VARCINST, FALSE) ||
@@ -431,10 +441,10 @@ void us_package(INTBIG count, CHAR *par[])
 		}
 	}
 
-	/* recompute bounds of new facet */
+	/* recompute bounds of new cell */
 	(*el_curconstraint->solve)(np);
 
-	ttyputmsg(_("Facet %s created"), describenodeproto(np));
+	ttyputmsg(_("Cell %s created"), describenodeproto(np));
 }
 
 void us_port(INTBIG count, CHAR *par[])
@@ -546,10 +556,10 @@ void us_port(INTBIG count, CHAR *par[])
 		return;
 	}
 
-	if (namesamen(pt, x_("identify-facet"), l) == 0 && l >= 10)
+	if (namesamen(pt, x_("identify-cell"), l) == 0 && l >= 10)
 	{
-		/* make sure there is a current facet */
-		np = us_needfacet();
+		/* make sure there is a current cell */
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
 		if ((el_curwindowpart->state&WINDOWTYPE) == DISP3DWINDOW)
 		{
@@ -597,11 +607,11 @@ void us_port(INTBIG count, CHAR *par[])
 			return;
 		}
 
-		/* make sure ports are in the same facet */
+		/* make sure ports are in the same cell */
 		np = geomparent(fromgeom);
 		if (np != geomparent(togeom))
 		{
-			us_abortcommand(_("Port motion must be within a single facet"));
+			us_abortcommand(_("Port motion must be within a single cell"));
 			return;
 		}
 
@@ -654,7 +664,7 @@ void us_port(INTBIG count, CHAR *par[])
 		if (reducehighlighting == 0) us_pophighlight(FALSE); else
 		{
 			newhigh.status = HIGHFROM;
-			newhigh.facet = np;
+			newhigh.cell = np;
 			newhigh.fromgeom = fromgeom;
 			newhigh.fromport = fromport;
 			us_addhighlight(&newhigh);
@@ -664,8 +674,8 @@ void us_port(INTBIG count, CHAR *par[])
 
 	if (namesamen(pt, x_("re-export-all"), l) == 0 && l >= 1)
 	{
-		/* make sure there is a current facet */
-		np = us_needfacet();
+		/* make sure there is a current cell */
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
 
 		/* disallow port action if lock is on */
@@ -675,15 +685,15 @@ void us_port(INTBIG count, CHAR *par[])
 		us_pushhighlight();
 		us_clearhighlightcount();
 
-		/* look at every node in this facet */
+		/* look at every node in this cell */
 		total = 0;
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
-			/* only look for facets, not primitives */
+			/* only look for cells, not primitives */
 			if (ni->proto->primindex != 0) continue;
 
 			/* ignore recursive references (showing icon in contents) */
-			if (ni->proto->cell == np->cell) continue;
+			if (isiconof(ni->proto, np)) continue;
 
 			/* clear marks on the ports of this node */
 			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -767,7 +777,7 @@ void us_port(INTBIG count, CHAR *par[])
 		{
 			ni = g[i]->entryaddr.ni;
 
-			/* only look for facets, not primitives */
+			/* only look for cells, not primitives */
 			if (ni->proto->primindex != 0) continue;
 
 			/* clear marks on the ports of this node */
@@ -825,8 +835,8 @@ void us_port(INTBIG count, CHAR *par[])
 
 	if (namesamen(pt, x_("power-ground-re-export"), l) == 0 && l >= 1)
 	{
-		/* make sure there is a current facet */
-		np = us_needfacet();
+		/* make sure there is a current cell */
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
 
 		/* disallow port action if lock is on */
@@ -836,15 +846,15 @@ void us_port(INTBIG count, CHAR *par[])
 		us_pushhighlight();
 		us_clearhighlightcount();
 
-		/* look at every node in this facet */
+		/* look at every node in this cell */
 		total = 0;
 		for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
-			/* only look for facets, not primitives */
+			/* only look for cells, not primitives */
 			if (ni->proto->primindex != 0) continue;
 
 			/* ignore recursive references (showing icon in contents) */
-			if (ni->proto->cell == np->cell) continue;
+			if (isiconof(ni->proto, np)) continue;
 
 			/* clear marks on the ports of this node */
 			for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
