@@ -45,7 +45,7 @@ static struct
 	{x_("align"),      2,  &us_statusalign},
 	{x_("angle"),      2,  &us_statusangle},
 	{x_("arc"),        2,  &us_statusarc},
-	{x_("facet"),      1,  &us_statusfacet},
+	{x_("cell"),       1,  &us_statuscell},
 	{x_("grid"),       1,  &us_statusgridsize},
 	{x_("lambda"),     1,  &us_statuslambda},
 	{x_("numselected"),2,  &us_statusselectcount},
@@ -55,7 +55,7 @@ static struct
 	{x_("project"),    2,  &us_statusproject},
 	{x_("root"),       1,  &us_statusroot},
 	{x_("selection"),  2,  &us_statusselection},
-	{x_("size"),       2,  &us_statusfacetsize},
+	{x_("size"),       2,  &us_statuscellsize},
 	{x_("technology"), 1,  &us_statustechnology},
 	{x_("x"),          1,  &us_statusxpos},
 	{x_("y"),          1,  &us_statusypos},
@@ -157,17 +157,17 @@ void us_window(INTBIG count, CHAR *par[])
 			return;
 		}
 
-		np = us_needfacet();
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
 
 		/* save and erase highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
 
-		/* make the facet fill the window */
+		/* make the cell fill the window */
 		us_fullview(np, &lx, &hx, &ly, &hy);
 		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
-			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outofcell);
 		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 
 		startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
@@ -222,7 +222,7 @@ void us_window(INTBIG count, CHAR *par[])
 		lx = x - curwx/2;      ly = y - curwy/2;
 		hx = lx + curwx;       hy = ly + curwy;
 		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
-			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outofcell);
 		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 1);
 
 		/* save and erase highlighting */
@@ -256,7 +256,7 @@ void us_window(INTBIG count, CHAR *par[])
 		}
 #endif
 
-		np = us_needfacet();
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
 
 		/* cannot manipulate a nonstandard window */
@@ -274,7 +274,7 @@ void us_window(INTBIG count, CHAR *par[])
 		lx = xcur - curwx/2;   ly = ycur - curwy/2;
 		hx = lx + curwx;       hy = ly + curwy;
 		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
-			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outofcell);
 		us_squarescreen(el_curwindowpart, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 1);
 
 		/* save and erase highlighting */
@@ -370,7 +370,7 @@ void us_window(INTBIG count, CHAR *par[])
 		switch (el_curwindowpart->state&WINDOWTYPE)
 		{
 			case DISPWINDOW:
-				if (us_needfacet() == NONODEPROTO) return;
+				if (us_needcell() == NONODEPROTO) return;
 				if (pp[estrlen(pp)-1] == 'l') dist = atola(pp, 0); else
 					dist = muldiv(atofr(pp), (el_curwindowpart->screenhy - el_curwindowpart->screenly), WHOLE);
 				us_slideup(-dist);
@@ -462,7 +462,7 @@ void us_window(INTBIG count, CHAR *par[])
 		{
 			(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)oldw,
 				VWINDOWPART|VDONTSAVE);
-			us_setfacetname(oldw);
+			us_setcellname(oldw);
 		}
 		return;
 	}
@@ -478,9 +478,9 @@ void us_window(INTBIG count, CHAR *par[])
 			return;
 		}
 
-		np = us_needfacet();
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
-		lambda = lambdaoffacet(np);
+		lambda = lambdaofcell(np);
 		x = muldiv(el_curwindowpart->gridx, lambda, WHOLE);
 		y = muldiv(el_curwindowpart->gridy, lambda, WHOLE);
 		curwx = el_curwindowpart->screenhx-el_curwindowpart->screenlx;
@@ -552,10 +552,10 @@ void us_window(INTBIG count, CHAR *par[])
 		}
 
 		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
-			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outoffacet);
+			xformbox(&lx, &hx, &ly, &hy, el_curwindowpart->outofcell);
 		if (lx == hx && ly == hy)
 		{
-			lambda = lambdaoffacet(np);
+			lambda = lambdaofcell(np);
 			lx -= lambda;
 			hx += lambda;
 			ly -= lambda;
@@ -612,9 +612,9 @@ void us_window(INTBIG count, CHAR *par[])
 			return;
 		}
 
-		np = us_needfacet();
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
-		lambda = lambdaoffacet(np);
+		lambda = lambdaofcell(np);
 		if (count >= 2) dist = atola(par[1], 0); else
 			dist = 2 * lambda;
 		if (dist == 0)
@@ -671,7 +671,7 @@ void us_window(INTBIG count, CHAR *par[])
 		switch (el_curwindowpart->state&WINDOWTYPE)
 		{
 			case DISPWINDOW:
-				if (us_needfacet() == NONODEPROTO) return;
+				if (us_needcell() == NONODEPROTO) return;
 				if (pp[estrlen(pp)-1] == 'l') dist = atola(pp, 0); else
 					dist = muldiv(atofr(pp), (el_curwindowpart->screenhx - el_curwindowpart->screenlx), WHOLE);
 				us_slideleft(dist);
@@ -789,14 +789,15 @@ void us_window(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("measure"), l) == 0 && l >= 2)
 	{
-		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
+		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW &&
+			(el_curwindowpart->state&WINDOWTYPE) != WAVEFORMWINDOW)
 		{
-			us_abortcommand(_("Can only measure distance in an edit window"));
+			us_abortcommand(_("Can only measure distance in an edit and waveform windows"));
 			return;
 		}
 		if (el_curwindowpart->curnodeproto == NONODEPROTO)
 		{
-			us_abortcommand(_("No facet in this window to measure"));
+			us_abortcommand(_("No cell in this window to measure"));
 			return;
 		}
 		if ((us_state&MEASURINGDISTANCE) != 0)
@@ -928,9 +929,9 @@ void us_window(INTBIG count, CHAR *par[])
 			return;
 		}
 
-		np = us_needfacet();
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
-		lambda = lambdaoffacet(np);
+		lambda = lambdaofcell(np);
 		if (count >= 2) dist = atola(par[1], 0); else
 			dist = 2 * lambda;
 		if (dist == 0)
@@ -1113,7 +1114,7 @@ void us_window(INTBIG count, CHAR *par[])
 		switch (el_curwindowpart->state&WINDOWTYPE)
 		{
 			case DISPWINDOW:
-				if (us_needfacet() == NONODEPROTO) return;
+				if (us_needcell() == NONODEPROTO) return;
 				if (pp[estrlen(pp)-1] == 'l') dist = atola(pp, 0); else
 					dist = muldiv(atofr(pp), (el_curwindowpart->screenhx - el_curwindowpart->screenlx), WHOLE);
 				us_slideleft(-dist);
@@ -1290,7 +1291,7 @@ void us_window(INTBIG count, CHAR *par[])
 		return;
 	}
 
-	if (namesamen(pp, x_("tiny-facets"), l) == 0 && l >= 2)
+	if (namesamen(pp, x_("tiny-cells"), l) == 0 && l >= 2)
 	{
 		if (us_needwindow()) return;
 		if (count >= 2)
@@ -1300,7 +1301,7 @@ void us_window(INTBIG count, CHAR *par[])
 			{
 				startobjectchange((INTBIG)us_tool, VTOOL);
 				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflagskey,
-					us_useroptions | DRAWTINYFACETS, VINTEGER);
+					us_useroptions | DRAWTINYCELLS, VINTEGER);
 				if (count >= 3)
 				{
 					i = atofr(par[2]);
@@ -1312,20 +1313,20 @@ void us_window(INTBIG count, CHAR *par[])
 			{
 				startobjectchange((INTBIG)us_tool, VTOOL);
 				(void)setvalkey((INTBIG)us_tool, VTOOL, us_optionflagskey,
-					us_useroptions & ~DRAWTINYFACETS, VINTEGER);
+					us_useroptions & ~DRAWTINYCELLS, VINTEGER);
 				endobjectchange((INTBIG)us_tool, VTOOL);
 			} else
 			{
-				ttyputusage(x_("window tiny-facets draw|(hash-out [LAMBDAPERPIXEL])"));
+				ttyputusage(x_("window tiny-cells draw|(hash-out [LAMBDAPERPIXEL])"));
 				return;
 			}
 		}
-		if ((us_useroptions&DRAWTINYFACETS) != 0)
+		if ((us_useroptions&DRAWTINYCELLS) != 0)
 		{
-			ttyputverbose(M_("Tiny facets will be drawn"));
+			ttyputverbose(M_("Tiny cells will be drawn"));
 		} else
 		{
-			ttyputverbose(M_("Tiny facets will be hashed-out after %s lambda per pixel"),
+			ttyputverbose(M_("Tiny cells will be hashed-out after %s lambda per pixel"),
 				frtoa(us_tinyratio));
 		}
 		return;
@@ -1333,7 +1334,7 @@ void us_window(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("trace-displayed"), l) == 0 && l >= 2)
 	{
-		np = us_needfacet();
+		np = us_needcell();
 		if (np == NONODEPROTO) return;
 
 		/* cannot manipulate a nonstandard window */
@@ -1403,7 +1404,7 @@ void us_window(INTBIG count, CHAR *par[])
 		switch (el_curwindowpart->state&WINDOWTYPE)
 		{
 			case DISPWINDOW:
-				if (us_needfacet() == NONODEPROTO) return;
+				if (us_needcell() == NONODEPROTO) return;
 				if (pp[estrlen(pp)-1] == 'l') dist = atola(pp, 0); else
 					dist = muldiv(atofr(pp), (el_curwindowpart->screenhy - el_curwindowpart->screenly), WHOLE);
 				us_slideup(dist);
@@ -1560,7 +1561,7 @@ void us_window(INTBIG count, CHAR *par[])
 				us_abortcommand(_("Cannot view this window in 3 dimensions"));
 				return;
 			}
-			np = us_needfacet();
+			np = us_needcell();
 			if (np == NONODEPROTO) return;
 
 			us_3dsetupviewing(w);
@@ -1568,7 +1569,7 @@ void us_window(INTBIG count, CHAR *par[])
 			/* clear highlighting */
 			us_clearhighlightcount();
 
-			/* make the facet fill the window */
+			/* make the cell fill the window */
 			us_fullview(np, &lx, &hx, &ly, &hy);
 			us_squarescreen(w, NOWINDOWPART, FALSE, &lx, &hx, &ly, &hy, 0);
 
@@ -1652,7 +1653,7 @@ void us_yanknode(INTBIG count, CHAR *par[])
 	list = us_gethighlighted(WANTNODEINST, 0, 0);
 	if (list[0] == NOGEOM)
 	{
-		us_abortcommand(_("Must highlight facet(s) to be yanked"));
+		us_abortcommand(_("Must highlight cell(s) to be yanked"));
 		return;
 	}
 
@@ -1666,13 +1667,13 @@ void us_yanknode(INTBIG count, CHAR *par[])
 		/* disallow yanking if lock is on */
 		if (us_cantedit(np, topno, TRUE)) return;
 
-		/* turn off highlighting for the first facet */
+		/* turn off highlighting for the first cell */
 		if (!found) us_clearhighlightcount();
 
-		/* yank this facet */
+		/* yank this cell */
 		us_yankonenode(topno);
 		found = TRUE;
 	}
 
-	if (!found) us_abortcommand(_("Can only yank facets"));
+	if (!found) us_abortcommand(_("Can only yank cells"));
 }
