@@ -42,7 +42,7 @@
 #include <math.h>
 
 #define TRAN_PIN   -1
-#define TRAN_FACET -2
+#define TRAN_CELL -2
 
 /* prototypes for local routines */
 static PORTPROTO *us_convport(NODEINST*, NODEINST*, PORTPROTO*);
@@ -57,24 +57,24 @@ static NODEPROTO *us_tran_linkage(CHAR*, VIEW*, NODEPROTO*);
 static void       us_tran_logmakearcs(NODEPROTO*, NODEPROTO*);
 static NODEINST  *us_tran_logmakenode(NODEPROTO*, NODEINST*, INTSML, INTSML, NODEPROTO*, TECHNOLOGY*);
 static void       us_tran_logmakenodes(NODEPROTO*, NODEPROTO*, TECHNOLOGY*);
-static NODEPROTO *us_tran_makelayoutfacets(NODEPROTO*, CHAR*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
+static NODEPROTO *us_tran_makelayoutcells(NODEPROTO*, CHAR*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
 static BOOLEAN    us_tran_makelayoutparts(NODEPROTO*, NODEPROTO*, TECHNOLOGY*, TECHNOLOGY*, VIEW*);
 static void       us_tran_makemanhattan(NODEPROTO*);
 
 /*
- * this routine converts facet "oldfacet" to one of technology "newtech".
- * Returns the address of the new facet (NONODEPROTO on error).
+ * this routine converts cell "oldcell" to one of technology "newtech".
+ * Returns the address of the new cell (NONODEPROTO on error).
  */
-NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
+NODEPROTO *us_convertcell(NODEPROTO *oldcell, TECHNOLOGY *newtech)
 {
-	NODEPROTO *newfacet, *np;
+	NODEPROTO *newcell, *np;
 	NODEPROTO *(*localconversion)(NODEPROTO*, TECHNOLOGY*);
 	REGISTER TECHNOLOGY *oldtech, *tech;
 	REGISTER ARCINST *ai;
 	VARIABLE *var;
 
 	/* cannot convert text-only views */
-	if ((oldfacet->cellview->viewstate&TEXTVIEW) != 0)
+	if ((oldcell->cellview->viewstate&TEXTVIEW) != 0)
 	{
 		ttyputerr(_("Cannot convert textual views: only layout and schematic"));
 		return(NONODEPROTO);
@@ -91,23 +91,23 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 		if (var != NOVARIABLE)
 		{
 			localconversion = (NODEPROTO *(*)(NODEPROTO*, TECHNOLOGY*))var->addr;
-			newfacet = (*(localconversion))(oldfacet, newtech);
-			if (newfacet == NONODEPROTO) return(NONODEPROTO);
+			newcell = (*(localconversion))(oldcell, newtech);
+			if (newcell == NONODEPROTO) return(NONODEPROTO);
 		} else    /* Convert to schematic here */
 		{
-			/* create facet in new technology */
-			newfacet = us_tran_linkage(oldfacet->cell->cellname, el_schematicview, oldfacet);
-			if (newfacet == NONODEPROTO) return(NONODEPROTO);
+			/* create cell in new technology */
+			newcell = us_tran_linkage(oldcell->protoname, el_schematicview, oldcell);
+			if (newcell == NONODEPROTO) return(NONODEPROTO);
 
-			/* create the parts in this facet */
-			us_tran_logmakenodes(oldfacet, newfacet, newtech);
-			us_tran_logmakearcs(oldfacet, newfacet);
+			/* create the parts in this cell */
+			us_tran_logmakenodes(oldcell, newcell, newtech);
+			us_tran_logmakearcs(oldcell, newcell);
 
 			/* now make adjustments for manhattan-ness */
-			us_tran_makemanhattan(newfacet);
+			us_tran_makemanhattan(newcell);
 
 			/* set "FIXANG" if reasonable */
-			for(ai = newfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+			for(ai = newcell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 			{
 				if (ai->end[0].xpos == ai->end[1].xpos &&
 					ai->end[0].ypos == ai->end[1].ypos) continue;
@@ -116,54 +116,54 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 			}
 		}
 
-		/* after adjusting contents, must re-solve to get proper facet size */
-		(*el_curconstraint->solve)(newfacet);
+		/* after adjusting contents, must re-solve to get proper cell size */
+		(*el_curconstraint->solve)(newcell);
 	} else
 	{
 		/* do general conversion between technologies */
-		oldtech = oldfacet->tech;
+		oldtech = oldcell->tech;
 
 		/* reset flag that primitive cannot be converted */
 		for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
 			for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 				np->temp1 = 0;
-		newfacet = us_tran_makelayoutfacets(oldfacet, oldfacet->cell->cellname,
+		newcell = us_tran_makelayoutcells(oldcell, oldcell->protoname,
 			oldtech, newtech, el_layoutview);
 	}
-	return(newfacet);
+	return(newcell);
 }
 
 /*
- * routine to create a new facet called "newfacetname" that is to be the
- * equivalent to an old facet in "facet".  The view type of the new facet is
- * in "newfacetview" and the view type of the old facet is in "facetview"
+ * routine to create a new cell called "newcellname" that is to be the
+ * equivalent to an old cell in "cell".  The view type of the new cell is
+ * in "newcellview" and the view type of the old cell is in "cellview"
  */
-NODEPROTO *us_tran_linkage(CHAR *newfacetname, VIEW *newfacetview, NODEPROTO *facet)
+NODEPROTO *us_tran_linkage(CHAR *newcellname, VIEW *newcellview, NODEPROTO *cell)
 {
-	NODEPROTO *newfacet;
-	REGISTER CHAR *facetname;
+	NODEPROTO *newcell;
+	REGISTER CHAR *cellname;
 	REGISTER void *infstr;
 
-	/* create the new facet */
-	if (newfacetview->sviewname[0] == 0) facetname = newfacetname; else
+	/* create the new cell */
+	if (newcellview->sviewname[0] == 0) cellname = newcellname; else
 	{
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, newfacetname);
+		addstringtoinfstr(infstr, newcellname);
 		addtoinfstr(infstr, '{');
-		addstringtoinfstr(infstr, newfacetview->sviewname);
+		addstringtoinfstr(infstr, newcellview->sviewname);
 		addtoinfstr(infstr, '}');
-		facetname = returninfstr(infstr);
+		cellname = returninfstr(infstr);
 	}
-	newfacet = us_newnodeproto(facetname, facet->cell->lib);
-	if (newfacet == NONODEPROTO)
-		ttyputmsg(_("Could not create facet: %s"), facetname); else
-			ttyputmsg(_("Creating new facet: %s"), facetname);
-	return(newfacet);
+	newcell = us_newnodeproto(cellname, cell->lib);
+	if (newcell == NONODEPROTO)
+		ttyputmsg(_("Could not create cell: %s"), cellname); else
+			ttyputmsg(_("Creating new cell: %s"), cellname);
+	return(newcell);
 }
 
 /********************** CODE FOR CONVERSION TO SCHEMATIC **********************/
 
-void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *newtech)
+void us_tran_logmakenodes(NODEPROTO *cell, NODEPROTO *newcell, TECHNOLOGY *newtech)
 {
 	NODEINST *ni, *schemni;
 	NODEPROTO *onp;
@@ -176,30 +176,30 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 	UINTBIG descript[TEXTDESCRIPTSIZE];
 
 	/*
-	 * for each node, create a new node in the newfacet, of the correct
+	 * for each node, create a new node in the newcell, of the correct
 	 * logical type.  Also, store a pointer to the new node in the old
 	 * node's temp1.  This is used in the arc translation part of the
 	 * program to find the new ends of each arc.
 	 */
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		type = us_tranismos(ni);
 		switch (type)
 		{
 			case TRAN_PIN:
 				/* compute new x, y coordinates */
-				schemni = us_tran_logmakenode(sch_wirepinprim, ni, 0, 0, newfacet, newtech);
+				schemni = us_tran_logmakenode(sch_wirepinprim, ni, 0, 0, newcell, newtech);
 				break;
-			case TRAN_FACET:
-				for(onp = ni->proto->cell->firstincell; onp != NONODEPROTO; onp = onp->nextincell)
+			case TRAN_CELL:
+				FOR_CELLGROUP(onp, ni->proto)
 					if (onp->cellview == el_schematicview) break;
 				if (onp == NONODEPROTO)
 				{
-					onp = us_convertfacet(ni->proto, newtech);
+					onp = us_convertcell(ni->proto, newtech);
 					if (onp == NONODEPROTO) break;
 				}
 				schemni = us_tran_logmakenode(onp, ni, ni->transpose, ni->rotation,
-					newfacet, newtech);
+					newcell, newtech);
 				break;
 			case NPUNKNOWN:	/* could not match it */
 				 schemni = NONODEINST;
@@ -217,7 +217,7 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 				rotate += 2700;
 				while (rotate >= 3600) rotate -= 3600;
 				schemni = us_tran_logmakenode(sch_transistorprim, ni, trans, rotate,
-					newfacet, newtech);
+					newcell, newtech);
 
 				/* set the type of the transistor */
 				switch (type)
@@ -291,7 +291,7 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 			{
 				pp = us_tranconvpp(ni, pexp->proto);
 				if (pp == NOPORTPROTO) continue;
-				pp2 = newportproto(newfacet, schemni, pp, pexp->exportproto->protoname);
+				pp2 = newportproto(newcell, schemni, pp, pexp->exportproto->protoname);
 				if (pp2 == NOPORTPROTO) return;
 				pp2->userbits = (pp2->userbits & ~STATEBITS) |
 					(pexp->exportproto->userbits & STATEBITS);
@@ -305,7 +305,7 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 }
 
 NODEINST *us_tran_logmakenode(NODEPROTO *prim, NODEINST *orig, INTSML trn, INTSML rot,
-	NODEPROTO *newfacet, TECHNOLOGY *newtech)
+	NODEPROTO *newcell, TECHNOLOGY *newtech)
 {
 	REGISTER INTBIG cx, cy, scaleu, scaled;
 	INTBIG sx, sy;
@@ -318,11 +318,11 @@ NODEINST *us_tran_logmakenode(NODEPROTO *prim, NODEINST *orig, INTSML trn, INTSM
 	cx = muldiv((orig->lowx+orig->highx)/2, scaleu, scaled) - (prim->highx-prim->lowx)/2;
 	cy = muldiv((orig->lowy+orig->highy)/2, scaleu, scaled) - (prim->highy-prim->lowy)/2;
 	defaultnodesize(prim, &sx, &sy);
-	newni = newnodeinst(prim, cx, cx+sx, cy, cy+sy, trn, rot, newfacet);
+	newni = newnodeinst(prim, cx, cx+sx, cy, cy+sy, trn, rot, newcell);
 	return(newni);
 }
 
-void us_tran_logmakearcs(NODEPROTO *facet, NODEPROTO *newfacet)
+void us_tran_logmakearcs(NODEPROTO *cell, NODEPROTO *newcell)
 {
 	PORTPROTO *oldpp1, *oldpp2, *newpp1, *newpp2;
 	ARCINST *oldai, *newai;
@@ -330,10 +330,10 @@ void us_tran_logmakearcs(NODEPROTO *facet, NODEPROTO *newfacet)
 	INTBIG x1, x2, y1, y2, bits;
 
 	/*
-	 * for each arc in facet, find the ends in the new technology, and
-	 * make a new arc to connect them in the new facet.
+	 * for each arc in cell, find the ends in the new technology, and
+	 * make a new arc to connect them in the new cell.
 	 */
-	for(oldai = facet->firstarcinst; oldai != NOARCINST; oldai = oldai->nextarcinst)
+	for(oldai = cell->firstarcinst; oldai != NOARCINST; oldai = oldai->nextarcinst)
 	{
 		newni1 = (NODEINST *)oldai->end[0].nodeinst->temp1;
 		newni2 = (NODEINST *)oldai->end[1].nodeinst->temp1;
@@ -356,7 +356,7 @@ void us_tran_logmakearcs(NODEPROTO *facet, NODEPROTO *newfacet)
 		/* create the new arc */
 		bits = us_makearcuserbits(sch_wirearc) & ~(FIXANG|FIXED);
 		newai = newarcinst(sch_wirearc, defaultarcwidth(sch_wirearc), bits,
-			newni1, newpp1, x1, y1, newni2, newpp2, x2, y2, newfacet);
+			newni1, newpp1, x1, y1, newni2, newpp2, x2, y2, newcell);
 		if (newai == NOARCINST) break;
 		endobjectchange((INTBIG)newai, VARCINST);
 	}
@@ -364,7 +364,7 @@ void us_tran_logmakearcs(NODEPROTO *facet, NODEPROTO *newfacet)
 
 #define MAXADJUST 5
 
-void us_tran_makemanhattan(NODEPROTO *newfacet)
+void us_tran_makemanhattan(NODEPROTO *newcell)
 {
 	REGISTER NODEINST *ni;
 	REGISTER PORTARCINST *pi;
@@ -373,8 +373,8 @@ void us_tran_makemanhattan(NODEPROTO *newfacet)
 	REGISTER INTBIG dist, bestdist, bestx, besty, xp, yp;
 	INTBIG x[MAXADJUST], y[MAXADJUST];
 
-	/* adjust this facet */
-	for(ni = newfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* adjust this cell */
+	for(ni = newcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex == 0) continue;
 		if (((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH) != NPPIN) continue;
@@ -426,7 +426,7 @@ PORTPROTO *us_tranconvpp(NODEINST *ni, PORTPROTO *mospp)
 		case TRAN_PIN:
 			schempp = schemni->proto->firstportproto;
 			break;
-		case TRAN_FACET:
+		case TRAN_CELL:
 			schempp = getportproto(schemni->proto, mospp->protoname);
 			break;
 		default: /* transistor */
@@ -443,13 +443,13 @@ PORTPROTO *us_tranconvpp(NODEINST *ni, PORTPROTO *mospp)
  * this routine figures out if the current nodeinst is a MOS component
  * (a wire or transistor).  If it's a transistor, return corresponding
  * define from efunction.h; if it's a passive connector, return TRAN_PIN;
- * if it's a facet, return TRAN_FACET; else return NPUNKNOWN.
+ * if it's a cell, return TRAN_CELL; else return NPUNKNOWN.
  */
 INTBIG us_tranismos(NODEINST *ni)
 {
 	INTBIG fun;
 
-	if (ni->proto->primindex == 0) return(TRAN_FACET);
+	if (ni->proto->primindex == 0) return(TRAN_CELL);
 	fun = (ni->proto->userbits & NFUNCTION) >> NFUNCTIONSH;
 	switch(fun)
 	{
@@ -492,52 +492,52 @@ PORTPROTO *us_trangetproto(NODEINST *ni, INTBIG port)
 /************************* CODE FOR CONVERSION TO LAYOUT *************************/
 
 /*
- * routine to recursively descend from facet "oldfacet" and find subfacets that
- * have to be converted.  When all subfacets have been converted, convert this
- * one into a new one called "newfacetname".  The technology for the old facet
- * is "oldtech" and the technology to use for the new facet is "newtech".  The
+ * routine to recursively descend from cell "oldcell" and find subcells that
+ * have to be converted.  When all subcells have been converted, convert this
+ * one into a new one called "newcellname".  The technology for the old cell
+ * is "oldtech" and the technology to use for the new cell is "newtech".  The
  * old view type is "oldview" and the new view type is "nview".
  */
-NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, CHAR *newfacetname,
+NODEPROTO *us_tran_makelayoutcells(NODEPROTO *oldcell, CHAR *newcellname,
 	TECHNOLOGY *oldtech, TECHNOLOGY *newtech, VIEW *nview)
 {
-	REGISTER NODEPROTO *newfacet, *rnp;
+	REGISTER NODEPROTO *newcell, *rnp;
 	REGISTER INTBIG bits;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	CHAR *str;
 
-	/* first convert the sub-facets */
-	for(ni = oldfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	/* first convert the sub-cells */
+	for(ni = oldcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		/* ignore primitives */
 		if (ni->proto->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (ni->proto->cell == oldfacet->cell) continue;
+		if (isiconof(ni->proto, oldcell)) continue;
 
-		/* ignore facets with associations */
-		for(rnp = ni->proto->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
+		/* ignore cells with associations */
+		FOR_CELLGROUP(rnp, ni->proto)
 			if (rnp->cellview == nview) break;
 		if (rnp != NONODEPROTO) continue;
 
-		/* make up a name for this facet */
-		(void)allocstring(&str, ni->proto->cell->cellname, el_tempcluster);
+		/* make up a name for this cell */
+		(void)allocstring(&str, ni->proto->protoname, el_tempcluster);
 
-		(void)us_tran_makelayoutfacets(ni->proto, str, oldtech, newtech, nview);
+		(void)us_tran_makelayoutcells(ni->proto, str, oldtech, newtech, nview);
 		efree(str);
 	}
 
-	/* create the facet and fill it with parts */
-	newfacet = us_tran_linkage(newfacetname, nview, oldfacet);
-	if (newfacet == NONODEPROTO) return(NONODEPROTO);
-	if (us_tran_makelayoutparts(oldfacet, newfacet, oldtech, newtech, nview))
+	/* create the cell and fill it with parts */
+	newcell = us_tran_linkage(newcellname, nview, oldcell);
+	if (newcell == NONODEPROTO) return(NONODEPROTO);
+	if (us_tran_makelayoutparts(oldcell, newcell, oldtech, newtech, nview))
 	{
 		/* adjust for maximum Manhattan-ness */
-		us_tran_makemanhattan(newfacet);
+		us_tran_makemanhattan(newcell);
 
 		/* reset shrinkage values and constraints to defaults (is this needed? !!!) */
-		for(ai = newfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+		for(ai = newcell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		{
 			bits = us_makearcuserbits(ai->proto);
 			if ((bits&FIXED) != 0) ai->userbits |= FIXED;
@@ -546,15 +546,15 @@ NODEPROTO *us_tran_makelayoutfacets(NODEPROTO *oldfacet, CHAR *newfacetname,
 		}
 	}
 
-	return(newfacet);
+	return(newcell);
 }
 
 /*
- * routine to create a new facet in "newfacet" from the contents of an old facet
- * in "oldfacet".  The technology for the old facet is "oldtech" and the
- * technology to use for the new facet is "newtech".
+ * routine to create a new cell in "newcell" from the contents of an old cell
+ * in "oldcell".  The technology for the old cell is "oldtech" and the
+ * technology to use for the new cell is "newtech".
  */
-BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
+BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldcell, NODEPROTO *newcell,
 	TECHNOLOGY *oldtech, TECHNOLOGY *newtech, VIEW *nview)
 {
 	REGISTER NODEPROTO *newnp;
@@ -577,37 +577,37 @@ BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	newlambda = el_curlib->lambda[newtech->techindex];
 
 	/* first convert the nodes */
-	for(ni = oldfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = oldcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		ni->temp1 = 0;
-	for(ni = oldfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = oldcell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
-		/* handle sub-facets */
+		/* handle sub-cells */
 		if (ni->proto->primindex == 0)
 		{
-			for(newnp = ni->proto->cell->firstincell; newnp != NONODEPROTO; newnp = newnp->nextincell)
+			FOR_CELLGROUP(newnp, ni->proto)
 				if (newnp->cellview == nview) break;
 			if (newnp == NONODEPROTO)
 			{
-				ttyputerr(_("No equivalent facet for %s"), describenodeproto(ni->proto));
+				ttyputerr(_("No equivalent cell for %s"), describenodeproto(ni->proto));
 				continue;
 			}
-			us_tranplacenode(ni, newnp, newfacet, oldtech, newtech);
+			us_tranplacenode(ni, newnp, newcell, oldtech, newtech);
 			continue;
 		}
 
 		/* handle primitives */
-		if (ni->proto == gen_facetcenterprim) continue;
+		if (ni->proto == gen_cellcenterprim) continue;
 		newnp = us_figurenewnproto(ni, newtech);
-		us_tranplacenode(ni, newnp, newfacet, oldtech, newtech);
+		us_tranplacenode(ni, newnp, newcell, oldtech, newtech);
 	}
 
 	/*
-	 * for each arc in facet, find the ends in the new technology, and
-	 * make a new arc to connect them in the new facet
+	 * for each arc in cell, find the ends in the new technology, and
+	 * make a new arc to connect them in the new cell
 	 */
 	badarcs = 0;
 	univarcs = FALSE;
-	for(ai = oldfacet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = oldcell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		/* get the nodes and ports on the two ends of the arc */
 		end1 = (NODEINST *)ai->end[0].nodeinst->temp1;
@@ -690,10 +690,10 @@ BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 		}
 		/* create the new arc */
 		if (newarcinst(newap, newwid, newbits, end1, schempp1, x1, y1,
-			end2, schempp2, x2, y2, newfacet) == NOARCINST)
+			end2, schempp2, x2, y2, newcell) == NOARCINST)
 		{
-			ttyputmsg(_("Facet %s: can't run arc from node %s port %s at (%s,%s)"),
-				describenodeproto(newfacet), describenodeinst(end1),
+			ttyputmsg(_("Cell %s: can't run arc from node %s port %s at (%s,%s)"),
+				describenodeproto(newcell), describenodeinst(end1),
 					schempp1->protoname, latoa(x1, 0), latoa(y1, 0));
 			ttyputmsg(_("   to node %s port %s at (%s,%s)"), describenodeinst(end2),
 				schempp2->protoname, latoa(x2, 0), latoa(y2, 0));
@@ -702,12 +702,12 @@ BOOLEAN us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 
 	/* print warning if arcs were made nonmanhattan */
 	if (badarcs != 0)
-		ttyputmsg(_("WARNING: %ld %s made not-fixed-angle in facet %s"), badarcs,
-			makeplural(_("arc"), badarcs), describenodeproto(newfacet));
+		ttyputmsg(_("WARNING: %ld %s made not-fixed-angle in cell %s"), badarcs,
+			makeplural(_("arc"), badarcs), describenodeproto(newcell));
 	return(univarcs);
 }
 
-void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
+void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newcell,
 	TECHNOLOGY *oldtech, TECHNOLOGY *newtech)
 {
 	INTBIG lx, ly, hx, hy, nlx, nly, nhx, nhy, bx, by, length, width;
@@ -787,7 +787,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 	}
 
 	/* create the node */
-	newni = newnodeinst(newnp, newlx, newhx, newly, newhy, trn, ni->rotation, newfacet);
+	newni = newnodeinst(newnp, newlx, newhx, newly, newhy, trn, ni->rotation, newcell);
 	if (newni == NONODEINST) return;
 	newni->userbits |= (ni->userbits & (NEXPAND | WIPED | NSHORT));
 	ni->temp1 = (INTBIG)newni;
@@ -812,7 +812,7 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 	for(pexp = ni->firstportexpinst; pexp != NOPORTEXPINST; pexp = pexp->nextportexpinst)
 	{
 		pp = us_convport(ni, newni, pexp->proto);
-		pp2 = newportproto(newfacet, newni, pp, pexp->exportproto->protoname);
+		pp2 = newportproto(newcell, newni, pp, pexp->exportproto->protoname);
 		if (pp2 == NOPORTPROTO) return;
 		pp2->userbits = (pp2->userbits & ~STATEBITS) | (pexp->exportproto->userbits & STATEBITS);
 		TDCOPY(pp2->textdescript, pexp->exportproto->textdescript);
@@ -832,7 +832,7 @@ PORTPROTO *us_convport(NODEINST *ni, NODEINST *newni, PORTPROTO *oldpp)
 
 	if (newni->proto->primindex == 0)
 	{
-		/* facets can associate by comparing names */
+		/* cells can associate by comparing names */
 		pp = getportproto(newni->proto, oldpp->protoname);
 		if (pp != NOPORTPROTO) return(pp);
 	}
@@ -1273,7 +1273,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		base = tot;
-		(void)allocstring(&names[tot], np->primname, el_tempcluster);
+		(void)allocstring(&names[tot], np->protoname, el_tempcluster);
 
 		func = (np->userbits&NFUNCTION) >> NFUNCTIONSH;
 		(void)allocstring(&funcs[tot], nodefunctionname(func, NONODEINST), el_tempcluster);
