@@ -1705,7 +1705,7 @@ void us_diaeditsavedialogs(void)
             for(i=1, item = dia->firstitem; item != 0; item = item->next, i++)
             {
                 if (item->name == 0) continue;
-                efprintf(out, x_("#define %s_%s%*ld"), dia->name, item->name, int(maxnamelen) - estrlen(item->name) + 3, i);
+                efprintf(out, x_("#define %s_%s%*ld"), dia->name, item->name, maxnamelen - estrlen(item->name) + 3, i);
                 if (item->comment != 0) efprintf(out, x_("\t\t/* %s (%s) */"), item->comment, us_diaeditshorttypes[item->type]);
                 efprintf(out, x_("\n"));
             }
@@ -1911,7 +1911,7 @@ void us_diaeditloadui(CHAR *dianame)
             ttyputmsg(x_("Duplicate item %s"), line);
             err = TRUE;
         }
-        if (k != int(i)) changed = TRUE;
+        if (k != i) changed = TRUE;
         items[k] = item;
         
     }
