@@ -37,8 +37,8 @@
 
 static INTBIG us_stopevent = 0;
 
-/* for drawing facet name, outline or instance name (color changes) */
-GRAPHICS us_facetgra = {LAYERO, 0, SOLIDC, SOLIDC,
+/* for drawing cell name, outline or instance name (color changes) */
+GRAPHICS us_cellgra = {LAYERO, 0, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
 /* for drawing outlines (color changes) */
@@ -69,7 +69,7 @@ GRAPHICS us_gbox = {LAYERG, GRID, SOLIDC, SOLIDC,
 GRAPHICS us_egbox = {LAYERG, ALLOFF, SOLIDC, SOLIDC,
 	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
 
-/* for drawing patterned facet contents (when resolution is too small, color changes) */
+/* for drawing patterned cell contents (when resolution is too small, color changes) */
 static GRAPHICS us_graybox = {LAYERO, GRAY, PATTERNED, PATTERNED,
 					{0x0000, /*                  */
 					0x0303,  /*       XX      XX */
@@ -111,7 +111,7 @@ static GRAPHICS us_dimbox = {LAYERH, HIGHLIT, PATTERNED, PATTERNED,
 
 #define MAXGRID         75
 #define MINGRID          4	/* the minimum grid has 4 pixels spacing */
-#define TXTMAXFACETSIZE 36	/* maximum point size of facet text */
+#define TXTMAXCELLSIZE  36	/* maximum point size of cell text */
 
 /* prototypes for local routines */
 static void   us_showemptywindow(WINDOWPART*);
@@ -120,7 +120,7 @@ static void   us_combinelayers(ARCINST*, INTBIG*, INTBIG*);
 static INTBIG us_drawall(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, XARRAY, INTBIG, BOOLEAN);
 static INTBIG us_drawarcinstpeek(ARCINST*, XARRAY, INTBIG);
 static INTBIG us_drawnodeinstpeek(NODEINST*, XARRAY, INTBIG);
-static void   us_drawfacetcontents(NODEPROTO *facet, WINDOWPART *w, BOOLEAN now);
+static void   us_drawcellcontents(NODEPROTO *cell, WINDOWPART *w, BOOLEAN now);
 static int    us_sortshownports(const void *e1, const void *e2);
 
 /******************** WINDOW CONTROL ********************/
@@ -240,7 +240,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 		computewindowscale(el_curwindowpart);
 	}
 
-	/* must recompute this by hand because facet bounds don't include facet-centers or big text */
+	/* must recompute this by hand because cell bounds don't include cell-centers or big text */
 	first = 1;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
@@ -261,7 +261,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 		}
 	}
 
-	/* include all arcs in the facet */
+	/* include all arcs in the cell */
 	for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		us_getarcbounds(ai, &nlx, &nhx, &nly, &nhy);
@@ -271,7 +271,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 		*screenhy = maxi(*screenhy, nhy);
 	}
 
-	/* include all displayed facet variables */
+	/* include all displayed cell variables */
 	oldwin = setvariablewindow(el_curwindowpart);
 	for(i = 0; i < np->numvar; i++)
 	{
@@ -279,7 +279,7 @@ void us_fullview(NODEPROTO *np, INTBIG *screenlx, INTBIG *screenhx, INTBIG *scre
 		if ((var->type&VDISPLAY) == 0) continue;
 		str = describedisplayedvariable(var, -1, -1);
 
-		/* determine center of text (facet variables are offset from (0,0)) */
+		/* determine center of text (cell variables are offset from (0,0)) */
 		poly->xv[0] = poly->yv[0] = 0;
 		poly->count = 1;
 		poly->style = FILLED;
@@ -558,7 +558,7 @@ void us_squarescreen(WINDOWPART *w, WINDOWPART *formerw, BOOLEAN largescale, INT
 		if (*screenhx == *screenlx) return;
 		if (w->curnodeproto == NONODEPROTO)
 			lambda = el_curlib->lambda[el_curtech->techindex]; else
-				lambda = lambdaoffacet(w->curnodeproto);
+				lambda = lambdaofcell(w->curnodeproto);
 		design = (*screenhx - *screenlx) / lambda;
 		if (design <= 0) design = 1;
 		image = w->usehx - w->uselx;
@@ -707,7 +707,7 @@ void us_redisplay(WINDOWPART *w)
 		w->usely += DISPLAYSLIDERSIZE;
 
 		/* the corner */
-		us_drawslidercorner(w, hx+1, hx+DISPLAYSLIDERSIZE, ly-DISPLAYSLIDERSIZE, ly-1);
+		us_drawslidercorner(w, hx+1, hx+DISPLAYSLIDERSIZE, ly-DISPLAYSLIDERSIZE, ly-1, FALSE);
 
 		/* fill in the current slider positions */
 		us_drawdispwindowsliders(w);
@@ -737,7 +737,7 @@ BOOLEAN us_windowgetsexploericon(WINDOWPART *w)
 /*
  * Routine to draw a grey box in the corner where two sliders meet.
  */
-void us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy)
+void us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, BOOLEAN drawtopright)
 {
 	static POLYGON *poly = NOPOLYGON;
 	WINDOWPART ww;
@@ -757,6 +757,14 @@ void us_drawslidercorner(WINDOWPART *win, INTBIG lx, INTBIG hx, INTBIG ly, INTBI
 	poly->style = FILLEDRECT;
 	maketruerectpoly(lx, hx, ly, hy, poly);
 	us_showpoly(poly, &ww);
+
+	/* draw the top and right edge */
+	if (drawtopright)
+	{
+		us_box.col = BLACK;
+		gra_drawbox(win, lx, lx+11, ly+11, ly+11, &us_box);
+		gra_drawbox(win, lx+11, lx+11, ly, ly+11, &us_box);
+	}
 }
 
 /*
@@ -767,7 +775,7 @@ void us_drawdispwindowsliders(WINDOWPART *w)
 {
 	REGISTER INTBIG lx, hx, ly, hy, numicons;
 	REGISTER NODEPROTO *np;
-	INTBIG facetsizex, facetsizey;
+	INTBIG cellsizex, cellsizey;
 	REGISTER INTBIG screensizex, screensizey,
 		thumbsizex, thumbsizey, thumbareax, thumbareay, thumbposx, thumbposy;
 
@@ -788,35 +796,35 @@ void us_drawdispwindowsliders(WINDOWPART *w)
 	hy = w->usehy;
 	if (np != NONODEPROTO)
 	{
-		/* determine amount of the facet that is shown */
-		facetsizex = np->highx - np->lowx;
-		facetsizey = np->highy - np->lowy;
-		if (facetsizex > 0 && facetsizey >= 0)
+		/* determine amount of the cell that is shown */
+		cellsizex = np->highx - np->lowx;
+		cellsizey = np->highy - np->lowy;
+		if (cellsizex > 0 && cellsizey >= 0)
 		{
 			screensizex = w->screenhx - w->screenlx;
 			screensizey = w->screenhy - w->screenly;
 			thumbareax = (hx - lx - DISPLAYSLIDERSIZE*2-4) / 2;
 			thumbareay = (hy - ly - DISPLAYSLIDERSIZE*2-4) / 2;
-			if (facetsizex <= screensizex)
+			if (cellsizex <= screensizex)
 			{
 				thumbsizex = thumbareax;
 				thumbposx = muldiv(w->screenhx - (np->highx + np->lowx)/2, thumbareax,
 					w->screenhx-w->screenlx) + (hx - lx - thumbareax) / 2 + lx;
 			} else
 			{
-				thumbsizex = thumbareax * screensizex / facetsizex;
+				thumbsizex = thumbareax * screensizex / cellsizex;
 				if (thumbsizex < 20) thumbsizex = 20;
 				thumbposx = muldiv((w->screenhx + w->screenlx)/2 - np->lowx, thumbareax,
 					np->highx-np->lowx) + (hx - lx - thumbareax) / 2 + lx;
 			}
-			if (facetsizey <= screensizey)
+			if (cellsizey <= screensizey)
 			{
 				thumbsizey = thumbareay;
 				thumbposy = muldiv(w->screenhy - (np->highy + np->lowy)/2, thumbareay,
 					w->screenhy-w->screenly) + (hy - ly - thumbareay) / 2 + ly;
 			} else
 			{
-				thumbsizey = thumbareay * screensizey / facetsizey;
+				thumbsizey = thumbareay * screensizey / cellsizey;
 				if (thumbsizey < 20) thumbsizey = 20;
 				thumbposy = muldiv((w->screenhy + w->screenly)/2 - np->lowy, thumbareay,
 					np->highy-np->lowy) + (hy - ly - thumbareay) / 2 + ly;
@@ -1097,7 +1105,7 @@ void us_drawhorizontalsliderthumb(WINDOWPART *w, INTBIG ly, INTBIG lx, INTBIG hx
  */
 void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 {
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER VARIABLE *var;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER INTBIG i, j, lambda, alignment;
@@ -1109,8 +1117,8 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 
 	/* erase the window */
 	us_erasewindow(w);
-	facet = w->curnodeproto;
-	if (facet == NONODEPROTO)
+	cell = w->curnodeproto;
+	if (cell == NONODEPROTO)
 	{
 		us_showemptywindow(w);
 		return;
@@ -1126,19 +1134,19 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 		w->state = (w->state & ~INPLACEEDIT) | SURROUNDINPLACEEDIT;
 
 		/* draw the surround */
-		us_drawfacetcontents(w->topnodeproto, w, TRUE);
+		us_drawcellcontents(w->topnodeproto, w, TRUE);
 
-		/* dim the entire facet */
+		/* dim the entire cell */
 		(void)needstaticpolygon(&poly, 4, us_tool->cluster);
 		maketruerectpoly(w->screenlx, w->screenhx, w->screenly, w->screenhy, poly);
 		poly->desc = &us_dimbox;
 		poly->style = FILLEDRECT;
 		(*us_displayroutine)(poly, w);
 
-		/* clear the area of the facet */
-		makerectpoly(facet->lowx, facet->highx, facet->lowy, facet->highy, poly);
+		/* clear the area of the cell */
+		makerectpoly(cell->lowx, cell->highx, cell->lowy, cell->highy, poly);
 		poly->style = FILLED;
-		xformpoly(poly, w->outoffacet);
+		xformpoly(poly, w->outofcell);
 		poly->desc = &us_hbox;   us_hbox.col = 0;
 		(*us_displayroutine)(poly, w);
 
@@ -1149,23 +1157,23 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 	/* draw the frame if there is one */
 	if ((w->state&WINDOWTYPE) != DISP3DWINDOW)
 	{
-		j = framepolys(facet);
+		j = framepolys(cell);
 		if (j != 0)
 		{
 			/* get polygon */
 			(void)needstaticpolygon(&poly, 6, us_tool->cluster);
 			for(i=0; i<j; i++)
 			{
-				framepoly(i, poly, facet);
+				framepoly(i, poly, cell);
 				(*us_displayroutine)(poly, w);
 			}
 		}
 	}
 
-	us_drawfacetcontents(facet, w, now);
+	us_drawcellcontents(cell, w, now);
 
-	/* show this facet and export variables */
-	us_drawnodeprotovariables(facet, el_matid, w, FALSE);
+	/* show this cell and export variables */
+	us_drawnodeprotovariables(cell, el_matid, w, FALSE);
 
 	/* re-draw grid if on */
 	if ((w->state&(GRIDON|GRIDTOOSMALL)) == GRIDON &&
@@ -1175,7 +1183,7 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 		(void)needstaticpolygon(&poly, 6, us_tool->cluster);
 
 		/* grid spacing */
-		lambda = lambdaoffacet(facet);
+		lambda = lambdaofcell(cell);
 		poly->xv[0] = muldiv(w->gridx, lambda, WHOLE);
 		poly->yv[0] = muldiv(w->gridy, lambda, WHOLE);
 
@@ -1187,8 +1195,8 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 			poly->yv[1] = w->screenly / poly->yv[0] * poly->yv[0];
 		} else
 		{
-			grabpoint(facet, &cenx, &ceny);
-			tech = facet->tech;
+			grabpoint(cell, &cenx, &ceny);
+			tech = cell->tech;
 			if (tech == NOTECHNOLOGY) tech = el_curtech;
 			alignment = muldiv(us_alignment_ratio, el_curlib->lambda[tech->techindex], WHOLE);
 			poly->xv[1] = us_alignvalue(cenx, alignment, &dummy);
@@ -1219,9 +1227,9 @@ void us_redisplaynow(WINDOWPART *w, BOOLEAN now)
 }
 
 /*
- * Routine to draw the nodes and arcs in facet "facet".  Draw it in 1 pass if "now" is TRUE.
+ * Routine to draw the nodes and arcs in cell "cell".  Draw it in 1 pass if "now" is TRUE.
  */
-void us_drawfacetcontents(NODEPROTO *facet, WINDOWPART *w, BOOLEAN now)
+void us_drawcellcontents(NODEPROTO *cell, WINDOWPART *w, BOOLEAN now)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
@@ -1230,20 +1238,20 @@ void us_drawfacetcontents(NODEPROTO *facet, WINDOWPART *w, BOOLEAN now)
 	/* initialize hierarchy traversal */
 	begintraversehierarchy();
 
-	for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+	for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (now)
 		{
-			if (us_drawfacet(ni, LAYERA, el_matid, 3, w) < 0) break;
+			if (us_drawcell(ni, LAYERA, el_matid, 3, w) < 0) break;
 		} else
 		{
-			ret = us_drawfacet(ni, LAYERA, el_matid, 1, w);
+			ret = us_drawcell(ni, LAYERA, el_matid, 1, w);
 			if (ret < 0) break;
 			if (ret == 2) us_queueopaque(ni->geom, FALSE);
 		}
 	}
 
-	for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+	for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 	{
 		if (now)
 		{
@@ -1288,7 +1296,7 @@ void us_erasescreen(WINDOWFRAME *mw)
 }
 
 /*
- * Routine to display a message in windows with no facet
+ * Routine to display a message in windows with no cell
  */
 void us_showemptywindow(WINDOWPART *w)
 {
@@ -1300,9 +1308,9 @@ void us_showemptywindow(WINDOWPART *w)
 	if ((w->state&WINDOWTYPE) == DISP3DWINDOW) return;
 	makerectpoly(w->screenlx, w->screenhx, w->screenly, w->screenhy, poly);
 	if ((w->state&INPLACEEDIT) != 0)
-		xformpoly(poly, w->outoffacet);
+		xformpoly(poly, w->outofcell);
 	poly->style = TEXTBOX;
-	poly->string = _("No facet in this window");
+	poly->string = _("No cell in this window");
 	TDCLEAR(poly->textdescript);
 	TDSETSIZE(poly->textdescript, TXTSETPOINTS(20));
 	poly->tech = el_curtech;
@@ -1338,14 +1346,14 @@ void us_gridset(WINDOWPART *w, INTBIG state)
 	np = w->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputmsg(_("Edit a facet before manipulating the grid"));
+		ttyputmsg(_("Edit a cell before manipulating the grid"));
 		return;
 	}
 
 	np = w->curnodeproto;
 	if (np != NONODEPROTO)
 	{
-		lambda = np->cell->lib->lambda[np->tech->techindex];
+		lambda = np->lib->lambda[np->tech->techindex];
 		x0 = applyxscale(w, muldiv(w->gridx, lambda, WHOLE));
 		y0 = applyxscale(w, muldiv(w->gridy, lambda, WHOLE));
 		if (x0 <= 2 || y0 <= 2)
@@ -1375,7 +1383,7 @@ typedef struct
 /*
  * routine to identify the port locations by number in a nodeinst.  If "count" is
  * nonzero, identify "count" nodes in the list "nilist".  Otherwise identify the
- * exports of facet "np".  Draw these ports in layer "on" and use numbers instead
+ * exports of cell "np".  Draw these ports in layer "on" and use numbers instead
  * of names if "usenumbers" is true.
  */
 void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on, BOOLEAN usenumbers)
@@ -1397,7 +1405,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 
 	/* determine the window to use */
 	if (count == 0) parent = np; else parent = nilist[0]->parent;
-	if (parent == getcurfacet()) w = el_curwindowpart; else
+	if (parent == getcurcell()) w = el_curwindowpart; else
 		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 			if (parent == w->curnodeproto) break;
 	if (w == NOWINDOWPART) return;
@@ -1416,7 +1424,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 			subpp = pp->subportproto;
 			portposition(subni, subpp, &x, &y);
 			if ((w->state&INPLACEEDIT) != 0)
-				xform(x, y, &x, &y, w->outoffacet);
+				xform(x, y, &x, &y, w->outofcell);
 			if (x < w->screenlx || x > w->screenhx ||
 				y < w->screenly || y > w->screenhy) ignored++; else
 					total++;
@@ -1430,7 +1438,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 			{
 				portposition(ni, pp, &x, &y);
 				if ((w->state&INPLACEEDIT) != 0)
-					xform(x, y, &x, &y, w->outoffacet);
+					xform(x, y, &x, &y, w->outofcell);
 				if (x < w->screenlx || x > w->screenhx ||
 					y < w->screenly || y > w->screenhy) ignored++; else
 						total++;
@@ -1442,7 +1450,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 		if (ignored <= 0)
 		{
 			if (count == 0)
-				ttyputmsg(_("There are no ports on facet %s"), describenodeproto(np)); else
+				ttyputmsg(_("There are no ports on cell %s"), describenodeproto(np)); else
 					ttyputmsg(_("There are no ports on the node(s)"));
 		} else
 		{
@@ -1494,7 +1502,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 	for(i=0; i<total; i++)
 	{
 		if ((w->state&INPLACEEDIT) != 0)
-			xform(portx[i], porty[i], &portx[i], &porty[i], w->intofacet);
+			xform(portx[i], porty[i], &portx[i], &porty[i], w->intocell);
 	}
 
 	/* associate ports with display locations */
@@ -1508,7 +1516,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 			portposition(subni, subpp, &x, &y);
 			xout = x;   yout = y;
 			if ((w->state&INPLACEEDIT) != 0)
-				xform(xout, yout, &xout, &yout, w->outoffacet);
+				xform(xout, yout, &xout, &yout, w->outofcell);
 			if (xout < w->screenlx || xout > w->screenhx ||
 				yout < w->screenly || yout > w->screenhy) continue;
 
@@ -1528,7 +1536,7 @@ void us_identifyports(INTBIG count, NODEINST **nilist, NODEPROTO *np, INTBIG on,
 				portposition(ni, pp, &x, &y);
 				xout = x;   yout = y;
 				if ((w->state&INPLACEEDIT) != 0)
-					xform(xout, yout, &xout, &yout, w->outoffacet);
+					xform(xout, yout, &xout, &yout, w->outofcell);
 				if (xout < w->screenlx || xout > w->screenhx ||
 					yout < w->screenly || yout > w->screenhy) continue;
 
@@ -1649,9 +1657,9 @@ int us_sortshownports(const void *e1, const void *e2)
  * The nodeinst is drawin in window "w".  The routine returns a layers code
  * to indicate any other layers that must be drawn.  It returns negative
  * if the display has been interrupted.  It is assumed that this
- * nodeinst is in the current facet and must be transformed properly first.
+ * nodeinst is in the current cell and must be transformed properly first.
  */
-INTBIG us_drawfacet(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers, WINDOWPART *w)
+INTBIG us_drawcell(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers, WINDOWPART *w)
 {
 	XARRAY localtran, trans;
 	REGISTER INTBIG res;
@@ -1700,7 +1708,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 	REGISTER ARCINST *iar;
 	REGISTER VARIABLE *var;
 
-	/* initialize for drawing of facets */
+	/* initialize for drawing of cells */
 	us_stopevent++;
 	if ((us_stopevent%25) == 0)
 		if (stopping(STOPREASONDISPLAY)) return(-2);
@@ -1713,7 +1721,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 
 	/* get outline of nodeinst in the window */
 	if ((w->state&INPLACEEDIT) == 0) transcpy(prevtrans, cliptrans); else
-		transmult(prevtrans, w->outoffacet, cliptrans);
+		transmult(prevtrans, w->outofcell, cliptrans);
 	if (ismanhattan(cliptrans))
 	{
 		/* manhattan orientation, so only examine 2 diagonal corner points */
@@ -1791,11 +1799,11 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 		}
 	} else
 	{
-		/* draw a facet */
+		/* draw a cell */
 		if (on == 0)
 		{
-			/* facet off: undraw the facet center if it is defined */
-			poly->desc = &us_facetgra;   us_facetgra.col = ALLOFF;
+			/* cell off: undraw the cell center if it is defined */
+			poly->desc = &us_cellgra;   us_cellgra.col = ALLOFF;
 			var = getvalkey((INTBIG)ni->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center_key);
 			if (var != NOVARIABLE)
 			{
@@ -1809,7 +1817,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 				(*us_displayroutine)(poly, w);
 			}
 
-			/* facet is off, so simply blank the area */
+			/* cell is off, so simply blank the area */
 			us_getnodebounds(ni, &bx, &ux, &by, &uy);
 
 			/* extend the bounds by 1 pixel */
@@ -1829,7 +1837,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 			return(0);
 		}
 
-		/* if drawing in-place surround, do not draw the facet being edited */
+		/* if drawing in-place surround, do not draw the cell being edited */
 		if ((w->state&SURROUNDINPLACEEDIT) != 0)
 		{
 			NODEINST **nilist;
@@ -1851,28 +1859,28 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 		maketrans(ni, localtran);
 		transmult(localtran, prevtrans, subrot);
 
-		/* get facet rectangle */
+		/* get cell rectangle */
 		maketruerectpoly(ni->lowx, ni->highx, ni->lowy, ni->highy, poly);
 		poly->style = CLOSEDRECT;
 		xformpoly(poly, prevtrans);
 		getbbox(poly, &portcliplx, &portcliphx, &portcliply, &portcliphy);
 		(void)us_makescreen(&portcliplx, &portcliply, &portcliphx, &portcliphy, w);
 
-		/* if facet is not expanded, draw its outline, name and ports */
+		/* if cell is not expanded, draw its outline, name and ports */
 		if ((ni->userbits & NEXPAND) == 0)
 		{
-			/* draw the unexpanded facet */
+			/* draw the unexpanded cell */
 			if ((layers&2) != 0)
 			{
-				/* draw the facet outline as four vectors */
-				poly->desc = &us_facetgra;   us_facetgra.col = el_colfacet;
+				/* draw the cell outline as four vectors */
+				poly->desc = &us_cellgra;   us_cellgra.col = el_colcell;
 				poly->layer = -1;
 				if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
 				{
 					(*us_displayroutine)(poly, w);
 				}
 
-				/* write the facet name */
+				/* write the cell name */
 				if (TDGETPOS(ni->textdescript) == VTPOSBOXED)
 				{
 					makerectpoly(ni->lowx, ni->highx, ni->lowy, ni->highy, poly);
@@ -1885,19 +1893,19 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 				}
 				adjustdisoffset((INTBIG)ni, VNODEINST, ni->proto->tech, poly, ni->textdescript);
 				xformpoly(poly, prevtrans);
-				poly->desc = &us_facetgra;   us_facetgra.col = el_colfacettxt;
+				poly->desc = &us_cellgra;   us_cellgra.col = el_colcelltxt;
 				poly->string = describenodeproto(ni->proto);
 				size = TDGETSIZE(poly->textdescript);
 				if (TXTGETQLAMBDA(size) != 0)
 				{
 					size = truefontsize(size, w, poly->tech);
-					if (size > TXTMAXFACETSIZE) size = TXTMAXFACETSIZE;
+					if (size > TXTMAXCELLSIZE) size = TXTMAXCELLSIZE;
 					TDSETSIZE(poly->textdescript, TXTSETPOINTS(size));
 				}
 				if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
 					(*us_displayroutine)(poly, w);
 
-				/* see if there are displayable variables on the facet */
+				/* see if there are displayable variables on the cell */
 				displaytotal = tech_displayablenvars(ni, w, &tech_oneprocpolyloop);
 				for(i = 0; i < displaytotal; i++)
 				{
@@ -1907,7 +1915,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 						(*us_displayroutine)(poly, w);
 				}
 
-				/* draw the facet center if it is defined */
+				/* draw the cell center if it is defined */
 				var = getvalkey((INTBIG)ni->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center_key);
 				if (var != NOVARIABLE)
 				{
@@ -1960,18 +1968,18 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 		} else
 		{
 			/* if the resolution is too fine, just draw texture pattern */
-			if ((us_useroptions&DRAWTINYFACETS) == 0 && (w->state&WINDOWTYPE) != DISP3DWINDOW)
+			if ((us_useroptions&DRAWTINYCELLS) == 0 && (w->state&WINDOWTYPE) != DISP3DWINDOW)
 			{
-				lambda = lambdaoffacet(ni->parent);
+				lambda = lambdaofcell(ni->parent);
 				ratio = lambda * us_tinyratio / WHOLE;
 				if ((w->screenhx - w->screenlx) / ratio > w->usehx - w->uselx &&
 					(w->screenhy - w->screenly) / ratio > w->usehy - w->usely)
 				{
 					/* cannot sensibly draw the contents at this resolution: just draw a pattern */
-					poly->desc = &us_graybox;   us_graybox.col = el_colfacet;
+					poly->desc = &us_graybox;   us_graybox.col = el_colcell;
 					poly->style = FILLEDRECT;
 					(*us_displayroutine)(poly, w);
-					poly->desc = &us_facetgra;   us_facetgra.col = el_colfacet;
+					poly->desc = &us_cellgra;   us_cellgra.col = el_colcell;
 					if (poly->style == FILLEDRECT) poly->style = CLOSEDRECT; else
 						poly->style = CLOSED;
 					(*us_displayroutine)(poly, w);
@@ -1979,7 +1987,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 				}
 			}
 
-			/* write facet that is expanded */
+			/* write cell that is expanded */
 			if ((layers&2) == 0) moretodo |= 2; else
 			{
 				/* write ports that must always be displayed */
@@ -2011,7 +2019,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 
 						/* draw the export if requested */
 						if (drawport != 0)
-							us_writeprotoname(pp, LAYERA, *xptr, LAYERO, el_colfacettxt, w,
+							us_writeprotoname(pp, LAYERA, *xptr, LAYERO, el_colcelltxt, w,
 								portcliplx, portcliphx, portcliply, portcliphy, portstyle);
 
 						/* draw attributes on exported ports */
@@ -2023,11 +2031,11 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 			/* descend hierarchy to this node */
 			downhierarchy(ni, ni->proto, 0);
 
-			/* search through facet */
+			/* search through cell */
 			for(ino = np->firstnodeinst; ino != NONODEINST; ino = ino->nextnodeinst)
 			{
 				if ((ino->userbits&NVISIBLEINSIDE) != 0) continue;
-				res = us_drawfacet(ino, LAYERA, subrot, layers, w);
+				res = us_drawcell(ino, LAYERA, subrot, layers, w);
 				if (res < 0) break;
 				moretodo |= res;
 			}
@@ -2042,7 +2050,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 			/* draw text */
 			if ((layers&2) != 0)
 			{
-				/* see if there are displayable variables on the facet instance */
+				/* see if there are displayable variables on the cell instance */
 				displaytotal = tech_displayablenvars(ni, w, &tech_oneprocpolyloop);
 				for(i = 0; i < displaytotal; i++)
 				{
@@ -2052,7 +2060,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 						(*us_displayroutine)(poly, w);
 				}
 
-				/* draw facet variables on expanded facets */
+				/* draw cell variables on expanded cells */
 				us_drawnodeprotovariables(ni->proto, subrot, w, TRUE);
 			}
 		}
@@ -2068,7 +2076,7 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 				if (on == 0)
 				{
 					us_writeprotoname(pe->exportproto, on, prevtrans, LAYERO,
-						el_colfacettxt&on, w, 0, 0, 0, 0,
+						el_colcelltxt&on, w, 0, 0, 0, 0,
 							(us_useroptions&EXPORTLABELS)>>EXPORTLABELSSH);
 					us_drawportprotovariables(pe->exportproto, on, prevtrans, w, FALSE);
 				} else
@@ -2082,9 +2090,9 @@ INTBIG us_drawnodeinst(NODEINST *ni, INTBIG on, XARRAY prevtrans, INTBIG layers,
 }
 
 /*
- * Routine to draw all attributes on facet "np".  The facet is in window "w"
+ * Routine to draw all attributes on cell "np".  The cell is in window "w"
  * and is transformed by "trans".  If "ignoreinherit" is true, ignore inheritable
- * attributes (because this is a subfacet, and the inherited instance attributes are to be
+ * attributes (because this is a subcell, and the inherited instance attributes are to be
  * shown).
  */
 void us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w, BOOLEAN ignoreinherit)
@@ -2096,10 +2104,10 @@ void us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w, BOOLE
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, us_tool->cluster);
 
-	displaytotal = tech_displayablefacetvars(np, w, &tech_oneprocpolyloop);
+	displaytotal = tech_displayablecellvars(np, w, &tech_oneprocpolyloop);
 	for(i = 0; i < displaytotal; i++)
 	{
-		var = tech_filldisplayablefacetvar(np, poly, w, 0, &tech_oneprocpolyloop);
+		var = tech_filldisplayablecellvar(np, poly, w, 0, &tech_oneprocpolyloop);
 		if (ignoreinherit && TDGETINHERIT(var->textdescript) != 0) continue;
 		xformpoly(poly, trans);
 		if ((w->state&WINDOWTYPE) == DISP3DWINDOW) us_3dshowpoly(poly, w); else
@@ -2110,7 +2118,7 @@ void us_drawnodeprotovariables(NODEPROTO *np, XARRAY trans, WINDOWPART *w, BOOLE
 /*
  * Routine to draw all attributes on port "pp" with color "on".  The port is in window "w"
  * and is transformed by "trans".  If "ignoreinherit" is true, ignore inheritable
- * attributes (because this is a subfacet, and the inherited instance attributes are to be
+ * attributes (because this is a subcell, and the inherited instance attributes are to be
  * shown).
  */
 void us_drawportprotovariables(PORTPROTO *pp, INTBIG on, XARRAY trans, WINDOWPART *w, BOOLEAN ignoreinherit)
@@ -2287,7 +2295,7 @@ void us_writeprotoname(PORTPROTO *pp, INTBIG on, XARRAY prevtrans, INTBIG bits,
 	REGISTER INTBIG sx, sy, lambda;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER NODEINST *ni;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	REGISTER PORTPROTO *rpp;
 	REGISTER TECHNOLOGY *tech;
 
@@ -2298,9 +2306,9 @@ void us_writeprotoname(PORTPROTO *pp, INTBIG on, XARRAY prevtrans, INTBIG bits,
 	(void)needstaticpolygon(&poly, 4, us_tool->cluster);
 
 	/* get technology and lambda */
-	facet = pp->subnodeinst->parent;
-	tech = facet->tech;
-	lambda = facet->cell->lib->lambda[tech->techindex];
+	cell = pp->subnodeinst->parent;
+	tech = cell->tech;
+	lambda = cell->lib->lambda[tech->techindex];
 
 	/* account for port offset */
 	t1 = (XARRAY *)tempt1;   t2 = (XARRAY *)tempt2;
@@ -2380,7 +2388,7 @@ void us_writeprotoname(PORTPROTO *pp, INTBIG on, XARRAY prevtrans, INTBIG bits,
 		/* acount for node rotation, which port position */
 		poly->style = rotatelabel(poly->style, TDGETROTATION(poly->textdescript), prevtrans);
 
-		/* clip the port text to the facet bounds, if requested */
+		/* clip the port text to the cell bounds, if requested */
 		if (portcliplx != portcliphx)
 		{
 			sx = applyxscale(w, px-w->screenlx) + w->uselx;
@@ -2512,7 +2520,7 @@ void us_dopeek(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, NODEPROTO *np, WINDOW
 
 /*
  * routine to draw everything between "lx" and "hx" in X and between "ly"
- * and "hy" in Y of facet "np", given a transformation matrix of "trans".
+ * and "hy" in Y of cell "np", given a transformation matrix of "trans".
  * If "layers" is 1 then only the transparent layers will be drawn and if
  * "layers" is 2 then only the opaque layers will be drawn.  Drawing is done
  * in window "w".  The routine returns the other layers that need to be drawn
@@ -2581,11 +2589,11 @@ INTBIG us_drawall(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, NODEPROTO *np, XAR
 					tbound = (XARRAY *)bound;
 				}
 
-				/* compute bounding area inside of sub-facet */
+				/* compute bounding area inside of sub-cell */
 				newlx = lx;   newly = ly;   newhx = hx;   newhy = hy;
 				xformbox(&newlx, &newhx, &newly, &newhy, *tbound);
 
-				/* compute new matrix for sub-facet display */
+				/* compute new matrix for sub-cell display */
 				localtrans[2][0] = -localtrans[2][0];
 				localtrans[2][1] = -localtrans[2][1];
 				transmult(localtrans, *tthis, subrot);
