@@ -344,7 +344,7 @@ CHAR *us_editemacsgetline(WINDOWPART *win, INTBIG lindex)
 }
 
 /*
- * routine to add line "str" to the text facet to become line "lindex"
+ * routine to add line "str" to the text cell to become line "lindex"
  */
 void us_editemacsaddline(WINDOWPART *win, INTBIG lindex, CHAR *str)
 {
@@ -1786,7 +1786,7 @@ void us_editemacssetheader(WINDOWPART *win, CHAR *header)
 		{
 			if (graphicshas(CANUSEFRAMES))
 				us_editemacstext(win, _("EMACS editor: close the window when done"), 0, -1); else
-					us_editemacstext(win, _("EMACS editor: text-only facet"), 0, -1);
+					us_editemacstext(win, _("EMACS editor: text-only cell"), 0, -1);
 		}
 	}
 	if (save != 0) header[e->screenchars] = (CHAR)save;
