@@ -313,7 +313,7 @@ CHAR *us_editpacgetline(WINDOWPART *win, INTBIG lindex)
 }
 
 /*
- * routine to add line "str" to the text facet to become line "lindex"
+ * routine to add line "str" to the text cell to become line "lindex"
  */
 void us_editpacaddline(WINDOWPART *win, INTBIG lindex, CHAR *str)
 {
@@ -1787,7 +1787,7 @@ void us_editpacdrawsliders(WINDOWPART *win)
 
 		/* the corner */
 		us_drawslidercorner(win, win->usehx-DISPLAYSLIDERSIZE+1, win->usehx, win->usely,
-			win->usely+DISPLAYSLIDERSIZE-1);
+			win->usely+DISPLAYSLIDERSIZE-1, FALSE);
 		us_editpacdrawvscroll(win);
 	}
 }
@@ -1925,7 +1925,7 @@ void us_editpacsetheader(WINDOWPART *win, CHAR *header)
 		{
 			if (graphicshas(CANUSEFRAMES))
 				us_editpactext(win, _("Point-and-Click editor: close the window when done"), 0, -1); else
-					us_editpactext(win, _("Point-and-Click editor: text-only facet"), 0, -1);
+					us_editpactext(win, _("Point-and-Click editor: text-only cell"), 0, -1);
 		}
 	}
 	e->horizfactor = formerhf;
