@@ -49,7 +49,7 @@ typedef struct Inodedescr
 
 static NODEPROTO *us_graphmainview(NODEPROTO *np);
 
-void us_graphfacets(NODEPROTO *top)
+void us_graphcells(NODEPROTO *top)
 {
 	REGISTER NODEPROTO *np, *sub, *graphnp, *truenp, *truesubnp;
 	REGISTER NODEINST *ni, *nibot, *toppin;
@@ -60,24 +60,25 @@ void us_graphfacets(NODEPROTO *top)
 	REGISTER PORTPROTO *pinpp;
 	REGISTER VARIABLE *var;
 	REGISTER NODEDESCR *nd, *ndsub;
+	CHAR *newname;
 	float spread;
 	REGISTER void *infstr;
 
 	pinpp = gen_invispinprim->firstportproto;
 
-	/* create the graph facet */
-	graphnp = newnodeproto(x_("FacetStructure"), el_curlib);
+	/* create the graph cell */
+	graphnp = newnodeproto(x_("CellStructure"), el_curlib);
 	if (graphnp == NONODEPROTO) return;
 	if (graphnp->prevversion != NONODEPROTO)
-		ttyputverbose(M_("Creating new version of facet: FacetStructure")); else
-			ttyputverbose(M_("Creating facet: FacetStructure"));
+		ttyputverbose(M_("Creating new version of cell: CellStructure")); else
+			ttyputverbose(M_("Creating cell: CellStructure"));
 
-	/* clear flags on all of the facets */
+	/* clear flags on all of the cells */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = -1;
 
-	/* find all top-level facets */
+	/* find all top-level cells */
 	if (top != NONODEPROTO) top->temp1 = 0; else
 	{
 		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -86,7 +87,7 @@ void us_graphfacets(NODEPROTO *top)
 		}
 	}
 
-	/* now place all facets at their proper depth */
+	/* now place all cells at their proper depth */
 	maxdepth = 0;
 	more = 1;
 	while (more != 0)
@@ -102,7 +103,7 @@ void us_graphfacets(NODEPROTO *top)
 				if (sub->primindex != 0) continue;
 
 				/* ignore recursive references (showing icon in contents) */
-				if (sub->cell == np->cell) continue;
+				if (isiconof(sub, np)) continue;
 				if (sub->temp1 <= np->temp1)
 				{
 					sub->temp1 = np->temp1 + 1;
@@ -120,7 +121,7 @@ void us_graphfacets(NODEPROTO *top)
 			}
 		}
 
-		/* add in any facets referenced from other libraries */
+		/* add in any cells referenced from other libraries */
 		if (more == 0 && top == NONODEPROTO)
 		{
 			for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -132,7 +133,7 @@ void us_graphfacets(NODEPROTO *top)
 		}
 	}
 
-	/* now assign X coordinates to each facet */
+	/* now assign X coordinates to each cell */
 	maxdepth++;
 	maxwidth = 0;
 	xval = emalloc((SIZEOFINTBIG * maxdepth), el_tempcluster);
@@ -143,10 +144,10 @@ void us_graphfacets(NODEPROTO *top)
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
-		/* ignore icon facets from the graph (merge with contents) */
+		/* ignore icon cells from the graph (merge with contents) */
 		if (np->temp1 == -1) continue;
 
-		/* ignore associated facets for now */
+		/* ignore associated cells for now */
 		truenp = us_graphmainview(np);
 		if (truenp != NONODEPROTO &&
 			(np->firstnodeinst == NONODEINST || np->cellview == el_iconview ||
@@ -197,7 +198,7 @@ void us_graphfacets(NODEPROTO *top)
 		nd->x = x;   nd->y = y;
 	}
 
-	/* make unattached facets sit with their contents view */
+	/* make unattached cells sit with their contents view */
 	if (top == NONODEPROTO)
 	{
 		for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -228,13 +229,14 @@ void us_graphfacets(NODEPROTO *top)
 	infstr = initinfstr();
 	if (top != NONODEPROTO)
 	{
-		formatinfstr(infstr, _("Structure below facet %s"), describenodeproto(top));
+		formatinfstr(infstr, _("Structure below cell %s"), describenodeproto(top));
 	} else
 	{
 		formatinfstr(infstr, _("Structure of library %s"), el_curlib->libname);
 	}
-	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(infstr),
-		VSTRING|VDISPLAY);
+	allocstring(&newname, returninfstr(infstr), el_tempcluster);
+	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)newname, VSTRING|VDISPLAY);
+	efree(newname);
 	if (var != NOVARIABLE)
 		TDSETSIZE(var->textdescript, TXTSETQLAMBDA(24));
 
@@ -252,7 +254,7 @@ void us_graphfacets(NODEPROTO *top)
 		endobjectchange((INTBIG)ni, VNODEINST);
 		nd->pin = ni;
 
-		/* write the facet name in the node */
+		/* write the cell name in the node */
 		var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)describenodeproto(np),
 			VSTRING|VDISPLAY);
 		if (var != NOVARIABLE)
@@ -287,7 +289,7 @@ void us_graphfacets(NODEPROTO *top)
 	{
 		if (np == graphnp) continue;
 
-		/* always use the contents facet, not the icon */
+		/* always use the contents cell, not the icon */
 		truenp = contentsview(np);
 		if (truenp == NONODEPROTO) truenp = np;
 		if (truenp->temp1 == -1) continue;
@@ -301,7 +303,7 @@ void us_graphfacets(NODEPROTO *top)
 			if (sub->primindex != 0) continue;
 
 			/* ignore recursive references (showing icon in contents) */
-			if (sub->cell == truenp->cell) continue;
+			if (isiconof(sub, truenp)) continue;
 
 			truesubnp = contentsview(sub);
 			if (truesubnp == NONODEPROTO) truesubnp = sub;
@@ -309,7 +311,7 @@ void us_graphfacets(NODEPROTO *top)
 			if (truesubnp->temp2 == clock) continue;
 			truesubnp->temp2 = clock;
 
-			/* draw a line from facet "truenp" to facet "truesubnp" */
+			/* draw a line from cell "truenp" to cell "truesubnp" */
 			x = nd->x;
 			y = nd->y;
 
@@ -343,9 +345,9 @@ void us_graphfacets(NODEPROTO *top)
 }
 
 /*
- * routine to find the main facet that "np" is associated with in the graph.  This code is
- * essentially the same as "contentsfacet()" except that any original type is allowed.
- * Returns NONODEPROTO if the facet is not associated.
+ * routine to find the main cell that "np" is associated with in the graph.  This code is
+ * essentially the same as "contentscell()" except that any original type is allowed.
+ * Returns NONODEPROTO if the cell is not associated.
  */
 NODEPROTO *us_graphmainview(NODEPROTO *np)
 {
@@ -356,18 +358,18 @@ NODEPROTO *us_graphmainview(NODEPROTO *np)
 	if (np->primindex != 0) return(NONODEPROTO);
 
 	/* first check to see if there is a schematics link */
-	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
+	FOR_CELLGROUP(rnp, np)
 	{
 		if (rnp->cellview == el_schematicview) return(rnp);
 		if ((rnp->cellview->viewstate&MULTIPAGEVIEW) != 0) return(rnp);
 	}
 
 	/* now check to see if there is any layout link */
-	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
+	FOR_CELLGROUP(rnp, np)
 		if (rnp->cellview == el_layoutview) return(rnp);
 
 	/* finally check to see if there is any "unknown" link */
-	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
+	FOR_CELLGROUP(rnp, np)
 		if (rnp->cellview == el_unknownview) return(rnp);
 
 	/* no contents found */
@@ -419,12 +421,12 @@ void us_illustratecommandset(void)
 	REGISTER ARCINST *ai;
 	REGISTER VARIABLE *var;
 
-	/* create the graph facet */
+	/* create the graph cell */
 	graphnp = newnodeproto(x_("CommandStructure"), el_curlib);
 	if (graphnp == NONODEPROTO) return;
 	if (graphnp->prevversion != NONODEPROTO)
-		ttyputmsg(_("Creating new version of facet: CommandStructure")); else
-			ttyputmsg(_("Creating facet: CommandStructure"));
+		ttyputmsg(_("Creating new version of cell: CommandStructure")); else
+			ttyputmsg(_("Creating cell: CommandStructure"));
 
 	us_maxillustratedepth = 0;
 	us_maxcommandentries = 0;
@@ -513,9 +515,9 @@ void us_illustratecommandset(void)
 		efree((CHAR *)ci);
 	}
 
-	/* have the facet displayed on the screen */
+	/* have the cell displayed on the screen */
 	newmessage[0] = x_("CommandStructure");
-	us_editfacet(1, newmessage);
+	us_editcell(1, newmessage);
 }
 
 COMILL *us_illustratecommand(CHAR *name, INTBIG depth, COMILL *thisci)
@@ -560,23 +562,22 @@ COMILL *us_illustratecommand(CHAR *name, INTBIG depth, COMILL *thisci)
 		if (cc->toplist == topoftechs) arg = x_("TECH"); else
 		if (cc->toplist == topoflibs) arg = x_("LIB"); else
 		if (cc->toplist == topoftools) arg = x_("TOOL"); else
-		if (cc->toplist == topofcells) arg = x_("CELL"); else
 		if (cc->toplist == topofviews) arg = x_("VIEW"); else
 		if (cc->toplist == topofnets) arg = x_("NET"); else
 		if (cc->toplist == topofarcs) arg = x_("ARC"); else
-		if (cc->toplist == topoffacets) arg = x_("FACET"); else
+		if (cc->toplist == topofcells) arg = x_("CELL"); else
 		if (cc->toplist == us_topofcommands) arg = x_("COM"); else
 		if (cc->toplist == us_topofmacros) arg = x_("MACRO"); else
 		if (cc->toplist == us_topofpopupmenu) arg = x_("POPUP"); else
 		if (cc->toplist == us_topofports) arg = x_("PORT"); else
-		if (cc->toplist == us_topofcports) arg = x_("FACETPORT"); else
+		if (cc->toplist == us_topofcports) arg = x_("CELLPORT"); else
 		if (cc->toplist == us_topofexpports) arg = x_("EXPORT"); else
 		if (cc->toplist == us_topofwindows) arg = x_("WINDOWPART"); else
 		if (cc->toplist == us_topoflayers) arg = x_("LAYER"); else
 		if (cc->toplist == us_topofhighlight) arg = x_("HIGH"); else
 		if (cc->toplist == us_topofarcnodes) arg = x_("ARC/NODE"); else
 		if (cc->toplist == us_topofnodes) arg = x_("NODE"); else
-		if (cc->toplist == us_topofcellfacets) arg = x_("FACET/CELL"); else
+		if (cc->toplist == us_topofcells) arg = x_("CELL"); else
 		if (cc->toplist == us_topofprims) arg = x_("PRIM"); else
 		if (cc->toplist == us_topofconstraints) arg = x_("CONSTR"); else
 		if (cc->toplist == us_topofmbuttons) arg = x_("BUTTON"); else
