@@ -155,7 +155,8 @@ void us_addhighlight(HIGHLIGHT *thishigh)
 
 #if SIMTOOL
 		/* if current window is simulating, show equivalent elsewhere */
-		if (el_curwindowpart != NOWINDOWPART && (el_curwindowpart->state&WINDOWSIMMODE) != 0)
+		if (el_curwindowpart != NOWINDOWPART && (el_curwindowpart->state&WINDOWSIMMODE) != 0 &&
+			(thishigh->status&HIGHTYPE) == HIGHFROM)
 		{
 			onelist[0] = x_("show-equivalent");
 			telltool(net_tool, 1, onelist);
@@ -173,7 +174,7 @@ void us_addhighlight(HIGHLIGHT *thishigh)
 	{
 		if (us_makehighlight(((CHAR **)var->addr)[i], &oldhigh)) continue;
 		if ((oldhigh.status&HIGHTYPE) != (thishigh->status&HIGHTYPE)) continue;
-		if (oldhigh.facet != thishigh->facet) continue;
+		if (oldhigh.cell != thishigh->cell) continue;
 		if ((oldhigh.status&HIGHTYPE) == HIGHLINE || (oldhigh.status&HIGHTYPE) == HIGHBBOX)
 		{
 			if (oldhigh.stalx != thishigh->stalx || oldhigh.stahx != thishigh->stahx ||
@@ -255,7 +256,7 @@ void us_delhighlight(HIGHLIGHT *thishigh)
 	{
 		if (us_makehighlight(((CHAR **)var->addr)[thish], &oldhigh)) continue;
 		if ((oldhigh.status&HIGHTYPE) != (thishigh->status&HIGHTYPE)) continue;
-		if (oldhigh.facet != thishigh->facet) continue;
+		if (oldhigh.cell != thishigh->cell) continue;
 		if ((oldhigh.status&HIGHTYPE) == HIGHLINE || (oldhigh.status&HIGHTYPE) == HIGHBBOX)
 		{
 			if (oldhigh.stalx != thishigh->stalx || oldhigh.stahx != thishigh->stahx ||
@@ -361,7 +362,7 @@ void us_setfind(HIGHLIGHT *newhigh, INTBIG findpoint, INTBIG extrainfo, INTBIG f
 }
 
 /*
- * Routine to select the area (slx <= X <= shx, sly <= Y <= shy) in facet "np".
+ * Routine to select the area (slx <= X <= shx, sly <= Y <= shy) in cell "np".
  * If "special" is nonzero, select "hard-to-select" items.
  * If "selport" is nonzero, select ports.
  * If "nobbox" is nonzero, do not show bounding box.
@@ -389,18 +390,18 @@ INTBIG us_selectarea(NODEPROTO *np, INTBIG slx, INTBIG shx, INTBIG sly, INTBIG s
 	clearstrings(us_selectareastringarray);
 
 	/* build a list of objects to highlight */
-	newhigh.facet = np;
+	newhigh.cell = np;
 	newhigh.fromport = NOPORTPROTO;
 	newhigh.fromvar = NOVARIABLE;
 	newhigh.fromvarnoeval = NOVARIABLE;
 	newhigh.frompoint = 0;
 
 	newhightext.status = HIGHTEXT;
-	newhightext.facet = np;
+	newhightext.cell = np;
 	newhightext.fromvarnoeval = NOVARIABLE;
 	newhightext.frompoint = 0;
 
-	if ((us_useroptions&HIDETXTFACET) == 0)
+	if ((us_useroptions&HIDETXTCELL) == 0)
 	{
 		for(i=0; i<np->numvar; i++)
 		{
@@ -490,7 +491,7 @@ INTBIG us_selectarea(NODEPROTO *np, INTBIG slx, INTBIG shx, INTBIG sly, INTBIG s
 			}
 		}
 	}
-	slop = FARTEXTLIMIT * lambdaoffacet(np);
+	slop = FARTEXTLIMIT * lambdaofcell(np);
 	search = initsearch(slx-slop, shx+slop, sly-slop, shy+slop, np);
 	while ((geom = nextobject(search)) != NOGEOM)
 	{
@@ -498,7 +499,7 @@ INTBIG us_selectarea(NODEPROTO *np, INTBIG slx, INTBIG shx, INTBIG sly, INTBIG s
 		{
 			ni = geom->entryaddr.ni;
 
-			/* don't find facets if not requested */
+			/* don't find cells if not requested */
 			if (special == 0 && (us_useroptions&NOINSTANCESELECT) != 0 &&
 				ni->proto->primindex == 0) continue;
 
@@ -889,7 +890,7 @@ GEOM **us_gethighlighted(INTBIG type, INTBIG *textcount, CHAR ***textinfo)
 		{
 			lx = high.stalx;   hx = high.stahx;
 			ly = high.staly;   hy = high.stahy;
-			search = initsearch(lx, hx, ly, hy, high.facet);
+			search = initsearch(lx, hx, ly, hy, high.cell);
 			while ((geom = nextobject(search)) != NOGEOM)
 			{
 				if (!us_geommatchestype(geom, type)) continue;
@@ -936,7 +937,7 @@ GEOM **us_gethighlighted(INTBIG type, INTBIG *textcount, CHAR ***textinfo)
 		{
 			lx = high.stalx;   hx = high.stahx;
 			ly = high.staly;   hy = high.stahy;
-			search = initsearch(lx, hx, ly, hy, high.facet);
+			search = initsearch(lx, hx, ly, hy, high.cell);
 			for(;;)
 			{
 				geom = nextobject(search);
@@ -1146,7 +1147,7 @@ INTBIG *us_getallhighlighted(void)
 		if ((high.status&HIGHTYPE) == HIGHFROM) total++;
 		if ((high.status&HIGHTYPE) == HIGHBBOX)
 		{
-			search = initsearch(high.stalx, high.stahx, high.staly, high.stahy, high.facet);
+			search = initsearch(high.stalx, high.stahx, high.staly, high.stahy, high.cell);
 			while ((geom = nextobject(search)) != NOGEOM) total++;
 		}
 
@@ -1196,7 +1197,7 @@ INTBIG *us_getallhighlighted(void)
 		{
 			lx = high.stalx;   hx = high.stahx;
 			ly = high.staly;   hy = high.stahy;
-			search = initsearch(lx, hx, ly, hy, high.facet);
+			search = initsearch(lx, hx, ly, hy, high.cell);
 			for(;;)
 			{
 				geom = nextobject(search);
@@ -1288,7 +1289,7 @@ INTBIG *us_getallhighlighted(void)
  * routine to get the boundary of an area delimited by the highlight.
  * The bounds are put in the reference variables "lx", "hx", "ly", and "hy".
  * If there is no highlighted area, the routine returns with NONODEPROTO
- * Otherwise the routine returns the facet that contains the area.
+ * Otherwise the routine returns the cell that contains the area.
  */
 NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 {
@@ -1299,7 +1300,7 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 	INTBIG tlx, thx, tly, thy, xc, yc;
 	XARRAY trans;
 	static POLYGON *poly = NOPOLYGON;
-	REGISTER NODEPROTO *thisfacet;
+	REGISTER NODEPROTO *thiscell;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER VARIABLE *var;
 
@@ -1309,7 +1310,7 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 	var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightedkey);
 	if (var == NOVARIABLE) return(NONODEPROTO);
 
-	thisfacet = getcurfacet();
+	thiscell = getcurcell();
 	good = bad = 0;
 	(void)us_makehighlight(((CHAR **)var->addr)[0], &high);
 	len = getlength(var);
@@ -1317,8 +1318,8 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 	for(i=0; i<len; i++)
 	{
 		(void)us_makehighlight(((CHAR **)var->addr)[i], &high);
-		if (thisfacet == NONODEPROTO) thisfacet = high.facet;
-		if (high.facet == thisfacet) good++; else
+		if (thiscell == NONODEPROTO) thiscell = high.cell;
+		if (high.cell == thiscell) good++; else
 		{
 			bad++;
 			continue;
@@ -1345,7 +1346,7 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 					if (ni != NONODEINST) tech = ni->proto->tech; else
 					{
 						if (high.fromgeom != NOGEOM) tech = high.fromgeom->entryaddr.ai->proto->tech; else
-							tech = high.facet->tech;
+							tech = high.cell->tech;
 					}
 					us_maketextpoly(describevariable(high.fromvar, -1, -1), el_curwindowpart,
 						(high.fromgeom->lowx + high.fromgeom->highx) / 2,
@@ -1399,10 +1400,10 @@ NODEPROTO *us_getareabounds(INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 	}
 	if (good == 0 && bad != 0)
 	{
-		us_abortcommand(_("Highlighted areas must be in the current facet"));
+		us_abortcommand(_("Highlighted areas must be in the current cell"));
 		return(NONODEPROTO);
 	}
-	return(thisfacet);
+	return(thiscell);
 }
 
 /*
@@ -1471,7 +1472,7 @@ void us_moveselectedtext(INTBIG numtexts, CHAR **textlist, GEOM **list, INTBIG o
 			}
 		}
 		if (type == VNODEPROTO && high.fromvar != NOVARIABLE)
-			us_undrawfacetvariable(high.fromvar, (NODEPROTO *)addr);
+			us_undrawcellvariable(high.fromvar, (NODEPROTO *)addr);
 
 		/* set the new descriptor on the text */
 		lambda = el_curlib->lambda[us_hightech(&high)->techindex];
@@ -1484,7 +1485,7 @@ void us_moveselectedtext(INTBIG numtexts, CHAR **textlist, GEOM **list, INTBIG o
 
 		/* redisplay the text */
 		if (type == VNODEPROTO && high.fromvar != NOVARIABLE)
-			us_drawfacetvariable(high.fromvar, (NODEPROTO *)addr);
+			us_drawcellvariable(high.fromvar, (NODEPROTO *)addr);
 		if (type == VPORTPROTO)
 		{
 			endobjectchange((INTBIG)ni, VNODEINST);
@@ -1566,7 +1567,7 @@ void us_sethighlight(HIGHLIGHT *high, INTBIG on)
 		{
 			if ((w->state&WINDOWTYPE) != DISPWINDOW &&
 				(w->state&WINDOWTYPE) != DISP3DWINDOW) continue;
-			if (w->curnodeproto != high->facet) continue;
+			if (w->curnodeproto != high->cell) continue;
 			us_showpoly(poly, w);
 		}
 		return;
@@ -1585,7 +1586,7 @@ void us_sethighlight(HIGHLIGHT *high, INTBIG on)
 		{
 			if ((w->state&WINDOWTYPE) != DISPWINDOW &&
 				(w->state&WINDOWTYPE) != DISP3DWINDOW) continue;
-			if (w->curnodeproto != high->facet) continue;
+			if (w->curnodeproto != high->cell) continue;
 			us_showpoly(poly, w);
 		}
 		return;
@@ -1607,7 +1608,7 @@ void us_sethighlight(HIGHLIGHT *high, INTBIG on)
 		{
 			if ((w->state&WINDOWTYPE) != DISPWINDOW &&
 				(w->state&WINDOWTYPE) != DISP3DWINDOW) continue;
-			if (w->curnodeproto != high->facet) continue;
+			if (w->curnodeproto != high->cell) continue;
 
 			us_gethightextsize(high, &xw, &yw, w);
 
@@ -1641,7 +1642,7 @@ void us_sethighlight(HIGHLIGHT *high, INTBIG on)
 		{
 			if ((w->state&WINDOWTYPE) != DISPWINDOW &&
 				(w->state&WINDOWTYPE) != DISP3DWINDOW) continue;
-			if (w->curnodeproto != high->facet) continue;
+			if (w->curnodeproto != high->cell) continue;
 			us_showpoly(poly, w);
 		}
 	}
@@ -1908,7 +1909,7 @@ void us_highlighteverywhere(GEOM *look, PORTPROTO *port, INTBIG point, BOOLEAN v
 
 /*
  * Routine to draw extra verbose highlighting on object "look" (if it is a node, then
- * "pp" is the port on that node).  The color is "color", the parent facet is "par", and
+ * "pp" is the port on that node).  The color is "color", the parent cell is "par", and
  * if it is an arc, the polygon for that arc is "arcpoly".
  */
 void us_highlightverbose(GEOM *look, PORTPROTO *pp, INTBIG color, NODEPROTO *par, POLYGON *arcpoly)
@@ -2266,17 +2267,17 @@ BOOLEAN us_makehighlight(CHAR *str, HIGHLIGHT *high)
 
 	pt = str;
 
-	/* look for the "FACET=" keyword */
+	/* look for the "CELL=" keyword */
 	keyword = getkeyword(&pt, x_("="));
 	if (keyword == NOSTRING) return(TRUE);
-	if (namesame(keyword, x_("FACET")) != 0) return(TRUE);
+	if (namesame(keyword, x_("CELL")) != 0) return(TRUE);
 	if (tonextchar(&pt) != '=') return(TRUE);
 
-	/* get the facet name */
+	/* get the cell name */
 	keyword = getkeyword(&pt, x_(" \t"));
 	if (keyword == NOSTRING) return(TRUE);
-	high->facet = getnodeproto(keyword);
-	if (high->facet == NONODEPROTO) return(TRUE);
+	high->cell = getnodeproto(keyword);
+	if (high->cell == NONODEPROTO) return(TRUE);
 
 	/* get the type of highlight */
 	keyword = getkeyword(&pt, x_("="));
@@ -2352,7 +2353,7 @@ BOOLEAN us_makehighlight(CHAR *str, HIGHLIGHT *high)
 				}
 			} else
 			{
-				addr = (INTBIG)high->facet;
+				addr = (INTBIG)high->cell;
 				type = VNODEPROTO;
 			}
 			high->fromvarnoeval = getvalnoeval(addr, type, -1, keyword);
@@ -2404,7 +2405,7 @@ CHAR *us_makehighlightstring(HIGHLIGHT *high)
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
-	formatinfstr(infstr, x_("FACET=%s"), describenodeproto(high->facet));
+	formatinfstr(infstr, x_("CELL=%s"), describenodeproto(high->cell));
 	switch (high->status&HIGHTYPE)
 	{
 		case HIGHFROM:
@@ -2449,7 +2450,7 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTBIG *style
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 	XARRAY trans;
 	INTBIG newxc, newyc;
 	REGISTER INTSML saverot, savetrn;
@@ -2472,7 +2473,7 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTBIG *style
 			portposition(ni, high->fromport->subportproto,
 				&poly->xv[0], &poly->yv[0]);
 			ni->rotation = saverot;   ni->transpose = savetrn;
-			adjustdisoffset((INTBIG)high->fromport, VPORTPROTO, high->facet->tech,
+			adjustdisoffset((INTBIG)high->fromport, VPORTPROTO, high->cell->tech,
 				poly, descript);
 			makerot(high->fromport->subnodeinst, trans);
 			xformpoly(poly, trans);
@@ -2495,9 +2496,9 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTBIG *style
 			}
 		} else
 		{
-			/* facet variables are offset from (0,0) */
+			/* cell variables are offset from (0,0) */
 			poly->xv[0] = poly->yv[0] = 0;
-			adjustdisoffset((INTBIG)high->facet, VNODEPROTO, high->facet->tech,
+			adjustdisoffset((INTBIG)high->cell, VNODEPROTO, high->cell->tech,
 				poly, descript);
 		}
 		*style = poly->style;
@@ -2508,8 +2509,8 @@ void us_gethightextcenter(HIGHLIGHT *high, INTBIG *xc, INTBIG *yc, INTBIG *style
 		portposition(high->fromport->subnodeinst, high->fromport->subportproto,
 			&poly->xv[0], &poly->yv[0]);
 		makeangle(ni->rotation, ni->transpose, trans);
-		facet = ni->parent;
-		lambda = facet->cell->lib->lambda[facet->tech->techindex];
+		cell = ni->parent;
+		lambda = cell->lib->lambda[cell->tech->techindex];
 		newxc = TDGETXOFF(descript);
 		newxc = newxc * lambda / 4;
 		newyc = TDGETYOFF(descript);
@@ -2645,7 +2646,7 @@ void us_gethighaddrtype(HIGHLIGHT *high, INTBIG *addr, INTBIG *type)
 			}
 			if (high->fromgeom == NOGEOM)
 			{
-				*addr = (INTBIG)high->facet;
+				*addr = (INTBIG)high->cell;
 				*type = VNODEPROTO;
 				return;
 			}
@@ -2707,25 +2708,25 @@ BOOLEAN us_nodemoveswithtext(HIGHLIGHT *high)
  */
 TECHNOLOGY *us_hightech(HIGHLIGHT *high)
 {
-	REGISTER NODEPROTO *facet;
+	REGISTER NODEPROTO *cell;
 
-	facet = us_highfacet(high);
-	if (facet == NONODEPROTO) return(el_curtech);
-	if (facet->tech == NOTECHNOLOGY)
-		facet->tech = whattech(facet);
-	return(facet->tech);
+	cell = us_highcell(high);
+	if (cell == NONODEPROTO) return(el_curtech);
+	if (cell->tech == NOTECHNOLOGY)
+		cell->tech = whattech(cell);
+	return(cell->tech);
 }
 
 /*
- * Routine to figure out the facet to use for highlight "high".
+ * Routine to figure out the cell to use for highlight "high".
  */
-NODEPROTO *us_highfacet(HIGHLIGHT *high)
+NODEPROTO *us_highcell(HIGHLIGHT *high)
 {
 	if (high->fromvar != NOVARIABLE)
 	{
 		if (high->fromport != NOPORTPROTO)
 			return(high->fromport->subnodeinst->parent);
-		if (high->fromgeom == NOGEOM) return(high->facet);
+		if (high->fromgeom == NOGEOM) return(high->cell);
 		if (high->fromgeom->entryisnode)
 			return(high->fromgeom->entryaddr.ni->parent);
 		return(high->fromgeom->entryaddr.ai->parent);
@@ -2773,7 +2774,7 @@ TECHNOLOGY *us_getobjectinfo(INTBIG addr, INTBIG type, INTBIG *lx, INTBIG *hx, I
 	return(NOTECHNOLOGY);
 }
 
-void us_drawfacetvariable(VARIABLE *var, NODEPROTO *np)
+void us_drawcellvariable(VARIABLE *var, NODEPROTO *np)
 {
 	REGISTER INTBIG i, displaytotal;
 	REGISTER WINDOWPART *w;
@@ -2782,10 +2783,10 @@ void us_drawfacetvariable(VARIABLE *var, NODEPROTO *np)
 	/* get polygon */
 	(void)needstaticpolygon(&poly, 4, us_tool->cluster);
 
-	displaytotal = tech_displayablefacetvars(np, NOWINDOWPART, &tech_oneprocpolyloop);
+	displaytotal = tech_displayablecellvars(np, NOWINDOWPART, &tech_oneprocpolyloop);
 	for(i = 0; i < displaytotal; i++)
 	{
-		(void)tech_filldisplayablefacetvar(np, poly, NOWINDOWPART, 0, &tech_oneprocpolyloop);
+		(void)tech_filldisplayablecellvar(np, poly, NOWINDOWPART, 0, &tech_oneprocpolyloop);
 		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 		{
 			if (w->curnodeproto != np) continue;
@@ -2794,7 +2795,7 @@ void us_drawfacetvariable(VARIABLE *var, NODEPROTO *np)
 	}
 }
 
-void us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np)
+void us_undrawcellvariable(VARIABLE *var, NODEPROTO *np)
 {
 	INTBIG x, y;
 	INTBIG tsx, tsy;
@@ -2829,7 +2830,7 @@ void us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np)
 		lx = slx;   hx = shx;
 		ly = sly;   hy = shy;
 		if ((w->state&INPLACEEDIT) != 0) 
-			xformbox(&lx, &hx, &ly, &hy, w->outoffacet);
+			xformbox(&lx, &hx, &ly, &hy, w->outofcell);
 		if (us_makescreen(&lx, &ly, &hx, &hy, w)) continue;
 		screendrawbox(w, lx, hx, ly, hy, &us_ebox);
 
@@ -2848,7 +2849,7 @@ void us_undrawfacetvariable(VARIABLE *var, NODEPROTO *np)
 			if (geom->entryisnode)
 			{
 				ni = geom->entryaddr.ni;
-				(void)us_drawfacet(ni, LAYERA, el_matid, 3, w);
+				(void)us_drawcell(ni, LAYERA, el_matid, 3, w);
 			} else
 			{
 				ai = geom->entryaddr.ai;
