@@ -44,7 +44,8 @@ GRAPHICS us_menufigs = {LAYERA, MENGLY, SOLIDC, SOLIDC,
 
 /* for drawing menu shadows */
 static GRAPHICS us_shadowdesc = {LAYERA, MENGLY, PATTERNED, PATTERNED,
-	{0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA}, NOVARIABLE, 0};
+	{0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA,
+	0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA,0x5555,0xAAAA}, NOVARIABLE, 0};
 
 /* for drawing menu text (nothing changes) */
 GRAPHICS us_menutext = {LAYERA, MENTXT, SOLIDC, SOLIDC,
@@ -55,11 +56,13 @@ GRAPHICS us_menutext = {LAYERA, MENTXT, SOLIDC, SOLIDC,
 
 /* prototypes for local routines */
 static INTBIG us_groupfunction(NODEPROTO*);
+#ifndef USEQT
 static void us_pmfirst(void);
 static void us_pmdone(void);
 static BOOLEAN us_pmeachchar(INTBIG, INTBIG, INTSML);
 static BOOLEAN us_pmeachdown(INTBIG, INTBIG);
 static void us_pminvertline(void);
+#endif
 
 /****************************** MENU DISPLAY ******************************/
 
@@ -92,8 +95,12 @@ void us_drawmenu(INTBIG scaletofit, WINDOWFRAME *mw)
 	/* draw menus if requested */
 	if ((us_tool->toolstate&MENUON) != 0)
 	{
+#ifdef USEQT
+		if (us_menuframe == NOWINDOWFRAME || (mw != NOWINDOWFRAME && us_menuframe != mw)) return;
+#else
 		if (mw != NOWINDOWFRAME && us_menuframe != NOWINDOWFRAME &&
 			us_menuframe != mw) return;
+#endif
 
 		/* draw the menu entries */
 		var = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu_key);
@@ -103,12 +110,12 @@ void us_drawmenu(INTBIG scaletofit, WINDOWFRAME *mw)
 		{
 			/* horizontal menus */
 			for(y=0; y<us_menuy; y++) for(x=0; x<us_menux; x++)
-				us_drawmenuentry(x, y, ((char **)var->addr)[y * us_menux + x]);
+				us_drawmenuentry(x, y, ((CHAR **)var->addr)[y * us_menux + x]);
 		} else
 		{
 			/* vertical menus */
 			for(x=0; x<us_menux; x++) for(y=0; y<us_menuy; y++)
-				us_drawmenuentry(x, y, ((char **)var->addr)[x * us_menuy + y]);
+				us_drawmenuentry(x, y, ((CHAR **)var->addr)[x * us_menuy + y]);
 		}
 
 		/* highlight any special entry (shouldn't update status display too) */
@@ -118,7 +125,7 @@ void us_drawmenu(INTBIG scaletofit, WINDOWFRAME *mw)
 	}
 }
 
-void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
+void us_drawmenuentry(INTBIG x, INTBIG y, CHAR *str)
 {
 	REGISTER INTBIG i, scaleu, scaled, x1, y1, lowx, lowy, highx, highy, xl,
 		yl, xh, yh, ofun, fun, lambda, bits, wid, twid;
@@ -132,7 +139,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	VARIABLE colorvar[2];
 	WINDOWPART ww;
 	XARRAY trans;
-	char line[100];
+	CHAR line[100];
 	INTBIG swid, shei, pangle;
 	INTBIG pxs, pys;
 	static POLYGON *poly = NOPOLYGON;
@@ -387,7 +394,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 		if (commandbinding.menumessage != 0)
 			poly->string = commandbinding.menumessage; else
 		{
-			(void)strncpy(line, commandbinding.command, 99);
+			(void)estrncpy(line, commandbinding.command, 99);
 			poly->string = line;
 			if (islower(line[0])) line[0] = toupper(line[0]);
 		}
@@ -467,8 +474,10 @@ void us_setmenunodearcs(void)
 	REGISTER ARCPROTO *ap;
 	REGISTER NODEPROTO *np, *pinnp;
 	REGISTER INTBIG didinst, i;
+	REGISTER BOOLEAN isgetproto;
 	REGISTER VARIABLE *var;
-	char si[20], sj[20], *par[MAXPARS+6];
+	REGISTER void *infstr;
+	CHAR si[20], sj[20], *par[MAXPARS+6];
 	COMMANDBINDING commandbinding;
 	extern COMCOMP us_userp;
 
@@ -480,12 +489,21 @@ void us_setmenunodearcs(void)
 	didinst = 0;
 	for(i=0; i<us_menuy*us_menux; i++)
 	{
-		us_parsebinding(((char **)var->addr)[i], &commandbinding);
+		us_parsebinding(((CHAR **)var->addr)[i], &commandbinding);
 
 		/* make sure the menu item is a "getproto" command */
-		if (commandbinding.command != 0 &&
-			(namesamen(commandbinding.command, "getproto", 8) == 0 ||
-			namesamen(commandbinding.command, "pmgetproto", 10) == 0))
+		isgetproto = FALSE;
+		if (commandbinding.command != 0)
+		{
+			if (namesamen(commandbinding.command, x_("getproto"), 8) == 0 ||
+				namesamen(commandbinding.command, x_("pmgetproto"), 10) == 0 ||
+				namesamen(commandbinding.command, x_("rem getproto"), 12) == 0 ||
+				namesamen(commandbinding.command, x_("rem pmgetproto"), 14) == 0)
+			{
+				isgetproto = TRUE;
+			}
+		}
+		if (isgetproto)
 		{
 			/* make sure the command is getting a primitive in a technology */
 			if (commandbinding.nodeglyph == NONODEPROTO ||
@@ -494,17 +512,17 @@ void us_setmenunodearcs(void)
 				/* load up the strings for the menu indices */
 				if (us_menupos <= 1)
 				{
-					(void)sprintf(si, "%ld", i%us_menux);
-					(void)sprintf(sj, "%ld", i/us_menux);
+					(void)esnprintf(si, 20, x_("%ld"), i%us_menux);
+					(void)esnprintf(sj, 20, x_("%ld"), i/us_menux);
 				} else
 				{
-					(void)sprintf(si, "%ld", i/us_menuy);
-					(void)sprintf(sj, "%ld", i%us_menuy);
+					(void)esnprintf(si, 20, x_("%ld"), i/us_menuy);
+					(void)esnprintf(sj, 20, x_("%ld"), i%us_menuy);
 				}
-				par[0] = "set";          par[1] = "menu";
-				par[2] = "background";   par[3] = "blue";
+				par[0] = x_("set");          par[1] = x_("menu");
+				par[2] = x_("background");   par[3] = x_("blue");
 				par[4] = sj;             par[5] = si;
-				par[6] = "getproto";
+				par[6] = x_("getproto");
 
 				/* found a "getproto" command: now change it */
 				if (ap != NOARCPROTO)
@@ -522,8 +540,8 @@ void us_setmenunodearcs(void)
 					}
 					if (ap != NOARCPROTO)
 					{
-						par[3] = "red";
-						par[7] = "arc";   par[8] = describearcproto(ap);
+						par[3] = x_("red");
+						par[7] = x_("arc");   par[8] = describearcproto(ap);
 						us_bind(9, par);
 						ap = ap->nextarcproto;
 						us_freebindingparse(&commandbinding);
@@ -535,12 +553,12 @@ void us_setmenunodearcs(void)
 				if (didinst == 0)
 				{
 					didinst = 1;
-					if (parse("pmgetproto", &us_userp, FALSE) >= 0)
+					if (parse(x_("pmgetproto"), &us_userp, FALSE) >= 0)
 					{
-						par[2] = "message";
+						par[2] = x_("message");
 						par[3] = _("Inst.");
-						par[6] = "pmgetproto";
-						par[7] = "instance";
+						par[6] = x_("pmgetproto");
+						par[7] = x_("instance");
 						us_bind(8, par);
 						us_freebindingparse(&commandbinding);
 						continue;
@@ -555,8 +573,16 @@ void us_setmenunodearcs(void)
 					if (np != NONODEPROTO &&
 						((np->userbits&NFUNCTION)>>NFUNCTIONSH) != NPNODE)
 					{
-						par[7] = "node";   par[8] = describenodeproto(np);
-						us_bind(9, par);
+						par[4] = x_("glyph");
+						par[5] = describenodeproto(np);
+						par[6] = sj;             par[7] = si;
+						par[8] = x_("rem");
+						par[9] = x_("getproto");
+						par[10] = x_("node");
+						infstr = initinfstr();
+						formatinfstr(infstr, "%s:%s", np->tech->techname, nldescribenodeproto(np));
+						par[11] = returninfstr(infstr);
+						us_bind(12, par);
 						np = np->nextnodeproto;
 						us_freebindingparse(&commandbinding);
 						continue;
@@ -564,7 +590,7 @@ void us_setmenunodearcs(void)
 				}
 
 				/* no nodes or arcs left: make it a blank entry */
-				par[6] = "-";
+				par[6] = x_("-");
 				us_bind(7, par);
 			}
 		}
@@ -581,7 +607,7 @@ void us_setmenunodearcs(void)
 void us_setmenusize(INTBIG x, INTBIG y, INTBIG position, BOOLEAN allgetproto)
 {
 	REGISTER INTBIG i, oldlen;
-	REGISTER char **temp, *last;
+	REGISTER CHAR **temp, *last;
 	REGISTER VARIABLE *oldvar;
 	COMMANDBINDING commandbinding;
 
@@ -604,22 +630,22 @@ void us_setmenusize(INTBIG x, INTBIG y, INTBIG position, BOOLEAN allgetproto)
 	(void)setvalkey((INTBIG)us_tool, VTOOL, us_menu_position_key, position, VINTEGER|VDONTSAVE);
 
 	/* rebuild the binding array size */
-	temp = (char **)emalloc(x*y * (sizeof (char *)), el_tempcluster);
+	temp = (CHAR **)emalloc(x*y * (sizeof (CHAR *)), el_tempcluster);
 	if (temp == 0) return;
 	if (allgetproto)
 	{
-		for(i=0; i<x*y; i++) temp[i] = "command=getproto";
+		for(i=0; i<x*y; i++) temp[i] = x_("command=getproto");
 		oldlen = 0;
 		last = 0;
 	} else
 	{
-		for(i=0; i<x*y; i++) temp[i] = "";
+		for(i=0; i<x*y; i++) temp[i] = x_("");
 		oldvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_binding_menu_key);
 		if (oldvar == NOVARIABLE) oldlen = 0; else oldlen = getlength(oldvar);
 		last = NOSTRING;
 		for(i=0; i<mini(oldlen, x*y); i++)
 		{
-			last = ((char **)oldvar->addr)[i];
+			last = ((CHAR **)oldvar->addr)[i];
 			(void)allocstring(&temp[i], last, el_tempcluster);
 		}
 
@@ -628,9 +654,9 @@ void us_setmenusize(INTBIG x, INTBIG y, INTBIG position, BOOLEAN allgetproto)
 		{
 			us_parsebinding(last, &commandbinding);
 			if (i < x*y && *commandbinding.command != 0 &&
-				namesamen(commandbinding.command, "getproto", 8) == 0)
+				namesamen(commandbinding.command, x_("getproto"), 8) == 0)
 			{
-				for(; i<x*y; i++) temp[i] = "command=getproto";
+				for(; i<x*y; i++) temp[i] = x_("command=getproto");
 			} else last = NOSTRING;
 			us_freebindingparse(&commandbinding);
 		}
@@ -638,12 +664,37 @@ void us_setmenusize(INTBIG x, INTBIG y, INTBIG position, BOOLEAN allgetproto)
 	(void)setvalkey((INTBIG)us_tool, VTOOL, us_binding_menu_key, (INTBIG)temp,
 		VSTRING|VISARRAY|VDONTSAVE|((x*y)<<VLENGTHSH));
 	for(i=0; i<mini(oldlen, x*y); i++) efree(temp[i]);
-	efree((char *)temp);
+	efree((CHAR *)temp);
 	if (last != NOSTRING) us_setmenunodearcs();
 }
 
 /******************** POPUP MENUS ********************/
 
+#ifdef USEQT
+
+/*
+ * routine to display the popup menu "menu" and allow picking.  The menu
+ * terminates when any button is clicked (a down-click is necessary if "*waitfordown"
+ * is true).  If "header" is true, display a header.  If "top" and "left" are not
+ * negative, they are used as the coordinates of the upper-left of the menu.  If
+ * "quitline" is nonzero, then exit the menu when the cursor moves over that line
+ * (1: left side, 2: right side, 3: pulldown menu extent, 4: popup menu extent).
+ * Returns the address of the item in the menu that is selected and sets "menu" to
+ * the menu (if a submenu in a hierarchy was used).  Returns NOPOPUPMENUITEM
+ * if no entry was selected.  Returns zero if this function cannot be done.  If the
+ * mouse is still down (because it crossed the quit line) then "waitfordown" is set
+ * true.  Also sets the "changed" items to nonzero for any entries that are modified.
+ */
+POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, BOOLEAN *waitfordown, BOOLEAN header,
+	INTBIG left, INTBIG top, INTBIG quitline)
+{
+	INTBIG i = nativepopupmenu(cmenu, header, left, top);
+	if (i < 0) return(NOPOPUPMENUITEM);
+	return(&(*cmenu)->list[i]);
+}
+
+#else /* USEQT */
+
 #define ATTVALGAP 20		/* distance between attribute and value columns */
 
 /* structure for popup menus */
@@ -685,7 +736,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, BOOLEAN *waitfordown, BOOLEAN hea
 {
 	REGISTER INTBIG i, yp, startfont;
 	BOOLEAN waitdown;
-	REGISTER char *savepos, *pt;
+	REGISTER CHAR *savepos, *pt;
 	REGISTER INTBIG textscale, save_pix;
 	UINTBIG descript[TEXTDESCRIPTSIZE];
 	INTBIG x, y, chwid, swid, shei;
@@ -753,7 +804,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, BOOLEAN *waitfordown, BOOLEAN hea
 		if (textscale == startfont) TDSETSIZE(descript, TXTMENU); else
 			TDSETSIZE(descript, textscale);
 		screensettextinfo(&us_pmcur.popupwindow, NOTECHNOLOGY, descript);
-		screengettextsize(&us_pmcur.popupwindow, "0", &chwid, &y);
+		screengettextsize(&us_pmcur.popupwindow, x_("0"), &chwid, &y);
 		us_pmcur.txthei = y+2;
 		for(i=0; i<us_pmcur.current->total; i++)
 		{
@@ -889,7 +940,7 @@ POPUPMENUITEM *us_popupmenu(POPUPMENU **cmenu, BOOLEAN *waitfordown, BOOLEAN hea
 		} else
 		{
 			/* draw a text entry */
-			savepos = &mi->attribute[strlen(mi->attribute)-1];
+			savepos = &mi->attribute[estrlen(mi->attribute)-1];
 			if (mi->attribute[0] != '>' && *savepos == '<') *savepos = 0; else
 				savepos = 0;
 			pt = us_stripampersand(mi->attribute);
@@ -1010,7 +1061,7 @@ BOOLEAN us_pmeachchar(INTBIG x, INTBIG y, INTSML chr)
 	/* add a letter to a value field */
 	screengettextsize(&us_pmcur.popupwindow, mi->value, &xs, &ys);
 	i = us_pmcur.posx+2+us_pmcur.attlen+ATTVALGAP+xs;
-	mi->value[us_pmcur.curpos] = (char)chr;
+	mi->value[us_pmcur.curpos] = (CHAR)chr;
 	us_pmcur.curpos++;
 	mi->value[us_pmcur.curpos] = 0;
 	us_pminvertline();
@@ -1157,16 +1208,17 @@ void us_pminvertline(void)
 	screeninvertbox(&us_pmcur.popupwindow, us_pmcur.posx+1,
 		us_pmcur.posx+us_pmcur.sizex-2, yp, yp+us_pmcur.txthei-1);
 }
+#endif /* USEQT */
 
 /* 
  * Routine to remove the "&" from the string "msg" and return the new string.
  * This is used in menu entries, which use the "&" character to mark the
  * location of the mnemonic for the entry.
  */
-char *us_stripampersand(char *msg)
+CHAR *us_stripampersand(CHAR *msg)
 {
-	static char buf[200];
-	REGISTER char *pt;
+	static CHAR buf[200];
+	REGISTER CHAR *pt;
 
 	pt = buf;
 	while (*msg != 0)
@@ -1204,7 +1256,7 @@ void us_setkeyequiv(POPUPMENU *pm, INTBIG i)
 {
 	REGISTER INTBIG len, special;
 	REGISTER INTSML key;
-	REGISTER char *pt, lastchar;
+	REGISTER CHAR *pt, lastchar;
 	REGISTER POPUPMENUITEM *mi;
 	REGISTER void *infstr;
 
@@ -1215,7 +1267,7 @@ void us_setkeyequiv(POPUPMENU *pm, INTBIG i)
 	if (mi->response->menu != NOPOPUPMENU) return;
 
 	/* remove ending "<" for checkmarks */
-	len = strlen(mi->attribute);
+	len = estrlen(mi->attribute);
 	lastchar = 0;
 	if (mi->attribute[len-1] == '<')
 	{
@@ -1237,15 +1289,15 @@ void us_setkeyequiv(POPUPMENU *pm, INTBIG i)
 			key = tolower(key);
 		} else special = 0;
 		infstr = initinfstr();
-		formatinfstr(infstr, "%c%c", key, *pt);
-		addstringtoinfstr(infstr, "command=");
+		formatinfstr(infstr, x_("%c%c"), key, *pt);
+		addstringtoinfstr(infstr, x_("command="));
 		addstringtoinfstr(infstr, mi->response->comname);
 		us_appendargs(infstr, mi->response);
 		us_setkeybinding(returninfstr(infstr), key, special, FALSE);
 	}
 
 	/* restore ending "<" checkmark */
-	len = strlen(mi->attribute);
+	len = estrlen(mi->attribute);
 	mi->attribute[len] = lastchar;
 }
 
@@ -1258,8 +1310,8 @@ void us_validatemenu(POPUPMENU *pm)
 	REGISTER INTBIG i, j, index;
 	REGISTER POPUPMENUITEM *mi;
 	REGISTER USERCOM *uc;
-	REGISTER char *pt;
-	char tagged[256];
+	REGISTER CHAR *pt;
+	CHAR tagged[256];
 
 	for(i=0; i<256; i++) tagged[i] = 0;
 	for(j=0; j < pm->total; j++)
@@ -1280,6 +1332,6 @@ void us_validatemenu(POPUPMENU *pm)
 			ttyputerr(_("Warning: two entries share letter '%c' ('%s' and '%s')"),
 				index, mi->attribute, pm->list[tagged[index]-1].attribute);
 		}
-		tagged[index] = (char)(j+1);
+		tagged[index] = (CHAR)(j+1);
 	}
 }
