@@ -776,7 +776,6 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 	REGISTER TECHNOLOGY *tech;
 	REGISTER VARIABLE *var, *highvar;
 	REGISTER VIEW *view;
-	REGISTER CELL *c;
 	REGISTER NETWORK *net;
 	REGISTER WINDOWPART *win;
 	GEOM *fromgeom, *togeom;
@@ -847,10 +846,10 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 			*name = save;
 			if (np == NONODEPROTO) return(TRUE);
 			*objaddr = (INTBIG)np;
-		} else if (namesamen(type, x_("facet"), i) == 0 && i >= 1)
+		} else if (namesamen(type, x_("cell"), i) == 0 && i >= 1)
 		{
 			*objtype = VNODEPROTO;
-			if (estrcmp(pp, x_("~")) == 0) np = getcurfacet(); else
+			if (estrcmp(pp, x_("~")) == 0) np = getcurcell(); else
 			{
 				np = getnodeproto(pp);
 				if (np != NONODEPROTO && np->primindex != 0) np = NONODEPROTO;
@@ -858,18 +857,6 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 			*name = save;
 			if (np == NONODEPROTO) return(TRUE);
 			*objaddr = (INTBIG)np;
-		} else if (namesamen(type, x_("cell"), i) == 0 && i >= 1)
-		{
-			*objtype = VCELL;
-			if (estrcmp(pp, x_("~")) != 0) c = getcell(pp); else
-			{
-				np = getcurfacet();
-				if (np == NONODEPROTO) c = NOCELL; else
-					c = np->cell;
-			}
-			*name = save;
-			if (c == NOCELL) return(TRUE);
-			*objaddr = (INTBIG)c;
 		} else if (namesamen(type, x_("view"), i) == 0 && i >= 1)
 		{
 			*objtype = VVIEW;
@@ -891,7 +878,7 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 		} else if (namesamen(type, x_("net"), i) == 0 && i >= 2)
 		{
 			*objtype = VNETWORK;
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO) return(TRUE);
 			net = getnetwork(pp, np);
 			*name = save;
@@ -957,9 +944,9 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 					*objtype = VARCINST;
 			} else if (namesamen(name, x_("nodes"), 5) == 0)
 			{
-				/* construct a list of the nodes in this facet */
+				/* construct a list of the nodes in this cell */
 				name += 5;
-				np = getcurfacet();
+				np = getcurcell();
 				if (np == NONODEPROTO) return(TRUE);
 				varcount = 0;
 				for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -974,9 +961,9 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 				*objtype = VGENERAL | VISARRAY | ((varcount*2) << VLENGTHSH) | VDONTSAVE;
 			} else if (namesamen(name, x_("arcs"), 4) == 0)
 			{
-				/* construct a list of the arcs in this facet */
+				/* construct a list of the arcs in this cell */
 				name += 4;
-				np = getcurfacet();
+				np = getcurcell();
 				if (np == NONODEPROTO) return(TRUE);
 				varcount = 0;
 				for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
@@ -991,9 +978,9 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 				*objtype = VGENERAL | VISARRAY | ((varcount*2) << VLENGTHSH) | VDONTSAVE;
 			} else if (namesamen(name, x_("ports"), 5) == 0)
 			{
-				/* construct a list of the ports in this facet */
+				/* construct a list of the ports in this cell */
 				name += 5;
-				np = getcurfacet();
+				np = getcurcell();
 				if (np == NONODEPROTO) return(TRUE);
 				varcount = 0;
 				for(port = np->firstportproto; port != NOPORTPROTO; port = port->nextportproto)
@@ -1008,9 +995,9 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 				*objtype = VGENERAL | VISARRAY | ((varcount*2) << VLENGTHSH) | VDONTSAVE;
 			} else if (namesamen(name, x_("nets"), 4) == 0)
 			{
-				/* construct a list of the networks in this facet */
+				/* construct a list of the networks in this cell */
 				name += 4;
-				np = getcurfacet();
+				np = getcurcell();
 				if (np == NONODEPROTO) return(TRUE);
 				varcount = 0;
 				for(net = np->firstnetwork; net != NONETWORK; net = net->nextnetwork)
@@ -1023,9 +1010,9 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 				}
 				*objaddr = (INTBIG)us_evaluatevarlist;
 				*objtype = VGENERAL | VISARRAY | ((varcount*2) << VLENGTHSH) | VDONTSAVE;
-			} else if (namesamen(name, x_("facets"), 6) == 0)
+			} else if (namesamen(name, x_("cells"), 6) == 0)
 			{
-				/* construct a list of the facets in this library */
+				/* construct a list of the cells in this library */
 				name += 6;
 				varcount = 0;
 				for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
@@ -1081,7 +1068,7 @@ BOOLEAN us_evaluatevariable(CHAR *name, INTBIG *objaddr, INTBIG *objtype, CHAR *
 			if (*name == '.') name++;
 		} else
 		{
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO) return(TRUE);
 			*objaddr = (INTBIG)np;
 			*objtype = VNODEPROTO;
@@ -1703,9 +1690,9 @@ INTBIG ttygetparam(CHAR *prompt, COMCOMP *parameter, INTBIG keycount, CHAR *para
 	BOOLEAN multiplefiles;
 	REGISTER CHAR *pt, *next;
 	DIALOGHOOK *dh;
-	extern COMCOMP us_arrayxp, us_editfacetp, us_spreaddp, us_artlookp,
+	extern COMCOMP us_arrayxp, us_editcellp, us_spreaddp, us_artlookp,
 		us_defnodexsp, us_lambdachp, us_replacep, us_visiblelayersp, us_portlp,
-		us_copyfacetp, us_showp, us_gridalip, us_defarcsp, us_portep, us_menup,
+		us_copycellp, us_showp, us_gridalip, us_defarcsp, us_portep, us_menup,
 		us_yesnop, us_viewn1p, us_noyesp, us_colorpvaluep, us_viewfp, us_nodetptlp,
 		us_colorreadp, us_colorwritep, us_varvep, us_nodetp, us_showop, us_librarywp,
 		us_windowrnamep, us_technologyup, us_technologyedlp, us_librarydp, us_helpp,
@@ -1714,7 +1701,7 @@ INTBIG ttygetparam(CHAR *prompt, COMCOMP *parameter, INTBIG keycount, CHAR *para
 		us_nodetcaip, us_bindgkeyp, us_sizep, us_sizewp, us_defnodep, us_showup,
 		us_librarykp, us_findobjap, us_window3dp, us_gridp, us_technologytp, us_textfp,
 		us_renamecp, us_findnnamep, us_findexportp, us_noyesalwaysp, us_varop,
-		us_copyfacetdp, us_findnodep, us_technologycnnp, us_showep, us_purelayerp,
+		us_copycelldp, us_findnodep, us_technologycnnp, us_showep, us_purelayerp,
 		us_textsp, us_viewdp, us_interpretcp, us_findarcp, us_varvmp, us_showrp,
 		us_varbdp, us_portcp, us_showfp, us_varbs1p, us_findintp, us_viewc1p,
 		us_defnodenotp, us_nodetptmp;
@@ -1741,20 +1728,20 @@ INTBIG ttygetparam(CHAR *prompt, COMCOMP *parameter, INTBIG keycount, CHAR *para
 	if (parameter == &us_varop)               return(us_attributesdlog());
 	if (parameter == &us_varbdp)              return(us_attrparamdlog());
 	if (parameter == &us_varbs1p)             return(us_attrreportdlog());
-	if (parameter == &us_copyfacetp)          return(us_copyfacetdlog(prompt));
+	if (parameter == &us_copycellp)           return(us_copycelldlog(prompt));
 	if (parameter == &us_defnodenotp)         return(us_copyrightdlog());
 	if (parameter == &us_defarcsp)            return(us_defarcdlog());
 	if (parameter == &us_defnodexsp)          return(us_defnodedlog());
 	if (parameter == &us_textdsp)             return(us_deftextdlog(prompt));
 	if (parameter == &us_technologyedlp)      return(us_dependentlibdlog());
-	if (parameter == &us_editfacetp)          return(us_editfacetdlog(prompt));
+	if (parameter == &us_editcellp)           return(us_editcelldlog(prompt));
 	if (parameter == &us_librarynp)           return(us_examineoptionsdlog());
 	if (parameter == &us_libraryrp)           return(us_findoptionsdlog());
-	if (parameter == &us_defnodep)            return(us_facetdlog());
-	if (parameter == &us_showfp)              return(us_facetlist());
-	if (parameter == &us_showdp)              return(us_facetselect(prompt, paramstart, 0));
-	if (parameter == &us_viewc1p)             return(us_facetselect(prompt, paramstart, 1));
-	if (parameter == &us_showup)              return(us_facetselect(_("Facet to delete"), paramstart, 2));
+	if (parameter == &us_defnodep)            return(us_celldlog());
+	if (parameter == &us_showfp)              return(us_celllist());
+	if (parameter == &us_showdp)              return(us_cellselect(prompt, paramstart, 0));
+	if (parameter == &us_viewc1p)             return(us_cellselect(prompt, paramstart, 1));
+	if (parameter == &us_showup)              return(us_cellselect(_("Cell to delete"), paramstart, 2));
 	if (parameter == &us_textfp)              return(us_findtextdlog());
 	if (parameter == &us_viewfp)              return(us_frameoptionsdlog());
 	if (parameter == &us_showrp)              return(us_generaloptionsdlog());
@@ -1762,7 +1749,7 @@ INTBIG ttygetparam(CHAR *prompt, COMCOMP *parameter, INTBIG keycount, CHAR *para
 	if (parameter == &us_portcp)              return(us_globalsignaldlog());
 	if (parameter == &us_helpp)               return(us_helpdlog(prompt));
 	if (parameter == &us_colorhighp)          return(us_highlayerlog());
-	if (parameter == &us_copyfacetdp)         return(us_iconstyledlog());
+	if (parameter == &us_copycelldp)          return(us_iconstyledlog());
 	if (parameter == &us_interpretcp)         return(us_javaoptionsdlog());
 	if (parameter == &us_lambdachp)           return(us_lambdadlog());
 	if (parameter == &us_librarydp)           return(us_librarypathdlog());
@@ -1779,12 +1766,12 @@ INTBIG ttygetparam(CHAR *prompt, COMCOMP *parameter, INTBIG keycount, CHAR *para
 	if (parameter == &us_nodetptlp)           return(us_placetextdlog());
 	if (parameter == &us_librarywriteformatp) return(us_plotoptionsdlog());
 	if (parameter == &us_portlp)              return(us_portdisplaydlog());
-	if (parameter == &us_portep)              return(us_portdlog(paramstart));
+	if (parameter == &us_portep)              return(us_portdlog());
 	if (parameter == &us_bindgkeyp)           return(us_quickkeydlog());
 	if (parameter == &us_renameop)            return(us_renamedlog(VLIBRARY));
 	if (parameter == &us_renamenp)            return(us_renamedlog(VTECHNOLOGY));
 	if (parameter == &us_renamecp)            return(us_renamedlog(VPORTPROTO));
-	if (parameter == &us_findnamep)           return(us_renamedlog(VCELL));
+	if (parameter == &us_findnamep)           return(us_renamedlog(VNODEPROTO));
 	if (parameter == &us_findintp)            return(us_renamedlog(VNETWORK));
 	if (parameter == &us_replacep)            return(us_replacedlog());
 	if (parameter == &us_nodetptmp)           return(us_romgendlog());
