@@ -63,7 +63,7 @@ static void us_addobjects(NODEPROTO*);
 static BOOLEAN us_wildmatch(CHAR*, CHAR*);
 static void us_explaintool(INTBIG, struct explanation[]);
 static void us_drawarcmenu(ARCPROTO *ap);
-static BOOLEAN us_isuniquename(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclude);
+static BOOLEAN us_isuniquename(CHAR *name, NODEPROTO *cell, INTBIG type, void *exclude);
 
 static STATUSFIELD *us_clearstatuslines[3] = {0, 0, 0};
 
@@ -78,8 +78,8 @@ void us_freestatusmemory(void)
 	if (us_statusalign != 0) ttyfreestatusfield(us_statusalign);
 	if (us_statusangle != 0) ttyfreestatusfield(us_statusangle);
 	if (us_statusarc != 0) ttyfreestatusfield(us_statusarc);
-	if (us_statusfacet != 0) ttyfreestatusfield(us_statusfacet);
-	if (us_statusfacetsize != 0) ttyfreestatusfield(us_statusfacetsize);
+	if (us_statuscell != 0) ttyfreestatusfield(us_statuscell);
+	if (us_statuscellsize != 0) ttyfreestatusfield(us_statuscellsize);
 	if (us_statusselectcount != 0) ttyfreestatusfield(us_statusselectcount);
 	if (us_statusgridsize != 0) ttyfreestatusfield(us_statusgridsize);
 	if (us_statuslambda != 0) ttyfreestatusfield(us_statuslambda);
@@ -113,16 +113,16 @@ void us_initstatus(void)
 		first = FALSE;
 		lines = ttynumstatuslines();
 		for(i=0; i<lines; i++) us_clearstatuslines[i] = ttydeclarestatusfield(i+1, 0, 100, x_(""));
-		us_statusfacet = us_statusnode = us_statusarc = 0;
+		us_statuscell = us_statusnode = us_statusarc = 0;
 		us_statuslambda = us_statustechnology = us_statusxpos = us_statusypos = 0;
-		us_statusangle = us_statusalign = us_statusfacetsize = us_statusgridsize = 0;
+		us_statusangle = us_statusalign = us_statuscellsize = us_statusgridsize = 0;
 		us_statusproject = us_statusroot = us_statuspart = us_statuspackage = 0;
 		us_statusselection = us_statusselectcount = 0;
-		us_statusfacet       = ttydeclarestatusfield(0,  0,   0, x_(""));
+		us_statuscell        = ttydeclarestatusfield(0,  0,   0, x_(""));
 		us_statusnode        = ttydeclarestatusfield(1,  0,  20, _("NODE: "));
 		us_statusarc         = ttydeclarestatusfield(1, 20,  40, _("ARC: "));
 		us_statusselectcount = ttydeclarestatusfield(1, 40,  52, _("SELECTED: "));
-		us_statusfacetsize   = ttydeclarestatusfield(1, 52,  69, _("SIZE: "));
+		us_statuscellsize    = ttydeclarestatusfield(1, 52,  69, _("SIZE: "));
 		us_statuslambda      = ttydeclarestatusfield(1, 69,  82, _("LAMBDA: "));
 		us_statustechnology  = ttydeclarestatusfield(1, 82, 100, _("TECHNOLOGY: "));
 		us_statusxpos        = ttydeclarestatusfield(1, 69,  82, _("X: "));
@@ -281,7 +281,7 @@ void us_shadownodeproto(WINDOWFRAME *frame, NODEPROTO *np)
 					{
 						if (high.fromport == NOPORTPROTO)
 						{
-							formatinfstr(infstr, _("%s (facet name)"),
+							formatinfstr(infstr, _("%s (cell name)"),
 								describenodeinst(high.fromgeom->entryaddr.ni));
 						} else
 						{
@@ -291,7 +291,7 @@ void us_shadownodeproto(WINDOWFRAME *frame, NODEPROTO *np)
 					{
 						if (high.fromgeom == NOGEOM)
 						{
-							formatinfstr(infstr, _("%s on facet"),
+							formatinfstr(infstr, _("%s on cell"),
 								us_trueattributename(var));
 						} else if (high.fromport != NOPORTPROTO)
 						{
@@ -316,14 +316,18 @@ void us_shadownodeproto(WINDOWFRAME *frame, NODEPROTO *np)
 						}
 					}
 					pt = returninfstr(infstr);
-				}
-				if ((high.status&HIGHFROM) != 0 && high.fromgeom->entryisnode)
+				} else if ((high.status&HIGHFROM) != 0 && high.fromgeom->entryisnode)
 				{
 					ni = high.fromgeom->entryaddr.ni;
 					if (ni->proto == np)
 					{
 						/* one node selected that is the same as the current proto: qualify proto */
-						pt = us_describenodeinsttype(np, ni->userbits&NTECHBITS);
+						infstr = initinfstr();
+						addstringtoinfstr(infstr, us_describenodeinsttype(np, ni, ni->userbits&NTECHBITS));
+						var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
+						if (var != NOVARIABLE)
+							formatinfstr(infstr, x_(" [%s]"), (CHAR *)var->addr);
+						pt = returninfstr(infstr);
 					}
 				}
 			}
@@ -507,8 +511,8 @@ void us_setnodeangle(WINDOWFRAME *frame)
 	ttysetstatusfield(frame, us_statusangle, hold, FALSE);
 }
 
-/* write the name of the facet in window "w" */
-void us_setfacetname(WINDOWPART *w)
+/* write the name of the cell in window "w" */
+void us_setcellname(WINDOWPART *w)
 {
 	REGISTER EDITOR *ed;
 	REGISTER void *infstr;
@@ -521,7 +525,7 @@ void us_setfacetname(WINDOWPART *w)
 	if (el_curwindowpart != NOWINDOWPART && w != el_curwindowpart &&
 		w->frame == el_curwindowpart->frame) return;
 
-	/* write the facet name */
+	/* write the cell name */
 	infstr = initinfstr();
 	switch (w->state&WINDOWTYPE)
 	{
@@ -541,14 +545,14 @@ void us_setfacetname(WINDOWPART *w)
 		case DISP3DWINDOW:
 			if (w->curnodeproto != NONODEPROTO)
 			{
-				formatinfstr(infstr, x_("%s:%s"), w->curnodeproto->cell->lib->libname,
+				formatinfstr(infstr, x_("%s:%s"), w->curnodeproto->lib->libname,
 					nldescribenodeproto(w->curnodeproto));
-				if (w->curnodeproto->cell->lib != el_curlib)
+				if (w->curnodeproto->lib != el_curlib)
 					formatinfstr(infstr, _(" - Current library: %s"), el_curlib->libname);
 			}
 			break;
 		case EXPLORERWINDOW:
-			addstringtoinfstr(infstr, _("Facet Explorer"));
+			addstringtoinfstr(infstr, _("Cell Explorer"));
 			break;
 		case WAVEFORMWINDOW:
 			if (w->curnodeproto != NONODEPROTO)
@@ -561,7 +565,7 @@ void us_setfacetname(WINDOWPART *w)
 			break;
 	}
 
-	ttysetstatusfield(w->frame, us_statusfacet, returninfstr(infstr), TRUE);
+	ttysetstatusfield(w->frame, us_statuscell, returninfstr(infstr), TRUE);
 }
 
 /*
@@ -587,9 +591,9 @@ void us_setselectioncount(void)
 }
 
 /*
- * write the size of the facet in window "w" from the size of "w->curnodeproto"
+ * write the size of the cell in window "w" from the size of "w->curnodeproto"
  */
-void us_setfacetsize(WINDOWPART *w)
+void us_setcellsize(WINDOWPART *w)
 {
 	REGISTER NODEPROTO *np;
 	CHAR valstring[50];
@@ -608,14 +612,14 @@ void us_setfacetsize(WINDOWPART *w)
 				break;
 			case DISPWINDOW:
 			case DISP3DWINDOW:
-				lambda = lambdaoffacet(np);
+				lambda = lambdaofcell(np);
 				(void)estrcpy(valstring, latoa(np->highx - np->lowx, lambda));
 				(void)estrcat(valstring, x_("x"));
 				(void)estrcat(valstring, latoa(np->highy - np->lowy, lambda));
 				break;
 		}
 	}
-	ttysetstatusfield(w->frame, us_statusfacetsize, valstring, FALSE);
+	ttysetstatusfield(w->frame, us_statuscellsize, valstring, FALSE);
 }
 
 /* write the grid size of window "w" from "w->gridx" and "w->gridy" */
@@ -662,13 +666,13 @@ void us_redostatus(WINDOWFRAME *frame)
 	/* write the window information on the window lines */
 	for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
 	{
-		us_setfacetname(w);
+		us_setcellname(w);
 		if (graphicshas(CANSTATUSPERFRAME) || w->frame == frame)
-			us_setfacetsize(w);
+			us_setcellsize(w);
 		us_setgridsize(w);
 	}
 	if (el_curwindowpart != NOWINDOWPART)
-		us_setfacetsize(el_curwindowpart);
+		us_setcellsize(el_curwindowpart);
 
 	/* other fields */
 	us_setnodeangle(frame);
@@ -815,7 +819,6 @@ static struct
 	{x_("R-tree"),       VRTNODE},
 	{x_("Fixed-Point"),  VFRACT},
 	{x_("Network"),      VNETWORK},
-	{x_("Cell"),         VCELL},
 	{x_("View"),         VVIEW},
 	{x_("WindowPart"),   VWINDOWPART},
 	{x_("Graphics"),     VGRAPHICS},
@@ -890,14 +893,14 @@ CHAR *us_variableattributes(VARIABLE *var, INTBIG aindex)
 	return(returninfstr(infstr));
 }
 
-/* routine to recursively count and print the nodes in facet "facet" */
-void us_describecontents(NODEPROTO *facet)
+/* routine to recursively count and print the nodes in cell "cell" */
+void us_describecontents(NODEPROTO *cell)
 {
 	REGISTER INTBIG i;
 	REGISTER NODEPROTO *np;
 	REGISTER LIBRARY *lib, *printlib;
 	REGISTER TECHNOLOGY *curtech, *printtech, *tech;
-	REGISTER NODEPROTO **sortedfacets;
+	REGISTER NODEPROTO **sortedcells;
 
 	/* first zero the count of each nodeproto */
 	for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
@@ -907,11 +910,11 @@ void us_describecontents(NODEPROTO *facet)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->temp1 = 0;
 
-	/* now look at every object recursively in this facet */
-	us_addobjects(facet);
+	/* now look at every object recursively in this cell */
+	us_addobjects(cell);
 
 	/* print the totals */
-	ttyputmsg(_("Contents of facet %s:"), describenodeproto(facet));
+	ttyputmsg(_("Contents of cell %s:"), describenodeproto(cell));
 	printtech = NOTECHNOLOGY;
 	for(curtech = el_technologies; curtech != NOTECHNOLOGY; curtech = curtech->nexttechnology)
 	{
@@ -929,13 +932,13 @@ void us_describecontents(NODEPROTO *facet)
 	}
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 	{
-		sortedfacets = us_sortlib(lib, (CHAR *)0, FALSE);
-		if (sortedfacets == 0) ttyputnomemory(); else
+		sortedcells = us_sortlib(lib, (CHAR *)0);
+		if (sortedcells == 0) ttyputnomemory(); else
 		{
 			printlib = NOLIBRARY;
-			for(i = 0; sortedfacets[i] != NONODEPROTO; i++)
+			for(i = 0; sortedcells[i] != NONODEPROTO; i++)
 			{
-				np = sortedfacets[i];
+				np = sortedcells[i];
 				if (np->temp1 == 0) continue;
 				if (lib != printlib)
 				{
@@ -945,13 +948,13 @@ void us_describecontents(NODEPROTO *facet)
 				ttyputmsg(_("%6d %s %s"), np->temp1, nldescribenodeproto(np),
 					makeplural(_("node"), np->temp1));
 			}
-			efree((CHAR *)sortedfacets);
+			efree((CHAR *)sortedcells);
 		}
 	}
 }
 
 /*
- * routine to recursively examine facet "np" and update the number of
+ * routine to recursively examine cell "np" and update the number of
  * instantiated primitive nodeprotos in the "temp1" field of the nodeprotos.
  */
 void us_addobjects(NODEPROTO *np)
@@ -965,7 +968,7 @@ void us_addobjects(NODEPROTO *np)
 		if (ni->proto->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (ni->proto->cell == np->cell) continue;
+		if (isiconof(ni->proto, np)) continue;
 		cnp = contentsview(ni->proto);
 		if (cnp == NONODEPROTO) cnp = ni->proto;
 		us_addobjects(cnp);
@@ -1020,15 +1023,17 @@ CHAR *us_describemenunode(COMMANDBINDING *commandbinding)
 
 	if (commandbinding->menumessage == 0) bits = 0; else
 		bits = myatoi(commandbinding->menumessage);
-	return(us_describenodeinsttype(commandbinding->nodeglyph, bits));
+	return(us_describenodeinsttype(commandbinding->nodeglyph, NONODEINST, bits));
 }
 
 /*
- * Routine to return a description of node "np" that is qualified with bits "bits"
+ * Routine to return a description of node "np" that is qualified with bits "bits".
+ * It may also be qualified by having an instance "ni" (but it may be NONODEINST).
  */
-CHAR *us_describenodeinsttype(NODEPROTO *np, INTBIG bits)
+CHAR *us_describenodeinsttype(NODEPROTO *np, NODEINST *ni, INTBIG bits)
 {
 	REGISTER INTBIG i;
+	REGISTER CHAR *pt;
 	REGISTER void *infstr;
 
 	infstr = initinfstr();
@@ -1038,24 +1043,27 @@ CHAR *us_describenodeinsttype(NODEPROTO *np, INTBIG bits)
 			*us_specialstatus[i].prim == np) break;
 	if (us_specialstatus[i].prim != 0)
 	{
-		addstringtoinfstr(infstr, x_(" ("));
-		addstringtoinfstr(infstr, us_specialstatus[i].statusmessage);
-		addstringtoinfstr(infstr, x_(")"));
+		formatinfstr(infstr, x_(" (%s)"), us_specialstatus[i].statusmessage);
+	} else
+	{
+		/* add information if from technology editor */
+		if (ni != NONODEINST)
+		{
+			pt = us_teceddescribenode(ni);
+			if (pt != 0) formatinfstr(infstr, x_(" (%s)"), pt);
+		}
 	}
 	return(returninfstr(infstr));
 }
 
 /*
- * routine to sort the facets in library "lib" by facet name and return an
+ * routine to sort the cells in library "lib" by cell name and return an
  * array of NODEPROTO pointers (terminating with NONODEPROTO).  If "matchspec"
- * is nonzero, it is a string that forces wildcard matching of facet names.
- * If "shortlist" is true, only list one facet of every cell.  Remember
- * to free the returned array when done.  Routine returns zero upon error.
+ * is nonzero, it is a string that forces wildcard matching of cell names.
  */
-NODEPROTO **us_sortlib(LIBRARY *lib, CHAR *matchspec, BOOLEAN shortlist)
+NODEPROTO **us_sortlib(LIBRARY *lib, CHAR *matchspec)
 {
 	REGISTER NODEPROTO **sortindex, *np;
-	REGISTER CELL *c;
 	REGISTER INTBIG total, i;
 	REGISTER CHAR *pt;
 
@@ -1066,36 +1074,21 @@ NODEPROTO **us_sortlib(LIBRARY *lib, CHAR *matchspec, BOOLEAN shortlist)
 		if (*pt == ':') matchspec = pt+1;
 	}
 
-	/* count the number of facets in the library */
+	/* count the number of cells in the library */
 	total = 0;
-	if (shortlist)
-	{
-		for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
-			if (us_wildmatch(c->cellname, matchspec)) total++;
-	} else
-	{
-		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
-			if (us_wildmatch(nldescribenodeproto(np), matchspec)) total++;
-	}
+	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+		if (us_wildmatch(nldescribenodeproto(np), matchspec)) total++;
 
 	/* allocate array for sorting entries */
 	sortindex = (NODEPROTO **)emalloc(((total+1) * (sizeof (NODEPROTO *))), el_tempcluster);
 	if (sortindex == 0) return(0);
-	if (shortlist)
-	{
-		for(c = lib->firstcell, i = 0; c != NOCELL; c = c->nextcell)
-			if (us_wildmatch(c->cellname, matchspec))
-				sortindex[i++] = c->firstincell;
-	} else
-	{
-		for(np = lib->firstnodeproto, i = 0; np != NONODEPROTO; np = np->nextnodeproto)
-			if (us_wildmatch(nldescribenodeproto(np), matchspec))
-				sortindex[i++] = np;
-	}
+	for(np = lib->firstnodeproto, i = 0; np != NONODEPROTO; np = np->nextnodeproto)
+		if (us_wildmatch(nldescribenodeproto(np), matchspec))
+			sortindex[i++] = np;
 	sortindex[i] = NONODEPROTO;
 
-	/* sort the facet names */
-	esort(sortindex, total, sizeof (NODEPROTO *), sort_facetnameascending);
+	/* sort the cell names */
+	esort(sortindex, total, sizeof (NODEPROTO *), sort_cellnameascending);
 	return(sortindex);
 }
 
@@ -1398,6 +1391,7 @@ USERVARIABLES us_uservariables[] =
 	{x_("ART_degrees"),              N_("Number of Degrees")},
 	{x_("ART_message"),              N_("Text")},
 	{x_("NET_ncc_match"),            N_("NCC equivalence")},
+	{x_("NET_ncc_forcedassociation"),N_("NCC association")},
 	{x_("NODE_name"),                N_("Node Name")},
 	{x_("SCHEM_capacitance"),        N_("Capacitance")},
 	{x_("SCHEM_diode"),              N_("Diode Size")},
@@ -1535,12 +1529,12 @@ void us_printcolorvalue(INTBIG ind)
 }
 
 /*
- * routine to make a line of text that describes facet "np".  The text
- * includes the facet name, version, creation, and revision dates.  The
- * amount of space to leave for the facet name is "maxlen" characters
+ * routine to make a line of text that describes cell "np".  The text
+ * includes the cell name, version, creation, and revision dates.  The
+ * amount of space to leave for the cell name is "maxlen" characters
  * (which is negative if dumping to a file).
  */
-CHAR *us_makefacetline(NODEPROTO *np, INTBIG maxlen)
+CHAR *us_makecellline(NODEPROTO *np, INTBIG maxlen)
 {
 	CHAR line[40];
 	REGISTER INTBIG l, i, gooddrc, len, total, lambda;
@@ -1629,7 +1623,7 @@ CHAR *us_makefacetline(NODEPROTO *np, INTBIG maxlen)
 		addstringtoinfstr(infstr, x_("  "));
 	if ((np->cellview->viewstate&TEXTVIEW) != 0)
 	{
-		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
+		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_cell_message_key);
 		if (var == NOVARIABLE) len = 0; else
 			len = getlength(var);
 		if (maxlen < 0) esnprintf(line, 40, _("%ld lines"), len); else
@@ -1637,7 +1631,7 @@ CHAR *us_makefacetline(NODEPROTO *np, INTBIG maxlen)
 		addstringtoinfstr(infstr, line);
 	} else
 	{
-		lambda = lambdaoffacet(np);
+		lambda = lambdaofcell(np);
 		estrcpy(line, latoa(np->highx-np->lowx, lambda));
 		if (maxlen >= 0)
 		{
@@ -1661,7 +1655,7 @@ CHAR *us_makefacetline(NODEPROTO *np, INTBIG maxlen)
 		esnprintf(line, 40, x_("%4ld"), total);
 	addstringtoinfstr(infstr, line);
 
-	/* show other factors about the facet */
+	/* show other factors about the cell */
 	if (maxlen < 0) addtoinfstr(infstr, '\t'); else
 		addstringtoinfstr(infstr, x_("   "));
 	if ((np->userbits&NPLOCKED) != 0) addstringtoinfstr(infstr, x_("L")); else
@@ -1860,7 +1854,7 @@ BOOLEAN us_saveeverything(void)
 			for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 			{
 				if (ni->proto->primindex != 0) continue;
-				deplib = ni->proto->cell->lib;
+				deplib = ni->proto->lib;
 				if (deplib == lib) continue;
 				if (deplib->temp1 <= lib->temp1) continue;
 				l = deplib->temp1;   deplib->temp1 = lib->temp1;   lib->temp1 = l;
@@ -2045,15 +2039,15 @@ INTBIG us_getcolormapentry(CHAR *pp, BOOLEAN layerletter)
 }
 
 /*
- * routine to return a unique port prototype name in facet "facet" given that
+ * routine to return a unique port prototype name in cell "cell" given that
  * a new prototype wants to be named "name".  The routine allocates space
  * for the string that is returned so this must be freed when done.
  */
-CHAR *us_uniqueportname(CHAR *name, NODEPROTO *facet)
+CHAR *us_uniqueportname(CHAR *name, NODEPROTO *cell)
 {
 	CHAR *str;
 
-	str = us_uniqueobjectname(name, facet, VPORTPROTO, 0);
+	str = us_uniqueobjectname(name, cell, VPORTPROTO, 0);
 
 	if (us_uniqueretstr != NOSTRING) efree(us_uniqueretstr);
 	(void)allocstring(&us_uniqueretstr, str, us_tool->cluster);
@@ -2061,11 +2055,11 @@ CHAR *us_uniqueportname(CHAR *name, NODEPROTO *facet)
 }
 
 /*
- * Routine to determine whether the name "name" is unique in facet "facet"
+ * Routine to determine whether the name "name" is unique in cell "cell"
  * (given that it is on objects of type "type").  Does not consider object
  * "exclude" (if nonzero).
  */
-BOOLEAN us_isuniquename(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclude)
+BOOLEAN us_isuniquename(CHAR *name, NODEPROTO *cell, INTBIG type, void *exclude)
 {
 	REGISTER PORTPROTO *pp;
 	REGISTER ARCINST *ai;
@@ -2075,12 +2069,12 @@ BOOLEAN us_isuniquename(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclude
 	switch (type)
 	{
 		case VPORTPROTO:
-			pp = getportproto(facet, name);
+			pp = getportproto(cell, name);
 			if (pp == NOPORTPROTO) break;
 			if (exclude != 0 && (PORTPROTO *)exclude == pp) break;
 			return(FALSE);
 		case VNODEINST:
-			for(ni = facet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
+			for(ni = cell->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 			{
 				if (exclude != 0 && (NODEINST *)exclude == ni) continue;
 				var = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name_key);
@@ -2089,7 +2083,7 @@ BOOLEAN us_isuniquename(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclude
 			}
 			break;
 		case VARCINST:
-			for(ai = facet->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
+			for(ai = cell->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 			{
 				if (exclude != 0 && (ARCINST *)exclude == ai) continue;
 				var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name_key);
@@ -2102,10 +2096,10 @@ BOOLEAN us_isuniquename(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclude
 }
 
 /*
- * routine to return a unique object name in facet "facet" starting with the
+ * routine to return a unique object name in cell "cell" starting with the
  * name "name".
  */
-CHAR *us_uniqueobjectname(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclude)
+CHAR *us_uniqueobjectname(CHAR *name, NODEPROTO *cell, INTBIG type, void *exclude)
 {
 	CHAR *newname, separatestring[2];
 	REGISTER INTBIG nextindex, i, possiblestart, possibleend, startindex, endindex, spacing,
@@ -2114,7 +2108,7 @@ CHAR *us_uniqueobjectname(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclu
 	REGISTER void *infstr;
 
 	/* first see if the name is unique */
-	if (us_isuniquename(name, facet, type, exclude)) return(name);
+	if (us_isuniquename(name, cell, type, exclude)) return(name);
 
 	/* now see if the name ends in "]" */
 	i = estrlen(name);
@@ -2168,7 +2162,7 @@ CHAR *us_uniqueobjectname(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclu
 							endindex+spacing*nextindex);
 						addstringtoinfstr(infstr, &name[endpos]);
 						newname = returninfstr(infstr);
-						if (us_isuniquename(newname, facet, type, 0)) break;
+						if (us_isuniquename(newname, cell, type, 0)) break;
 					}
 					return(newname);
 				}
@@ -2196,7 +2190,7 @@ CHAR *us_uniqueobjectname(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclu
 					formatinfstr(infstr, x_("[%ld"), nextindex);
 					addstringtoinfstr(infstr, &name[endpos]);
 					newname = returninfstr(infstr);
-					if (us_isuniquename(newname, facet, type, 0)) break;
+					if (us_isuniquename(newname, cell, type, 0)) break;
 				}
 				return(newname);
 			}
@@ -2233,7 +2227,7 @@ CHAR *us_uniqueobjectname(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclu
 				formatinfstr(infstr, x_("%c%ld"), us_separatechar, nextindex);
 				addstringtoinfstr(infstr, &name[possibleend]);
 				newname = returninfstr(infstr);
-				if (us_isuniquename(newname, facet, type, 0)) break;
+				if (us_isuniquename(newname, cell, type, 0)) break;
 			}
 			return(newname);
 		}
@@ -2265,7 +2259,7 @@ CHAR *us_uniqueobjectname(CHAR *name, NODEPROTO *facet, INTBIG type, void *exclu
 		formatinfstr(infstr, x_("%s%ld"), separatestring, nextindex);
 		addstringtoinfstr(infstr, &name[endpos]);
 		newname = returninfstr(infstr);
-		if (us_isuniquename(newname, facet, type, 0)) break;
+		if (us_isuniquename(newname, cell, type, 0)) break;
 	}
 	return(newname);
 }
