@@ -61,7 +61,7 @@ void ttynewcommand(void)
  * routine to output a normal message into the messages window
  * in the style of "printf"
  */
-void ttyputmsg(char *msg, ...)
+void ttyputmsg(CHAR *msg, ...)
 {
 	va_list ap;
 
@@ -81,7 +81,7 @@ void ttyputmsg(char *msg, ...)
  * information that can be done without) into the messages window
  * in the style of "printf"
  */
-void ttyputverbose(char *msg, ...)
+void ttyputverbose(CHAR *msg, ...)
 {
 	va_list ap;
 
@@ -103,7 +103,7 @@ void ttyputverbose(char *msg, ...)
  * routine to output an error message into the messages window
  * in the style of "printf"
  */
-void ttyputerr(char *msg, ...)
+void ttyputerr(CHAR *msg, ...)
 {
 	va_list ap;
 
@@ -117,7 +117,7 @@ void ttyputerr(char *msg, ...)
  * Routine to put out a message that is in 2 parts: a keystroke and a meaning.
  * The length of the "keystroke" field is "length".
  */
-void ttyputinstruction(char *keystroke, INTBIG length, char *meaning)
+void ttyputinstruction(CHAR *keystroke, INTBIG length, CHAR *meaning)
 {
 	REGISTER INTBIG i;
 	REGISTER void *infstr;
@@ -129,15 +129,15 @@ void ttyputinstruction(char *keystroke, INTBIG length, char *meaning)
 			addtoinfstr(infstr, *keystroke++);
 	}
 	addstringtoinfstr(infstr, meaning);
-	ttyputmsg("%s", returninfstr(infstr));
+	ttyputmsg(x_("%s"), returninfstr(infstr));
 }
 
-void ttyputusage(char *usage)
+void ttyputusage(CHAR *usage)
 {
 	ttyputerr(_("Usage: %s"), usage);
 }
 
-void ttyputbadusage(char *command)
+void ttyputbadusage(CHAR *command)
 {
 	ttyputerr(_("Bad '%s' command"), command);
 }
@@ -151,7 +151,7 @@ void ttyputnomemory(void)
  * routine to cause the current command to be aborted by removing it from
  * any macro and by printing the message on the terminal
  */
-void us_abortcommand(char *msg, ...)
+void us_abortcommand(CHAR *msg, ...)
 {
 	va_list ap;
 
@@ -206,10 +206,10 @@ static DIALOGITEM us_ttyinputdialogitems[] =
 {
  /*  1 */ {0, {96,200,120,264}, BUTTON, N_("OK")},
  /*  2 */ {0, {96,24,120,88}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {58,38,74,246}, EDITTEXT, ""},
- /*  4 */ {0, {3,9,51,281}, MESSAGE, ""}
+ /*  3 */ {0, {58,38,74,246}, EDITTEXT, x_("")},
+ /*  4 */ {0, {3,9,51,281}, MESSAGE, x_("")}
 };
-static DIALOG us_ttyinputdialog = {{50,75,188,371}, "", 0, 4, us_ttyinputdialogitems, 0, 0};
+static DIALOG us_ttyinputdialog = {{50,75,188,371}, x_(""), 0, 4, us_ttyinputdialogitems, 0, 0};
 
 /* special items for the "ttygetline" dialog: */
 #define DGTL_LINE     3		/* line (edit text) */
@@ -219,15 +219,15 @@ static DIALOG us_ttyinputdialog = {{50,75,188,371}, "", 0, 4, us_ttyinputdialogi
  * routine to print "prompt" and then read a line of text from the terminal
  * The address of the text line is returned (0 if cancelled).
  */
-char *ttygetline(char *prompt)
+CHAR *ttygetline(CHAR *prompt)
 {
 	INTBIG itemHit;
-	char *line, *pt, *defaultval, localprompt[256];
+	CHAR *line, *pt, *defaultval, localprompt[256];
 	REGISTER void *dia;
 
 	/* parse default value */
-	strcpy(localprompt, prompt);
-	defaultval = "";
+	estrcpy(localprompt, prompt);
+	defaultval = x_("");
 	for(pt=localprompt; *pt != 0; pt++) if (*pt == '[') break;
 	if (*pt != 0)
 	{
@@ -265,7 +265,7 @@ char *ttygetline(char *prompt)
  * messages window.  The address of the text line is returned.  Returns
  * zero if end-of-file is typed (^D).
  */
-char *ttygetlinemessages(char *prompt)
+CHAR *ttygetlinemessages(CHAR *prompt)
 {
 	return(getmessagesstring(prompt));
 }
@@ -282,14 +282,14 @@ void ttyclearmessages(void)
 /*
  * Routine to write information into trace file
  */
-void etrace(INTBIG mode, char *s, ...)
+void etrace(INTBIG mode, CHAR *s, ...)
 {
 	va_list ap;
-	char line[500];
+	CHAR line[500];
 
 	if (us_tracefile == NULL)
 	{
-		us_tracefile = fopen("trace.txt", "w");
+		us_tracefile = xcreate(x_("trace.txt"), el_filetypetext, 0, 0);
 		if (us_tracefile == NULL) return;
 	}
 
@@ -298,7 +298,7 @@ void etrace(INTBIG mode, char *s, ...)
 	evsnprintf(line, 500, s, ap);
 	va_end(ap);
 
-	fprintf(us_tracefile, line);
+	efprintf(us_tracefile, line);
 	fflush(us_tracefile);
 }
 
@@ -308,19 +308,19 @@ void etrace(INTBIG mode, char *s, ...)
  * internal routine to print a message in the scrolling area with the
  * style of "printf".  Pops up the messages window if "important" is true.
  */
-void us_ttyprint(BOOLEAN important, char *msg, va_list ap)
+void us_ttyprint(BOOLEAN important, CHAR *msg, va_list ap)
 {
-	char line[8192];
+	CHAR line[8192];
 	REGISTER INTBIG i, j, k;
 
 	if (us_ttyttywriteseparator != 0)
 	{
 		us_sepcount++;
-		sprintf(line,
-			"================================= %ld =================================",
+		esnprintf(line, 8192,
+			x_("================================= %ld ================================="),
 				us_sepcount);
 		putmessagesstring(line, important);
-		if (us_termaudit != 0) xprintf(us_termaudit, "%s\n", line);
+		if (us_termaudit != 0) xprintf(us_termaudit, x_("%s\n"), line);
 		us_ttyttywriteseparator = 0;
 	}
 
@@ -328,7 +328,7 @@ void us_ttyprint(BOOLEAN important, char *msg, va_list ap)
 	evsnprintf(line, 8192, msg, ap);
 
 	/* remove excessive trailing space */
-	i = strlen(line);
+	i = estrlen(line);
 	while (i > 1 && (line[i-1] == ' ' || line[i-1] == '\t') &&
 		(line[i-2] == ' ' || line[i-2] == '\t')) line[--i] = 0;
 
@@ -339,7 +339,7 @@ void us_ttyprint(BOOLEAN important, char *msg, va_list ap)
 		{
 			line[j] = 0;
 			putmessagesstring(&line[k], important);
-			if (us_termaudit != 0) xprintf(us_termaudit, "%s\n", &line[k]);
+			if (us_termaudit != 0) xprintf(us_termaudit, x_("%s\n"), &line[k]);
 			k = j + 1;
 		}
 	}
@@ -347,6 +347,6 @@ void us_ttyprint(BOOLEAN important, char *msg, va_list ap)
 	if (k < i)
 	{
 		putmessagesstring(&line[k], important);
-		if (us_termaudit != 0) xprintf(us_termaudit, "%s\n", &line[k]);
+		if (us_termaudit != 0) xprintf(us_termaudit, x_("%s\n"), &line[k]);
 	}
 }
