@@ -114,8 +114,8 @@ BOOLEAN us_tracedown(INTBIG x, INTBIG y)
 		tx = x;   ty = y;
 		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
 		{
-			xform(fx, fy, &fx, &fy, el_curwindowpart->outoffacet);
-			xform(tx, ty, &tx, &ty, el_curwindowpart->outoffacet);
+			xform(fx, fy, &fx, &fy, el_curwindowpart->outofcell);
+			xform(tx, ty, &tx, &ty, el_curwindowpart->outofcell);
 		}
 		screendrawline(el_curwindowpart, fx, fy, tx, ty, &us_highl, 0);
 	}
@@ -147,8 +147,8 @@ void us_traceup(void)
 		ty = us_tracedata[us_tracelist+1];
 		if ((el_curwindowpart->state&INPLACEEDIT) != 0)
 		{
-			xform(fx, fy, &fx, &fy, el_curwindowpart->outoffacet);
-			xform(tx, ty, &tx, &ty, el_curwindowpart->outoffacet);
+			xform(fx, fy, &fx, &fy, el_curwindowpart->outofcell);
+			xform(tx, ty, &tx, &ty, el_curwindowpart->outofcell);
 		}
 		screendrawline(el_curwindowpart, us_tracedata[i-2], us_tracedata[i-1],
 			us_tracedata[i], us_tracedata[i+1], &us_highl, 0);
@@ -195,7 +195,7 @@ void us_findpointbegin(void)
 	if (highvar == NOVARIABLE) return;
 	(void)us_makehighlight(((CHAR **)highvar->addr)[0], &newhigh);
 	newhigh.fromport = NOPORTPROTO;
-	newhigh.facet = getcurfacet();
+	newhigh.cell = getcurcell();
 	us_setfind(&newhigh, 1, 0, 0, 0);
 
 	/* get the point to be moved */
@@ -913,13 +913,14 @@ void us_findibegin(void)
 	us_finddoibegin(FALSE);
 }
 
-static UINTBIG us_initialtime, us_doubleclicktime;
+static UINTBIG us_initialtime, us_motiondelayafterselection;
 
 void us_finddoibegin(BOOLEAN complement)
 {
 	REGISTER VARIABLE *highvar;
 	REGISTER NODEINST *ni;
 	REGISTER PORTPROTO *pp;
+	REGISTER VARIABLE *var;
 	REGISTER INTBIG len, another;
 	HIGHLIGHT newhigh, oldhigh;
 	INTBIG i;
@@ -927,7 +928,9 @@ void us_finddoibegin(BOOLEAN complement)
 
 	/* remember initial time of this action */
 	us_initialtime = ticktime();
-	us_doubleclicktime = doubleclicktime() / 2;
+	var = getvalkey((INTBIG)us_tool, VTOOL, VFRACT, us_motiondelaykey);
+	if (var == NOVARIABLE) us_motiondelayafterselection = 30; else
+		us_motiondelayafterselection = var->addr * 30 / WHOLE;
 
 	/* initialize polygon */
 	(void)needstaticpolygon(&us_dragpoly, 4, us_tool->cluster);
@@ -941,7 +944,7 @@ void us_finddoibegin(BOOLEAN complement)
 	if (getxy(&xcur, &ycur)) return;
 	us_dragx = xcur;   us_dragy = ycur;
 	us_dragox = us_dragx;   us_dragoy = us_dragy;
-	us_dragnodeproto = getcurfacet();
+	us_dragnodeproto = getcurcell();
 
 	/* see what is highlighted */
 	highvar = getvalkey((INTBIG)us_tool, VTOOL, VSTRING|VISARRAY, us_highlightedkey);
@@ -1056,7 +1059,7 @@ void us_finddoibegin(BOOLEAN complement)
 	for(i=0; i<len; i++)
 	{
 		if (us_makehighlight(((CHAR **)highvar->addr)[i], &oldhigh)) continue;
-		if (oldhigh.facet != newhigh.facet) continue;
+		if (oldhigh.cell != newhigh.cell) continue;
 		if ((oldhigh.status&HIGHTYPE) != (newhigh.status&HIGHTYPE)) continue;
 		if (oldhigh.fromgeom != newhigh.fromgeom) continue;
 		if ((oldhigh.status&HIGHTYPE) == HIGHTEXT)
@@ -1072,7 +1075,7 @@ void us_finddoibegin(BOOLEAN complement)
 	if (!complement)
 	{
 		/* normal find/move */
-		newhigh.facet = getcurfacet();
+		newhigh.cell = getcurcell();
 		if (i >= len || us_dragpoint >= 0)
 		{
 			/* object is not highlighted: select only it and move */
@@ -1090,7 +1093,7 @@ void us_finddoibegin(BOOLEAN complement)
 		if (i >= len)
 		{
 			/* object not highlighted: add it and move */
-			newhigh.facet = getcurfacet();
+			newhigh.cell = getcurcell();
 			us_setfind(&newhigh, 0, (us_dragextra != 0 ? HIGHEXTRA : 0), 1, us_dragnobox);
 		} else
 		{
@@ -1123,7 +1126,7 @@ void us_finddoibegin(BOOLEAN complement)
 	if (us_dragobjectlist[0] == NOGEOM && us_dragtextcount == 0) return;
 	us_cantdrag = 0;
 
-	/* stop if from different facets */
+	/* stop if from different cells */
 	for(i=0; us_dragobjectlist[i] != NOGEOM; i++)
 		if (us_dragnodeproto != geomparent(us_dragobjectlist[i])) return;
 
@@ -1168,7 +1171,7 @@ BOOLEAN us_findidown(INTBIG x, INTBIG y)
 			/* pan the screen if the edge was hit */
 			us_panatscreenedge(&x, &y);
 			now = eventtime();
-			if (now < us_initialtime + us_doubleclicktime) ret = 0; else
+			if (now < us_initialtime + us_motiondelayafterselection) ret = 0; else
 				ret = us_multidragdown(x, y);
 			break;
 		case 1:
@@ -1197,7 +1200,7 @@ void us_findiup(void)
 	{
 		us_multidragup();
 		now = ticktime();
-		if (now >= us_initialtime + us_doubleclicktime &&
+		if (now >= us_initialtime + us_motiondelayafterselection &&
 			us_cantdrag == 0 && el_pleasestop == 0)
 		{
 			if (getxy(&xcur, &ycur)) return;
@@ -1279,7 +1282,7 @@ void us_findiup(void)
 			for(k=0; k<len; k++)
 			{
 				if (us_makehighlight(((CHAR **)highvar->addr)[k], &oldhigh)) continue;
-				if (oldhigh.facet != newhigh.facet) continue;
+				if (oldhigh.cell != newhigh.cell) continue;
 				if ((oldhigh.status&HIGHTYPE) != (newhigh.status&HIGHTYPE)) continue;
 				if ((oldhigh.status&HIGHTYPE) == HIGHFROM)
 				{
@@ -1519,8 +1522,8 @@ void us_createbegin(void)
 		us_dragangle/3600, &cx, &cy, centeredprimitives);
 
 	/* adjust size if technologies differ */
-	us_adjustfornodeinfacet(us_dragnodeproto, el_curwindowpart->curnodeproto, &cx, &cy);
-	us_adjustfornodeinfacet(us_dragnodeproto, el_curwindowpart->curnodeproto, &pxs, &pys);
+	us_adjustfornodeincell(us_dragnodeproto, el_curwindowpart->curnodeproto, &cx, &cy);
+	us_adjustfornodeincell(us_dragnodeproto, el_curwindowpart->curnodeproto, &pxs, &pys);
 	ni->lowx = xcur;   ni->highx = xcur + pxs;
 	ni->lowy = ycur;   ni->highy = ycur + pys;
 	makerot(ni, trans);
@@ -1573,8 +1576,8 @@ void us_createabegin(void)
 	corneroffset(NONODEINST, us_dragnodeproto, 0, 0, &cx, &cy, centeredprimitives);
 
 	/* adjust size if technologies differ */
-	us_adjustfornodeinfacet(us_dragnodeproto, us_dragwindow->curnodeproto, &cx, &cy);
-	us_adjustfornodeinfacet(us_dragnodeproto, us_dragwindow->curnodeproto, &pxs, &pys);
+	us_adjustfornodeincell(us_dragnodeproto, us_dragwindow->curnodeproto, &cx, &cy);
+	us_adjustfornodeincell(us_dragnodeproto, us_dragwindow->curnodeproto, &pxs, &pys);
 
 	ni->lowx = xcur;   ni->highx = xcur + pxs;
 	ni->lowy = ycur;   ni->highy = ycur + pys;
@@ -1634,11 +1637,10 @@ BOOLEAN us_createadown(INTBIG x, INTBIG y)
 	if (us_dragjoinfactor)
 	{
 		defaultnodesize(us_dragnodeproto, &pxs, &pys);
+		us_adjustfornodeincell(us_dragnodeproto, us_dragwindow->curnodeproto, &pxs, &pys);
 		alignment = muldiv(us_alignment_ratio, el_curlib->lambda[el_curtech->techindex], WHOLE);
 		foundgeom = us_getclosest(us_lastcurx-us_dragoffx+pxs/2, us_lastcury-us_dragoffy+pys/2,
 			alignment/2, us_dragwindow->curnodeproto);
-if (foundgeom != NOGEOM)
-	dist = 7;
 
 		/* determine closest port if a node was found */
 		if (foundgeom != NOGEOM && foundgeom->entryisnode)
@@ -2409,14 +2411,14 @@ BOOLEAN us_hthumbdown(INTBIG x, INTBIG y)
 void us_hthumbtrackingcallback(INTBIG delta)
 {
 	REGISTER NODEPROTO *np;
-	REGISTER INTBIG facetsizex, screensizex, thumbareax, dsx;
+	REGISTER INTBIG cellsizex, screensizex, thumbareax, dsx;
 
 	np = us_dragwindow->curnodeproto;
 	if (np == NONODEPROTO) return;
-	facetsizex = np->highx - np->lowx;
+	cellsizex = np->highx - np->lowx;
 	screensizex = us_dragwindow->screenhx - us_dragwindow->screenlx;
 	thumbareax = (us_dragwindow->usehx - us_dragwindow->uselx - DISPLAYSLIDERSIZE*2-4) / 2;
-	if (facetsizex <= screensizex)
+	if (cellsizex <= screensizex)
 	{
 		dsx = delta * (us_dragwindow->screenhx-us_dragwindow->screenlx) / thumbareax;
 	} else
@@ -2536,15 +2538,15 @@ BOOLEAN us_vthumbdown(INTBIG x, INTBIG y)
 void us_vthumbtrackingcallback(INTBIG delta)
 {
 	REGISTER NODEPROTO *np;
-	REGISTER INTBIG facetsizey, screensizey, thumbareay, dsy;
+	REGISTER INTBIG cellsizey, screensizey, thumbareay, dsy;
 
 	/* adjust the screen */
 	np = us_dragwindow->curnodeproto;
 	if (np == NONODEPROTO) return;
-	facetsizey = np->highy - np->lowy;
+	cellsizey = np->highy - np->lowy;
 	screensizey = us_dragwindow->screenhy - us_dragwindow->screenly;
 	thumbareay = (us_dragwindow->usehy - us_dragwindow->usely - DISPLAYSLIDERSIZE*2-4) / 2;
-	if (facetsizey <= screensizey)
+	if (cellsizey <= screensizey)
 	{
 		dsy = delta * (us_dragwindow->screenhy-us_dragwindow->screenly) / thumbareay;
 	} else
@@ -2911,8 +2913,8 @@ void us_wanttoinvert(INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, WINDOWPART *w)
 {
 	if ((w->state&INPLACEEDIT) != 0)
 	{
-		xform(fx, fy, &fx, &fy, w->outoffacet);
-		xform(tx, ty, &tx, &ty, w->outoffacet);
+		xform(fx, fy, &fx, &fy, w->outofcell);
+		xform(tx, ty, &tx, &ty, w->outofcell);
 	}
 	fx = applyxscale(w, fx-w->screenlx) + w->uselx;
 	fy = applyyscale(w, fy-w->screenly) + w->usely;
