@@ -107,7 +107,7 @@ static void    us_3drotatepointaboutaxis(float *p, float theta, float *r, float
 #define ZUP(x)       ((x) << ZSHIFT)
 #define ZDN(x)       (((x) + 1) >> ZSHIFT)
 
-#define CROSSSIZE      2				/* size in pixels of half a cross */
+#define CROSSSIZE      3				/* size in pixels of half a cross */
 #define BIGCROSSSIZE   5				/* size in pixels of half a big cross */
 
 extern GRAPHICS us_ebox;
@@ -117,7 +117,6 @@ static INTBIG us_showin(WINDOWPART*, GEOM*, NODEPROTO*, XARRAY, INTBIG, INTBIG);
 static void us_queuevicinity(WINDOWPART*, GEOM*, NODEPROTO*, XARRAY, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 static void us_wanttodrawo(INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG, WINDOWPART*, GRAPHICS*, INTBIG);
 static void us_drawextendedpolyline(POLYGON*, WINDOWPART*);
-static void us_reverse(POLYGON*);
 
 /*
  * Routine to free all memory associated with this module.
@@ -152,7 +151,7 @@ void us_freewindowmemory(void)
 
 /******************** WINDOW DISPLAY ********************/
 
-/* routine to erase the facet in window "w" */
+/* routine to erase the cell in window "w" */
 void us_clearwindow(WINDOWPART *w)
 {
 	REGISTER INTBIG newstate;
@@ -179,21 +178,21 @@ void us_erasewindow(WINDOWPART *w)
 
 	maketruerectpoly(w->screenlx, w->screenhx, w->screenly, w->screenhy, poly);
 	if ((w->state&INPLACEEDIT) != 0)
-		xformpoly(poly, w->intofacet);
+		xformpoly(poly, w->intocell);
 	poly->desc = &us_ebox;
 	poly->style = FILLEDRECT;
 	(*us_displayroutine)(poly, w);
 }
 
 /*
- * routine to begin editing facet "cur" in the current window.  The screen
- * extents of the facet are "lx", "hx", "ly", and "hy".  If "focusinst"
- * is not NONODEINST, then highlight that node and port "facetinstport"
+ * routine to begin editing cell "cur" in the current window.  The screen
+ * extents of the cell are "lx", "hx", "ly", and "hy".  If "focusinst"
+ * is not NONODEINST, then highlight that node and port "cellinstport"
  * (if it is not NOPORTPROTO) in the new window.  If "newframe" is true,
- * create a window for this facet, otherwise reuse the current one.
+ * create a window for this cell, otherwise reuse the current one.
  */
-void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
-	NODEINST *focusinst, PORTPROTO *facetinstport, BOOLEAN newframe, BOOLEAN pushpop, BOOLEAN exact)
+void us_switchtocell(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy,
+	NODEINST *focusinst, PORTPROTO *cellinstport, BOOLEAN newframe, BOOLEAN pushpop, BOOLEAN exact)
 {
 	HIGHLIGHT newhigh;
 	REGISTER INTBIG i, l, resethandlers, oldmode;
@@ -230,7 +229,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 
 	if (newframe)
 	{
-		/* just create a new window for this facet */
+		/* just create a new window for this cell */
 		neww = us_wantnewwindow(0);
 		if (neww == NOWINDOWPART)
 		{
@@ -259,11 +258,11 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 			return;
 
 		/* get the text that belongs here */
-		var = getvalkey((INTBIG)cur, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
+		var = getvalkey((INTBIG)cur, VNODEPROTO, VSTRING|VISARRAY, el_cell_message_key);
 		if (var == NOVARIABLE)
 		{
 			one[0] = x_("");
-			var = setvalkey((INTBIG)cur, VNODEPROTO, el_facet_message_key, (INTBIG)one,
+			var = setvalkey((INTBIG)cur, VNODEPROTO, el_cell_message_key, (INTBIG)one,
 				VSTRING|VISARRAY|(1<<VLENGTHSH));
 			if (var == NOVARIABLE) return;
 		}
@@ -287,7 +286,7 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 
 		/* setup for editing */
 		neww->curnodeproto = cur;
-		neww->changehandler = us_textfacetchanges;
+		neww->changehandler = us_textcellchanges;
 	} else
 	{
 		neww->curnodeproto = cur;
@@ -305,8 +304,8 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 			}
 		}
 
-		/* if editing a technology-edit facet, indicate so */
-		if ((cur->userbits&TECEDITFACET) != 0)
+		/* if editing a technology-edit cell, indicate so */
+		if ((cur->userbits&TECEDITCELL) != 0)
 		{
 			us_setwindowmode(neww, neww->state, neww->state | WINDOWTECEDMODE);
 		}
@@ -361,9 +360,9 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 		if (focusinst != NONODEINST)
 		{
 			newhigh.status = HIGHFROM;
-			newhigh.facet = focusinst->parent;
+			newhigh.cell = focusinst->parent;
 			newhigh.fromgeom = focusinst->geom;
-			newhigh.fromport = facetinstport;
+			newhigh.fromport = cellinstport;
 			newhigh.frompoint = 0;
 			newhigh.fromvar = NOVARIABLE;
 			newhigh.fromvarnoeval = NOVARIABLE;
@@ -375,8 +374,8 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 	endobjectchange((INTBIG)us_tool, VTOOL);
 	(void)setvalkey((INTBIG)us_tool, VTOOL, us_current_window_key, (INTBIG)neww,
 		VWINDOWPART|VDONTSAVE);
-	us_setfacetname(neww);
-	us_setfacetsize(neww);
+	us_setcellname(neww);
+	us_setcellsize(neww);
 	us_setgridsize(neww);
 	if (neww->redisphandler != 0) (*neww->redisphandler)(neww);
 	if ((neww->state&WINDOWTECEDMODE) != 0 && (oldmode&WINDOWTECEDMODE) == 0)
@@ -399,10 +398,10 @@ void us_switchtofacet(NODEPROTO *cur, INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy
 
 /*
  * Routine to switch technologies.  If "forcedtechnology" is nonzero, switch to that
- * technology, otherwise determine technology from facet "facet".  If "always" is false,
+ * technology, otherwise determine technology from cell "cell".  If "always" is false,
  * only switch if the user has selected "auto-switching".
  */
-void us_ensurepropertechnology(NODEPROTO *facet, CHAR *forcedtechnology, BOOLEAN always)
+void us_ensurepropertechnology(NODEPROTO *cell, CHAR *forcedtechnology, BOOLEAN always)
 {
 	REGISTER USERCOM *uc;
 	REGISTER TECHNOLOGY *tech;
@@ -412,10 +411,10 @@ void us_ensurepropertechnology(NODEPROTO *facet, CHAR *forcedtechnology, BOOLEAN
 	/* if not auto-switching technologies, quit */
 	if ((us_useroptions&AUTOSWITCHTECHNOLOGY) == 0) return;
 
-	/* see if facet has a technology */
-	if (facet == NONODEPROTO) return;
-	if ((facet->cellview->viewstate&TEXTVIEW) != 0) return;
-	tech = facet->tech;
+	/* see if cell has a technology */
+	if (cell == NONODEPROTO) return;
+	if ((cell->cellview->viewstate&TEXTVIEW) != 0) return;
+	tech = cell->tech;
 	if (tech == gen_tech) return;
 	if ((tech->userbits&NOPRIMTECHNOLOGY) != 0) return;
 
@@ -423,7 +422,7 @@ void us_ensurepropertechnology(NODEPROTO *facet, CHAR *forcedtechnology, BOOLEAN
 	lastframe = getwindowframe(TRUE);
 	if (us_getmacro(x_("pmtesetup")) == NOVARIABLE) return;
 	infstr = initinfstr();
-	formatinfstr(infstr, x_("pmtesetup \"%s\""), us_techname(facet));
+	formatinfstr(infstr, x_("pmtesetup \"%s\""), us_techname(cell));
 	uc = us_makecommand(returninfstr(infstr));
 	if (uc != NOUSERCOM)
 	{
@@ -631,7 +630,7 @@ void us_endchanges(WINDOWPART *which)
 
 		if (which != NOWINDOWPART)
 		{
-			us_writeprotoname(pp, LAYERA, rottrans, LAYERO, el_colfacettxt, which, 0, 0, 0, 0,
+			us_writeprotoname(pp, LAYERA, rottrans, LAYERO, el_colcelltxt, which, 0, 0, 0, 0,
 				(us_useroptions&EXPORTLABELS)>>EXPORTLABELSSH);
 			us_drawportprotovariables(pp, LAYERA, rottrans, which, FALSE);
 		} else
@@ -641,7 +640,7 @@ void us_endchanges(WINDOWPART *which)
 				if ((w->state&WINDOWTYPE) != DISPWINDOW &&
 					(w->state&WINDOWTYPE) != DISP3DWINDOW) continue;
 				if (w->curnodeproto != pp->parent) continue;
-				us_writeprotoname(pp, LAYERA, rottrans, LAYERO, el_colfacettxt, w, 0, 0, 0, 0,
+				us_writeprotoname(pp, LAYERA, rottrans, LAYERO, el_colcelltxt, w, 0, 0, 0, 0,
 					(us_useroptions&EXPORTLABELS)>>EXPORTLABELSSH);
 				us_drawportprotovariables(pp, LAYERA, rottrans, w, FALSE);
 			}
@@ -667,7 +666,7 @@ INTBIG us_showin(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY trans, IN
 	REGISTER INTBIG moretodo, res;
 	REGISTER INTBIG objlocal;
 
-	/* if the parent is the current facet in the window, draw the instance */
+	/* if the parent is the current cell in the window, draw the instance */
 	moretodo = 0;
 	oldwin = setvariablewindow(w);
 	if (parnt == w->curnodeproto)
@@ -711,7 +710,7 @@ INTBIG us_showin(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY trans, IN
 		return(moretodo);
 	}
 
-	/* look at all instances of the parent facet that are expanded */
+	/* look at all instances of the parent cell that are expanded */
 	if (object->entryisnode)
 		objlocal = object->entryaddr.ni->userbits & RELOCLN; else
 			objlocal = object->entryaddr.ai->userbits & RELOCLA;
@@ -801,8 +800,8 @@ void us_unqueueredraw(LIBRARY *lib)
 	for(r = us_firstredraw; r != NOREDRAW; r = nextr)
 	{
 		nextr = r->nextredraw;
-		if (r->entryisnode) rlib = r->entryaddr.ni->parent->cell->lib; else
-			rlib = r->entryaddr.ai->parent->cell->lib;
+		if (r->entryisnode) rlib = r->entryaddr.ni->parent->lib; else
+			rlib = r->entryaddr.ai->parent->lib;
 		if (rlib == lib)
 		{
 			if (lastr == NOREDRAW) us_firstredraw = nextr; else
@@ -978,10 +977,10 @@ void us_freeredraw(REDRAW *r)
 }
 
 /*
- * routine to queue for local re-draw anything in facet "parnt" that is
+ * routine to queue for local re-draw anything in cell "parnt" that is
  * in the vicinity of "object" with bounding box (lx-hx, ly-hy).  The objects
  * are to be drawn on if "on" is nonzero.  The transformation matrix
- * between the bounding box and the facet is in "trans".
+ * between the bounding box and the cell is in "trans".
  */
 void us_queuevicinity(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY trans, INTBIG lx,
 	INTBIG hx, INTBIG ly, INTBIG hy, INTBIG on)
@@ -1024,7 +1023,7 @@ void us_queuevicinity(WINDOWPART *w, GEOM *object, NODEPROTO *parnt, XARRAY tran
 	if (by < w->screenly) by = w->screenly;
 	if (uy > w->screenhy) uy = w->screenhy;
 
-	slop = FARTEXTLIMIT * lambdaoffacet(parnt);
+	slop = FARTEXTLIMIT * lambdaofcell(parnt);
 	search = initsearch(bx-slop, ux+slop, by-slop, uy+slop, parnt);
 	if (object == NOGEOM) local = TRUE; else local = FALSE;
 	for(;;)
@@ -1101,7 +1100,7 @@ void us_showpoly(POLYGON *obj, WINDOWPART *w)
 	}
 
 	/* transform to space of this window */
-	if ((w->state&INPLACEEDIT) != 0) xformpoly(obj, w->outoffacet);
+	if ((w->state&INPLACEEDIT) != 0) xformpoly(obj, w->outofcell);
 
 	/* now draw the polygon */
 	gra = obj->desc;
@@ -1146,7 +1145,7 @@ void us_showpoly(POLYGON *obj, WINDOWPART *w)
 			if (objc->count > 2)
 			{
 				/* always clockwise */
-				if (areapoly(objc) < 0.0) us_reverse(objc);
+				if (areapoly(objc) < 0.0) reversepoly(objc);
 				screendrawpolygon(w, objc->xv, objc->yv, objc->count, objc->desc);
 
 				/* for patterned and outlined polygons, draw the outline too */
@@ -1376,7 +1375,7 @@ void us_showpoly(POLYGON *obj, WINDOWPART *w)
 	}
 
 	/* transform from space of this window */
-	if ((w->state&INPLACEEDIT) != 0) xformpoly(obj, w->intofacet);
+	if ((w->state&INPLACEEDIT) != 0) xformpoly(obj, w->intocell);
 }
 
 /*
@@ -1627,25 +1626,6 @@ BOOLEAN us_makescreen(INTBIG *lx, INTBIG *ly, INTBIG *ux, INTBIG *uy, WINDOWPART
 	return(FALSE);
 }
 
-/*
- * reverse the edge order of a polygon
- */
-void us_reverse(POLYGON *poly)
-{
-	REGISTER INTBIG i, invi;
-	REGISTER INTBIG mx, my;
-
-	for (i = 0, invi = poly->count-1; i<invi; i++, invi--)
-	{
-		mx = poly->xv[invi];
-		my = poly->yv[invi];
-		poly->xv[invi] = poly->xv[i];
-		poly->yv[invi] = poly->yv[i];
-		poly->xv[i] = mx;
-		poly->yv[i] = my;
-	}
-}
-
 /******************** 3D DISPLAY ********************/
 
 /*
@@ -2186,7 +2166,7 @@ void us_3dshowpoly(POLYGON *poly, WINDOWPART *w)
 	if (poly->desc->col == 0) return;
 
 	/* special case when drawing instance boundaries */
-	if (poly->desc->col == el_colfacet)
+	if (poly->desc->col == el_colcell)
 	{
 		(void)get3dfactors(el_curtech, 0, &depth, &thickness);
 		topdepth = depth;
