@@ -200,7 +200,7 @@ static LIBRARY    *vhdl_lib;				/* behavioral library */
 static FILE       *vhdl_fp;					/* current file */
 static VARIABLE   *vhdl_var;				/* current variable */
 static INTBIG      vhdl_linecount;			/* current line number */
-static NODEPROTO  *vhdl_facet;				/* current output facet */
+static NODEPROTO  *vhdl_cell;				/* current output cell */
 extern INTBIG      vhdl_errorcount;
 extern SYMBOLLIST *vhdl_gsymbols;
        TOOL       *vhdl_tool;
@@ -214,12 +214,12 @@ static void      vhdl_addrealports(void *infstr, NODEINST *ni, INTBIG special);
 static void      vhdl_addstring(void*, CHAR*, NODEPROTO*);
 static void      vhdl_addtheseports(void*, NODEINST*, NODEPROTO*, UINTBIG, CHAR*);
 static BOOLEAN   vhdl_compile(NODEPROTO*);
-static void      vhdl_convertfacet(NODEPROTO*, BOOLEAN);
+static void      vhdl_convertcell(NODEPROTO*, BOOLEAN);
 static INTBIG    vhdl_endinput(void);
 static INTBIG    vhdl_endoutput(void);
 static void      vhdl_freescannermemory(void);
 static BOOLEAN   vhdl_generatevhdl(NODEPROTO *np);
-static time_t    vhdl_getfacetdate(NODEPROTO *np);
+static time_t    vhdl_getcelldate(NODEPROTO *np);
 static INTBIG    vhdl_getnextline(CHAR*);
 static INTBIG    vhdl_identfirsthash(CHAR*);
 static INTBIG    vhdl_identsecondhash(CHAR*, INTBIG);
@@ -284,25 +284,25 @@ void vhdl_set(INTBIG count, CHAR *par[])
 			np = getnodeproto(par[1]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("No facet named %s"), par[1]);
+				ttyputerr(_("No cell named %s"), par[1]);
 				return;
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr(M_("Can only convert facets to VHDL, not primitives"));
+				ttyputerr(M_("Can only convert cells to VHDL, not primitives"));
 				return;
 			}
 		} else
 		{
-			np = getcurfacet();
+			np = getcurcell();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr(_("No current facet"));
+				ttyputerr(_("No current cell"));
 				return;
 			}
 		}
 		begintraversehierarchy();
-		vhdl_convertfacet(np, TRUE);
+		vhdl_convertcell(np, TRUE);
 		endtraversehierarchy();
 
 		return;
@@ -310,7 +310,7 @@ void vhdl_set(INTBIG count, CHAR *par[])
 
 	if (namesamen(pp, x_("compile-now"), l) == 0)
 	{
-		np = getcurfacet();
+		np = getcurcell();
 		if (np == NONODEPROTO)
 		{
 			ttyputerr(_("Must be editing a cell"));
@@ -389,13 +389,13 @@ void vhdl_set(INTBIG count, CHAR *par[])
 		if (namesamen(pp, x_("vhdl-on-disk"), l) == 0)
 		{
 			setvalkey((INTBIG)vhdl_tool, VTOOL, vhdl_vhdlondiskkey, 0, VINTEGER);
-			ttyputverbose(M_("VHDL will be kept in facets"));
+			ttyputverbose(M_("VHDL will be kept in cells"));
 			return;
 		}
 		if (namesamen(pp, x_("netlist-on-disk"), l) == 0)
 		{
 			setvalkey((INTBIG)vhdl_tool, VTOOL, vhdl_netlistondiskkey, 0, VINTEGER);
-			ttyputverbose(M_("Netlists will be kept in facets"));
+			ttyputverbose(M_("Netlists will be kept in cells"));
 			return;
 		}
 		ttyputbadusage(x_("telltool vhdl-compiler not"));
@@ -451,7 +451,7 @@ void vhdl_slice(void)
 {
 	REGISTER NODEPROTO *np;
 
-	np = getcurfacet();
+	np = getcurcell();
 	if (np == NONODEPROTO)
 	{
 		ttyputerr(_("Must be editing a cell"));
@@ -467,16 +467,16 @@ void vhdl_slice(void)
 
 /*
  * make requests of the VHDL tool:
- *  "begin-vhdl-input" TAKES: facet, string for source  RETURNS: nonzero on error
- *  "begin-netlist-input" TAKES: facet, filetype, string for source
+ *  "begin-vhdl-input" TAKES: cell, string for source  RETURNS: nonzero on error
+ *  "begin-netlist-input" TAKES: cell, filetype, string for source
  *                        RETURNS: nonzero on error
- *  "want-netlist-input" TAKES: facet, filetype
+ *  "want-netlist-input" TAKES: cell, filetype
  *                       RETURNS: nonzero on error
  *  "get-line" TAKES: buffer address  RETURNS: line number, zero on EOF
  *  "end-input"
  *
- *  "begin-vhdl-output" TAKES: facet, string for source  RETURNS: output name (zero on error)
- *  "begin-netlist-output" TAKES: facet  RETURNS: output name (zero on error)
+ *  "begin-vhdl-output" TAKES: cell, string for source  RETURNS: output name (zero on error)
+ *  "begin-netlist-output" TAKES: cell  RETURNS: output name (zero on error)
  *  "put-line" TAKES: buffer address
  *  "end-output"
  */
@@ -500,7 +500,7 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 
 	if (namesame(command, x_("begin-vhdl-input")) == 0)
 	{
-		/* get the arguments (1=facet, 2=source) */
+		/* get the arguments (1=cell, 2=source) */
 		arg1 = va_arg(ap, INTBIG);
 		arg2 = va_arg(ap, INTBIG);
 
@@ -510,7 +510,7 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 
 	if (namesame(command, x_("begin-netlist-input")) == 0)
 	{
-		/* get the arguments (1=facet, 2=filetype, 3=source) */
+		/* get the arguments (1=cell, 2=filetype, 3=source) */
 		arg1 = va_arg(ap, INTBIG);
 		arg2 = va_arg(ap, INTBIG);
 		arg3 = va_arg(ap, INTBIG);
@@ -534,7 +534,7 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 
 	if (namesame(command, x_("want-netlist-input")) == 0)
 	{
-		/* get the arguments (1=facet, 2=filetype) */
+		/* get the arguments (1=cell, 2=filetype) */
 		arg1 = va_arg(ap, INTBIG);
 		arg2 = va_arg(ap, INTBIG);
 
@@ -575,7 +575,7 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 					{
 						if (vhdl_getnextline(buffer) != 0)
 						{
-							desired = x_("-- VHDL automatically generated from facet ");
+							desired = x_("-- VHDL automatically generated from cell ");
 							len = estrlen(desired);
 							if (estrncmp(buffer, desired, len) == 0)
 							{
@@ -586,11 +586,11 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 				}
 				vhdl_endinput();
 
-				/* if original is not VHDL, check all facets for recency */
+				/* if original is not VHDL, check all cells for recency */
 				if (orignp->cellview != el_vhdlview && i == 0)
 				{
 					/* check all in cell for recency */
-					for(np = orignp->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
+					FOR_CELLGROUP(np, orignp)
 						if (netlistdate < np->revisiondate)
 					{
 						i = 1;
@@ -614,7 +614,7 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 			{
 				if (vhdl_getnextline(buffer) != 0)
 				{
-					desired = x_("-- VHDL automatically generated from facet ");
+					desired = x_("-- VHDL automatically generated from cell ");
 					len = estrlen(desired);
 					if (estrncmp(buffer, desired, len) == 0)
 					{
@@ -629,7 +629,7 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 				if (orignp->cellview != el_vhdlview)
 				{
 					/* check all in cell for recency */
-					for(np = orignp->cell->firstincell; np != NONODEPROTO; np = np->nextincell)
+					FOR_CELLGROUP(np, orignp)
 						if (vhdldate < np->revisiondate)
 					{
 						i = 1;
@@ -643,22 +643,22 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 			}
 			if (i != 0)
 			{
-				/* no valid VHDL: convert facet */
+				/* no valid VHDL: convert cell */
 				np = (NODEPROTO *)arg1;
 				begintraversehierarchy();
-				vhdl_convertfacet(np, FALSE);
+				vhdl_convertcell(np, FALSE);
 				endtraversehierarchy();
 			}
 
 			/* compile VHDL to netlist */
-			if (vhdl_compile(getcurfacet())) return(1);
+			if (vhdl_compile(getcurcell())) return(1);
 		}
 		return(0);
 	}
 
 	if (namesame(command, x_("begin-vhdl-output")) == 0)
 	{
-		/* get the arguments (1=facet, 2=source) */
+		/* get the arguments (1=cell, 2=source) */
 		arg1 = va_arg(ap, INTBIG);
 		arg2 = va_arg(ap, INTBIG);
 
@@ -685,8 +685,8 @@ INTBIG vhdl_request(CHAR *command, va_list ap)
 }
 
 /*
- * routine returns false if all facets in the hierarchy below facet "np" are less recent
- * than "dateoffile".  Returns true if any more recent facet is found.
+ * routine returns false if all cells in the hierarchy below cell "np" are less recent
+ * than "dateoffile".  Returns true if any more recent cell is found.
  */
 BOOLEAN vhdl_morerecentcontents(NODEPROTO *np, UINTBIG dateoffile)
 {
@@ -699,7 +699,7 @@ BOOLEAN vhdl_morerecentcontents(NODEPROTO *np, UINTBIG dateoffile)
 		if (subnp->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (subnp->cell == np->cell) continue;
+		if (isiconof(subnp, np)) continue;
 		if (subnp->cellview == el_iconview)
 		{
 			subnp = contentsview(subnp);
@@ -714,9 +714,9 @@ BOOLEAN vhdl_morerecentcontents(NODEPROTO *np, UINTBIG dateoffile)
 /****************************** GENERALIZED VHDL/NET I/O ******************************/
 
 /*
- * Routine to begin input of a file or facet of type "filetype".  If "diskflag" is true,
- * use a disk file whose name is the cell name of facet "np".  If "diskflag" is false, use
- * the facet with the appropriate view of "np".  Returns the name of the input source in
+ * Routine to begin input of a file or cell of type "filetype".  If "diskflag" is true,
+ * use a disk file whose name is the cell name of cell "np".  If "diskflag" is false, use
+ * the cell with the appropriate view of "np".  Returns the name of the input source in
  * "intended" and its last modification date in "revisiondate".  Returns nonzero on error.
  */
 INTBIG vhdl_startinput(NODEPROTO *np, INTBIG filetype, BOOLEAN diskflag, CHAR **intended,
@@ -729,7 +729,7 @@ INTBIG vhdl_startinput(NODEPROTO *np, INTBIG filetype, BOOLEAN diskflag, CHAR **
 
 	if (np == NONODEPROTO || np->primindex != 0)
 	{
-		*intended = x_("NO CURRENT FACET");
+		*intended = x_("NO CURRENT CELL");
 		return(1);
 	}
 
@@ -760,27 +760,27 @@ INTBIG vhdl_startinput(NODEPROTO *np, INTBIG filetype, BOOLEAN diskflag, CHAR **
 		/* attempt to open file */
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, x_("file "));
-		addstringtoinfstr(infstr, np->cell->cellname);
+		addstringtoinfstr(infstr, np->protoname);
 		*intended = returninfstr(infstr);
-		if ((vhdl_fp = xopen(np->cell->cellname, filetype, x_(""), &filename)) == 0) return(1);
+		if ((vhdl_fp = xopen(np->protoname, filetype, x_(""), &filename)) == 0) return(1);
 		*revisiondate = (UINTBIG)filedate(filename);
 	} else
 	{
 		/* find proper view of this cell */
 		if (np->cellview == view) onp = np; else
-			for(onp = np->cell->firstincell; onp != NONODEPROTO; onp = onp->nextincell)
+			FOR_CELLGROUP(onp, np)
 				if (onp->cellview == view) break;
 		if (onp == NONODEPROTO)
 		{
-			*intended = x_("CANNOT FIND FACET VIEW");
+			*intended = x_("CANNOT FIND CELL VIEW");
 			return(1);
 		}
 
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, x_("facet "));
+		addstringtoinfstr(infstr, x_("cell "));
 		addstringtoinfstr(infstr, describenodeproto(onp));
 		*intended = returninfstr(infstr);
-		vhdl_var = getvalkey((INTBIG)onp, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
+		vhdl_var = getvalkey((INTBIG)onp, VNODEPROTO, VSTRING|VISARRAY, el_cell_message_key);
 		if (vhdl_var == NOVARIABLE) return(1);
 		*revisiondate = onp->revisiondate;
 	}
@@ -800,7 +800,7 @@ INTBIG vhdl_endinput(void)
 }
 
 /*
- * Routine to get the next line from the current input file/facet into the buffer
+ * Routine to get the next line from the current input file/cell into the buffer
  * at "addr".  Returns the line number (1-based).  Returns zero on EOF.
  */
 INTBIG vhdl_getnextline(CHAR *addr)
@@ -833,8 +833,8 @@ INTBIG vhdl_getnextline(CHAR *addr)
 
 /*
  * Routine to begin output of a file of type "filetype" (either VHDL or Netlist) that is either
- * to disk ("diskflag" true) or to a facet ("diskflag" false).  If it is to disk,
- * the file name is the cell name of facet "np".  If it is to a facet, that facet is the
+ * to disk ("diskflag" true) or to a cell ("diskflag" false).  If it is to disk,
+ * the file name is the cell name of cell "np".  If it is to a cell, that cell is the
  * appropriate view of "np".  Returns the intended destination in "indended".
  * Returns 1 on error, -1 if aborted.
  */
@@ -866,13 +866,13 @@ INTBIG vhdl_startoutput(NODEPROTO *np, INTBIG filetype, BOOLEAN diskflag, CHAR *
 	} else view = NOVIEW;
 
 	vhdl_fp = 0;
-	vhdl_facet = NONODEPROTO;
+	vhdl_cell = NONODEPROTO;
 	if (diskflag)
 	{
 		/* attempt to open output file */
 		infstr = initinfstr();
 		addstringtoinfstr(infstr, x_("file "));
-		addstringtoinfstr(infstr, np->cell->cellname);
+		addstringtoinfstr(infstr, np->protoname);
 		addstringtoinfstr(infstr, x_("."));
 		addstringtoinfstr(infstr, ext);
 		*intended = returninfstr(infstr);
@@ -888,14 +888,14 @@ INTBIG vhdl_startoutput(NODEPROTO *np, INTBIG filetype, BOOLEAN diskflag, CHAR *
 	{
 		/* make proper view of this cell */
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, x_("facet "));
-		addstringtoinfstr(infstr, np->cell->cellname);
+		addstringtoinfstr(infstr, x_("cell "));
+		addstringtoinfstr(infstr, np->protoname);
 		addstringtoinfstr(infstr, x_("{"));
 		addstringtoinfstr(infstr, view->sviewname);
 		addstringtoinfstr(infstr, x_("}"));
 		*intended = returninfstr(infstr);
-		vhdl_facet = newnodeproto(&(*intended)[6], np->cell->lib);
-		if (vhdl_facet == NONODEPROTO) return(1);
+		vhdl_cell = newnodeproto(&(*intended)[5], np->lib);
+		if (vhdl_cell == NONODEPROTO) return(1);
 		vhdl_stringarray = newstringarray(vhdl_tool->cluster);
 	}
 	return(0);
@@ -908,11 +908,11 @@ INTBIG vhdl_endoutput(void)
 		xclose(vhdl_fp);
 		vhdl_fp = 0;
 	}
-	if (vhdl_facet != NONODEPROTO)
+	if (vhdl_cell != NONODEPROTO)
 	{
-		stringarraytotextfacet(vhdl_stringarray, vhdl_facet, FALSE);
+		stringarraytotextcell(vhdl_stringarray, vhdl_cell, FALSE);
 		killstringarray(vhdl_stringarray);
-		vhdl_facet = NONODEPROTO;
+		vhdl_cell = NONODEPROTO;
 	}
 	return(0);
 }
@@ -965,11 +965,11 @@ void vhdl_print(CHAR *fstring, ...)
 }
 
 /*
- * Routine to determine the revision date of facet "np", including any subfacets.
+ * Routine to determine the revision date of cell "np", including any subcells.
  */
-time_t vhdl_getfacetdate(NODEPROTO *np)
+time_t vhdl_getcelldate(NODEPROTO *np)
 {
-	REGISTER time_t mostrecent, subfacetdate;
+	REGISTER time_t mostrecent, subcelldate;
 	REGISTER NODEINST *ni;
 
 	mostrecent = (time_t)np->revisiondate;
@@ -978,9 +978,9 @@ time_t vhdl_getfacetdate(NODEPROTO *np)
 		if (ni->proto->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (ni->proto->cell == np->cell) continue;
-		subfacetdate = vhdl_getfacetdate(ni->proto);
-		if (subfacetdate > mostrecent) mostrecent = subfacetdate;
+		if (isiconof(ni->proto, np)) continue;
+		subcelldate = vhdl_getcelldate(ni->proto);
+		if (subcelldate > mostrecent) mostrecent = subcelldate;
 	}
 	return(mostrecent);
 }
@@ -988,11 +988,11 @@ time_t vhdl_getfacetdate(NODEPROTO *np)
 /****************************** GENERATION ******************************/
 
 /*
- * Routine to ensure that facet "np" and all subfacets have VHDL on them.
- * If "force" is true, do conversion even if VHDL facet is newer.  Otherwise
+ * Routine to ensure that cell "np" and all subcells have VHDL on them.
+ * If "force" is true, do conversion even if VHDL cell is newer.  Otherwise
  * convert only if necessary.
  */
-void vhdl_convertfacet(NODEPROTO *np, BOOLEAN force)
+void vhdl_convertcell(NODEPROTO *np, BOOLEAN force)
 {
 	REGISTER NODEPROTO *npvhdl, *onp;
 	REGISTER LIBRARY *lib;
@@ -1004,10 +1004,10 @@ void vhdl_convertfacet(NODEPROTO *np, BOOLEAN force)
 	FILE *f;
 	CHAR *intended, *filename, *desired, *firstline;
 
-	/* cannot make VHDL for facet with no ports */
+	/* cannot make VHDL for cell with no ports */
 	if (np->firstportproto == NOPORTPROTO)
 	{
-		ttyputerr(_("Cannot convert facet %s to VHDL: it has no ports"), describenodeproto(np));
+		ttyputerr(_("Cannot convert cell %s to VHDL: it has no ports"), describenodeproto(np));
 		return;
 	}
 
@@ -1017,14 +1017,14 @@ void vhdl_convertfacet(NODEPROTO *np, BOOLEAN force)
 
 	if (!force)
 	{
-		/* determine most recent change to this or any subfacet */
-		dateoflayout = vhdl_getfacetdate(np);
+		/* determine most recent change to this or any subcell */
+		dateoflayout = vhdl_getcelldate(np);
 
 		/* if there is already VHDL that is newer, stop now */
 		if (vhdlondisk)
 		{
 			/* look for the disk file */
-			f = xopen(np->cell->cellname, io_filetypevhdl, x_(""), &filename);
+			f = xopen(np->protoname, io_filetypevhdl, x_(""), &filename);
 			if (f != NULL)
 			{
 				xclose(f);
@@ -1032,16 +1032,16 @@ void vhdl_convertfacet(NODEPROTO *np, BOOLEAN force)
 			}
 		} else
 		{
-			/* look for the facet */
+			/* look for the cell */
 			npvhdl = anyview(np, el_vhdlview);
 			if (npvhdl != NONODEPROTO)
 			{
-				/* examine the VHDL to see if it really came from this facet */
-				var = getvalkey((INTBIG)npvhdl, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
+				/* examine the VHDL to see if it really came from this cell */
+				var = getvalkey((INTBIG)npvhdl, VNODEPROTO, VSTRING|VISARRAY, el_cell_message_key);
 				if (var != NOVARIABLE)
 				{
 					firstline = ((CHAR **)var->addr)[0];
-					desired = x_("-- VHDL automatically generated from facet ");
+					desired = x_("-- VHDL automatically generated from cell ");
 					len = estrlen(desired);
 					if (estrncmp(firstline, desired, len) == 0)
 					{
@@ -1062,7 +1062,7 @@ void vhdl_convertfacet(NODEPROTO *np, BOOLEAN force)
 		if (i > 0) ttyputerr(_("Cannot write %s"), intended);
 		return;
 	}
-	ttyputmsg(_("Converting layout in facet %s, writing VHDL to %s"), describenodeproto(np),
+	ttyputmsg(_("Converting layout in cell %s, writing VHDL to %s"), describenodeproto(np),
 		intended);
 
 	/* recursively generate the VHDL */
@@ -1100,14 +1100,14 @@ BOOLEAN vhdl_generatevhdl(NODEPROTO *np)
 
 	/* indicate the source of this VHDL */
 	infstr = initinfstr();
-	addstringtoinfstr(infstr, x_("-- VHDL automatically generated from facet "));
+	addstringtoinfstr(infstr, x_("-- VHDL automatically generated from cell "));
 	addstringtoinfstr(infstr, describenodeproto(np));
 	vhdl_printoneline(returninfstr(infstr));
 
 	/* build the "entity" line */
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, x_("entity "));
-	vhdl_addstring(infstr, np->cell->cellname, NONODEPROTO);
+	vhdl_addstring(infstr, np->protoname, NONODEPROTO);
 	addstringtoinfstr(infstr, x_(" is port("));
 	vhdl_addportlist(infstr, NONODEINST, np, 0);
 	addstringtoinfstr(infstr, x_(");"));
@@ -1116,16 +1116,16 @@ BOOLEAN vhdl_generatevhdl(NODEPROTO *np)
 	/* add the "end" line */
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, x_("  end "));
-	vhdl_addstring(infstr, np->cell->cellname, NONODEPROTO);
+	vhdl_addstring(infstr, np->protoname, NONODEPROTO);
 	addstringtoinfstr(infstr, x_(";"));
 	vhdl_print(returninfstr(infstr));
 
 	/* now write the "architecture" line */
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, x_("architecture "));
-	vhdl_addstring(infstr, np->cell->cellname, NONODEPROTO);
+	vhdl_addstring(infstr, np->protoname, NONODEPROTO);
 	addstringtoinfstr(infstr, x_("_BODY of "));
-	vhdl_addstring(infstr, np->cell->cellname, NONODEPROTO);
+	vhdl_addstring(infstr, np->protoname, NONODEPROTO);
 	addstringtoinfstr(infstr, x_(" is"));
 	vhdl_print(returninfstr(infstr));
 
@@ -1154,7 +1154,7 @@ BOOLEAN vhdl_generatevhdl(NODEPROTO *np)
 		if (ni->proto->primindex == 0)
 		{
 			/* ignore recursive references (showing icon in contents) */
-			if (ni->proto->cell == np->cell) continue;
+			if (isiconof(ni->proto, np)) continue;
 		}
 		pt = vhdl_primname(ni, &special);
 		if (pt[0] == 0) continue;
@@ -1185,7 +1185,7 @@ BOOLEAN vhdl_generatevhdl(NODEPROTO *np)
 		}
 		if (special == BLOCKXNOR)
 		{
-			i = eatoi(&pt[3]);
+			i = eatoi(&pt[4]);
 			if (i <= MAXINPUTS) gotxnor[i]++; else
 				ttyputerr(x_("Cannot handle %ld-input XNOR, limit is %d"), i, MAXINPUTS);
 			continue;
@@ -1372,7 +1372,7 @@ BOOLEAN vhdl_generatevhdl(NODEPROTO *np)
 		if (ni->proto->primindex == 0)
 		{
 			/* ignore recursive references (showing icon in contents) */
-			if (ni->proto->cell == np->cell) continue;
+			if (isiconof(ni->proto, np)) continue;
 		}
 
 		pt = vhdl_primname(ni, &special);
@@ -1439,19 +1439,19 @@ BOOLEAN vhdl_generatevhdl(NODEPROTO *np)
 	/* write the end of the body */
 	infstr = initinfstr();
 	addstringtoinfstr(infstr, x_("end "));
-	vhdl_addstring(infstr, np->cell->cellname, NONODEPROTO);
+	vhdl_addstring(infstr, np->protoname, NONODEPROTO);
 	addstringtoinfstr(infstr, x_("_BODY;"));
 	vhdl_print(returninfstr(infstr));
 	vhdl_print(x_(""));
 
-	/* finally, generate VHDL for all subfacets */
+	/* finally, generate VHDL for all subcells */
 	np->temp1 = 1;
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		if (ni->proto->primindex != 0) continue;
 
 		/* ignore recursive references (showing icon in contents) */
-		if (ni->proto->cell == np->cell) continue;
+		if (isiconof(ni->proto, np)) continue;
 		if (ni->proto->temp1 != 0) continue;
 		cnp = contentsview(ni->proto);
 		if (cnp == NONODEPROTO) cnp = ni->proto;
@@ -1460,12 +1460,12 @@ BOOLEAN vhdl_generatevhdl(NODEPROTO *np)
 		/* ignore component with no ports */
 		if (cnp->firstportproto == NOPORTPROTO) continue;
 
-		/* if ALS, see if this facet is in the reference library */
+		/* if ALS, see if this cell is in the reference library */
 		if (vhdl_lib != NOLIBRARY && vhdl_target == TARGET_ALS)
 		{
 			for(onp = vhdl_lib->firstnodeproto; onp != NONODEPROTO; onp = onp->nextnodeproto)
 				if (onp->cellview == el_netlistalsview &&
-					namesame(onp->cell->cellname, cnp->cell->cellname) == 0) break;
+					namesame(onp->protoname, cnp->protoname) == 0) break;
 			if (onp != NONODEPROTO) continue;
 		}
 
@@ -1690,9 +1690,9 @@ CHAR *vhdl_primname(NODEINST *ni, INTBIG *special)
 	/* initialize */
 	if (tech_vhdl_names_key == 0) tech_vhdl_names_key = makekey(x_("TECH_vhdl_names"));
 
-	/* facet instances are easy */
+	/* cell instances are easy */
 	*special = BLOCKNORMAL;
-	if (ni->proto->primindex == 0) return(ni->proto->cell->cellname);
+	if (ni->proto->primindex == 0) return(ni->proto->protoname);
 
 	/* get the primitive function */
 	k = nodefunction(ni);
@@ -1883,7 +1883,7 @@ CHAR *vhdl_primname(NODEINST *ni, INTBIG *special)
 				for(ptr = str; *ptr != 0; ptr++) if (*ptr == '/') break;
 				if (*ptr == '/') (void)esnprintf(pt, 30, &ptr[1], inport); else
 					(void)esnprintf(pt, 30, str, inport);
-				*special = BLOCKNOR;
+				*special = BLOCKXNOR;
 				ai->temp1 = 0;
 			} else
 			{
@@ -1933,8 +1933,8 @@ CHAR *vhdl_primname(NODEINST *ni, INTBIG *special)
 
 /*
  * Routine to add the string "orig" to the infinite string.
- * If "environment" is not NONODEPROTO, it is the facet in which this signal is
- * to reside, and if that facet has nodes with this name, the signal must be renamed.
+ * If "environment" is not NONODEPROTO, it is the cell in which this signal is
+ * to reside, and if that cell has nodes with this name, the signal must be renamed.
  */
 void vhdl_addstring(void *infstr, CHAR *orig, NODEPROTO *environment)
 {
@@ -1976,7 +1976,7 @@ void vhdl_addstring(void *infstr, CHAR *orig, NODEPROTO *environment)
 		for(ni = environment->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 		{
 			if (ni->proto->primindex != 0) continue;
-			if (namesame(orig, ni->proto->cell->cellname) == 0) break;
+			if (namesame(orig, ni->proto->protoname) == 0) break;
 		}
 		if (ni != NONODEINST)
 		{
@@ -2136,12 +2136,12 @@ void vhdl_addtheseports(void *infstr, NODEINST *ni, NODEPROTO *np, UINTBIG bits,
 /****************************** COMPILATION ******************************/
 
 /*
- * routine to compile the VHDL in "basefacet" (or wherever the related VHDL
+ * routine to compile the VHDL in "basecell" (or wherever the related VHDL
  * view is).  If "toplevel" is nonzero, this network is the final output, so
- * it MUST be recompiled if any subfacets have changed.  Returns true
+ * it MUST be recompiled if any subcells have changed.  Returns true
  * on error.
  */
-BOOLEAN vhdl_compile(NODEPROTO *basefacet)
+BOOLEAN vhdl_compile(NODEPROTO *basecell)
 {
 	CHAR *intended, *fromintended;
 	INTBIG	i, filetype;
@@ -2168,8 +2168,8 @@ BOOLEAN vhdl_compile(NODEPROTO *basefacet)
 	netlistondisk = FALSE;
 	if (var != NOVARIABLE && var->addr != 0) netlistondisk = TRUE;
 
-	/* see if there is netlist associated with this facet */
-	if (vhdl_startinput(basefacet, filetype, netlistondisk, &intended, &netlistdate) == 0)
+	/* see if there is netlist associated with this cell */
+	if (vhdl_startinput(basecell, filetype, netlistondisk, &intended, &netlistdate) == 0)
 		err = FALSE; else
 			err = TRUE;
 	if (!err)
@@ -2179,11 +2179,11 @@ BOOLEAN vhdl_compile(NODEPROTO *basefacet)
 	}
 
 	/* get VHDL */
-	if (vhdl_startinput(basefacet, io_filetypevhdl, vhdlondisk, &intended, &vhdldate) != 0)
+	if (vhdl_startinput(basecell, io_filetypevhdl, vhdlondisk, &intended, &vhdldate) != 0)
 	{
 		/* issue error if this isn't an icon */
-		if (basefacet->cellview != el_iconview)
-			ttyputerr(_("Cannot find VHDL for %s"), basefacet->cell->cellname);
+		if (basecell->cellview != el_iconview)
+			ttyputerr(_("Cannot find VHDL for %s"), basecell->protoname);
 		return(TRUE);
 	}
 
@@ -2218,7 +2218,7 @@ BOOLEAN vhdl_compile(NODEPROTO *basefacet)
 	}
 
 	/* prepare to create netlist */
-	retval = vhdl_startoutput(basefacet, filetype, netlistondisk, &intended);
+	retval = vhdl_startoutput(basecell, filetype, netlistondisk, &intended);
 	if (retval != 0)
 	{
 		if (retval > 0) ttyputerr(_("Cannot write %s"), intended);
@@ -2230,7 +2230,7 @@ BOOLEAN vhdl_compile(NODEPROTO *basefacet)
 	/* write output */
 	switch (vhdl_target)
 	{
-		case TARGET_ALS:     vhdl_genals(vhdl_lib, basefacet);  break;
+		case TARGET_ALS:     vhdl_genals(vhdl_lib, basecell);  break;
 		case TARGET_NETLISP: vhdl_gennet(vhdl_target);          break;
 		case TARGET_RSIM:    vhdl_gennet(vhdl_target);          break;
 		case TARGET_SILOS:   vhdl_gensilos();                   break;
@@ -3071,8 +3071,8 @@ static DIALOGITEM vhdl_optionsdialogitems[] =
 {
  /*  1 */ {0, {336,244,360,308}, BUTTON, N_("OK")},
  /*  2 */ {0, {300,244,324,308}, BUTTON, N_("Cancel")},
- /*  3 */ {0, {308,4,324,166}, CHECK, N_("VHDL stored in facet")},
- /*  4 */ {0, {332,4,348,179}, CHECK, N_("Netlist stored in facet")},
+ /*  3 */ {0, {308,4,324,166}, CHECK, N_("VHDL stored in cell")},
+ /*  4 */ {0, {332,4,348,179}, CHECK, N_("Netlist stored in cell")},
  /*  5 */ {0, {28,8,224,319}, SCROLL, x_("")},
  /*  6 */ {0, {236,4,252,203}, MESSAGE, N_("VHDL for primitive:")},
  /*  7 */ {0, {260,4,276,203}, MESSAGE, N_("VHDL for negated primitive:")},
@@ -3084,8 +3084,8 @@ static DIALOGITEM vhdl_optionsdialogitems[] =
 static DIALOG vhdl_optionsdialog = {{50,75,419,403}, N_("VHDL Options"), 0, 11, vhdl_optionsdialogitems, 0, 0};
 
 /* special items for the "VHDL Options" dialog: */
-#define DVHO_VHDLINFACET   3		/* VHDL stored in facet (check) */
-#define DVHO_NETINFACET    4		/* Netlist stored in facet (check) */
+#define DVHO_VHDLINCELL    3		/* VHDL stored in cell (check) */
+#define DVHO_NETINCELL     4		/* Netlist stored in cell (check) */
 #define DVHO_PRIMLIST      5		/* List of schematics prims (scroll) */
 #define DVHO_UNNEGATEDNAME 8		/* Unnegated name (edit text) */
 #define DVHO_NEGATEDNAME   9		/* Negated name (edit text) */
@@ -3140,7 +3140,7 @@ void vhdl_optionsdlog(void)
 	for(i=0; i<len; i++)
 	{
 		infstr = initinfstr();
-		addstringtoinfstr(infstr, nplist[i]->primname);
+		addstringtoinfstr(infstr, nplist[i]->protoname);
 		if (*varnames[i] != 0)
 		{
 			addstringtoinfstr(infstr, x_(" ("));
@@ -3151,8 +3151,8 @@ void vhdl_optionsdlog(void)
 	}
 	DiaSelectLine(dia, DVHO_PRIMLIST, 0);
 
-	if (!vhdlondisk) DiaSetControl(dia, DVHO_VHDLINFACET, 1);
-	if (!netlistondisk) DiaSetControl(dia, DVHO_NETINFACET, 1);
+	if (!vhdlondisk) DiaSetControl(dia, DVHO_VHDLINCELL, 1);
+	if (!netlistondisk) DiaSetControl(dia, DVHO_NETINCELL, 1);
 
 	/* loop until done */
 	technameschanged = 0;
@@ -3160,7 +3160,7 @@ void vhdl_optionsdlog(void)
 	{
 		itemHit = DiaNextHit(dia);
 		if (itemHit == OK || itemHit == CANCEL) break;
-		if (itemHit == DVHO_VHDLINFACET || itemHit == DVHO_NETINFACET)
+		if (itemHit == DVHO_VHDLINCELL || itemHit == DVHO_NETINCELL)
 		{
 			DiaSetControl(dia, itemHit, 1 - DiaGetControl(dia, itemHit));
 			continue;
@@ -3199,7 +3199,7 @@ void vhdl_optionsdlog(void)
 			(void)reallocstring(&varnames[i], pt, el_tempcluster);
 
 			infstr = initinfstr();
-			addstringtoinfstr(infstr, nplist[i]->primname);
+			addstringtoinfstr(infstr, nplist[i]->protoname);
 			if (*varnames[i] != 0)
 			{
 				addstringtoinfstr(infstr, x_(" ("));
@@ -3213,10 +3213,10 @@ void vhdl_optionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		if (DiaGetControl(dia, DVHO_VHDLINFACET) != 0) ondisk = FALSE; else ondisk = TRUE;
+		if (DiaGetControl(dia, DVHO_VHDLINCELL) != 0) ondisk = FALSE; else ondisk = TRUE;
 		if (ondisk != vhdlondisk)
 			setval((INTBIG)vhdl_tool, VTOOL, x_("VHDL_vhdl_on_disk"), ondisk, VINTEGER);
-		if (DiaGetControl(dia, DVHO_NETINFACET) != 0) ondisk = FALSE; else ondisk = TRUE;
+		if (DiaGetControl(dia, DVHO_NETINCELL) != 0) ondisk = FALSE; else ondisk = TRUE;
 		if (ondisk != netlistondisk)
 			setval((INTBIG)vhdl_tool, VTOOL, x_("VHDL_netlist_on_disk"), ondisk, VINTEGER);
 		if (technameschanged != 0)
