@@ -209,7 +209,7 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 		{
 			interfacef->flags &= ~ENTITY_WRITTEN;
 		}
-		vhdl_genals_interface(top_interface, basenp->cell->cellname);
+		vhdl_genals_interface(top_interface, basenp->protoname);
 	}
 
 	/* print closing line of output file */
@@ -346,14 +346,14 @@ BOOLEAN vhdl_addnetlist(LIBRARY *lib, CHAR *name)
 	{
 		if (np->cellview != el_netlistalsview) continue;
 		infstr = initinfstr();
-		for(pn = np->cell->cellname; *pn != 0; pn++)
+		for(pn = np->protoname; *pn != 0; pn++)
 			if (isalnum(*pn)) addtoinfstr(infstr, *pn); else
 				addtoinfstr(infstr, '_');
 		key = returninfstr(infstr);
 		if (namesame(name, key) != 0) continue;
 
 		/* add it to the netlist */
-		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message_key);
+		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_cell_message_key);
 		if (var == NOVARIABLE) continue;
 		len = getlength(var);
 		vhdl_print(x_(""));
