@@ -94,7 +94,7 @@ void vhdl_genquisc(void)
 	CHAR *pn, *key;
 	INTBIG total;
 	REGISTER LIBRARY *celllib;
-	REGISTER CELL *cell;
+	REGISTER NODEPROTO *np;
 	DBINTERFACE *top_interface, *interfacef;
 	UNRESLIST *ulist;
 	REGISTER void *infstr;
@@ -133,28 +133,28 @@ void vhdl_genquisc(void)
 	for (ulist = vhdl_unresolved_list; ulist != NULL; ulist = ulist->next)
 	{
 		/* see if this is a reference to a cell in the current library */
-		for(cell = el_curlib->firstcell; cell != NOCELL; cell = cell->nextcell)
+		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		{
 			infstr = initinfstr();
-			for(pn = cell->cellname; *pn != 0; pn++)
+			for(pn = np->protoname; *pn != 0; pn++)
 				if (isalnum(*pn)) addtoinfstr(infstr, *pn); else
 					addtoinfstr(infstr, '_');
 			key = returninfstr(infstr);
 			if (namesame(ulist->interfacef->string, key) == 0) break;
 		}
-		if (cell == NOCELL && celllib != NOLIBRARY)
+		if (np == NONODEPROTO && celllib != NOLIBRARY)
 		{
-			for(cell = celllib->firstcell; cell != NOCELL; cell = cell->nextcell)
+			for(np = celllib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			{
 				infstr = initinfstr();
-				for(pn = cell->cellname; *pn != 0; pn++)
+				for(pn = np->protoname; *pn != 0; pn++)
 					if (isalnum(*pn)) addtoinfstr(infstr, *pn); else
 						addtoinfstr(infstr, '_');
 				key = returninfstr(infstr);
 				if (namesame(ulist->interfacef->string, key) == 0) break;
 			}
 		}
-		if (cell != NOCELL)
+		if (np != NONODEPROTO)
 		{
 			ulist->numref = 0;
 			continue;
